""" Cisco_IOS_XR_l2vpn_oper 

This module contains a collection of YANG definitions
for Cisco IOS\-XR l2vpn package operational data.

This module contains definitions
for the following management objects\:
  l2vpn\-forwarding\: Show L2VPN forwarding
  l2vpnv2\: l2vpnv2
  generic\-interface\-list\-v2\: generic interface list v2

Copyright (c) 2013\-2017 by Cisco Systems, Inc.
All rights reserved.

"""
from collections import OrderedDict

from ydk.types import Entity, EntityPath, Identity, Enum, YType, YLeaf, YLeafList, YList, LeafDataList, Bits, Empty, Decimal64
from ydk.filters import YFilter
from ydk.errors import YError, YModelError
from ydk.errors.error_handler import handle_type_error as _handle_type_error


class EvpnMainInterface(Enum):
    """
    EvpnMainInterface (Enum Class)

    Evpn main interface

    .. data:: evpn_main_interface_ac = 1

    	EVPN main interface type AC

    .. data:: evpn_main_interface_nve = 2

    	EVPN main interface type NVE

    .. data:: evpn_main_interface_ac_vfi = 3

    	EVPN main interface type AC VFI

    .. data:: evpn_main_interface_ac_pw = 4

    	EVPN main interface type AC PW

    """

    evpn_main_interface_ac = Enum.YLeaf(1, "evpn-main-interface-ac")

    evpn_main_interface_nve = Enum.YLeaf(2, "evpn-main-interface-nve")

    evpn_main_interface_ac_vfi = Enum.YLeaf(3, "evpn-main-interface-ac-vfi")

    evpn_main_interface_ac_pw = Enum.YLeaf(4, "evpn-main-interface-ac-pw")


class IccpSmPortState(Enum):
    """
    IccpSmPortState (Enum Class)

    ICCP\-based service multi\-homing port state

    .. data:: unknown = 0

    	Unknown

    .. data:: unconfigured = 1

    	Unconfigured

    .. data:: unsynchronized = 2

    	Unsynchronized

    .. data:: operational = 3

    	Operational

    .. data:: failed = 4

    	Failed

    .. data:: reverting = 5

    	Reverting

    """

    unknown = Enum.YLeaf(0, "unknown")

    unconfigured = Enum.YLeaf(1, "unconfigured")

    unsynchronized = Enum.YLeaf(2, "unsynchronized")

    operational = Enum.YLeaf(3, "operational")

    failed = Enum.YLeaf(4, "failed")

    reverting = Enum.YLeaf(5, "reverting")


class IccpSmState(Enum):
    """
    IccpSmState (Enum Class)

    ICCP\-based service multi\-homing group state

    .. data:: unresolved = 0

    	Unresolved

    .. data:: provisioned = 1

    	Provisioned

    .. data:: connecting = 2

    	Connecting

    .. data:: connected = 3

    	Connected

    .. data:: synchronizing = 4

    	Synchronizing

    .. data:: synchronized = 5

    	Synchronized

    """

    unresolved = Enum.YLeaf(0, "unresolved")

    provisioned = Enum.YLeaf(1, "provisioned")

    connecting = Enum.YLeaf(2, "connecting")

    connected = Enum.YLeaf(3, "connected")

    synchronizing = Enum.YLeaf(4, "synchronizing")

    synchronized = Enum.YLeaf(5, "synchronized")


class IflistRepStatus(Enum):
    """
    IflistRepStatus (Enum Class)

    Interface list replication status

    .. data:: invalid = 0

    	Invalid

    .. data:: pending = 1

    	Pending

    .. data:: done = 2

    	Done

    .. data:: not_supported = 3

    	Not supported

    .. data:: failed = 4

    	Failed

    """

    invalid = Enum.YLeaf(0, "invalid")

    pending = Enum.YLeaf(1, "pending")

    done = Enum.YLeaf(2, "done")

    not_supported = Enum.YLeaf(3, "not-supported")

    failed = Enum.YLeaf(4, "failed")


class L2fibFeature(Enum):
    """
    L2fibFeature (Enum Class)

    L2fib feature

    .. data:: l2fib_feature_dhcp_snooping = 0

    	l2fib feature dhcp snooping

    .. data:: l2fib_feature_igmp_snooping = 1

    	l2fib feature igmp snooping

    .. data:: l2fib_feature_mld_snooping = 2

    	l2fib feature mld snooping

    .. data:: l2fib_feature_max = 3

    	l2fib feature max

    """

    l2fib_feature_dhcp_snooping = Enum.YLeaf(0, "l2fib-feature-dhcp-snooping")

    l2fib_feature_igmp_snooping = Enum.YLeaf(1, "l2fib-feature-igmp-snooping")

    l2fib_feature_mld_snooping = Enum.YLeaf(2, "l2fib-feature-mld-snooping")

    l2fib_feature_max = Enum.YLeaf(3, "l2fib-feature-max")


class L2fibG8032ApsPortStatus(Enum):
    """
    L2fibG8032ApsPortStatus (Enum Class)

    APS port status

    .. data:: l2fib_aps_port_state_unknown = 0

    	APS port state unknown

    .. data:: l2fib_aps_port_state_unbound = 1

    	APS port state unbound

    .. data:: l2fib_aps_port_state_bound = 2

    	APS port state bound

    """

    l2fib_aps_port_state_unknown = Enum.YLeaf(0, "l2fib-aps-port-state-unknown")

    l2fib_aps_port_state_unbound = Enum.YLeaf(1, "l2fib-aps-port-state-unbound")

    l2fib_aps_port_state_bound = Enum.YLeaf(2, "l2fib-aps-port-state-bound")


class L2fibG8032Rpl(Enum):
    """
    L2fibG8032Rpl (Enum Class)

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = Enum.YLeaf(0, "rpl-unknown")

    port0_owner = Enum.YLeaf(1, "port0-owner")

    port0_neighbor = Enum.YLeaf(2, "port0-neighbor")

    port0_next_neighbor = Enum.YLeaf(3, "port0-next-neighbor")

    port1_owner = Enum.YLeaf(4, "port1-owner")

    port1_neighbor = Enum.YLeaf(5, "port1-neighbor")

    port1_next_neighbor = Enum.YLeaf(6, "port1-next-neighbor")


class L2fibGroupState(Enum):
    """
    L2fibGroupState (Enum Class)

    group state

    .. data:: up = 0

    	Group State Up

    .. data:: down = 1

    	Group State Down

    """

    up = Enum.YLeaf(0, "up")

    down = Enum.YLeaf(1, "down")


class L2fibIpAddr(Enum):
    """
    L2fibIpAddr (Enum Class)

    L2fib ip addr

    .. data:: ip_none = 0

    	ip none

    .. data:: v4 = 4

    	v4

    .. data:: v6 = 6

    	v6

    """

    ip_none = Enum.YLeaf(0, "ip-none")

    v4 = Enum.YLeaf(4, "v4")

    v6 = Enum.YLeaf(6, "v6")


class L2fibL2tpSession(Enum):
    """
    L2fibL2tpSession (Enum Class)

    L2TPv2 and L2TPv3 session type

    .. data:: l2tpv3 = 0

    	L2TPv3 session

    .. data:: l2tpv2 = 1

    	L2TPv2 session

    """

    l2tpv3 = Enum.YLeaf(0, "l2tpv3")

    l2tpv2 = Enum.YLeaf(1, "l2tpv2")


class L2fibLoadBal(Enum):
    """
    L2fibLoadBal (Enum Class)

    L2fib load bal

    .. data:: flow_undef = 0

    	Load Balance Flow Undefined

    .. data:: src_dst_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: src_dst_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: vc = 3

    	Load Balance VC based

    """

    flow_undef = Enum.YLeaf(0, "flow-undef")

    src_dst_mac = Enum.YLeaf(1, "src-dst-mac")

    src_dst_ip = Enum.YLeaf(2, "src-dst-ip")

    vc = Enum.YLeaf(3, "vc")


class L2fibMainIfInstanceState(Enum):
    """
    L2fibMainIfInstanceState (Enum Class)

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: multicast_pe2ce_blocked = 8

    	Multicast PE to CE blocked state

    .. data:: multicast_blocked = 9

    	Multicast blocked state

    .. data:: port_state_unknown = 10

    	Port state unknown

    """

    forwarding = Enum.YLeaf(0, "forwarding")

    blocked = Enum.YLeaf(1, "blocked")

    mac_learning = Enum.YLeaf(2, "mac-learning")

    nack = Enum.YLeaf(3, "nack")

    forwarning_not_useful = Enum.YLeaf(4, "forwarning-not-useful")

    blocked_not_useful = Enum.YLeaf(5, "blocked-not-useful")

    mac_learning_not_useful = Enum.YLeaf(6, "mac-learning-not-useful")

    blocked_data_only = Enum.YLeaf(7, "blocked-data-only")

    multicast_pe2ce_blocked = Enum.YLeaf(8, "multicast-pe2ce-blocked")

    multicast_blocked = Enum.YLeaf(9, "multicast-blocked")

    port_state_unknown = Enum.YLeaf(10, "port-state-unknown")


class L2fibPwId(Enum):
    """
    L2fibPwId (Enum Class)

    Pseudowire ID type

    .. data:: default = 0

    	Default value - not set

    .. data:: manual = 1

    	Manual pseudowire ID

    .. data:: vpls = 2

    	VPLS pseudowire ID

    .. data:: vpws = 3

    	VPWS pseudowire ID

    .. data:: vpls_ldp = 4

    	VPLS with LDP signaling pseudowire ID

    .. data:: l2fib_pw_id_type_pwr = 5

    	PW-routing ID

    .. data:: l2fib_pw_id_type_evpn = 6

    	EVPN pseudowire ID

    """

    default = Enum.YLeaf(0, "default")

    manual = Enum.YLeaf(1, "manual")

    vpls = Enum.YLeaf(2, "vpls")

    vpws = Enum.YLeaf(3, "vpws")

    vpls_ldp = Enum.YLeaf(4, "vpls-ldp")

    l2fib_pw_id_type_pwr = Enum.YLeaf(5, "l2fib-pw-id-type-pwr")

    l2fib_pw_id_type_evpn = Enum.YLeaf(6, "l2fib-pw-id-type-evpn")


class L2fibPwRedundancyRole(Enum):
    """
    L2fibPwRedundancyRole (Enum Class)

    Pseudowire redundancy role

    .. data:: primary = 0

    	Primary pseudowire

    .. data:: backup = 1

    	Backup pseudowire

    """

    primary = Enum.YLeaf(0, "primary")

    backup = Enum.YLeaf(1, "backup")


class L2fibStormControlRateUnit(Enum):
    """
    L2fibStormControlRateUnit (Enum Class)

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = Enum.YLeaf(0, "pps")

    kb_ps = Enum.YLeaf(1, "kb-ps")


class L2vpnAcEncap(Enum):
    """
    L2vpnAcEncap (Enum Class)

    L2vpn ac encap

    .. data:: unknown_encap = 0

    	unknown encap

    .. data:: vlan = 1

    	vlan

    .. data:: qinq = 2

    	qinq

    .. data:: qin_any = 3

    	qin any

    .. data:: ethernet = 4

    	ethernet

    .. data:: atm_aal0 = 5

    	atm aal0

    .. data:: atm_aal5 = 6

    	atm aal5

    .. data:: atm_vp = 7

    	atm vp

    .. data:: atm_port = 8

    	atm port

    .. data:: hdlc = 9

    	hdlc

    .. data:: fr_dlci = 10

    	fr dlci

    .. data:: fr_dlci_local = 11

    	fr dlci local

    .. data:: ppp = 12

    	ppp

    .. data:: tdm_sa_to_p_e1 = 13

    	tdm sa to p e1

    .. data:: tdm_sa_to_p_t1 = 14

    	tdm sa to p t1

    .. data:: tdm_sa_to_p_e3 = 15

    	tdm sa to p e3

    .. data:: tdm_sa_to_p_t3 = 16

    	tdm sa to p t3

    .. data:: tdm_ce_so_psn = 17

    	tdm ce so psn

    .. data:: ip = 18

    	ip

    .. data:: vlan_encap = 19

    	vlan encap

    .. data:: dot1ad = 20

    	dot1ad

    .. data:: efp = 21

    	efp

    .. data:: bvi = 22

    	bvi

    .. data:: monitor_session = 23

    	monitor session

    .. data:: pseudowire_ether = 24

    	pseudowire ether

    .. data:: pseudowire_iw = 25

    	pseudowire iw

    .. data:: multi_segment_pseudowire = 26

    	multi segment pseudowire

    .. data:: pseudowire_l2_subinterface = 27

    	pseudowire l2 subinterface

    .. data:: virtual_network_interface = 28

    	virtual network interface

    .. data:: encap_types_max = 29

    	encap types max

    """

    unknown_encap = Enum.YLeaf(0, "unknown-encap")

    vlan = Enum.YLeaf(1, "vlan")

    qinq = Enum.YLeaf(2, "qinq")

    qin_any = Enum.YLeaf(3, "qin-any")

    ethernet = Enum.YLeaf(4, "ethernet")

    atm_aal0 = Enum.YLeaf(5, "atm-aal0")

    atm_aal5 = Enum.YLeaf(6, "atm-aal5")

    atm_vp = Enum.YLeaf(7, "atm-vp")

    atm_port = Enum.YLeaf(8, "atm-port")

    hdlc = Enum.YLeaf(9, "hdlc")

    fr_dlci = Enum.YLeaf(10, "fr-dlci")

    fr_dlci_local = Enum.YLeaf(11, "fr-dlci-local")

    ppp = Enum.YLeaf(12, "ppp")

    tdm_sa_to_p_e1 = Enum.YLeaf(13, "tdm-sa-to-p-e1")

    tdm_sa_to_p_t1 = Enum.YLeaf(14, "tdm-sa-to-p-t1")

    tdm_sa_to_p_e3 = Enum.YLeaf(15, "tdm-sa-to-p-e3")

    tdm_sa_to_p_t3 = Enum.YLeaf(16, "tdm-sa-to-p-t3")

    tdm_ce_so_psn = Enum.YLeaf(17, "tdm-ce-so-psn")

    ip = Enum.YLeaf(18, "ip")

    vlan_encap = Enum.YLeaf(19, "vlan-encap")

    dot1ad = Enum.YLeaf(20, "dot1ad")

    efp = Enum.YLeaf(21, "efp")

    bvi = Enum.YLeaf(22, "bvi")

    monitor_session = Enum.YLeaf(23, "monitor-session")

    pseudowire_ether = Enum.YLeaf(24, "pseudowire-ether")

    pseudowire_iw = Enum.YLeaf(25, "pseudowire-iw")

    multi_segment_pseudowire = Enum.YLeaf(26, "multi-segment-pseudowire")

    pseudowire_l2_subinterface = Enum.YLeaf(27, "pseudowire-l2-subinterface")

    virtual_network_interface = Enum.YLeaf(28, "virtual-network-interface")

    encap_types_max = Enum.YLeaf(29, "encap-types-max")


class L2vpnAdLsdErr(Enum):
    """
    L2vpnAdLsdErr (Enum Class)

    L2vpn ad lsd err

    .. data:: l2vpn_ad_lsd_err_type_none = 0

    	No Error

    .. data:: l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = 1

    	RW Creation aborted due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = 2

    	Lbl Alloc disallowed due to related RW Creation

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = 3

    	Lbl Alloc disallowed due to related Lbl Alloc

    	failure

    .. data:: l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = 4

    	Lbl Ctx mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = 5

    	FPI Size mismatch

    .. data:: l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = 6

    	FPI Version mismatch

    .. data:: l2vpn_ad_lsd_err_type_enospc = 7

    	Out of Label

    .. data:: l2vpn_ad_lsd_err_type_enomem = 8

    	No Memory

    .. data:: l2vpn_ad_lsd_err_type_undefined = 9

    	LABEL ERR

    """

    l2vpn_ad_lsd_err_type_none = Enum.YLeaf(0, "l2vpn-ad-lsd-err-type-none")

    l2vpn_ad_lsd_err_type_rw_create_abort_lbl_alloc = Enum.YLeaf(1, "l2vpn-ad-lsd-err-type-rw-create-abort-lbl-alloc")

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_rw_create = Enum.YLeaf(2, "l2vpn-ad-lsd-err-type-lbl-alloc-abort-rw-create")

    l2vpn_ad_lsd_err_type_lbl_alloc_abort_lbl_alloc = Enum.YLeaf(3, "l2vpn-ad-lsd-err-type-lbl-alloc-abort-lbl-alloc")

    l2vpn_ad_lsd_err_type_lbl_alloc_lbl_ctx_mismatch = Enum.YLeaf(4, "l2vpn-ad-lsd-err-type-lbl-alloc-lbl-ctx-mismatch")

    l2vpn_ad_lsd_err_type_rw_create_fpi_size_mismatch = Enum.YLeaf(5, "l2vpn-ad-lsd-err-type-rw-create-fpi-size-mismatch")

    l2vpn_ad_lsd_err_type_rw_create_fpi_version_mismatch = Enum.YLeaf(6, "l2vpn-ad-lsd-err-type-rw-create-fpi-version-mismatch")

    l2vpn_ad_lsd_err_type_enospc = Enum.YLeaf(7, "l2vpn-ad-lsd-err-type-enospc")

    l2vpn_ad_lsd_err_type_enomem = Enum.YLeaf(8, "l2vpn-ad-lsd-err-type-enomem")

    l2vpn_ad_lsd_err_type_undefined = Enum.YLeaf(9, "l2vpn-ad-lsd-err-type-undefined")


class L2vpnAdRd(Enum):
    """
    L2vpnAdRd (Enum Class)

    L2vpn ad rd

    .. data:: l2vpn_ad_rd_none = 0

    	Route Distinguisher not set

    .. data:: l2vpn_ad_rd_auto = 1

    	Route Distinguisher auto-generated

    .. data:: l2vpn_ad_rd_as = 2

    	Route Distinguisher with 2 Byte AS number

    .. data:: l2vpn_ad_rd_4byte_as = 3

    	Route Distinguisher with 4 Byte AS number

    .. data:: l2vpn_ad_rd_v4_addr = 4

    	Route Distinguisher with IPv4 Address

    """

    l2vpn_ad_rd_none = Enum.YLeaf(0, "l2vpn-ad-rd-none")

    l2vpn_ad_rd_auto = Enum.YLeaf(1, "l2vpn-ad-rd-auto")

    l2vpn_ad_rd_as = Enum.YLeaf(2, "l2vpn-ad-rd-as")

    l2vpn_ad_rd_4byte_as = Enum.YLeaf(3, "l2vpn-ad-rd-4byte-as")

    l2vpn_ad_rd_v4_addr = Enum.YLeaf(4, "l2vpn-ad-rd-v4-addr")


class L2vpnAdRt(Enum):
    """
    L2vpnAdRt (Enum Class)

    L2vpn ad rt

    .. data:: l2vpn_ad_rt_none = 0

    	Route target not set

    .. data:: l2vpn_ad_rt_as = 1

    	Route Target with 2 Byte AS number

    .. data:: l2vpn_ad_rt_4byte_as = 2

    	Route Target with 4 Byte AS number

    .. data:: l2vpn_ad_rt_v4_addr = 3

    	Route Target with IPv4 Address

    .. data:: es_import = 1538

    	Ethernet Segment Route Target from BGP

    """

    l2vpn_ad_rt_none = Enum.YLeaf(0, "l2vpn-ad-rt-none")

    l2vpn_ad_rt_as = Enum.YLeaf(1, "l2vpn-ad-rt-as")

    l2vpn_ad_rt_4byte_as = Enum.YLeaf(2, "l2vpn-ad-rt-4byte-as")

    l2vpn_ad_rt_v4_addr = Enum.YLeaf(3, "l2vpn-ad-rt-v4-addr")

    es_import = Enum.YLeaf(1538, "es-import")


class L2vpnAdSigMethod(Enum):
    """
    L2vpnAdSigMethod (Enum Class)

    L2vpn ad sig method

    .. data:: l2vpn_ad_sig_method_none = 0

    	None

    .. data:: l2vpn_ad_sig_method_bgp = 1

    	BGP

    .. data:: l2vpn_ad_sig_method_ldp = 2

    	LDP

    """

    l2vpn_ad_sig_method_none = Enum.YLeaf(0, "l2vpn-ad-sig-method-none")

    l2vpn_ad_sig_method_bgp = Enum.YLeaf(1, "l2vpn-ad-sig-method-bgp")

    l2vpn_ad_sig_method_ldp = Enum.YLeaf(2, "l2vpn-ad-sig-method-ldp")


class L2vpnAdVplsId(Enum):
    """
    L2vpnAdVplsId (Enum Class)

    L2vpn ad vpls id

    .. data:: l2vpn_ad_vpls_id_none = 0

    	VPLS-ID not set

    .. data:: l2vpn_ad_vpls_id_auto = 1

    	Auto generated VPLS-ID

    .. data:: l2vpn_ad_vpls_id_as = 10

    	VPLS-ID with 2 Byte AS number

    .. data:: l2vpn_ad_vpls_id_v4_addr = 266

    	VPLS-ID with IPv4 Address

    """

    l2vpn_ad_vpls_id_none = Enum.YLeaf(0, "l2vpn-ad-vpls-id-none")

    l2vpn_ad_vpls_id_auto = Enum.YLeaf(1, "l2vpn-ad-vpls-id-auto")

    l2vpn_ad_vpls_id_as = Enum.YLeaf(10, "l2vpn-ad-vpls-id-as")

    l2vpn_ad_vpls_id_v4_addr = Enum.YLeaf(266, "l2vpn-ad-vpls-id-v4-addr")


class L2vpnAtmMode(Enum):
    """
    L2vpnAtmMode (Enum Class)

    L2vpn atm mode

    .. data:: l2vpn_atm_port_mode = 0

    	ATM port mode

    .. data:: l2vpn_atm_vp_mode = 1

    	ATM Virtual Path mode

    .. data:: l2vpn_atm_vc_mode = 2

    	ATM Virtual Channel mode

    """

    l2vpn_atm_port_mode = Enum.YLeaf(0, "l2vpn-atm-port-mode")

    l2vpn_atm_vp_mode = Enum.YLeaf(1, "l2vpn-atm-vp-mode")

    l2vpn_atm_vc_mode = Enum.YLeaf(2, "l2vpn-atm-vc-mode")


class L2vpnBagAdEncap(Enum):
    """
    L2vpnBagAdEncap (Enum Class)

    L2VPN AD Encapsulation

    .. data:: l2vpn_bag_ad_encap_not_specified = 0

    	Not Specified

    .. data:: l2vpn_bag_ad_encap_ether_vlan = 1

    	Ether VLAN

    .. data:: l2vpn_bag_ad_encap_ether = 2

    	Ethernet

    """

    l2vpn_bag_ad_encap_not_specified = Enum.YLeaf(0, "l2vpn-bag-ad-encap-not-specified")

    l2vpn_bag_ad_encap_ether_vlan = Enum.YLeaf(1, "l2vpn-bag-ad-encap-ether-vlan")

    l2vpn_bag_ad_encap_ether = Enum.YLeaf(2, "l2vpn-bag-ad-encap-ether")


class L2vpnBagMacAgingMode(Enum):
    """
    L2vpnBagMacAgingMode (Enum Class)

    L2vpn bag mac aging mode

    .. data:: aging_none = 0

    	MAC Aging None

    .. data:: aging_absolute = 1

    	Mac Aging Absolute

    .. data:: aging_inactivity = 2

    	Mac Aging Inactivity

    """

    aging_none = Enum.YLeaf(0, "aging-none")

    aging_absolute = Enum.YLeaf(1, "aging-absolute")

    aging_inactivity = Enum.YLeaf(2, "aging-inactivity")


class L2vpnBagMacLimitAction(Enum):
    """
    L2vpnBagMacLimitAction (Enum Class)

    L2vpn bag mac limit action

    .. data:: limit_none = 0

    	MAC Limit Action None

    .. data:: limit_flood = 1

    	MAC Limit Action Flood

    .. data:: limit_no_flood = 2

    	MAC Limit Action No Flood

    .. data:: limit_shutdown = 3

    	MAC Limit Action Shut

    .. data:: limit_no_config = 4

    	Mac Limit Action No Config

    """

    limit_none = Enum.YLeaf(0, "limit-none")

    limit_flood = Enum.YLeaf(1, "limit-flood")

    limit_no_flood = Enum.YLeaf(2, "limit-no-flood")

    limit_shutdown = Enum.YLeaf(3, "limit-shutdown")

    limit_no_config = Enum.YLeaf(4, "limit-no-config")


class L2vpnBagMacLimitNotify(Enum):
    """
    L2vpnBagMacLimitNotify (Enum Class)

    L2vpn bag mac limit notify

    .. data:: mac_limit_notify_none = 0

    	MAC Limit Notify None

    .. data:: mac_limit_notify_syslog = 1

    	MAC Limit Notify Syslog

    .. data:: mac_limit_notify_trap = 2

    	MAC Limit Notify Trap

    .. data:: mac_limit_notify_syslog_trap = 3

    	MAC Limit Notify Syslog and Trap

    .. data:: mac_limit_notify_no_config = 4

    	MAC Limit Notify No Config

    """

    mac_limit_notify_none = Enum.YLeaf(0, "mac-limit-notify-none")

    mac_limit_notify_syslog = Enum.YLeaf(1, "mac-limit-notify-syslog")

    mac_limit_notify_trap = Enum.YLeaf(2, "mac-limit-notify-trap")

    mac_limit_notify_syslog_trap = Enum.YLeaf(3, "mac-limit-notify-syslog-trap")

    mac_limit_notify_no_config = Enum.YLeaf(4, "mac-limit-notify-no-config")


class L2vpnBagMacSecureAction(Enum):
    """
    L2vpnBagMacSecureAction (Enum Class)

    L2vpn bag mac secure action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = Enum.YLeaf(0, "not-set")

    restrict = Enum.YLeaf(1, "restrict")

    none = Enum.YLeaf(2, "none")

    shutdown = Enum.YLeaf(3, "shutdown")


class L2vpnBagMacWithdrawOption(Enum):
    """
    L2vpnBagMacWithdrawOption (Enum Class)

    L2vpn bag mac withdraw option

    .. data:: mac_withdraw_option_state_up = 0

    	Mac withdraw on state up

    .. data:: mac_withdraw_option_state_down = 1

    	Mac withdraw on state down

    .. data:: mac_withdraw_option_optimize = 2

    	Optimized Mac withdraw

    """

    mac_withdraw_option_state_up = Enum.YLeaf(0, "mac-withdraw-option-state-up")

    mac_withdraw_option_state_down = Enum.YLeaf(1, "mac-withdraw-option-state-down")

    mac_withdraw_option_optimize = Enum.YLeaf(2, "mac-withdraw-option-optimize")


class L2vpnBagStormControlRateUnit(Enum):
    """
    L2vpnBagStormControlRateUnit (Enum Class)

    Storm Control Rate Unit Type

    .. data:: pps = 0

    	Packets Per Second

    .. data:: kb_ps = 1

    	Kilobits Per Second

    """

    pps = Enum.YLeaf(0, "pps")

    kb_ps = Enum.YLeaf(1, "kb-ps")


class L2vpnBridge(Enum):
    """
    L2vpnBridge (Enum Class)

    L2vpn bridge

    .. data:: l2vpn_bridge_type_default = 0

    	Regular none PBB bridge

    .. data:: l2vpn_bridge_type_pbb_edge = 1

    	PBB edge bridge

    .. data:: l2vpn_bridge_type_pbb_core = 2

    	PBB core bridge

    """

    l2vpn_bridge_type_default = Enum.YLeaf(0, "l2vpn-bridge-type-default")

    l2vpn_bridge_type_pbb_edge = Enum.YLeaf(1, "l2vpn-bridge-type-pbb-edge")

    l2vpn_bridge_type_pbb_core = Enum.YLeaf(2, "l2vpn-bridge-type-pbb-core")


class L2vpnBridgeCoupledState(Enum):
    """
    L2vpnBridgeCoupledState (Enum Class)

    L2vpn bridge coupled state

    .. data:: disabled = 0

    	Coupled mode disabled

    .. data:: down = 2

    	Coupled state down

    .. data:: up = 3

    	Coupled state up

    """

    disabled = Enum.YLeaf(0, "disabled")

    down = Enum.YLeaf(2, "down")

    up = Enum.YLeaf(3, "up")


class L2vpnBridgeState(Enum):
    """
    L2vpnBridgeState (Enum Class)

    L2vpn bridge state

    .. data:: bridge_init = 0

    	Bridge Init State

    .. data:: bridge_up = 1

    	Bridge Up

    .. data:: bridge_down = 2

    	Bridge Down

    .. data:: bridge_admin_down = 3

    	Bridge Admin Down

    """

    bridge_init = Enum.YLeaf(0, "bridge-init")

    bridge_up = Enum.YLeaf(1, "bridge-up")

    bridge_down = Enum.YLeaf(2, "bridge-down")

    bridge_admin_down = Enum.YLeaf(3, "bridge-admin-down")


class L2vpnBriefPsn(Enum):
    """
    L2vpnBriefPsn (Enum Class)

    L2vpn brief psn

    .. data:: ls = 0

    	ls

    .. data:: atom = 1

    	atom

    .. data:: l2tpv3 = 2

    	l2tpv3

    .. data:: unknown_psn = 3

    	unknown psn

    """

    ls = Enum.YLeaf(0, "ls")

    atom = Enum.YLeaf(1, "atom")

    l2tpv3 = Enum.YLeaf(2, "l2tpv3")

    unknown_psn = Enum.YLeaf(3, "unknown-psn")


class L2vpnEncapMethod(Enum):
    """
    L2vpnEncapMethod (Enum Class)

    Encapsulation Method

    .. data:: l2vpn_pw_encaps_not_specified = 0

    	Not Specified

    .. data:: l2vpn_pw_encaps_l2tpv3 = 1

    	L2TPv3 encapsulation

    .. data:: l2vpn_pw_encaps_l2tpv2 = 2

    	L2TPv2 encapsulation

    .. data:: l2vpn_pw_encaps_mpls = 3

    	MPLS encapsulation

    .. data:: l2vpn_pw_encaps_unknown = 4

    	Unknown

    """

    l2vpn_pw_encaps_not_specified = Enum.YLeaf(0, "l2vpn-pw-encaps-not-specified")

    l2vpn_pw_encaps_l2tpv3 = Enum.YLeaf(1, "l2vpn-pw-encaps-l2tpv3")

    l2vpn_pw_encaps_l2tpv2 = Enum.YLeaf(2, "l2vpn-pw-encaps-l2tpv2")

    l2vpn_pw_encaps_mpls = Enum.YLeaf(3, "l2vpn-pw-encaps-mpls")

    l2vpn_pw_encaps_unknown = Enum.YLeaf(4, "l2vpn-pw-encaps-unknown")


class L2vpnFrMode(Enum):
    """
    L2vpnFrMode (Enum Class)

    L2vpn fr mode

    .. data:: l2vpn_fr_port_mode = 0

    	Frame Relay port mode

    .. data:: l2vpn_fr_dlci_mode = 1

    	Frame Relay DLCI mode

    """

    l2vpn_fr_port_mode = Enum.YLeaf(0, "l2vpn-fr-port-mode")

    l2vpn_fr_dlci_mode = Enum.YLeaf(1, "l2vpn-fr-dlci-mode")


class L2vpnG8032Rpl(Enum):
    """
    L2vpnG8032Rpl (Enum Class)

    RPL types in g8032 ring

    .. data:: rpl_unknown = 0

    	No RPL info

    .. data:: port0_owner = 1

    	Port 0 owner

    .. data:: port0_neighbor = 2

    	Port 0 neighbor

    .. data:: port0_next_neighbor = 3

    	Port 0 next neighbor

    .. data:: port1_owner = 4

    	Port 1 owner

    .. data:: port1_neighbor = 5

    	Port 1 neighbor

    .. data:: port1_next_neighbor = 6

    	Port 1 next neighbor

    """

    rpl_unknown = Enum.YLeaf(0, "rpl-unknown")

    port0_owner = Enum.YLeaf(1, "port0-owner")

    port0_neighbor = Enum.YLeaf(2, "port0-neighbor")

    port0_next_neighbor = Enum.YLeaf(3, "port0-next-neighbor")

    port1_owner = Enum.YLeaf(4, "port1-owner")

    port1_neighbor = Enum.YLeaf(5, "port1-neighbor")

    port1_next_neighbor = Enum.YLeaf(6, "port1-next-neighbor")


class L2vpnG8032UncfgReason(Enum):
    """
    L2vpnG8032UncfgReason (Enum Class)

    Unresolved reason for G8032 ring instance

    .. data:: reason_none = 0

    	No reason

    .. data:: ring_mp0_missing = 1

    	Main port0 missing

    .. data:: ring_mp1_missing = 2

    	Main port1 missing

    .. data:: inclusion_list_empty = 3

    	Inclusion list empty

    .. data:: aps0_missing = 4

    	APS port0 missing

    .. data:: aps0bp_notfound = 5

    	APS port0 not found as valid BP

    .. data:: aps0_no_ac_ctx = 6

    	APS port0 has no valid AC context

    .. data:: aps0_not_in_inclusion_list = 7

    	APS port0 not in inclusion list

    .. data:: aps0_mismatched = 8

    	APS port0 mismatched with main port

    .. data:: aps1_missing = 9

    	APS port1 missing

    .. data:: aps1bp_notfound = 10

    	APS port1 not found as valid BP

    .. data:: aps1_no_ac_ctx = 11

    	APS port1 has no valid AC context

    .. data:: aps1_not_in_inclusion_list = 12

    	APS port1 not in inclusion list

    .. data:: aps1_mismatched = 13

    	APS port1 mismatched with main port

    .. data:: aps_unprovisioned = 14

    	APS AC unrpvosioned

    """

    reason_none = Enum.YLeaf(0, "reason-none")

    ring_mp0_missing = Enum.YLeaf(1, "ring-mp0-missing")

    ring_mp1_missing = Enum.YLeaf(2, "ring-mp1-missing")

    inclusion_list_empty = Enum.YLeaf(3, "inclusion-list-empty")

    aps0_missing = Enum.YLeaf(4, "aps0-missing")

    aps0bp_notfound = Enum.YLeaf(5, "aps0bp-notfound")

    aps0_no_ac_ctx = Enum.YLeaf(6, "aps0-no-ac-ctx")

    aps0_not_in_inclusion_list = Enum.YLeaf(7, "aps0-not-in-inclusion-list")

    aps0_mismatched = Enum.YLeaf(8, "aps0-mismatched")

    aps1_missing = Enum.YLeaf(9, "aps1-missing")

    aps1bp_notfound = Enum.YLeaf(10, "aps1bp-notfound")

    aps1_no_ac_ctx = Enum.YLeaf(11, "aps1-no-ac-ctx")

    aps1_not_in_inclusion_list = Enum.YLeaf(12, "aps1-not-in-inclusion-list")

    aps1_mismatched = Enum.YLeaf(13, "aps1-mismatched")

    aps_unprovisioned = Enum.YLeaf(14, "aps-unprovisioned")


class L2vpnIdMgrAppBag(Enum):
    """
    L2vpnIdMgrAppBag (Enum Class)

    L2VPN ID Manager App Type

    .. data:: l2vpn_id_mgr_app_bag_type_virtual_ac = 0

    	Virtual AC

    .. data:: l2vpn_id_mgr_app_bag_type_ac = 1

    	AC

    .. data:: l2vpn_id_mgr_app_bag_type_pw = 2

    	PW

    .. data:: l2vpn_id_mgr_app_bag_type_bd = 3

    	BD

    .. data:: l2vpn_id_mgr_app_bag_type_fxc = 4

    	FXC

    .. data:: l2vpn_id_mgr_app_bag_type_mp2mp = 5

    	MP2MP

    .. data:: l2vpn_id_mgr_app_bag_type_rd = 6

    	RD

    .. data:: l2vpn_id_mgr_app_bag_type_pbb = 7

    	PBB

    .. data:: l2vpn_id_mgr_app_bag_type_if_list = 8

    	IFLIST

    .. data:: l2vpn_id_mgr_app_bag_type_atom = 9

    	ATOM

    .. data:: l2vpn_id_mgr_app_bag_type_global = 10

    	GLOBAL

    .. data:: l2vpn_id_mgr_app_bag_type_pw_group = 11

    	PWGROUP

    .. data:: l2vpn_id_mgr_app_bag_type_evpn = 12

    	EVPN

    .. data:: l2vpn_id_mgr_app_bag_type_evpn_lbl = 13

    	EVPN LBL

    .. data:: l2vpn_id_mgr_app_bag_type_evpn_rd = 14

    	EVPN RD

    .. data:: l2vpn_id_mgr_app_bag_type_ital = 15

    	ITAL

    .. data:: l2vpn_id_mgr_app_bag_type_bp = 16

    	BP

    .. data:: l2vpn_id_mgr_app_bag_type_count = 17

    	Count/Invalid

    """

    l2vpn_id_mgr_app_bag_type_virtual_ac = Enum.YLeaf(0, "l2vpn-id-mgr-app-bag-type-virtual-ac")

    l2vpn_id_mgr_app_bag_type_ac = Enum.YLeaf(1, "l2vpn-id-mgr-app-bag-type-ac")

    l2vpn_id_mgr_app_bag_type_pw = Enum.YLeaf(2, "l2vpn-id-mgr-app-bag-type-pw")

    l2vpn_id_mgr_app_bag_type_bd = Enum.YLeaf(3, "l2vpn-id-mgr-app-bag-type-bd")

    l2vpn_id_mgr_app_bag_type_fxc = Enum.YLeaf(4, "l2vpn-id-mgr-app-bag-type-fxc")

    l2vpn_id_mgr_app_bag_type_mp2mp = Enum.YLeaf(5, "l2vpn-id-mgr-app-bag-type-mp2mp")

    l2vpn_id_mgr_app_bag_type_rd = Enum.YLeaf(6, "l2vpn-id-mgr-app-bag-type-rd")

    l2vpn_id_mgr_app_bag_type_pbb = Enum.YLeaf(7, "l2vpn-id-mgr-app-bag-type-pbb")

    l2vpn_id_mgr_app_bag_type_if_list = Enum.YLeaf(8, "l2vpn-id-mgr-app-bag-type-if-list")

    l2vpn_id_mgr_app_bag_type_atom = Enum.YLeaf(9, "l2vpn-id-mgr-app-bag-type-atom")

    l2vpn_id_mgr_app_bag_type_global = Enum.YLeaf(10, "l2vpn-id-mgr-app-bag-type-global")

    l2vpn_id_mgr_app_bag_type_pw_group = Enum.YLeaf(11, "l2vpn-id-mgr-app-bag-type-pw-group")

    l2vpn_id_mgr_app_bag_type_evpn = Enum.YLeaf(12, "l2vpn-id-mgr-app-bag-type-evpn")

    l2vpn_id_mgr_app_bag_type_evpn_lbl = Enum.YLeaf(13, "l2vpn-id-mgr-app-bag-type-evpn-lbl")

    l2vpn_id_mgr_app_bag_type_evpn_rd = Enum.YLeaf(14, "l2vpn-id-mgr-app-bag-type-evpn-rd")

    l2vpn_id_mgr_app_bag_type_ital = Enum.YLeaf(15, "l2vpn-id-mgr-app-bag-type-ital")

    l2vpn_id_mgr_app_bag_type_bp = Enum.YLeaf(16, "l2vpn-id-mgr-app-bag-type-bp")

    l2vpn_id_mgr_app_bag_type_count = Enum.YLeaf(17, "l2vpn-id-mgr-app-bag-type-count")


class L2vpnInterface(Enum):
    """
    L2vpnInterface (Enum Class)

    L2vpn interface

    .. data:: l2vpn_intf_type_unknown = 0

    	Unknown

    .. data:: l2vpn_intf_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_intf_type_vlan = 2

    	Ethernet Vlan

    .. data:: l2vpn_intf_type_atm = 3

    	ATM

    .. data:: l2vpn_intf_type_frame_relay = 4

    	Frame Relay

    .. data:: l2vpn_intf_type_hdlc = 5

    	HDLC

    .. data:: l2vpn_intf_type_ppp = 6

    	PPP

    .. data:: l2vpn_intf_type_span = 7

    	SPAN

    .. data:: l2vpn_intf_type_bvi = 8

    	BVI

    .. data:: l2vpn_intf_type_cem = 9

    	CEM

    .. data:: l2vpn_intf_type_pw_ether = 10

    	PsuedowireEther

    .. data:: l2vpn_intf_type_pw_iw = 11

    	PsuedowireIW

    .. data:: l2vpn_intf_type_vni = 12

    	VXLAN

    """

    l2vpn_intf_type_unknown = Enum.YLeaf(0, "l2vpn-intf-type-unknown")

    l2vpn_intf_type_ethernet = Enum.YLeaf(1, "l2vpn-intf-type-ethernet")

    l2vpn_intf_type_vlan = Enum.YLeaf(2, "l2vpn-intf-type-vlan")

    l2vpn_intf_type_atm = Enum.YLeaf(3, "l2vpn-intf-type-atm")

    l2vpn_intf_type_frame_relay = Enum.YLeaf(4, "l2vpn-intf-type-frame-relay")

    l2vpn_intf_type_hdlc = Enum.YLeaf(5, "l2vpn-intf-type-hdlc")

    l2vpn_intf_type_ppp = Enum.YLeaf(6, "l2vpn-intf-type-ppp")

    l2vpn_intf_type_span = Enum.YLeaf(7, "l2vpn-intf-type-span")

    l2vpn_intf_type_bvi = Enum.YLeaf(8, "l2vpn-intf-type-bvi")

    l2vpn_intf_type_cem = Enum.YLeaf(9, "l2vpn-intf-type-cem")

    l2vpn_intf_type_pw_ether = Enum.YLeaf(10, "l2vpn-intf-type-pw-ether")

    l2vpn_intf_type_pw_iw = Enum.YLeaf(11, "l2vpn-intf-type-pw-iw")

    l2vpn_intf_type_vni = Enum.YLeaf(12, "l2vpn-intf-type-vni")


class L2vpnInterworking(Enum):
    """
    L2vpnInterworking (Enum Class)

    L2vpn interworking

    .. data:: l2vpn_iw_type_none = 0

    	None

    .. data:: l2vpn_iw_type_ethernet = 1

    	Ethernet

    .. data:: l2vpn_iw_type_ppp = 2

    	PPP

    .. data:: l2vpn_iw_type_ipv4 = 3

    	IPv4

    .. data:: l2vpn_iw_type_voluntary = 4

    	Voluntary

    .. data:: l2vpn_iw_type_frf8 = 5

    	FRF8

    """

    l2vpn_iw_type_none = Enum.YLeaf(0, "l2vpn-iw-type-none")

    l2vpn_iw_type_ethernet = Enum.YLeaf(1, "l2vpn-iw-type-ethernet")

    l2vpn_iw_type_ppp = Enum.YLeaf(2, "l2vpn-iw-type-ppp")

    l2vpn_iw_type_ipv4 = Enum.YLeaf(3, "l2vpn-iw-type-ipv4")

    l2vpn_iw_type_voluntary = Enum.YLeaf(4, "l2vpn-iw-type-voluntary")

    l2vpn_iw_type_frf8 = Enum.YLeaf(5, "l2vpn-iw-type-frf8")


class L2vpnIpcTransportMode(Enum):
    """
    L2vpnIpcTransportMode (Enum Class)

    L2vpn ipc transport mode

    .. data:: unicast = 0

    	L2VPN Unicast IPC transport mode

    .. data:: broadcast = 1

    	L2VPN Broadcast IPC transport mode

    .. data:: unknown = 2

    	L2VPN Unknown IPC transport mode

    """

    unicast = Enum.YLeaf(0, "unicast")

    broadcast = Enum.YLeaf(1, "broadcast")

    unknown = Enum.YLeaf(2, "unknown")


class L2vpnL2tpTunnelState(Enum):
    """
    L2vpnL2tpTunnelState (Enum Class)

    L2vpn l2tp tunnel state

    .. data:: l2vpn_l2tp_idle = 0

    	Idle

    .. data:: l2vpn_l2tp_wait_for_connecting = 1

    	Wait for connecting

    .. data:: l2vpn_l2tp_wait_for_connected = 2

    	Wait for connected

    .. data:: l2vpn_l2tp_in_coming_call = 3

    	Incoming call

    .. data:: l2vpn_l2tp_connected = 4

    	Connected

    .. data:: l2vpn_l2tp_disconnected = 5

    	Disconnected

    """

    l2vpn_l2tp_idle = Enum.YLeaf(0, "l2vpn-l2tp-idle")

    l2vpn_l2tp_wait_for_connecting = Enum.YLeaf(1, "l2vpn-l2tp-wait-for-connecting")

    l2vpn_l2tp_wait_for_connected = Enum.YLeaf(2, "l2vpn-l2tp-wait-for-connected")

    l2vpn_l2tp_in_coming_call = Enum.YLeaf(3, "l2vpn-l2tp-in-coming-call")

    l2vpn_l2tp_connected = Enum.YLeaf(4, "l2vpn-l2tp-connected")

    l2vpn_l2tp_disconnected = Enum.YLeaf(5, "l2vpn-l2tp-disconnected")


class L2vpnLoadBal(Enum):
    """
    L2vpnLoadBal (Enum Class)

    L2vpn load bal

    .. data:: not_supported = 0

    	Load Balance Flow Not Supported

    .. data:: source_dest_mac = 1

    	Load Balance Flow src-dst-mac

    .. data:: source_dest_ip = 2

    	Load Balance Flow src-dst-ip

    .. data:: undefined = 3

    	Load Balance Flow Undefined

    .. data:: pseudowire_label = 4

    	Load Balance PW Label based

    """

    not_supported = Enum.YLeaf(0, "not-supported")

    source_dest_mac = Enum.YLeaf(1, "source-dest-mac")

    source_dest_ip = Enum.YLeaf(2, "source-dest-ip")

    undefined = Enum.YLeaf(3, "undefined")

    pseudowire_label = Enum.YLeaf(4, "pseudowire-label")


class L2vpnMainIfInstanceState(Enum):
    """
    L2vpnMainIfInstanceState (Enum Class)

    State of a main port instance

    .. data:: forwarding = 0

    	Forwarding state

    .. data:: blocked = 1

    	Blocked state

    .. data:: mac_learning = 2

    	Mac learning state

    .. data:: nack = 3

    	Nack state

    .. data:: forwarning_not_useful = 4

    	Forwarding not useful state

    .. data:: blocked_not_useful = 5

    	Blocked not useful state

    .. data:: mac_learning_not_useful = 6

    	Mac Learning not useful state

    .. data:: blocked_data_only = 7

    	Blocked data only state

    .. data:: mcast_pe2_ce_blocked = 8

    	Mcast PE to CE blocked state

    .. data:: port_state_unknown = 9

    	Port state unknown

    """

    forwarding = Enum.YLeaf(0, "forwarding")

    blocked = Enum.YLeaf(1, "blocked")

    mac_learning = Enum.YLeaf(2, "mac-learning")

    nack = Enum.YLeaf(3, "nack")

    forwarning_not_useful = Enum.YLeaf(4, "forwarning-not-useful")

    blocked_not_useful = Enum.YLeaf(5, "blocked-not-useful")

    mac_learning_not_useful = Enum.YLeaf(6, "mac-learning-not-useful")

    blocked_data_only = Enum.YLeaf(7, "blocked-data-only")

    mcast_pe2_ce_blocked = Enum.YLeaf(8, "mcast-pe2-ce-blocked")

    port_state_unknown = Enum.YLeaf(9, "port-state-unknown")


class L2vpnMainIfProtectected(Enum):
    """
    L2vpnMainIfProtectected (Enum Class)

    L2vpn main if protectected

    .. data:: erp_protected = 0

    	ERP Protected

    .. data:: mstp_protected = 1

    	MSTP Protected

    .. data:: no_protected = 2

    	No protection

    """

    erp_protected = Enum.YLeaf(0, "erp-protected")

    mstp_protected = Enum.YLeaf(1, "mstp-protected")

    no_protected = Enum.YLeaf(2, "no-protected")


class L2vpnMemoryState(Enum):
    """
    L2vpnMemoryState (Enum Class)

    L2vpn memory state

    .. data:: memory_state_unknown = 0

    	Memory state Unknown

    .. data:: memory_state_normal = 1

    	Memory state Normal

    .. data:: memory_state_minor = 2

    	Memory state Minor

    .. data:: memory_state_severe = 3

    	Memory state Severe

    .. data:: memory_state_critical = 4

    	Memory state Critical

    .. data:: memory_state_invalid = 5

    	Memory state Invalid

    """

    memory_state_unknown = Enum.YLeaf(0, "memory-state-unknown")

    memory_state_normal = Enum.YLeaf(1, "memory-state-normal")

    memory_state_minor = Enum.YLeaf(2, "memory-state-minor")

    memory_state_severe = Enum.YLeaf(3, "memory-state-severe")

    memory_state_critical = Enum.YLeaf(4, "memory-state-critical")

    memory_state_invalid = Enum.YLeaf(5, "memory-state-invalid")


class L2vpnMirpLiteProtocolInfo(Enum):
    """
    L2vpnMirpLiteProtocolInfo (Enum Class)

    L2vpn mirp lite protocol info

    .. data:: vlan0 = 0

    	MVRP PDU using Vlan0

    .. data:: none = 1

    	none

    """

    vlan0 = Enum.YLeaf(0, "vlan0")

    none = Enum.YLeaf(1, "none")


class L2vpnMirpLiteStatus(Enum):
    """
    L2vpnMirpLiteStatus (Enum Class)

    L2vpn mirp lite status

    .. data:: enabled = 0

    	Supported, enabled

    .. data:: not_supported = 1

    	Not supported

    """

    enabled = Enum.YLeaf(0, "enabled")

    not_supported = Enum.YLeaf(1, "not-supported")


class L2vpnMstiState(Enum):
    """
    L2vpnMstiState (Enum Class)

    L2VPN MSTI state

    .. data:: msti_bag_stp_port_state_forwarding = 0

    	msti bag stp port state forwarding

    .. data:: msti_bag_stp_port_state_blocked = 1

    	msti bag stp port state blocked

    .. data:: msti_bag_stp_port_state_mac_learning = 2

    	msti bag stp port state mac learning

    .. data:: msti_bag_stp_port_state_nack = 3

    	msti bag stp port state nack

    .. data:: msti_bag_stp_port_state_forwarding_not_useful = 4

    	msti bag stp port state forwarding not useful

    .. data:: msti_bag_stp_port_state_blocked_not_useful = 5

    	msti bag stp port state blocked not useful

    .. data:: msti_bag_stp_port_state_mac_learning_not_useful = 6

    	msti bag stp port state mac learning not useful

    .. data:: msti_bag_erp_port_state_blocked_data_only = 7

    	msti bag erp port state blocked data only

    .. data:: msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = 8

    	msti bag erp port state evpn mcast pe2ce

    	blocked

    .. data:: msti_bag_erp_port_state_evpn_port_state_mcast_blocked = 9

    	msti bag erp port state evpn port state mcast

    	blocked

    """

    msti_bag_stp_port_state_forwarding = Enum.YLeaf(0, "msti-bag-stp-port-state-forwarding")

    msti_bag_stp_port_state_blocked = Enum.YLeaf(1, "msti-bag-stp-port-state-blocked")

    msti_bag_stp_port_state_mac_learning = Enum.YLeaf(2, "msti-bag-stp-port-state-mac-learning")

    msti_bag_stp_port_state_nack = Enum.YLeaf(3, "msti-bag-stp-port-state-nack")

    msti_bag_stp_port_state_forwarding_not_useful = Enum.YLeaf(4, "msti-bag-stp-port-state-forwarding-not-useful")

    msti_bag_stp_port_state_blocked_not_useful = Enum.YLeaf(5, "msti-bag-stp-port-state-blocked-not-useful")

    msti_bag_stp_port_state_mac_learning_not_useful = Enum.YLeaf(6, "msti-bag-stp-port-state-mac-learning-not-useful")

    msti_bag_erp_port_state_blocked_data_only = Enum.YLeaf(7, "msti-bag-erp-port-state-blocked-data-only")

    msti_bag_erp_port_state_evpn_mcast_pe2ce_blocked = Enum.YLeaf(8, "msti-bag-erp-port-state-evpn-mcast-pe2ce-blocked")

    msti_bag_erp_port_state_evpn_port_state_mcast_blocked = Enum.YLeaf(9, "msti-bag-erp-port-state-evpn-port-state-mcast-blocked")


class L2vpnP2mpPwPtree(Enum):
    """
    L2vpnP2mpPwPtree (Enum Class)

    L2vpn p2mp pw ptree

    .. data:: none = 0

    	None

    .. data:: rsvp_te = 1

    	RSVP TE

    .. data:: mldp = 2

    	MLDP

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2vpnPeer(Enum):
    """
    L2vpnPeer (Enum Class)

    L2vpn peer

    .. data:: none = 0

    	None

    .. data:: ipv4 = 1

    	IPv4

    .. data:: ipv6 = 2

    	IPv6

    .. data:: internal_label = 3

    	Internal Label

    """

    none = Enum.YLeaf(0, "none")

    ipv4 = Enum.YLeaf(1, "ipv4")

    ipv6 = Enum.YLeaf(2, "ipv6")

    internal_label = Enum.YLeaf(3, "internal-label")


class L2vpnPreferred(Enum):
    """
    L2vpnPreferred (Enum Class)

    Preferred Type

    .. data:: te_tunnel = 0

    	TE Tunnel

    .. data:: ip_tunnel = 1

    	IP Tunnel

    .. data:: tp_tunnel = 2

    	TP Tunnel

    .. data:: mte_tunnel = 3

    	mTE

    .. data:: mldp_tunnel = 4

    	mLDP

    .. data:: sr_te_policy = 5

    	SR TE Policy

    """

    te_tunnel = Enum.YLeaf(0, "te-tunnel")

    ip_tunnel = Enum.YLeaf(1, "ip-tunnel")

    tp_tunnel = Enum.YLeaf(2, "tp-tunnel")

    mte_tunnel = Enum.YLeaf(3, "mte-tunnel")

    mldp_tunnel = Enum.YLeaf(4, "mldp-tunnel")

    sr_te_policy = Enum.YLeaf(5, "sr-te-policy")


class L2vpnPrefpathOption(Enum):
    """
    L2vpnPrefpathOption (Enum Class)

    Preferred Path Option

    .. data:: l2vpn_pw_mpls_pref_path_not_specified = 0

    	Not Secified

    .. data:: l2vpn_pw_mpls_pref_path_next_hop_ip = 1

    	Next Hop IP

    .. data:: l2vpn_pw_mpls_pref_path_te_tunnel = 2

    	TE Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_ip_tunnel = 3

    	IP Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_tp_tunnel = 4

    	TP Tunnel

    .. data:: l2vpn_pw_mpls_pref_path_sr_te = 5

    	SR TE Policy

    """

    l2vpn_pw_mpls_pref_path_not_specified = Enum.YLeaf(0, "l2vpn-pw-mpls-pref-path-not-specified")

    l2vpn_pw_mpls_pref_path_next_hop_ip = Enum.YLeaf(1, "l2vpn-pw-mpls-pref-path-next-hop-ip")

    l2vpn_pw_mpls_pref_path_te_tunnel = Enum.YLeaf(2, "l2vpn-pw-mpls-pref-path-te-tunnel")

    l2vpn_pw_mpls_pref_path_ip_tunnel = Enum.YLeaf(3, "l2vpn-pw-mpls-pref-path-ip-tunnel")

    l2vpn_pw_mpls_pref_path_tp_tunnel = Enum.YLeaf(4, "l2vpn-pw-mpls-pref-path-tp-tunnel")

    l2vpn_pw_mpls_pref_path_sr_te = Enum.YLeaf(5, "l2vpn-pw-mpls-pref-path-sr-te")


class L2vpnProcNsrNotReadyReason(Enum):
    """
    L2vpnProcNsrNotReadyReason (Enum Class)

    L2vpn proc nsr not ready reason

    .. data:: collab_time_out = 0

    	Collaborator connection time out

    .. data:: collab_conntection_idt = 1

    	Collaborator connection down or IDT not done

    .. data:: nsr_peer_not_connected = 2

    	NSR peer not connected

    .. data:: nsr_peer_not_in_sync = 3

    	NSR peer not in sync

    """

    collab_time_out = Enum.YLeaf(0, "collab-time-out")

    collab_conntection_idt = Enum.YLeaf(1, "collab-conntection-idt")

    nsr_peer_not_connected = Enum.YLeaf(2, "nsr-peer-not-connected")

    nsr_peer_not_in_sync = Enum.YLeaf(3, "nsr-peer-not-in-sync")


class L2vpnProcRole(Enum):
    """
    L2vpnProcRole (Enum Class)

    L2VPN Process Role

    .. data:: unknown = 0

    	Unknown

    .. data:: v1_active = 1

    	V1 Active

    .. data:: v1_standby = 2

    	V1 Standby

    .. data:: v2_active = 3

    	V2 Active

    .. data:: v2_standby = 4

    	V2 Standby

    .. data:: v1_active_post_big_bang = 5

    	V1 Active post big-bang

    .. data:: v1_standby_post_big_bang = 6

    	V1 Standbyi post big-bang

    .. data:: count = 7

    	Count

    """

    unknown = Enum.YLeaf(0, "unknown")

    v1_active = Enum.YLeaf(1, "v1-active")

    v1_standby = Enum.YLeaf(2, "v1-standby")

    v2_active = Enum.YLeaf(3, "v2-active")

    v2_standby = Enum.YLeaf(4, "v2-standby")

    v1_active_post_big_bang = Enum.YLeaf(5, "v1-active-post-big-bang")

    v1_standby_post_big_bang = Enum.YLeaf(6, "v1-standby-post-big-bang")

    count = Enum.YLeaf(7, "count")


class L2vpnProtection(Enum):
    """
    L2vpnProtection (Enum Class)

    L2VPN Protection types

    .. data:: l2vpn_protection_unknown = 0

    	Unknown type of protection

    .. data:: l2vpn_protection_interface = 1

    	Interface protection type

    .. data:: l2vpn_protection_pseudowire = 2

    	PW protection type

    .. data:: l2vpn_protection_group = 3

    	Group protection type 

    """

    l2vpn_protection_unknown = Enum.YLeaf(0, "l2vpn-protection-unknown")

    l2vpn_protection_interface = Enum.YLeaf(1, "l2vpn-protection-interface")

    l2vpn_protection_pseudowire = Enum.YLeaf(2, "l2vpn-protection-pseudowire")

    l2vpn_protection_group = Enum.YLeaf(3, "l2vpn-protection-group")


class L2vpnProtectionRole(Enum):
    """
    L2vpnProtectionRole (Enum Class)

    L2VPN Configurable protection roles

    .. data:: l2vpn_protection_primary = 0

    	Segment configured as primary

    .. data:: l2vpn_protection_backup = 1

    	Segment configured as backup

    """

    l2vpn_protection_primary = Enum.YLeaf(0, "l2vpn-protection-primary")

    l2vpn_protection_backup = Enum.YLeaf(1, "l2vpn-protection-backup")


class L2vpnPtree(Enum):
    """
    L2vpnPtree (Enum Class)

    ptree type

    .. data:: none = 0

    	No ptree type

    .. data:: rsvp_te = 1

    	RSVP_TE ptree type

    .. data:: mldp = 2

    	MLDP ptree type

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2vpnPw(Enum):
    """
    L2vpnPw (Enum Class)

    L2vpn pw

    .. data:: l2vpn_pw_type_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_type_frame_relay_dlci = 1

    	Frame Relay DLCI

    .. data:: l2vpn_pw_type_atm_aal5_sdu = 2

    	ATM AAL5 SDU VCC transport

    .. data:: l2vpn_pw_type_atm_trans_cell = 3

    	ATM transparent cell transport

    .. data:: l2vpn_pw_type_ether_vlan = 4

    	Ethernet VLAN tagged mode 

    .. data:: l2vpn_pw_type_ether = 5

    	Ethernet

    .. data:: l2vpn_pw_type_hdlc = 6

    	HDLC

    .. data:: l2vpn_pw_type_ppp = 7

    	PPP

    .. data:: l2vpn_pw_type_sonet_over_mpls = 8

    	SONET/SDH Circuit Emulation Service Over MPLS

    	(CEM)

    .. data:: l2vpn_pw_type_atm_n_vcc_cell = 9

    	ATM n-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_n_vpc_cell = 10

    	ATM n-to-one VPC cell transport

    .. data:: l2vpn_pw_type_ip = 11

    	IP Layer2 Transport

    .. data:: l2vpn_pw_type_atm_vcc_cell = 12

    	ATM one-to-one VCC cell transport

    .. data:: l2vpn_pw_type_atm_vpc_cell = 13

    	ATM one-to-one VPC cell transport

    .. data:: l2vpn_pw_type_atm_aal5_pdu = 14

    	ATM AAL5 PDU VCC transport

    .. data:: l2vpn_pw_type_frame_relay = 15

    	Frame Relay port mode

    .. data:: l2vpn_pw_type_sonet = 16

    	SONET/SDH Circuit

    .. data:: l2vpn_pw_type_vpls = 17

    	VPLS

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e1 = 18

    	TDM E1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t1 = 19

    	TDM T1

    .. data:: l2vpn_pw_type_tdm_sa_to_p_e3 = 20

    	TDM E3

    .. data:: l2vpn_pw_type_tdm_sa_to_p_t3 = 21

    	TDM T3

    .. data:: l2vpn_pw_type_tdm_ce_so_psn = 22

    	TDM CES over PSN

    """

    l2vpn_pw_type_unknown = Enum.YLeaf(0, "l2vpn-pw-type-unknown")

    l2vpn_pw_type_frame_relay_dlci = Enum.YLeaf(1, "l2vpn-pw-type-frame-relay-dlci")

    l2vpn_pw_type_atm_aal5_sdu = Enum.YLeaf(2, "l2vpn-pw-type-atm-aal5-sdu")

    l2vpn_pw_type_atm_trans_cell = Enum.YLeaf(3, "l2vpn-pw-type-atm-trans-cell")

    l2vpn_pw_type_ether_vlan = Enum.YLeaf(4, "l2vpn-pw-type-ether-vlan")

    l2vpn_pw_type_ether = Enum.YLeaf(5, "l2vpn-pw-type-ether")

    l2vpn_pw_type_hdlc = Enum.YLeaf(6, "l2vpn-pw-type-hdlc")

    l2vpn_pw_type_ppp = Enum.YLeaf(7, "l2vpn-pw-type-ppp")

    l2vpn_pw_type_sonet_over_mpls = Enum.YLeaf(8, "l2vpn-pw-type-sonet-over-mpls")

    l2vpn_pw_type_atm_n_vcc_cell = Enum.YLeaf(9, "l2vpn-pw-type-atm-n-vcc-cell")

    l2vpn_pw_type_atm_n_vpc_cell = Enum.YLeaf(10, "l2vpn-pw-type-atm-n-vpc-cell")

    l2vpn_pw_type_ip = Enum.YLeaf(11, "l2vpn-pw-type-ip")

    l2vpn_pw_type_atm_vcc_cell = Enum.YLeaf(12, "l2vpn-pw-type-atm-vcc-cell")

    l2vpn_pw_type_atm_vpc_cell = Enum.YLeaf(13, "l2vpn-pw-type-atm-vpc-cell")

    l2vpn_pw_type_atm_aal5_pdu = Enum.YLeaf(14, "l2vpn-pw-type-atm-aal5-pdu")

    l2vpn_pw_type_frame_relay = Enum.YLeaf(15, "l2vpn-pw-type-frame-relay")

    l2vpn_pw_type_sonet = Enum.YLeaf(16, "l2vpn-pw-type-sonet")

    l2vpn_pw_type_vpls = Enum.YLeaf(17, "l2vpn-pw-type-vpls")

    l2vpn_pw_type_tdm_sa_to_p_e1 = Enum.YLeaf(18, "l2vpn-pw-type-tdm-sa-to-p-e1")

    l2vpn_pw_type_tdm_sa_to_p_t1 = Enum.YLeaf(19, "l2vpn-pw-type-tdm-sa-to-p-t1")

    l2vpn_pw_type_tdm_sa_to_p_e3 = Enum.YLeaf(20, "l2vpn-pw-type-tdm-sa-to-p-e3")

    l2vpn_pw_type_tdm_sa_to_p_t3 = Enum.YLeaf(21, "l2vpn-pw-type-tdm-sa-to-p-t3")

    l2vpn_pw_type_tdm_ce_so_psn = Enum.YLeaf(22, "l2vpn-pw-type-tdm-ce-so-psn")


class L2vpnPwClassControlWord(Enum):
    """
    L2vpnPwClassControlWord (Enum Class)

    L2vpn pw class control word

    .. data:: unset = 0

    	Unset

    .. data:: enable = 1

    	Enable

    .. data:: disable = 2

    	Disable

    """

    unset = Enum.YLeaf(0, "unset")

    enable = Enum.YLeaf(1, "enable")

    disable = Enum.YLeaf(2, "disable")


class L2vpnPwControlWord(Enum):
    """
    L2vpnPwControlWord (Enum Class)

    L2vpn pw control word

    .. data:: l2vpn_pw_control_word_unknown = 0

    	Unknown

    .. data:: l2vpn_pw_control_word_clear = 1

    	Clear

    .. data:: l2vpn_pw_control_word_set = 2

    	Set

    .. data:: l2vpn_pw_control_word_mandatory = 3

    	Mandatory

    """

    l2vpn_pw_control_word_unknown = Enum.YLeaf(0, "l2vpn-pw-control-word-unknown")

    l2vpn_pw_control_word_clear = Enum.YLeaf(1, "l2vpn-pw-control-word-clear")

    l2vpn_pw_control_word_set = Enum.YLeaf(2, "l2vpn-pw-control-word-set")

    l2vpn_pw_control_word_mandatory = Enum.YLeaf(3, "l2vpn-pw-control-word-mandatory")


class L2vpnPwFec(Enum):
    """
    L2vpnPwFec (Enum Class)

    L2vpn pw fec

    .. data:: l2vpn_pw_fec_128 = 0

    	FEC 128 pseudowire type

    .. data:: l2vpn_pw_fec_129 = 1

    	FEC 129 pseudowire type

    .. data:: l2vpn_pw_fec_not_applicable = 268435455

    	FEC Not Applicable

    """

    l2vpn_pw_fec_128 = Enum.YLeaf(0, "l2vpn-pw-fec-128")

    l2vpn_pw_fec_129 = Enum.YLeaf(1, "l2vpn-pw-fec-129")

    l2vpn_pw_fec_not_applicable = Enum.YLeaf(268435455, "l2vpn-pw-fec-not-applicable")


class L2vpnPwFlowLabel(Enum):
    """
    L2vpnPwFlowLabel (Enum Class)

    Pseudowire flow label load balance types

    .. data:: off = 0

    	Flow label is off

    .. data:: receive = 1

    	Flow label is enabled on the receive side

    .. data:: transmit = 2

    	Flow label is enabled on the transmit side

    .. data:: both = 3

    	Flow label is enabled on both transmit and

    	receive sides

    """

    off = Enum.YLeaf(0, "off")

    receive = Enum.YLeaf(1, "receive")

    transmit = Enum.YLeaf(2, "transmit")

    both = Enum.YLeaf(3, "both")


class L2vpnPwId(Enum):
    """
    L2vpnPwId (Enum Class)

    L2vpn pw id

    .. data:: l2vpn_pw_id_type_manual = 1

    	Manual

    .. data:: l2vpn_pw_id_type_ad_vpls = 2

    	AD VPLS

    .. data:: l2vpn_pw_id_type_ad_vpws = 3

    	AD VPWS

    .. data:: l2vpn_pw_id_type_ad_vpls_ldp = 4

    	AD VPLS-LDP

    .. data:: l2vpn_pw_id_type_pwr = 5

    	PWR

    .. data:: l2vpn_pw_id_type_evpn = 6

    	EVPN

    """

    l2vpn_pw_id_type_manual = Enum.YLeaf(1, "l2vpn-pw-id-type-manual")

    l2vpn_pw_id_type_ad_vpls = Enum.YLeaf(2, "l2vpn-pw-id-type-ad-vpls")

    l2vpn_pw_id_type_ad_vpws = Enum.YLeaf(3, "l2vpn-pw-id-type-ad-vpws")

    l2vpn_pw_id_type_ad_vpls_ldp = Enum.YLeaf(4, "l2vpn-pw-id-type-ad-vpls-ldp")

    l2vpn_pw_id_type_pwr = Enum.YLeaf(5, "l2vpn-pw-id-type-pwr")

    l2vpn_pw_id_type_evpn = Enum.YLeaf(6, "l2vpn-pw-id-type-evpn")


class L2vpnPwSequence(Enum):
    """
    L2vpnPwSequence (Enum Class)

    L2vpn pw sequence

    .. data:: l2vpn_pw_sequence_off = 0

    	Sequencing is Off

    .. data:: l2vpn_pw_sequence_xmit = 1

    	Sequencing on the transmit side

    .. data:: l2vpn_pw_sequence_recv = 2

    	Sequencing on the receive side

    .. data:: l2vpn_pw_sequence_trans = 3

    	Sequencing is transparent

    .. data:: l2vpn_pw_sequence_both = 4

    	Sequencing on both sides

    """

    l2vpn_pw_sequence_off = Enum.YLeaf(0, "l2vpn-pw-sequence-off")

    l2vpn_pw_sequence_xmit = Enum.YLeaf(1, "l2vpn-pw-sequence-xmit")

    l2vpn_pw_sequence_recv = Enum.YLeaf(2, "l2vpn-pw-sequence-recv")

    l2vpn_pw_sequence_trans = Enum.YLeaf(3, "l2vpn-pw-sequence-trans")

    l2vpn_pw_sequence_both = Enum.YLeaf(4, "l2vpn-pw-sequence-both")


class L2vpnPwState(Enum):
    """
    L2vpnPwState (Enum Class)

    L2vpn pw state

    .. data:: l2vpn_pw_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_pw_state_idle = 1

    	Idle

    .. data:: l2vpn_pw_state_provisioned = 2

    	Provisioned

    .. data:: l2vpn_pw_state_remote_standby = 3

    	Remote standby

    .. data:: l2vpn_pw_state_local_ready = 4

    	Local ready

    .. data:: l2vpn_pw_state_all_ready = 5

    	All ready

    .. data:: l2vpn_pw_state_established = 6

    	Established

    """

    l2vpn_pw_state_unresolved = Enum.YLeaf(0, "l2vpn-pw-state-unresolved")

    l2vpn_pw_state_idle = Enum.YLeaf(1, "l2vpn-pw-state-idle")

    l2vpn_pw_state_provisioned = Enum.YLeaf(2, "l2vpn-pw-state-provisioned")

    l2vpn_pw_state_remote_standby = Enum.YLeaf(3, "l2vpn-pw-state-remote-standby")

    l2vpn_pw_state_local_ready = Enum.YLeaf(4, "l2vpn-pw-state-local-ready")

    l2vpn_pw_state_all_ready = Enum.YLeaf(5, "l2vpn-pw-state-all-ready")

    l2vpn_pw_state_established = Enum.YLeaf(6, "l2vpn-pw-state-established")


class L2vpnRgState(Enum):
    """
    L2vpnRgState (Enum Class)

    L2vpn rg state

    .. data:: unknown = 0

    	Not defined

    .. data:: active = 1

    	Active

    .. data:: standby = 2

    	Standby

    """

    unknown = Enum.YLeaf(0, "unknown")

    active = Enum.YLeaf(1, "active")

    standby = Enum.YLeaf(2, "standby")


class L2vpnSegment(Enum):
    """
    L2vpnSegment (Enum Class)

    L2vpn segment

    .. data:: l2vpn_segment_type_unresolved = 0

    	Unresolved segment

    .. data:: l2vpn_segment_type_ac = 1

    	Attachment circuit segment

    .. data:: l2vpn_segment_type_pw = 2

    	Pseudowire segment

    .. data:: l2vpn_segment_type_bd_ac = 3

    	Bridge domain attachment circuit

    .. data:: l2vpn_segment_type_vfi = 4

    	Virtual forwarding instance segment

    .. data:: l2vpn_segment_type_bd_pw = 5

    	Bridge Pseudowire

    .. data:: l2vpn_segment_type_bd_pbb = 6

    	Bridge domain PBB segment

    .. data:: l2vpn_segment_type_bd_evpn = 7

    	Bridge domain EVPN segment

    .. data:: l2vpn_segment_type_vni = 8

    	VxLAN Network Identifier (VNI) segment

    """

    l2vpn_segment_type_unresolved = Enum.YLeaf(0, "l2vpn-segment-type-unresolved")

    l2vpn_segment_type_ac = Enum.YLeaf(1, "l2vpn-segment-type-ac")

    l2vpn_segment_type_pw = Enum.YLeaf(2, "l2vpn-segment-type-pw")

    l2vpn_segment_type_bd_ac = Enum.YLeaf(3, "l2vpn-segment-type-bd-ac")

    l2vpn_segment_type_vfi = Enum.YLeaf(4, "l2vpn-segment-type-vfi")

    l2vpn_segment_type_bd_pw = Enum.YLeaf(5, "l2vpn-segment-type-bd-pw")

    l2vpn_segment_type_bd_pbb = Enum.YLeaf(6, "l2vpn-segment-type-bd-pbb")

    l2vpn_segment_type_bd_evpn = Enum.YLeaf(7, "l2vpn-segment-type-bd-evpn")

    l2vpn_segment_type_vni = Enum.YLeaf(8, "l2vpn-segment-type-vni")


class L2vpnSegmentState(Enum):
    """
    L2vpnSegmentState (Enum Class)

    L2vpn segment state

    .. data:: l2vpn_segment_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_segment_state_up = 1

    	Up

    .. data:: l2vpn_segment_state_down = 2

    	Down

    .. data:: l2vpn_segment_state_admin_down = 3

    	Admin down

    .. data:: l2vpn_segment_state_local_up = 4

    	Local up

    .. data:: l2vpn_segment_state_remote_up = 5

    	Remote up

    .. data:: l2vpn_segment_state_connected = 6

    	Connected

    .. data:: l2vpn_segment_state_standby = 7

    	Standby

    .. data:: l2vpn_segment_state_standby_ready = 8

    	Standby Ready

    """

    l2vpn_segment_state_unresolved = Enum.YLeaf(0, "l2vpn-segment-state-unresolved")

    l2vpn_segment_state_up = Enum.YLeaf(1, "l2vpn-segment-state-up")

    l2vpn_segment_state_down = Enum.YLeaf(2, "l2vpn-segment-state-down")

    l2vpn_segment_state_admin_down = Enum.YLeaf(3, "l2vpn-segment-state-admin-down")

    l2vpn_segment_state_local_up = Enum.YLeaf(4, "l2vpn-segment-state-local-up")

    l2vpn_segment_state_remote_up = Enum.YLeaf(5, "l2vpn-segment-state-remote-up")

    l2vpn_segment_state_connected = Enum.YLeaf(6, "l2vpn-segment-state-connected")

    l2vpn_segment_state_standby = Enum.YLeaf(7, "l2vpn-segment-state-standby")

    l2vpn_segment_state_standby_ready = Enum.YLeaf(8, "l2vpn-segment-state-standby-ready")


class L2vpnService(Enum):
    """
    L2vpnService (Enum Class)

    L2vpn service

    .. data:: vpws = 0

    	VPWS service

    .. data:: vpls = 1

    	VPLS service

    """

    vpws = Enum.YLeaf(0, "vpws")

    vpls = Enum.YLeaf(1, "vpls")


class L2vpnSignallingProto(Enum):
    """
    L2vpnSignallingProto (Enum Class)

    L2vpn signalling proto

    .. data:: l2vpn_pw_sig_not_specified = 0

    	Not specified

    .. data:: l2vpn_pw_sig_none = 1

    	Static

    .. data:: l2vpn_pw_sig_l2tpv3 = 2

    	L2TPv3 signaling

    .. data:: l2vpn_pw_sig_l2tpv2 = 3

    	L2TPv2 signaling

    .. data:: l2vpn_pw_sig_ldp = 4

    	LDP

    .. data:: l2vpn_pw_sig_bgp = 5

    	BGP

    """

    l2vpn_pw_sig_not_specified = Enum.YLeaf(0, "l2vpn-pw-sig-not-specified")

    l2vpn_pw_sig_none = Enum.YLeaf(1, "l2vpn-pw-sig-none")

    l2vpn_pw_sig_l2tpv3 = Enum.YLeaf(2, "l2vpn-pw-sig-l2tpv3")

    l2vpn_pw_sig_l2tpv2 = Enum.YLeaf(3, "l2vpn-pw-sig-l2tpv2")

    l2vpn_pw_sig_ldp = Enum.YLeaf(4, "l2vpn-pw-sig-ldp")

    l2vpn_pw_sig_bgp = Enum.YLeaf(5, "l2vpn-pw-sig-bgp")


class L2vpnSrcAddressSet(Enum):
    """
    L2vpnSrcAddressSet (Enum Class)

    L2vpn src address set

    .. data:: unset = 0

    	Unset

    .. data:: set = 1

    	Set

    """

    unset = Enum.YLeaf(0, "unset")

    set = Enum.YLeaf(1, "set")


class L2vpnSyncStatus(Enum):
    """
    L2vpnSyncStatus (Enum Class)

    L2vpn sync status

    .. data:: not_ready = 0

    	Not Ready

    .. data:: ready = 1

    	Ready

    """

    not_ready = Enum.YLeaf(0, "not-ready")

    ready = Enum.YLeaf(1, "ready")


class L2vpnTdmMode(Enum):
    """
    L2vpnTdmMode (Enum Class)

    L2VPN TDM modes

    .. data:: unknown = 0

    	Unknown mode

    .. data:: ce_so_psn = 1

    	CESoPSN mode

    .. data:: sa_to_p_e1 = 2

    	SAToP E1 mode

    .. data:: sa_to_p_t1 = 3

    	SAToP T1 mode

    .. data:: sa_to_p_e3 = 4

    	SAToP E3 mode

    .. data:: sa_to_p_t3 = 5

    	SAToP T3 mode

    """

    unknown = Enum.YLeaf(0, "unknown")

    ce_so_psn = Enum.YLeaf(1, "ce-so-psn")

    sa_to_p_e1 = Enum.YLeaf(2, "sa-to-p-e1")

    sa_to_p_t1 = Enum.YLeaf(3, "sa-to-p-t1")

    sa_to_p_e3 = Enum.YLeaf(4, "sa-to-p-e3")

    sa_to_p_t3 = Enum.YLeaf(5, "sa-to-p-t3")


class L2vpnTdmRtpOption(Enum):
    """
    L2vpnTdmRtpOption (Enum Class)

    L2VPN TDM RTP option

    .. data:: unknown = 0

    	Unknown RTP option

    .. data:: present = 1

    	RTP option present

    .. data:: absent = 2

    	RTP option absent

    """

    unknown = Enum.YLeaf(0, "unknown")

    present = Enum.YLeaf(1, "present")

    absent = Enum.YLeaf(2, "absent")


class L2vpnTimeStampMode(Enum):
    """
    L2vpnTimeStampMode (Enum Class)

    L2VPN TDM Time stamp modes

    .. data:: unknown = 0

    	Unknown time stamp mode

    .. data:: differential = 1

    	Differential time stamp mode

    .. data:: absolute = 2

    	Absolute Time Stamp mode

    .. data:: none = 3

    	time stamp mode none

    """

    unknown = Enum.YLeaf(0, "unknown")

    differential = Enum.YLeaf(1, "differential")

    absolute = Enum.YLeaf(2, "absolute")

    none = Enum.YLeaf(3, "none")


class L2vpnTosMode(Enum):
    """
    L2vpnTosMode (Enum Class)

    L2vpn tos mode

    .. data:: l2vpn_pw_ip_tos_none = 0

    	None

    .. data:: l2vpn_pw_ip_tos_reflect = 1

    	Reflect the TOS

    """

    l2vpn_pw_ip_tos_none = Enum.YLeaf(0, "l2vpn-pw-ip-tos-none")

    l2vpn_pw_ip_tos_reflect = Enum.YLeaf(1, "l2vpn-pw-ip-tos-reflect")


class L2vpnTransportMode(Enum):
    """
    L2vpnTransportMode (Enum Class)

    L2vpn transport mode

    .. data:: l2vpn_transport_mode_not_specified = 0

    	Not specified

    .. data:: l2vpn_transport_mode_ethernet = 1

    	Ethernet

    .. data:: l2vpn_transport_mode_vlan = 2

    	VLAN

    .. data:: l2vpn_transport_mode_vlan_passthrough = 3

    	VLAN Passthrough

    """

    l2vpn_transport_mode_not_specified = Enum.YLeaf(0, "l2vpn-transport-mode-not-specified")

    l2vpn_transport_mode_ethernet = Enum.YLeaf(1, "l2vpn-transport-mode-ethernet")

    l2vpn_transport_mode_vlan = Enum.YLeaf(2, "l2vpn-transport-mode-vlan")

    l2vpn_transport_mode_vlan_passthrough = Enum.YLeaf(3, "l2vpn-transport-mode-vlan-passthrough")


class L2vpnVfiP2mpSignaling(Enum):
    """
    L2vpnVfiP2mpSignaling (Enum Class)

    L2vpn vfi p2mp signaling

    .. data:: none = 0

    	undefined signaling

    .. data:: bgp = 1

    	BGP signaling

    """

    none = Enum.YLeaf(0, "none")

    bgp = Enum.YLeaf(1, "bgp")


class L2vpnVfiP2mpTransport(Enum):
    """
    L2vpnVfiP2mpTransport (Enum Class)

    L2vpn vfi p2mp transport

    .. data:: none = 0

    	undefined transport

    .. data:: rsvp_te = 1

    	RSVP-TE transport

    """

    none = Enum.YLeaf(0, "none")

    rsvp_te = Enum.YLeaf(1, "rsvp-te")


class L2vpnVfiState(Enum):
    """
    L2vpnVfiState (Enum Class)

    L2vpn vfi state

    .. data:: unknown = 0

    	VFI Unknown

    .. data:: up = 1

    	VFI Up

    .. data:: down = 2

    	VFI Down

    .. data:: admin_down = 3

    	VFI Admin Down

    """

    unknown = Enum.YLeaf(0, "unknown")

    up = Enum.YLeaf(1, "up")

    down = Enum.YLeaf(2, "down")

    admin_down = Enum.YLeaf(3, "admin-down")


class L2vpnVirtualportState(Enum):
    """
    L2vpnVirtualportState (Enum Class)

    L2vpn virtualport state

    .. data:: l2vpn_vp_state_undefined = 0

    	Undefined

    .. data:: l2vpn_vp_state_up = 1

    	Up

    .. data:: l2vpn_vp_state_down = 2

    	Down

    """

    l2vpn_vp_state_undefined = Enum.YLeaf(0, "l2vpn-vp-state-undefined")

    l2vpn_vp_state_up = Enum.YLeaf(1, "l2vpn-vp-state-up")

    l2vpn_vp_state_down = Enum.YLeaf(2, "l2vpn-vp-state-down")


class L2vpnVniEncaps(Enum):
    """
    L2vpnVniEncaps (Enum Class)

    L2vpn vni encaps

    .. data:: l2vpn_vni_encap_vxlan = 0

    	VXLAN

    .. data:: l2vpn_vni_encap_softgre = 1

    	SOFTGRE

    """

    l2vpn_vni_encap_vxlan = Enum.YLeaf(0, "l2vpn-vni-encap-vxlan")

    l2vpn_vni_encap_softgre = Enum.YLeaf(1, "l2vpn-vni-encap-softgre")


class L2vpnVniMode(Enum):
    """
    L2vpnVniMode (Enum Class)

    L2vpn vni mode

    .. data:: l2vpn_vni_mode_l2_dp = 0

    	Data Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_dp = 1

    	Data Plane L3 Service

    .. data:: l2vpn_vni_mode_l2_cp = 2

    	Control Plane L2 Service

    .. data:: l2vpn_vni_mode_l3_cp = 3

    	Control Plane L3 Service

    """

    l2vpn_vni_mode_l2_dp = Enum.YLeaf(0, "l2vpn-vni-mode-l2-dp")

    l2vpn_vni_mode_l3_dp = Enum.YLeaf(1, "l2vpn-vni-mode-l3-dp")

    l2vpn_vni_mode_l2_cp = Enum.YLeaf(2, "l2vpn-vni-mode-l2-cp")

    l2vpn_vni_mode_l3_cp = Enum.YLeaf(3, "l2vpn-vni-mode-l3-cp")


class L2vpnXcState(Enum):
    """
    L2vpnXcState (Enum Class)

    L2vpn xc state

    .. data:: l2vpn_xc_state_unresolved = 0

    	Unresolved

    .. data:: l2vpn_xc_state_down = 1

    	Down

    .. data:: l2vpn_xc_state_up = 2

    	Up

    """

    l2vpn_xc_state_unresolved = Enum.YLeaf(0, "l2vpn-xc-state-unresolved")

    l2vpn_xc_state_down = Enum.YLeaf(1, "l2vpn-xc-state-down")

    l2vpn_xc_state_up = Enum.YLeaf(2, "l2vpn-xc-state-up")


class L2vpnp2mpPtree(Enum):
    """
    L2vpnp2mpPtree (Enum Class)

    L2vpnp2mp ptree

    .. data:: rsvp_te = 1

    	RSVPTE Type

    .. data:: mldp = 2

    	MLDP Type

    """

    rsvp_te = Enum.YLeaf(1, "rsvp-te")

    mldp = Enum.YLeaf(2, "mldp")


class L2vpnpw(Enum):
    """
    L2vpnpw (Enum Class)

    L2vpnpw

    .. data:: manual = 1

    	Manual pseudowire

    .. data:: vpls_autodiscovered = 2

    	VPLS autodiscovered pseudowire

    .. data:: vpws_autodiscovered = 3

    	VPWS autodiscovered pseudowire

    .. data:: vpls_autodiscovered_ldp = 4

    	VPLS autodiscovered pseudowire with LDP

    	signaling

    """

    manual = Enum.YLeaf(1, "manual")

    vpls_autodiscovered = Enum.YLeaf(2, "vpls-autodiscovered")

    vpws_autodiscovered = Enum.YLeaf(3, "vpws-autodiscovered")

    vpls_autodiscovered_ldp = Enum.YLeaf(4, "vpls-autodiscovered-ldp")


class MgmtL2fibBridge(Enum):
    """
    MgmtL2fibBridge (Enum Class)

    Mgmt l2fib bridge

    .. data:: mgmt_l2fib_bridge_type_default = 0

    	mgmt l2fib bridge type default

    .. data:: mgmt_l2fib_bridge_type_pbb_edge = 1

    	mgmt l2fib bridge type pbb edge

    .. data:: mgmt_l2fib_bridge_type_pbb_core = 2

    	mgmt l2fib bridge type pbb core

    """

    mgmt_l2fib_bridge_type_default = Enum.YLeaf(0, "mgmt-l2fib-bridge-type-default")

    mgmt_l2fib_bridge_type_pbb_edge = Enum.YLeaf(1, "mgmt-l2fib-bridge-type-pbb-edge")

    mgmt_l2fib_bridge_type_pbb_core = Enum.YLeaf(2, "mgmt-l2fib-bridge-type-pbb-core")


class MgmtL2fibBridgeMacEvpnCtx(Enum):
    """
    MgmtL2fibBridgeMacEvpnCtx (Enum Class)

    Mgmt l2fib bridge mac evpn ctx

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_none = 0

    	mgmt l2fib bridge mac evpn ctx none

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = 1

    	mgmt l2fib bridge mac evpn ctx esi id

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_local_label = 2

    	mgmt l2fib bridge mac evpn ctx local label

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_moi = 3

    	mgmt l2fib bridge mac evpn ctx moi

    .. data:: mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = 4

    	mgmt l2fib bridge mac evpn ctx bp ifh

    """

    mgmt_l2fib_bridge_mac_evpn_ctx_none = Enum.YLeaf(0, "mgmt-l2fib-bridge-mac-evpn-ctx-none")

    mgmt_l2fib_bridge_mac_evpn_ctx_esi_id = Enum.YLeaf(1, "mgmt-l2fib-bridge-mac-evpn-ctx-esi-id")

    mgmt_l2fib_bridge_mac_evpn_ctx_local_label = Enum.YLeaf(2, "mgmt-l2fib-bridge-mac-evpn-ctx-local-label")

    mgmt_l2fib_bridge_mac_evpn_ctx_moi = Enum.YLeaf(3, "mgmt-l2fib-bridge-mac-evpn-ctx-moi")

    mgmt_l2fib_bridge_mac_evpn_ctx_bp_ifh = Enum.YLeaf(4, "mgmt-l2fib-bridge-mac-evpn-ctx-bp-ifh")


class MgmtL2fibData(Enum):
    """
    MgmtL2fibData (Enum Class)

    Mgmt l2fib data

    .. data:: mgmt_l2fib_data_type_min = 0

    	mgmt l2fib data type min

    .. data:: mgmt_l2fib_data_type_xcon = 1

    	mgmt l2fib data type xcon

    .. data:: mgmt_l2fib_data_type_ac = 2

    	mgmt l2fib data type ac

    .. data:: mgmt_l2fib_data_type_span = 3

    	mgmt l2fib data type span

    .. data:: mgmt_l2fib_data_type_atom = 4

    	mgmt l2fib data type atom

    .. data:: mgmt_l2fib_data_type_pbb = 5

    	mgmt l2fib data type pbb

    .. data:: mgmt_l2fib_data_type_vni = 6

    	mgmt l2fib data type vni

    .. data:: mgmt_l2fib_data_type_n_hop = 7

    	mgmt l2fib data type n hop

    .. data:: mgmt_l2fib_data_type_l2tp = 8

    	mgmt l2fib data type l2tp

    .. data:: mgmt_l2fib_data_type_l2tpv2 = 9

    	mgmt l2fib data type l2tpv2

    .. data:: mgmt_l2fib_data_type_bridge = 10

    	mgmt l2fib data type bridge

    .. data:: mgmt_l2fib_data_type_bridge_shg = 11

    	mgmt l2fib data type bridge shg

    .. data:: mgmt_l2fib_data_type_bridge_port = 12

    	mgmt l2fib data type bridge port

    .. data:: mgmt_l2fib_data_type_bridge_mac = 13

    	mgmt l2fib data type bridge mac

    .. data:: mgmt_l2fib_data_type_mcast_table = 14

    	mgmt l2fib data type mcast table

    .. data:: mgmt_l2fib_data_type_mcast_leaf = 15

    	mgmt l2fib data type mcast leaf

    .. data:: mgmt_l2fib_data_type_mcast_xid = 16

    	mgmt l2fib data type mcast xid

    .. data:: mgmt_l2fib_data_type_dhcp = 17

    	mgmt l2fib data type dhcp

    .. data:: mgmt_l2fib_data_type_l2tp_ipv6_ts = 18

    	mgmt l2fib data type l2tp ipv6 ts

    .. data:: mgmt_l2fib_data_type_pwhe_mp = 19

    	mgmt l2fib data type pwhe mp

    .. data:: mgmt_l2fib_data_type_evpn = 20

    	mgmt l2fib data type evpn

    .. data:: mgmt_l2fib_data_type_fxs = 21

    	mgmt l2fib data type fxs

    .. data:: mgmt_l2fib_data_type_max = 22

    	mgmt l2fib data type max

    """

    mgmt_l2fib_data_type_min = Enum.YLeaf(0, "mgmt-l2fib-data-type-min")

    mgmt_l2fib_data_type_xcon = Enum.YLeaf(1, "mgmt-l2fib-data-type-xcon")

    mgmt_l2fib_data_type_ac = Enum.YLeaf(2, "mgmt-l2fib-data-type-ac")

    mgmt_l2fib_data_type_span = Enum.YLeaf(3, "mgmt-l2fib-data-type-span")

    mgmt_l2fib_data_type_atom = Enum.YLeaf(4, "mgmt-l2fib-data-type-atom")

    mgmt_l2fib_data_type_pbb = Enum.YLeaf(5, "mgmt-l2fib-data-type-pbb")

    mgmt_l2fib_data_type_vni = Enum.YLeaf(6, "mgmt-l2fib-data-type-vni")

    mgmt_l2fib_data_type_n_hop = Enum.YLeaf(7, "mgmt-l2fib-data-type-n-hop")

    mgmt_l2fib_data_type_l2tp = Enum.YLeaf(8, "mgmt-l2fib-data-type-l2tp")

    mgmt_l2fib_data_type_l2tpv2 = Enum.YLeaf(9, "mgmt-l2fib-data-type-l2tpv2")

    mgmt_l2fib_data_type_bridge = Enum.YLeaf(10, "mgmt-l2fib-data-type-bridge")

    mgmt_l2fib_data_type_bridge_shg = Enum.YLeaf(11, "mgmt-l2fib-data-type-bridge-shg")

    mgmt_l2fib_data_type_bridge_port = Enum.YLeaf(12, "mgmt-l2fib-data-type-bridge-port")

    mgmt_l2fib_data_type_bridge_mac = Enum.YLeaf(13, "mgmt-l2fib-data-type-bridge-mac")

    mgmt_l2fib_data_type_mcast_table = Enum.YLeaf(14, "mgmt-l2fib-data-type-mcast-table")

    mgmt_l2fib_data_type_mcast_leaf = Enum.YLeaf(15, "mgmt-l2fib-data-type-mcast-leaf")

    mgmt_l2fib_data_type_mcast_xid = Enum.YLeaf(16, "mgmt-l2fib-data-type-mcast-xid")

    mgmt_l2fib_data_type_dhcp = Enum.YLeaf(17, "mgmt-l2fib-data-type-dhcp")

    mgmt_l2fib_data_type_l2tp_ipv6_ts = Enum.YLeaf(18, "mgmt-l2fib-data-type-l2tp-ipv6-ts")

    mgmt_l2fib_data_type_pwhe_mp = Enum.YLeaf(19, "mgmt-l2fib-data-type-pwhe-mp")

    mgmt_l2fib_data_type_evpn = Enum.YLeaf(20, "mgmt-l2fib-data-type-evpn")

    mgmt_l2fib_data_type_fxs = Enum.YLeaf(21, "mgmt-l2fib-data-type-fxs")

    mgmt_l2fib_data_type_max = Enum.YLeaf(22, "mgmt-l2fib-data-type-max")


class MgmtL2fibMacLimitAction(Enum):
    """
    MgmtL2fibMacLimitAction (Enum Class)

    Mgmt l2fib mac limit action

    .. data:: mgmt_l2fib_mac_limit_action_type_none = 0

    	mgmt l2fib mac limit action type none

    .. data:: mgmt_l2fib_mac_limit_action_type_flood = 1

    	mgmt l2fib mac limit action type flood

    .. data:: mgmt_l2fib_mac_limit_action_type_no_flood = 2

    	mgmt l2fib mac limit action type no flood

    .. data:: mgmt_l2fib_mac_limit_action_type_shutdown = 3

    	mgmt l2fib mac limit action type shutdown

    """

    mgmt_l2fib_mac_limit_action_type_none = Enum.YLeaf(0, "mgmt-l2fib-mac-limit-action-type-none")

    mgmt_l2fib_mac_limit_action_type_flood = Enum.YLeaf(1, "mgmt-l2fib-mac-limit-action-type-flood")

    mgmt_l2fib_mac_limit_action_type_no_flood = Enum.YLeaf(2, "mgmt-l2fib-mac-limit-action-type-no-flood")

    mgmt_l2fib_mac_limit_action_type_shutdown = Enum.YLeaf(3, "mgmt-l2fib-mac-limit-action-type-shutdown")


class MgmtL2fibMacLimitNotify(Enum):
    """
    MgmtL2fibMacLimitNotify (Enum Class)

    Mgmt l2fib mac limit notify

    .. data:: mgmt_l2fib_mac_limit_notify_none = 0

    	mgmt l2fib mac limit notify none

    .. data:: mgmt_l2fib_mac_limit_notify_syslog = 1

    	mgmt l2fib mac limit notify syslog

    .. data:: mgmt_l2fib_mac_limit_notify_trap = 2

    	mgmt l2fib mac limit notify trap

    .. data:: mgmt_l2fib_mac_limit_notify_both = 3

    	mgmt l2fib mac limit notify both

    """

    mgmt_l2fib_mac_limit_notify_none = Enum.YLeaf(0, "mgmt-l2fib-mac-limit-notify-none")

    mgmt_l2fib_mac_limit_notify_syslog = Enum.YLeaf(1, "mgmt-l2fib-mac-limit-notify-syslog")

    mgmt_l2fib_mac_limit_notify_trap = Enum.YLeaf(2, "mgmt-l2fib-mac-limit-notify-trap")

    mgmt_l2fib_mac_limit_notify_both = Enum.YLeaf(3, "mgmt-l2fib-mac-limit-notify-both")


class MgmtL2fibMacSecAction(Enum):
    """
    MgmtL2fibMacSecAction (Enum Class)

    Mgmt l2fib mac sec action

    .. data:: not_set = 0

    	MAC Secure Action Not Set

    .. data:: restrict = 1

    	MAC Secure Action Restrict

    .. data:: none = 2

    	MAC Secure Action None

    .. data:: shutdown = 3

    	MAC Secure Action Shutdown

    """

    not_set = Enum.YLeaf(0, "not-set")

    restrict = Enum.YLeaf(1, "restrict")

    none = Enum.YLeaf(2, "none")

    shutdown = Enum.YLeaf(3, "shutdown")


class MgmtL2fibStatsData(Enum):
    """
    MgmtL2fibStatsData (Enum Class)

    Mgmt l2fib stats data

    .. data:: mgmt_l2fib_stats_type_unknown = 0

    	mgmt l2fib stats type unknown

    .. data:: mgmt_l2fib_stats_type_mcast = 1

    	mgmt l2fib stats type mcast

    """

    mgmt_l2fib_stats_type_unknown = Enum.YLeaf(0, "mgmt-l2fib-stats-type-unknown")

    mgmt_l2fib_stats_type_mcast = Enum.YLeaf(1, "mgmt-l2fib-stats-type-mcast")


class MgmtL2fibSwitching(Enum):
    """
    MgmtL2fibSwitching (Enum Class)

    Mgmt l2fib switching

    .. data:: mgmt_l2fib_switching_type_unknown = 0

    	mgmt l2fib switching type unknown

    .. data:: mgmt_l2fib_switching_type_ac_ac = 1

    	mgmt l2fib switching type ac ac

    .. data:: mgmt_l2fib_switching_type_ac_atom = 2

    	mgmt l2fib switching type ac atom

    .. data:: mgmt_l2fib_switching_type_ac_vfi = 3

    	mgmt l2fib switching type ac vfi

    .. data:: mgmt_l2fib_switching_type_ac_l2tp = 4

    	mgmt l2fib switching type ac l2tp

    .. data:: mgmt_l2fib_switching_type_atom_atom = 5

    	mgmt l2fib switching type atom atom

    .. data:: mgmt_l2fib_switching_type_vfi_atom = 6

    	mgmt l2fib switching type vfi atom

    .. data:: mgmt_l2fib_switching_type_vfi_l2tp = 7

    	mgmt l2fib switching type vfi l2tp

    .. data:: mgmt_l2fib_switching_type_l2tp_atom = 8

    	mgmt l2fib switching type l2tp atom

    .. data:: mgmt_l2fib_switching_type_l2tp_l2tp = 9

    	mgmt l2fib switching type l2tp l2tp

    .. data:: mgmt_l2fib_switching_type_max = 10

    	mgmt l2fib switching type max

    """

    mgmt_l2fib_switching_type_unknown = Enum.YLeaf(0, "mgmt-l2fib-switching-type-unknown")

    mgmt_l2fib_switching_type_ac_ac = Enum.YLeaf(1, "mgmt-l2fib-switching-type-ac-ac")

    mgmt_l2fib_switching_type_ac_atom = Enum.YLeaf(2, "mgmt-l2fib-switching-type-ac-atom")

    mgmt_l2fib_switching_type_ac_vfi = Enum.YLeaf(3, "mgmt-l2fib-switching-type-ac-vfi")

    mgmt_l2fib_switching_type_ac_l2tp = Enum.YLeaf(4, "mgmt-l2fib-switching-type-ac-l2tp")

    mgmt_l2fib_switching_type_atom_atom = Enum.YLeaf(5, "mgmt-l2fib-switching-type-atom-atom")

    mgmt_l2fib_switching_type_vfi_atom = Enum.YLeaf(6, "mgmt-l2fib-switching-type-vfi-atom")

    mgmt_l2fib_switching_type_vfi_l2tp = Enum.YLeaf(7, "mgmt-l2fib-switching-type-vfi-l2tp")

    mgmt_l2fib_switching_type_l2tp_atom = Enum.YLeaf(8, "mgmt-l2fib-switching-type-l2tp-atom")

    mgmt_l2fib_switching_type_l2tp_l2tp = Enum.YLeaf(9, "mgmt-l2fib-switching-type-l2tp-l2tp")

    mgmt_l2fib_switching_type_max = Enum.YLeaf(10, "mgmt-l2fib-switching-type-max")


class P2mpTransportState(Enum):
    """
    P2mpTransportState (Enum Class)

    P2mp transport state

    .. data:: none = 0

    	no information about the transport yet

    .. data:: ok = 1

    	transport up

    .. data:: error = 2

    	transport error

    .. data:: tunnel_down = 3

    	tunnel is down

    .. data:: max_tunnels_reached = 4

    	transport down because the maximum number of

    	tunnels is reached

    """

    none = Enum.YLeaf(0, "none")

    ok = Enum.YLeaf(1, "ok")

    error = Enum.YLeaf(2, "error")

    tunnel_down = Enum.YLeaf(3, "tunnel-down")

    max_tunnels_reached = Enum.YLeaf(4, "max-tunnels-reached")


class PreferredPathOption(Enum):
    """
    PreferredPathOption (Enum Class)

    Preferred path option

    .. data:: te_tunnel = 2

    	TE Tunnel

    .. data:: ip_tunnel = 3

    	IP Tunnel

    .. data:: tp_tunnel = 4

    	TP Tunnel

    .. data:: sr_te_policy = 5

    	SR TE Policy

    .. data:: mldp_tunnel = 6

    	mLDP Tunnel

    .. data:: mte_tunnel = 7

    	mTE Tunnel

    """

    te_tunnel = Enum.YLeaf(2, "te-tunnel")

    ip_tunnel = Enum.YLeaf(3, "ip-tunnel")

    tp_tunnel = Enum.YLeaf(4, "tp-tunnel")

    sr_te_policy = Enum.YLeaf(5, "sr-te-policy")

    mldp_tunnel = Enum.YLeaf(6, "mldp-tunnel")

    mte_tunnel = Enum.YLeaf(7, "mte-tunnel")



class L2vpnForwarding(Entity):
    """
    Show L2VPN forwarding
    
    .. attribute:: nodes
    
    	Per node L2VPN forwarding Operational data
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(L2vpnForwarding, self).__init__()
        self._top_entity = None

        self.yang_name = "l2vpn-forwarding"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", L2vpnForwarding.Nodes))])
        self._leafs = OrderedDict()

        self.nodes = L2vpnForwarding.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding"

    def __setattr__(self, name, value):
        self._perform_setattr(L2vpnForwarding, [], name, value)


    class Nodes(Entity):
        """
        Per node L2VPN forwarding Operational data
        
        .. attribute:: node
        
        	The L2VPN forwarding Operational data for a particular node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(L2vpnForwarding.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "l2vpn-forwarding"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", L2vpnForwarding.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(L2vpnForwarding.Nodes, [], name, value)


        class Node(Entity):
            """
            The L2VPN forwarding Operational data for a
            particular node
            
            .. attribute:: node_id  (key)
            
            	The identifier for the node
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: l2fibx_con_locals
            
            	The L2VPN forwarding Local LC XConnect Detail Table
            	**type**\:  :py:class:`L2fibxConLocals <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals>`
            
            .. attribute:: l2fib_mroute_summaries
            
            	Mroute Summary Table
            	**type**\:  :py:class:`L2fibMrouteSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries>`
            
            .. attribute:: l2fib_message_summary
            
            	L2FIB Message Summary information
            	**type**\:  :py:class:`L2fibMessageSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary>`
            
            .. attribute:: l2fib_mroutes
            
            	multicast information
            	**type**\:  :py:class:`L2fibMroutes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes>`
            
            .. attribute:: pbb_bmac_sa
            
            	PBB Backbone Source MAC information
            	**type**\:  :py:class:`PbbBmacSa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.PbbBmacSa>`
            
            .. attribute:: l2fib_mac_learning
            
            	The L2VPN forwarding Mac Learning Data
            	**type**\:  :py:class:`L2fibMacLearning <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning>`
            
            .. attribute:: l2fib_p2mp
            
            	p2mp information
            	**type**\:  :py:class:`L2fibP2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibP2mp>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_egresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware egress Table
            	**type**\:  :py:class:`L2fibEvpnInclMCastHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses>`
            
            .. attribute:: l2fibmac_hardware_ingresses
            
            	Bridge Hardware Ingress information
            	**type**\:  :py:class:`L2fibmacHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses>`
            
            .. attribute:: l2fib_evpn_ip4macs
            
            	EVPN IPv4\-MAC Table
            	**type**\:  :py:class:`L2fibEvpnIp4macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs>`
            
            .. attribute:: l2fib_pwhe_main_ports
            
            	PWHE Main\-port table
            	**type**\:  :py:class:`L2fibPwheMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts>`
            
            .. attribute:: l2fib_dhcp_binding_count
            
            	DHCP binding forwarding total count
            	**type**\:  :py:class:`L2fibDhcpBindingCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingCount>`
            
            .. attribute:: l2fib_bridge_domains
            
            	Bridge Domain forwarding detail
            	**type**\:  :py:class:`L2fibBridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains>`
            
            .. attribute:: l2fib_mstp_summaries
            
            	MSTP Summary Table
            	**type**\:  :py:class:`L2fibMstpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpSummaries>`
            
            .. attribute:: l2fib_resource_availability
            
            	Resource availability information
            	**type**\:  :py:class:`L2fibResourceAvailability <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibResourceAvailability>`
            
            .. attribute:: l2fibmac_hardware_egresses
            
            	Bridge Hardware Egress information
            	**type**\:  :py:class:`L2fibmacHardwareEgresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses>`
            
            .. attribute:: l2fibx_con_l2tpv2s
            
            	The L2VPN forwarding XConnect L2TPv2 Detail Table
            	**type**\:  :py:class:`L2fibxConL2tpv2s <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s>`
            
            .. attribute:: l2fib_mroute_ipv6s
            
            	multicast information
            	**type**\:  :py:class:`L2fibMrouteIpv6s <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s>`
            
            .. attribute:: l2fib_mon_sess_x_cons
            
            	The L2VPN forwarding Monitor Session XConnect Information
            	**type**\:  :py:class:`L2fibMonSessXCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons>`
            
            .. attribute:: l2fib_mmrp_summaries
            
            	Mmrp Summary Table
            	**type**\:  :py:class:`L2fibMmrpSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries>`
            
            .. attribute:: l2fib_pw_groups
            
            	PW Group Table Information
            	**type**\:  :py:class:`L2fibPwGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibPwGroups>`
            
            .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingresses
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast hardware ingress Table
            	**type**\:  :py:class:`L2fibEvpnInclMCastHardwareIngresses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses>`
            
            .. attribute:: l2fib_dhcp_binding_details
            
            	DHCP binding forwarding detail
            	**type**\:  :py:class:`L2fibDhcpBindingDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails>`
            
            .. attribute:: l2fibx_cons
            
            	The L2VPN forwarding XConnect Detail Table
            	**type**\:  :py:class:`L2fibxCons <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons>`
            
            .. attribute:: l2fib_main_interfaces
            
            	Main Interface
            	**type**\:  :py:class:`L2fibMainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces>`
            
            .. attribute:: l2fib_mstp_details
            
            	MSTP Detail Table
            	**type**\:  :py:class:`L2fibMstpDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpDetails>`
            
            .. attribute:: l2fib_l2tp
            
            	L2TP
            	**type**\:  :py:class:`L2fibL2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp>`
            
            .. attribute:: l2fib_g8032
            
            	G8032 information
            	**type**\:  :py:class:`L2fibG8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032>`
            
            .. attribute:: l2fib_bridge_ports
            
            	Bridge Port forwarding detail
            	**type**\:  :py:class:`L2fibBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts>`
            
            .. attribute:: l2fibmac_details
            
            	Bridge MAC detail information
            	**type**\:  :py:class:`L2fibmacDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails>`
            
            .. attribute:: l2fib_bridge_domain_names
            
            	Bridge Domain forwarding detail
            	**type**\:  :py:class:`L2fibBridgeDomainNames <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames>`
            
            .. attribute:: l2fib_mroute_ports
            
            	multicast bridge port information 
            	**type**\:  :py:class:`L2fibMroutePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts>`
            
            .. attribute:: l2fib_summary
            
            	L2FIB Summary information
            	**type**\:  :py:class:`L2fibSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary>`
            
            .. attribute:: l2fib_nve_peers
            
            	NVE Peer Table
            	**type**\:  :py:class:`L2fibNvePeers <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibNvePeers>`
            
            .. attribute:: l2fib_mmrps
            
            	mmmrp information
            	**type**\:  :py:class:`L2fibMmrps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps>`
            
            .. attribute:: l2fib_evpn_ip6macs
            
            	EVPN IPv6\-MAC Table
            	**type**\:  :py:class:`L2fibEvpnIp6macs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs>`
            
            .. attribute:: l2fib_dhcp_binding_summaries
            
            	DHCP binding forwarding summary
            	**type**\:  :py:class:`L2fibDhcpBindingSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries>`
            
            .. attribute:: l2fib_evpn_incl_m_casts
            
            	L2VPN forwarding bridge\-domain evpn inclusive multicast Table
            	**type**\:  :py:class:`L2fibEvpnInclMCasts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnForwarding.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_id']
                self._child_classes = OrderedDict([("l2fibx-con-locals", ("l2fibx_con_locals", L2vpnForwarding.Nodes.Node.L2fibxConLocals)), ("l2fib-mroute-summaries", ("l2fib_mroute_summaries", L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries)), ("l2fib-message-summary", ("l2fib_message_summary", L2vpnForwarding.Nodes.Node.L2fibMessageSummary)), ("l2fib-mroutes", ("l2fib_mroutes", L2vpnForwarding.Nodes.Node.L2fibMroutes)), ("pbb-bmac-sa", ("pbb_bmac_sa", L2vpnForwarding.Nodes.Node.PbbBmacSa)), ("l2fib-mac-learning", ("l2fib_mac_learning", L2vpnForwarding.Nodes.Node.L2fibMacLearning)), ("l2fib-p2mp", ("l2fib_p2mp", L2vpnForwarding.Nodes.Node.L2fibP2mp)), ("l2fib-evpn-incl-m-cast-hardware-egresses", ("l2fib_evpn_incl_m_cast_hardware_egresses", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses)), ("l2fibmac-hardware-ingresses", ("l2fibmac_hardware_ingresses", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses)), ("l2fib-evpn-ip4macs", ("l2fib_evpn_ip4macs", L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs)), ("l2fib-pwhe-main-ports", ("l2fib_pwhe_main_ports", L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts)), ("l2fib-dhcp-binding-count", ("l2fib_dhcp_binding_count", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingCount)), ("l2fib-bridge-domains", ("l2fib_bridge_domains", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains)), ("l2fib-mstp-summaries", ("l2fib_mstp_summaries", L2vpnForwarding.Nodes.Node.L2fibMstpSummaries)), ("l2fib-resource-availability", ("l2fib_resource_availability", L2vpnForwarding.Nodes.Node.L2fibResourceAvailability)), ("l2fibmac-hardware-egresses", ("l2fibmac_hardware_egresses", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses)), ("l2fibx-con-l2tpv2s", ("l2fibx_con_l2tpv2s", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s)), ("l2fib-mroute-ipv6s", ("l2fib_mroute_ipv6s", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s)), ("l2fib-mon-sess-x-cons", ("l2fib_mon_sess_x_cons", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons)), ("l2fib-mmrp-summaries", ("l2fib_mmrp_summaries", L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries)), ("l2fib-pw-groups", ("l2fib_pw_groups", L2vpnForwarding.Nodes.Node.L2fibPwGroups)), ("l2fib-evpn-incl-m-cast-hardware-ingresses", ("l2fib_evpn_incl_m_cast_hardware_ingresses", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses)), ("l2fib-dhcp-binding-details", ("l2fib_dhcp_binding_details", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails)), ("l2fibx-cons", ("l2fibx_cons", L2vpnForwarding.Nodes.Node.L2fibxCons)), ("l2fib-main-interfaces", ("l2fib_main_interfaces", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces)), ("l2fib-mstp-details", ("l2fib_mstp_details", L2vpnForwarding.Nodes.Node.L2fibMstpDetails)), ("l2fib-l2tp", ("l2fib_l2tp", L2vpnForwarding.Nodes.Node.L2fibL2tp)), ("l2fib-g8032", ("l2fib_g8032", L2vpnForwarding.Nodes.Node.L2fibG8032)), ("l2fib-bridge-ports", ("l2fib_bridge_ports", L2vpnForwarding.Nodes.Node.L2fibBridgePorts)), ("l2fibmac-details", ("l2fibmac_details", L2vpnForwarding.Nodes.Node.L2fibmacDetails)), ("l2fib-bridge-domain-names", ("l2fib_bridge_domain_names", L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames)), ("l2fib-mroute-ports", ("l2fib_mroute_ports", L2vpnForwarding.Nodes.Node.L2fibMroutePorts)), ("l2fib-summary", ("l2fib_summary", L2vpnForwarding.Nodes.Node.L2fibSummary)), ("l2fib-nve-peers", ("l2fib_nve_peers", L2vpnForwarding.Nodes.Node.L2fibNvePeers)), ("l2fib-mmrps", ("l2fib_mmrps", L2vpnForwarding.Nodes.Node.L2fibMmrps)), ("l2fib-evpn-ip6macs", ("l2fib_evpn_ip6macs", L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs)), ("l2fib-dhcp-binding-summaries", ("l2fib_dhcp_binding_summaries", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries)), ("l2fib-evpn-incl-m-casts", ("l2fib_evpn_incl_m_casts", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts))])
                self._leafs = OrderedDict([
                    ('node_id', YLeaf(YType.str, 'node-id')),
                ])
                self.node_id = None

                self.l2fibx_con_locals = L2vpnForwarding.Nodes.Node.L2fibxConLocals()
                self.l2fibx_con_locals.parent = self
                self._children_name_map["l2fibx_con_locals"] = "l2fibx-con-locals"

                self.l2fib_mroute_summaries = L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries()
                self.l2fib_mroute_summaries.parent = self
                self._children_name_map["l2fib_mroute_summaries"] = "l2fib-mroute-summaries"

                self.l2fib_message_summary = L2vpnForwarding.Nodes.Node.L2fibMessageSummary()
                self.l2fib_message_summary.parent = self
                self._children_name_map["l2fib_message_summary"] = "l2fib-message-summary"

                self.l2fib_mroutes = L2vpnForwarding.Nodes.Node.L2fibMroutes()
                self.l2fib_mroutes.parent = self
                self._children_name_map["l2fib_mroutes"] = "l2fib-mroutes"

                self.pbb_bmac_sa = L2vpnForwarding.Nodes.Node.PbbBmacSa()
                self.pbb_bmac_sa.parent = self
                self._children_name_map["pbb_bmac_sa"] = "pbb-bmac-sa"

                self.l2fib_mac_learning = L2vpnForwarding.Nodes.Node.L2fibMacLearning()
                self.l2fib_mac_learning.parent = self
                self._children_name_map["l2fib_mac_learning"] = "l2fib-mac-learning"

                self.l2fib_p2mp = L2vpnForwarding.Nodes.Node.L2fibP2mp()
                self.l2fib_p2mp.parent = self
                self._children_name_map["l2fib_p2mp"] = "l2fib-p2mp"

                self.l2fib_evpn_incl_m_cast_hardware_egresses = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses()
                self.l2fib_evpn_incl_m_cast_hardware_egresses.parent = self
                self._children_name_map["l2fib_evpn_incl_m_cast_hardware_egresses"] = "l2fib-evpn-incl-m-cast-hardware-egresses"

                self.l2fibmac_hardware_ingresses = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses()
                self.l2fibmac_hardware_ingresses.parent = self
                self._children_name_map["l2fibmac_hardware_ingresses"] = "l2fibmac-hardware-ingresses"

                self.l2fib_evpn_ip4macs = L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs()
                self.l2fib_evpn_ip4macs.parent = self
                self._children_name_map["l2fib_evpn_ip4macs"] = "l2fib-evpn-ip4macs"

                self.l2fib_pwhe_main_ports = L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts()
                self.l2fib_pwhe_main_ports.parent = self
                self._children_name_map["l2fib_pwhe_main_ports"] = "l2fib-pwhe-main-ports"

                self.l2fib_dhcp_binding_count = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingCount()
                self.l2fib_dhcp_binding_count.parent = self
                self._children_name_map["l2fib_dhcp_binding_count"] = "l2fib-dhcp-binding-count"

                self.l2fib_bridge_domains = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains()
                self.l2fib_bridge_domains.parent = self
                self._children_name_map["l2fib_bridge_domains"] = "l2fib-bridge-domains"

                self.l2fib_mstp_summaries = L2vpnForwarding.Nodes.Node.L2fibMstpSummaries()
                self.l2fib_mstp_summaries.parent = self
                self._children_name_map["l2fib_mstp_summaries"] = "l2fib-mstp-summaries"

                self.l2fib_resource_availability = L2vpnForwarding.Nodes.Node.L2fibResourceAvailability()
                self.l2fib_resource_availability.parent = self
                self._children_name_map["l2fib_resource_availability"] = "l2fib-resource-availability"

                self.l2fibmac_hardware_egresses = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses()
                self.l2fibmac_hardware_egresses.parent = self
                self._children_name_map["l2fibmac_hardware_egresses"] = "l2fibmac-hardware-egresses"

                self.l2fibx_con_l2tpv2s = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s()
                self.l2fibx_con_l2tpv2s.parent = self
                self._children_name_map["l2fibx_con_l2tpv2s"] = "l2fibx-con-l2tpv2s"

                self.l2fib_mroute_ipv6s = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s()
                self.l2fib_mroute_ipv6s.parent = self
                self._children_name_map["l2fib_mroute_ipv6s"] = "l2fib-mroute-ipv6s"

                self.l2fib_mon_sess_x_cons = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons()
                self.l2fib_mon_sess_x_cons.parent = self
                self._children_name_map["l2fib_mon_sess_x_cons"] = "l2fib-mon-sess-x-cons"

                self.l2fib_mmrp_summaries = L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries()
                self.l2fib_mmrp_summaries.parent = self
                self._children_name_map["l2fib_mmrp_summaries"] = "l2fib-mmrp-summaries"

                self.l2fib_pw_groups = L2vpnForwarding.Nodes.Node.L2fibPwGroups()
                self.l2fib_pw_groups.parent = self
                self._children_name_map["l2fib_pw_groups"] = "l2fib-pw-groups"

                self.l2fib_evpn_incl_m_cast_hardware_ingresses = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses()
                self.l2fib_evpn_incl_m_cast_hardware_ingresses.parent = self
                self._children_name_map["l2fib_evpn_incl_m_cast_hardware_ingresses"] = "l2fib-evpn-incl-m-cast-hardware-ingresses"

                self.l2fib_dhcp_binding_details = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails()
                self.l2fib_dhcp_binding_details.parent = self
                self._children_name_map["l2fib_dhcp_binding_details"] = "l2fib-dhcp-binding-details"

                self.l2fibx_cons = L2vpnForwarding.Nodes.Node.L2fibxCons()
                self.l2fibx_cons.parent = self
                self._children_name_map["l2fibx_cons"] = "l2fibx-cons"

                self.l2fib_main_interfaces = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces()
                self.l2fib_main_interfaces.parent = self
                self._children_name_map["l2fib_main_interfaces"] = "l2fib-main-interfaces"

                self.l2fib_mstp_details = L2vpnForwarding.Nodes.Node.L2fibMstpDetails()
                self.l2fib_mstp_details.parent = self
                self._children_name_map["l2fib_mstp_details"] = "l2fib-mstp-details"

                self.l2fib_l2tp = L2vpnForwarding.Nodes.Node.L2fibL2tp()
                self.l2fib_l2tp.parent = self
                self._children_name_map["l2fib_l2tp"] = "l2fib-l2tp"

                self.l2fib_g8032 = L2vpnForwarding.Nodes.Node.L2fibG8032()
                self.l2fib_g8032.parent = self
                self._children_name_map["l2fib_g8032"] = "l2fib-g8032"

                self.l2fib_bridge_ports = L2vpnForwarding.Nodes.Node.L2fibBridgePorts()
                self.l2fib_bridge_ports.parent = self
                self._children_name_map["l2fib_bridge_ports"] = "l2fib-bridge-ports"

                self.l2fibmac_details = L2vpnForwarding.Nodes.Node.L2fibmacDetails()
                self.l2fibmac_details.parent = self
                self._children_name_map["l2fibmac_details"] = "l2fibmac-details"

                self.l2fib_bridge_domain_names = L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames()
                self.l2fib_bridge_domain_names.parent = self
                self._children_name_map["l2fib_bridge_domain_names"] = "l2fib-bridge-domain-names"

                self.l2fib_mroute_ports = L2vpnForwarding.Nodes.Node.L2fibMroutePorts()
                self.l2fib_mroute_ports.parent = self
                self._children_name_map["l2fib_mroute_ports"] = "l2fib-mroute-ports"

                self.l2fib_summary = L2vpnForwarding.Nodes.Node.L2fibSummary()
                self.l2fib_summary.parent = self
                self._children_name_map["l2fib_summary"] = "l2fib-summary"

                self.l2fib_nve_peers = L2vpnForwarding.Nodes.Node.L2fibNvePeers()
                self.l2fib_nve_peers.parent = self
                self._children_name_map["l2fib_nve_peers"] = "l2fib-nve-peers"

                self.l2fib_mmrps = L2vpnForwarding.Nodes.Node.L2fibMmrps()
                self.l2fib_mmrps.parent = self
                self._children_name_map["l2fib_mmrps"] = "l2fib-mmrps"

                self.l2fib_evpn_ip6macs = L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs()
                self.l2fib_evpn_ip6macs.parent = self
                self._children_name_map["l2fib_evpn_ip6macs"] = "l2fib-evpn-ip6macs"

                self.l2fib_dhcp_binding_summaries = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries()
                self.l2fib_dhcp_binding_summaries.parent = self
                self._children_name_map["l2fib_dhcp_binding_summaries"] = "l2fib-dhcp-binding-summaries"

                self.l2fib_evpn_incl_m_casts = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts()
                self.l2fib_evpn_incl_m_casts.parent = self
                self._children_name_map["l2fib_evpn_incl_m_casts"] = "l2fib-evpn-incl-m-casts"
                self._segment_path = lambda: "node" + "[node-id='" + str(self.node_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpn-forwarding/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnForwarding.Nodes.Node, ['node_id'], name, value)


            class L2fibxConLocals(Entity):
                """
                The L2VPN forwarding Local LC XConnect Detail
                Table
                
                .. attribute:: l2fibx_con_local
                
                	Specify Sub Ifh
                	**type**\: list of  		 :py:class:`L2fibxConLocal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals, self).__init__()

                    self.yang_name = "l2fibx-con-locals"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibx-con-local", ("l2fibx_con_local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal))])
                    self._leafs = OrderedDict()

                    self.l2fibx_con_local = YList(self)
                    self._segment_path = lambda: "l2fibx-con-locals"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals, [], name, value)


                class L2fibxConLocal(Entity):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Base>`
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\: str
                    
                    	**length:** 0..72
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\: bool
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:  :py:class:`MgmtL2fibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibSwitching>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal, self).__init__()

                        self.yang_name = "l2fibx-con-local"
                        self.yang_parent_name = "l2fibx-con-locals"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Base)), ("segment1", ("segment1", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1)), ("segment2", ("segment2", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2))])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('xcon_name', YLeaf(YType.str, 'xcon-name')),
                            ('bound', YLeaf(YType.boolean, 'bound')),
                            ('switching_type', YLeaf(YType.enumeration, 'switching-type')),
                        ])
                        self.interface_name = None
                        self.xcon_name = None
                        self.bound = None
                        self.switching_type = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment1 = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"

                        self.segment2 = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._segment_path = lambda: "l2fibx-con-local" + "[interface-name='" + str(self.interface_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal, ['interface_name', 'xcon_name', 'bound', 'switching_type'], name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con-local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:  :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con-local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn)), ("monitor-session", ("monitor_session", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.monitor_session = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.Base>`
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:  :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.Base)), ("pbb-union", ("pbb_union", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('core_pbb_evpn_enabled', YLeaf(YType.boolean, 'core-pbb-evpn-enabled')),
                                ])
                                self.bound = None
                                self.forward_class = None
                                self.core_pbb_evpn_enabled = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.pbb_union = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb, ['bound', 'forward_class', 'core_pbb_evpn_enabled'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Core))])
                                    self._leafs = OrderedDict([
                                        ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                                    ])
                                    self.pbb_type = None

                                    self.edge = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"

                                    self.core = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._segment_path = lambda: "pbb-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion, ['pbb_type'], name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\: bool
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_configured', YLeaf(YType.boolean, 'mac-configured')),
                                            ('mac', YLeaf(YType.str, 'mac')),
                                        ])
                                        self.mac_configured = None
                                        self.mac = None
                                        self._segment_path = lambda: "edge"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Edge, ['mac_configured', 'mac'], name, value)


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ])
                                        self.vlan_id = None
                                        self._segment_path = lambda: "core"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pbb.PbbUnion.Core, ['vlan_id'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni.Base>`
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ingress_replication
                            
                            	Ingress Replication supported on VNI
                            	**type**\: bool
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni.Base))])
                                self._leafs = OrderedDict([
                                    ('srcip', YLeaf(YType.str, 'srcip')),
                                    ('mcastip', YLeaf(YType.str, 'mcastip')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                    ('encap', YLeaf(YType.uint32, 'encap')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('source_vtep_if', YLeaf(YType.str, 'source-vtep-if')),
                                    ('any_cast_ip', YLeaf(YType.str, 'any-cast-ip')),
                                    ('anycast_mcast_ip', YLeaf(YType.str, 'anycast-mcast-ip')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('vx_lan_mode', YLeaf(YType.uint32, 'vx-lan-mode')),
                                ])
                                self.srcip = None
                                self.mcastip = None
                                self.bound = None
                                self.parent_if = None
                                self.encap = None
                                self.udp_port = None
                                self.source_vtep_if = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.ingress_replication = None
                                self.vx_lan_mode = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni, ['srcip', 'mcastip', 'bound', 'parent_if', 'encap', 'udp_port', 'source_vtep_if', 'any_cast_ip', 'anycast_mcast_ip', 'ingress_replication', 'vx_lan_mode'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn.Base))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ])
                                self.bound = None
                                self.evi = None
                                self.forward_class = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn, ['bound', 'evi', 'forward_class'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\: str
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession.Base))])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('session_name', YLeaf(YType.str, 'session-name')),
                                    ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                ])
                                self.xcid = None
                                self.session_name = None
                                self.hardware_information = None
                                self.bound = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "monitor-session"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession, ['xcid', 'session_name', 'hardware_information', 'bound'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment1.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:  :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:  :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con-local"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac)), ("bp", ("bp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp)), ("fxs", ("fxs", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.bp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"

                            self.fxs = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Base>`
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:  :py:class:`P2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.P2mp>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Base)), ("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper)), ("p2mp", ("p2mp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.P2mp))])
                                self._leafs = OrderedDict([
                                    ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                    ('shg_id', YLeaf(YType.uint32, 'shg-id')),
                                    ('msti_pointer', YLeaf(YType.uint32, 'msti-pointer')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                                ])
                                self.bridge_id = None
                                self.shg_id = None
                                self.msti_pointer = None
                                self.segment_type = None
                                self.mvrp_sequence_number = None
                                self.learn_key = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.oper = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"

                                self.p2mp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.P2mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._segment_path = lambda: "bp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp, ['bridge_id', 'shg_id', 'msti_pointer', 'segment_type', 'mvrp_sequence_number', 'learn_key'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ])
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None

                                    self.operational_information = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._segment_path = lambda: "oper"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC limit percentage recovery threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\: bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\: bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature))])
                                        self._leafs = OrderedDict([
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                            ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                            ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                            ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                            ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                            ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                            ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                            ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                            ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                            ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                            ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                            ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                            ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                            ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                            ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                            ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                            ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                            ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                            ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                            ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                            ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                            ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                            ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                            ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                            ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                            ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                            ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                            ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                            ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                            ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                            ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                            ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                            ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                            ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                            ('msti', YLeaf(YType.uint32, 'msti')),
                                            ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                            ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                        ])
                                        self.mtu = None
                                        self.mac_aging_time = None
                                        self.mac_limit = None
                                        self.number_of_macs = None
                                        self.admin_disabled = None
                                        self.flooding_disabled = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_limit_action = None
                                        self.mac_limit_threshold = None
                                        self.mac_learning_disabled = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_limit_notification_type = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.mac_aging_type = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.is_dai_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.stp_participating = None
                                        self.bvi_configured = None
                                        self.is_bvi_up = None
                                        self.is_vni_enabled = None
                                        self.is_evpn_enabled = None
                                        self.unknown_unicast_flooding_disabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_evpn_flow_label = None
                                        self.is_evpn_cw_disable = None
                                        self.msti = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_igmp_snoop_enabled = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                                        self.feature = YList(self)
                                        self._segment_path = lambda: "operational-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld))])
                                            self._leafs = OrderedDict([
                                                ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                            ])
                                            self.feature_type = None

                                            self.dhcp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"

                                            self.igmp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"

                                            self.mld = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._segment_path = lambda: "feature"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "dhcp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "igmp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "mld"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                            class P2mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:  :py:class:`L2vpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPtree>`
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.P2mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                        ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                        ('tunnel_id', YLeaf(YType.uint16, 'tunnel-id')),
                                        ('p2mp_id', YLeaf(YType.uint16, 'p2mp-id')),
                                        ('extended_tunnel_id', YLeaf(YType.str, 'extended-tunnel-id')),
                                        ('ptree_owner_lmrib', YLeaf(YType.boolean, 'ptree-owner-lmrib')),
                                    ])
                                    self.ptree_type = None
                                    self.lsm_id = None
                                    self.tunnel_id = None
                                    self.p2mp_id = None
                                    self.extended_tunnel_id = None
                                    self.ptree_owner_lmrib = None
                                    self._segment_path = lambda: "p2mp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Bp.P2mp, ['ptree_type', 'lsm_id', 'tunnel_id', 'p2mp_id', 'extended_tunnel_id', 'ptree_owner_lmrib'], name, value)


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs.Base))])
                                self._leafs = OrderedDict([
                                    ('fxs_id', YLeaf(YType.uint32, 'fxs-id')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                ])
                                self.fxs_id = None
                                self.segment_type = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "fxs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs, ['fxs_id', 'segment_type'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConLocals.L2fibxConLocal.Segment2.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


            class L2fibMrouteSummaries(Entity):
                """
                Mroute Summary Table
                
                .. attribute:: l2fib_mroute_summary
                
                	Multicast Summary Information
                	**type**\: list of  		 :py:class:`L2fibMrouteSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries, self).__init__()

                    self.yang_name = "l2fib-mroute-summaries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mroute-summary", ("l2fib_mroute_summary", L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary))])
                    self._leafs = OrderedDict()

                    self.l2fib_mroute_summary = YList(self)
                    self._segment_path = lambda: "l2fib-mroute-summaries"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries, [], name, value)


                class L2fibMrouteSummary(Entity):
                    """
                    Multicast Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\: str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of  		 :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary.Message>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary, self).__init__()

                        self.yang_name = "l2fib-mroute-summary"
                        self.yang_parent_name = "l2fib-mroute-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("message", ("message", L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary.Message))])
                        self._leafs = OrderedDict([
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                            ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                            ('multicast_update', YLeaf(YType.uint32, 'multicast-update')),
                            ('multicast_update_dropped', YLeaf(YType.uint32, 'multicast-update-dropped')),
                            ('number_of_routes', YLeaf(YType.uint32, 'number-of-routes')),
                            ('number_of_routes_with_ole_offload', YLeaf(YType.uint32, 'number-of-routes-with-ole-offload')),
                            ('number_of_mroute_add', YLeaf(YType.uint32, 'number-of-mroute-add')),
                            ('number_mroute_deleted', YLeaf(YType.uint32, 'number-mroute-deleted')),
                            ('number_mroutes_deleted_all', YLeaf(YType.uint32, 'number-mroutes-deleted-all')),
                            ('number_mroute_delete_drop', YLeaf(YType.uint32, 'number-mroute-delete-drop')),
                            ('number_mroute_all_delete_drop', YLeaf(YType.uint32, 'number-mroute-all-delete-drop')),
                            ('number_xid_add', YLeaf(YType.uint32, 'number-xid-add')),
                            ('number_xid_deleted', YLeaf(YType.uint32, 'number-xid-deleted')),
                            ('number_of_xid', YLeaf(YType.uint32, 'number-of-xid')),
                            ('stale_deleted', YLeaf(YType.uint32, 'stale-deleted')),
                            ('stale_xid_deleted', YLeaf(YType.uint32, 'stale-xid-deleted')),
                        ])
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_name = None
                        self.bridge_domain_id = None
                        self.multicast_update = None
                        self.multicast_update_dropped = None
                        self.number_of_routes = None
                        self.number_of_routes_with_ole_offload = None
                        self.number_of_mroute_add = None
                        self.number_mroute_deleted = None
                        self.number_mroutes_deleted_all = None
                        self.number_mroute_delete_drop = None
                        self.number_mroute_all_delete_drop = None
                        self.number_xid_add = None
                        self.number_xid_deleted = None
                        self.number_of_xid = None
                        self.stale_deleted = None
                        self.stale_xid_deleted = None

                        self.message = YList(self)
                        self._segment_path = lambda: "l2fib-mroute-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary, ['bd_group_name', 'bd_name', 'bridge_domain_name', 'bridge_domain_id', 'multicast_update', 'multicast_update_dropped', 'number_of_routes', 'number_of_routes_with_ole_offload', 'number_of_mroute_add', 'number_mroute_deleted', 'number_mroutes_deleted_all', 'number_mroute_delete_drop', 'number_mroute_all_delete_drop', 'number_xid_add', 'number_xid_deleted', 'number_of_xid', 'stale_deleted', 'stale_xid_deleted'], name, value)


                    class Message(Entity):
                        """
                        Global Message Information
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary.Message, self).__init__()

                            self.yang_name = "message"
                            self.yang_parent_name = "l2fib-mroute-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('messgae_count', YLeaf(YType.uint32, 'messgae-count')),
                                ('time', YLeaf(YType.str, 'time')),
                                ('information1', YLeaf(YType.uint32, 'information1')),
                                ('information2', YLeaf(YType.uint32, 'information2')),
                            ])
                            self.messgae_count = None
                            self.time = None
                            self.information1 = None
                            self.information2 = None
                            self._segment_path = lambda: "message"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteSummaries.L2fibMrouteSummary.Message, ['messgae_count', 'time', 'information1', 'information2'], name, value)


            class L2fibMessageSummary(Entity):
                """
                L2FIB Message Summary information
                
                .. attribute:: event_history
                
                	Event history buffer
                	**type**\:  :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory>`
                
                .. attribute:: round_trip_delay
                
                	Round\-Trip delay
                	**type**\:  :py:class:`RoundTripDelay <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay>`
                
                .. attribute:: message
                
                	message
                	**type**\: list of  		 :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.Message>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary, self).__init__()

                    self.yang_name = "l2fib-message-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("event-history", ("event_history", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory)), ("round-trip-delay", ("round_trip_delay", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay)), ("message", ("message", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.Message))])
                    self._leafs = OrderedDict()

                    self.event_history = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory()
                    self.event_history.parent = self
                    self._children_name_map["event_history"] = "event-history"

                    self.round_trip_delay = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay()
                    self.round_trip_delay.parent = self
                    self._children_name_map["round_trip_delay"] = "round-trip-delay"

                    self.message = YList(self)
                    self._segment_path = lambda: "l2fib-message-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary, [], name, value)


                class EventHistory(Entity):
                    """
                    Event history buffer
                    
                    .. attribute:: event_neighbor_entry
                    
                    	number of item in the array
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: extra_information1
                    
                    	extra information1
                    	**type**\: list of  		 :py:class:`ExtraInformation1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation1>`
                    
                    .. attribute:: extra_information2
                    
                    	extra information2
                    	**type**\: list of  		 :py:class:`ExtraInformation2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation2>`
                    
                    .. attribute:: event_entry
                    
                    	event entry
                    	**type**\: list of  		 :py:class:`EventEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.EventEntry>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "l2fib-message-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("extra-information1", ("extra_information1", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation1)), ("extra-information2", ("extra_information2", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation2)), ("event-entry", ("event_entry", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.EventEntry))])
                        self._leafs = OrderedDict([
                            ('event_neighbor_entry', YLeaf(YType.uint16, 'event-neighbor-entry')),
                        ])
                        self.event_neighbor_entry = None

                        self.extra_information1 = YList(self)
                        self.extra_information2 = YList(self)
                        self.event_entry = YList(self)
                        self._segment_path = lambda: "event-history"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory, ['event_neighbor_entry'], name, value)


                    class ExtraInformation1(Entity):
                        """
                        extra information1
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation1, self).__init__()

                            self.yang_name = "extra-information1"
                            self.yang_parent_name = "event-history"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.uint32, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "extra-information1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation1, ['entry'], name, value)


                    class ExtraInformation2(Entity):
                        """
                        extra information2
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation2, self).__init__()

                            self.yang_name = "extra-information2"
                            self.yang_parent_name = "event-history"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.uint32, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "extra-information2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.ExtraInformation2, ['entry'], name, value)


                    class EventEntry(Entity):
                        """
                        event entry
                        
                        .. attribute:: event_time
                        
                        	The real timestamp of the event
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: event_type
                        
                        	Event type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: event_many
                        
                        	Multiple event instance flag
                        	**type**\: bool
                        
                        .. attribute:: event_sticky
                        
                        	Unwrittable flag
                        	**type**\: bool
                        
                        .. attribute:: event_flags
                        
                        	base flag object
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.EventEntry, self).__init__()

                            self.yang_name = "event-entry"
                            self.yang_parent_name = "event-history"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('event_time', YLeaf(YType.str, 'event-time')),
                                ('event_type', YLeaf(YType.uint8, 'event-type')),
                                ('event_many', YLeaf(YType.boolean, 'event-many')),
                                ('event_sticky', YLeaf(YType.boolean, 'event-sticky')),
                                ('event_flags', YLeaf(YType.uint32, 'event-flags')),
                            ])
                            self.event_time = None
                            self.event_type = None
                            self.event_many = None
                            self.event_sticky = None
                            self.event_flags = None
                            self._segment_path = lambda: "event-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.EventHistory.EventEntry, ['event_time', 'event_type', 'event_many', 'event_sticky', 'event_flags'], name, value)


                class RoundTripDelay(Entity):
                    """
                    Round\-Trip delay
                    
                    .. attribute:: bdxc_rtd
                    
                    	bdxc rtd
                    	**type**\:  :py:class:`BdxcRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.BdxcRtd>`
                    
                    .. attribute:: aging_rtd
                    
                    	aging rtd
                    	**type**\:  :py:class:`AgingRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.AgingRtd>`
                    
                    .. attribute:: punt_rtd
                    
                    	punt rtd
                    	**type**\:  :py:class:`PuntRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PuntRtd>`
                    
                    .. attribute:: lock_rtd
                    
                    	lock rtd
                    	**type**\:  :py:class:`LockRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.LockRtd>`
                    
                    .. attribute:: platform_init_rtd
                    
                    	platform init rtd
                    	**type**\:  :py:class:`PlatformInitRtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PlatformInitRtd>`
                    
                    .. attribute:: rtd_max_obj_type
                    
                    	RTD MAX OBJTYPE
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: create
                    
                    	create
                    	**type**\: list of  		 :py:class:`Create <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Create>`
                    
                    .. attribute:: modify
                    
                    	modify
                    	**type**\: list of  		 :py:class:`Modify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Modify>`
                    
                    .. attribute:: delete
                    
                    	delete
                    	**type**\: list of  		 :py:class:`Delete <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Delete>`
                    
                    .. attribute:: bind
                    
                    	bind
                    	**type**\: list of  		 :py:class:`Bind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Bind>`
                    
                    .. attribute:: unbind
                    
                    	unbind
                    	**type**\: list of  		 :py:class:`Unbind <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Unbind>`
                    
                    .. attribute:: mac_flush
                    
                    	mac flush
                    	**type**\: list of  		 :py:class:`MacFlush <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.MacFlush>`
                    
                    .. attribute:: pirtd
                    
                    	pirtd
                    	**type**\: list of  		 :py:class:`Pirtd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Pirtd>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay, self).__init__()

                        self.yang_name = "round-trip-delay"
                        self.yang_parent_name = "l2fib-message-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bdxc-rtd", ("bdxc_rtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.BdxcRtd)), ("aging-rtd", ("aging_rtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.AgingRtd)), ("punt-rtd", ("punt_rtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PuntRtd)), ("lock-rtd", ("lock_rtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.LockRtd)), ("platform-init-rtd", ("platform_init_rtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PlatformInitRtd)), ("create", ("create", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Create)), ("modify", ("modify", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Modify)), ("delete", ("delete", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Delete)), ("bind", ("bind", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Bind)), ("unbind", ("unbind", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Unbind)), ("mac-flush", ("mac_flush", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.MacFlush)), ("pirtd", ("pirtd", L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Pirtd))])
                        self._leafs = OrderedDict([
                            ('rtd_max_obj_type', YLeaf(YType.uint32, 'rtd-max-obj-type')),
                        ])
                        self.rtd_max_obj_type = None

                        self.bdxc_rtd = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.BdxcRtd()
                        self.bdxc_rtd.parent = self
                        self._children_name_map["bdxc_rtd"] = "bdxc-rtd"

                        self.aging_rtd = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.AgingRtd()
                        self.aging_rtd.parent = self
                        self._children_name_map["aging_rtd"] = "aging-rtd"

                        self.punt_rtd = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PuntRtd()
                        self.punt_rtd.parent = self
                        self._children_name_map["punt_rtd"] = "punt-rtd"

                        self.lock_rtd = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.LockRtd()
                        self.lock_rtd.parent = self
                        self._children_name_map["lock_rtd"] = "lock-rtd"

                        self.platform_init_rtd = L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PlatformInitRtd()
                        self.platform_init_rtd.parent = self
                        self._children_name_map["platform_init_rtd"] = "platform-init-rtd"

                        self.create = YList(self)
                        self.modify = YList(self)
                        self.delete = YList(self)
                        self.bind = YList(self)
                        self.unbind = YList(self)
                        self.mac_flush = YList(self)
                        self.pirtd = YList(self)
                        self._segment_path = lambda: "round-trip-delay"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay, ['rtd_max_obj_type'], name, value)


                    class BdxcRtd(Entity):
                        """
                        bdxc rtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.BdxcRtd, self).__init__()

                            self.yang_name = "bdxc-rtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "bdxc-rtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.BdxcRtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class AgingRtd(Entity):
                        """
                        aging rtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.AgingRtd, self).__init__()

                            self.yang_name = "aging-rtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "aging-rtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.AgingRtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class PuntRtd(Entity):
                        """
                        punt rtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PuntRtd, self).__init__()

                            self.yang_name = "punt-rtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "punt-rtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PuntRtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class LockRtd(Entity):
                        """
                        lock rtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.LockRtd, self).__init__()

                            self.yang_name = "lock-rtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "lock-rtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.LockRtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class PlatformInitRtd(Entity):
                        """
                        platform init rtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PlatformInitRtd, self).__init__()

                            self.yang_name = "platform-init-rtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "platform-init-rtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.PlatformInitRtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Create(Entity):
                        """
                        create
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Create, self).__init__()

                            self.yang_name = "create"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "create"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Create, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Modify(Entity):
                        """
                        modify
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Modify, self).__init__()

                            self.yang_name = "modify"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "modify"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Modify, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Delete(Entity):
                        """
                        delete
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Delete, self).__init__()

                            self.yang_name = "delete"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "delete"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Delete, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Bind(Entity):
                        """
                        bind
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Bind, self).__init__()

                            self.yang_name = "bind"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "bind"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Bind, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Unbind(Entity):
                        """
                        unbind
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Unbind, self).__init__()

                            self.yang_name = "unbind"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "unbind"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Unbind, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class MacFlush(Entity):
                        """
                        mac flush
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.MacFlush, self).__init__()

                            self.yang_name = "mac-flush"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "mac-flush"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.MacFlush, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                    class Pirtd(Entity):
                        """
                        pirtd
                        
                        .. attribute:: number_pd_update
                        
                        	The number of time PD is called
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pd_update_zero
                        
                        	The number of time PD is called in 0 time
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: minimum_round_trip_delay
                        
                        	The minimum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: maximum_round_trip_delay
                        
                        	The maximum round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: average_round_trip_delay
                        
                        	The average round trip delay
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Pirtd, self).__init__()

                            self.yang_name = "pirtd"
                            self.yang_parent_name = "round-trip-delay"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('number_pd_update', YLeaf(YType.uint32, 'number-pd-update')),
                                ('number_pd_update_zero', YLeaf(YType.uint32, 'number-pd-update-zero')),
                                ('minimum_round_trip_delay', YLeaf(YType.uint64, 'minimum-round-trip-delay')),
                                ('maximum_round_trip_delay', YLeaf(YType.uint64, 'maximum-round-trip-delay')),
                                ('average_round_trip_delay', YLeaf(YType.uint64, 'average-round-trip-delay')),
                            ])
                            self.number_pd_update = None
                            self.number_pd_update_zero = None
                            self.minimum_round_trip_delay = None
                            self.maximum_round_trip_delay = None
                            self.average_round_trip_delay = None
                            self._segment_path = lambda: "pirtd"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.RoundTripDelay.Pirtd, ['number_pd_update', 'number_pd_update_zero', 'minimum_round_trip_delay', 'maximum_round_trip_delay', 'average_round_trip_delay'], name, value)


                class Message(Entity):
                    """
                    message
                    
                    .. attribute:: messgae_count
                    
                    	number of message
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: time
                    
                    	Time string
                    	**type**\: str
                    
                    	**length:** 0..32
                    
                    .. attribute:: information1
                    
                    	Extra info 1
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: information2
                    
                    	Extra info 2
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.Message, self).__init__()

                        self.yang_name = "message"
                        self.yang_parent_name = "l2fib-message-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('messgae_count', YLeaf(YType.uint32, 'messgae-count')),
                            ('time', YLeaf(YType.str, 'time')),
                            ('information1', YLeaf(YType.uint32, 'information1')),
                            ('information2', YLeaf(YType.uint32, 'information2')),
                        ])
                        self.messgae_count = None
                        self.time = None
                        self.information1 = None
                        self.information2 = None
                        self._segment_path = lambda: "message"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMessageSummary.Message, ['messgae_count', 'time', 'information1', 'information2'], name, value)


            class L2fibMroutes(Entity):
                """
                multicast information
                
                .. attribute:: l2fib_mroute
                
                	Bridge Domain Multicast Information
                	**type**\: list of  		 :py:class:`L2fibMroute <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMroutes, self).__init__()

                    self.yang_name = "l2fib-mroutes"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mroute", ("l2fib_mroute", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute))])
                    self._leafs = OrderedDict()

                    self.l2fib_mroute = YList(self)
                    self._segment_path = lambda: "l2fib-mroutes"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes, [], name, value)


                class L2fibMroute(Entity):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:  :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.MulticastBaseInformation>`
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.SourcePrefix>`
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:  :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats>`
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:  :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\: str
                    
                    	**length:** 0..66
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute, self).__init__()

                        self.yang_name = "l2fib-mroute"
                        self.yang_parent_name = "l2fib-mroutes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-base-information", ("multicast_base_information", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.MulticastBaseInformation)), ("source-prefix", ("source_prefix", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.SourcePrefix)), ("destination-prefix", ("destination_prefix", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.DestinationPrefix)), ("forward-stats", ("forward_stats", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats)), ("irb-info", ("irb_info", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo))])
                        self._leafs = OrderedDict([
                            ('source', YLeaf(YType.str, 'source')),
                            ('group', YLeaf(YType.str, 'group')),
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('xid_count', YLeaf(YType.uint16, 'xid-count')),
                            ('platform_data_length', YLeaf(YType.uint8, 'platform-data-length')),
                            ('platform_data', YLeaf(YType.str, 'platform-data')),
                            ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                        ])
                        self.source = None
                        self.group = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_id = None
                        self.xid_count = None
                        self.platform_data_length = None
                        self.platform_data = None
                        self.hardware_information = None
                        self.bridge_domain_name = None

                        self.multicast_base_information = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"

                        self.source_prefix = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"

                        self.destination_prefix = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"

                        self.forward_stats = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"

                        self.irb_info = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._segment_path = lambda: "l2fib-mroute"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute, ['source', 'group', 'bd_group_name', 'bd_name', 'bridge_id', 'xid_count', 'platform_data_length', 'platform_data', 'hardware_information', 'bridge_domain_name'], name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "multicast-base-information"


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "source-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.SourcePrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "destination-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.DestinationPrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:  :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forward-stat", ("forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat))])
                            self._leafs = OrderedDict()

                            self.forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._segment_path = lambda: "forward-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats, [], name, value)


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:  :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast>`
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:  :py:class:`MgmtL2fibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibStatsData>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mulicast", ("mulicast", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast))])
                                self._leafs = OrderedDict([
                                    ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ])
                                self.data_type = None

                                self.mulicast = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._segment_path = lambda: "forward-stat"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat, ['data_type'], name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:  :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:  :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:  :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:  :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:  :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("multicast-forward-stat", ("multicast_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat)), ("received-stat", ("received_stat", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat)), ("punt", ("punt", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Punt)), ("drop", ("drop", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Drop)), ("multicast-core-forward-stat", ("multicast_core_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat)), ("core-received-stat", ("core_received_stat", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat))])
                                    self._leafs = OrderedDict()

                                    self.multicast_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"

                                    self.received_stat = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"

                                    self.punt = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"

                                    self.drop = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"

                                    self.multicast_core_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"

                                    self.core_received_stat = L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._segment_path = lambda: "mulicast"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast, [], name, value)


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, ['packets', 'bytes'], name, value)


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.ReceivedStat, ['packets', 'bytes'], name, value)


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "punt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Punt, ['packets', 'bytes'], name, value)


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.Drop, ['packets', 'bytes'], name, value)


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-core-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, ['packets', 'bytes'], name, value)


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "core-received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, ['packets', 'bytes'], name, value)


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\: list of  		 :py:class:`IrbPlatData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo.IrbPlatData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mroute"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("irb-plat-data", ("irb_plat_data", L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo.IrbPlatData))])
                            self._leafs = OrderedDict([
                                ('mxid_ac_interface_handle', YLeaf(YType.str, 'mxid-ac-interface-handle')),
                                ('mxid_pw_id', YLeaf(YType.uint32, 'mxid-pw-id')),
                                ('mxid_next_hop_address', YLeaf(YType.str, 'mxid-next-hop-address')),
                                ('irb_plat_data_len', YLeaf(YType.uint16, 'irb-plat-data-len')),
                            ])
                            self.mxid_ac_interface_handle = None
                            self.mxid_pw_id = None
                            self.mxid_next_hop_address = None
                            self.irb_plat_data_len = None

                            self.irb_plat_data = YList(self)
                            self._segment_path = lambda: "irb-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo, ['mxid_ac_interface_handle', 'mxid_pw_id', 'mxid_next_hop_address', 'irb_plat_data_len'], name, value)


                        class IrbPlatData(Entity):
                            """
                            IRB platform data
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo.IrbPlatData, self).__init__()

                                self.yang_name = "irb-plat-data"
                                self.yang_parent_name = "irb-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "irb-plat-data"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutes.L2fibMroute.IrbInfo.IrbPlatData, ['entry'], name, value)


            class PbbBmacSa(Entity):
                """
                PBB Backbone Source MAC information
                
                .. attribute:: configured
                
                	BMAC SA configured
                	**type**\: bool
                
                .. attribute:: mac
                
                	Backbone Source Mac
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: chassis_mac
                
                	Chassis Mac
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.PbbBmacSa, self).__init__()

                    self.yang_name = "pbb-bmac-sa"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('configured', YLeaf(YType.boolean, 'configured')),
                        ('mac', YLeaf(YType.str, 'mac')),
                        ('chassis_mac', YLeaf(YType.str, 'chassis-mac')),
                    ])
                    self.configured = None
                    self.mac = None
                    self.chassis_mac = None
                    self._segment_path = lambda: "pbb-bmac-sa"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.PbbBmacSa, ['configured', 'mac', 'chassis_mac'], name, value)


            class L2fibMacLearning(Entity):
                """
                The L2VPN forwarding Mac Learning Data
                
                .. attribute:: l2fib_mac_learning_macs
                
                	The L2VPN forwarding All Mac Learning Table
                	**type**\:  :py:class:`L2fibMacLearningMacs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs>`
                
                .. attribute:: l2fib_mac_learning_mac_ipv4s
                
                	The L2VPN forwarding Mac IPV4 Learning Table
                	**type**\:  :py:class:`L2fibMacLearningMacIpv4s <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s>`
                
                .. attribute:: l2fib_mac_learning_mac_ipv6s
                
                	The L2VPN forwarding Mac IPV6 Learning Table
                	**type**\:  :py:class:`L2fibMacLearningMacIpv6s <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMacLearning, self).__init__()

                    self.yang_name = "l2fib-mac-learning"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mac-learning-macs", ("l2fib_mac_learning_macs", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs)), ("l2fib-mac-learning-mac-ipv4s", ("l2fib_mac_learning_mac_ipv4s", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s)), ("l2fib-mac-learning-mac-ipv6s", ("l2fib_mac_learning_mac_ipv6s", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s))])
                    self._leafs = OrderedDict()

                    self.l2fib_mac_learning_macs = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs()
                    self.l2fib_mac_learning_macs.parent = self
                    self._children_name_map["l2fib_mac_learning_macs"] = "l2fib-mac-learning-macs"

                    self.l2fib_mac_learning_mac_ipv4s = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s()
                    self.l2fib_mac_learning_mac_ipv4s.parent = self
                    self._children_name_map["l2fib_mac_learning_mac_ipv4s"] = "l2fib-mac-learning-mac-ipv4s"

                    self.l2fib_mac_learning_mac_ipv6s = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s()
                    self.l2fib_mac_learning_mac_ipv6s.parent = self
                    self._children_name_map["l2fib_mac_learning_mac_ipv6s"] = "l2fib-mac-learning-mac-ipv6s"
                    self._segment_path = lambda: "l2fib-mac-learning"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning, [], name, value)


                class L2fibMacLearningMacs(Entity):
                    """
                    The L2VPN forwarding All Mac Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac
                    
                    	The attributes for a particular learned Mac Route
                    	**type**\: list of  		 :py:class:`L2fibMacLearningMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs, self).__init__()

                        self.yang_name = "l2fib-mac-learning-macs"
                        self.yang_parent_name = "l2fib-mac-learning"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2fib-mac-learning-mac", ("l2fib_mac_learning_mac", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac))])
                        self._leafs = OrderedDict()

                        self.l2fib_mac_learning_mac = YList(self)
                        self._segment_path = lambda: "l2fib-mac-learning-macs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs, [], name, value)


                    class L2fibMacLearningMac(Entity):
                        """
                        The attributes for a particular learned Mac
                        Route
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Addr>`
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:  :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Nhaddr>`
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac"
                            self.yang_parent_name = "l2fib-mac-learning-macs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("addr", ("addr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Addr)), ("nhaddr", ("nhaddr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Nhaddr))])
                            self._leafs = OrderedDict([
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('address', YLeaf(YType.str, 'address')),
                                ('bdid', YLeaf(YType.uint32, 'bdid')),
                                ('mac_address', YLeaf(YType.str, 'mac-address')),
                                ('element_type', YLeaf(YType.uint8, 'element-type')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('topology_id', YLeaf(YType.uint32, 'topology-id')),
                                ('mac_address_xr', YLeaf(YType.str, 'mac-address-xr')),
                                ('interface_handle_xr', YLeaf(YType.uint32, 'interface-handle-xr')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('generation', YLeaf(YType.uint8, 'generation')),
                            ])
                            self.interface_handle = None
                            self.address = None
                            self.bdid = None
                            self.mac_address = None
                            self.element_type = None
                            self.node_id = None
                            self.topology_id = None
                            self.mac_address_xr = None
                            self.interface_handle_xr = None
                            self.xcid = None
                            self.generation = None

                            self.addr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"

                            self.nhaddr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._segment_path = lambda: "l2fib-mac-learning-mac"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac, ['interface_handle', 'address', 'bdid', 'mac_address', 'element_type', 'node_id', 'topology_id', 'mac_address_xr', 'interface_handle_xr', 'xcid', 'generation'], name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "addr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Addr, ['addr_type', 'ip'], name, value)


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "nhaddr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacs.L2fibMacLearningMac.Nhaddr, ['addr_type', 'ip'], name, value)


                class L2fibMacLearningMacIpv4s(Entity):
                    """
                    The L2VPN forwarding Mac IPV4 Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac_ipv4
                    
                    	The attributes for a particular learned IPV4 Mac Route
                    	**type**\: list of  		 :py:class:`L2fibMacLearningMacIpv4 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s, self).__init__()

                        self.yang_name = "l2fib-mac-learning-mac-ipv4s"
                        self.yang_parent_name = "l2fib-mac-learning"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2fib-mac-learning-mac-ipv4", ("l2fib_mac_learning_mac_ipv4", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4))])
                        self._leafs = OrderedDict()

                        self.l2fib_mac_learning_mac_ipv4 = YList(self)
                        self._segment_path = lambda: "l2fib-mac-learning-mac-ipv4s"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s, [], name, value)


                    class L2fibMacLearningMacIpv4(Entity):
                        """
                        The attributes for a particular learned IPV4
                        Mac Route
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Addr>`
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:  :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Nhaddr>`
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac-ipv4"
                            self.yang_parent_name = "l2fib-mac-learning-mac-ipv4s"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("addr", ("addr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Addr)), ("nhaddr", ("nhaddr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Nhaddr))])
                            self._leafs = OrderedDict([
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('address', YLeaf(YType.str, 'address')),
                                ('bdid', YLeaf(YType.uint32, 'bdid')),
                                ('mac_address', YLeaf(YType.str, 'mac-address')),
                                ('element_type', YLeaf(YType.uint8, 'element-type')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('topology_id', YLeaf(YType.uint32, 'topology-id')),
                                ('mac_address_xr', YLeaf(YType.str, 'mac-address-xr')),
                                ('interface_handle_xr', YLeaf(YType.uint32, 'interface-handle-xr')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('generation', YLeaf(YType.uint8, 'generation')),
                            ])
                            self.interface_handle = None
                            self.address = None
                            self.bdid = None
                            self.mac_address = None
                            self.element_type = None
                            self.node_id = None
                            self.topology_id = None
                            self.mac_address_xr = None
                            self.interface_handle_xr = None
                            self.xcid = None
                            self.generation = None

                            self.addr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"

                            self.nhaddr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._segment_path = lambda: "l2fib-mac-learning-mac-ipv4"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4, ['interface_handle', 'address', 'bdid', 'mac_address', 'element_type', 'node_id', 'topology_id', 'mac_address_xr', 'interface_handle_xr', 'xcid', 'generation'], name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "addr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Addr, ['addr_type', 'ip'], name, value)


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv4"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "nhaddr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv4s.L2fibMacLearningMacIpv4.Nhaddr, ['addr_type', 'ip'], name, value)


                class L2fibMacLearningMacIpv6s(Entity):
                    """
                    The L2VPN forwarding Mac IPV6 Learning Table
                    
                    .. attribute:: l2fib_mac_learning_mac_ipv6
                    
                    	The attributes for a particular learned IPV6 Mac Route
                    	**type**\: list of  		 :py:class:`L2fibMacLearningMacIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s, self).__init__()

                        self.yang_name = "l2fib-mac-learning-mac-ipv6s"
                        self.yang_parent_name = "l2fib-mac-learning"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2fib-mac-learning-mac-ipv6", ("l2fib_mac_learning_mac_ipv6", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6))])
                        self._leafs = OrderedDict()

                        self.l2fib_mac_learning_mac_ipv6 = YList(self)
                        self._segment_path = lambda: "l2fib-mac-learning-mac-ipv6s"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s, [], name, value)


                    class L2fibMacLearningMacIpv6(Entity):
                        """
                        The attributes for a particular learned IPV6
                        Mac Route
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: address
                        
                        	IP Address
                        	**type**\: union of the below types:
                        
                        		**type**\: str
                        
                        			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        		**type**\: str
                        
                        			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: addr
                        
                        	IP Address
                        	**type**\:  :py:class:`Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Addr>`
                        
                        .. attribute:: nhaddr
                        
                        	IP Address
                        	**type**\:  :py:class:`Nhaddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Nhaddr>`
                        
                        .. attribute:: element_type
                        
                        	Element Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: topology_id
                        
                        	Topology ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_address_xr
                        
                        	MAC Address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: interface_handle_xr
                        
                        	Interface Handle
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	Cross\-connect Identifier
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: generation
                        
                        	HW MAC generation
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6, self).__init__()

                            self.yang_name = "l2fib-mac-learning-mac-ipv6"
                            self.yang_parent_name = "l2fib-mac-learning-mac-ipv6s"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("addr", ("addr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Addr)), ("nhaddr", ("nhaddr", L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Nhaddr))])
                            self._leafs = OrderedDict([
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('address', YLeaf(YType.str, 'address')),
                                ('bdid', YLeaf(YType.uint32, 'bdid')),
                                ('mac_address', YLeaf(YType.str, 'mac-address')),
                                ('element_type', YLeaf(YType.uint8, 'element-type')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('topology_id', YLeaf(YType.uint32, 'topology-id')),
                                ('mac_address_xr', YLeaf(YType.str, 'mac-address-xr')),
                                ('interface_handle_xr', YLeaf(YType.uint32, 'interface-handle-xr')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('generation', YLeaf(YType.uint8, 'generation')),
                            ])
                            self.interface_handle = None
                            self.address = None
                            self.bdid = None
                            self.mac_address = None
                            self.element_type = None
                            self.node_id = None
                            self.topology_id = None
                            self.mac_address_xr = None
                            self.interface_handle_xr = None
                            self.xcid = None
                            self.generation = None

                            self.addr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Addr()
                            self.addr.parent = self
                            self._children_name_map["addr"] = "addr"

                            self.nhaddr = L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Nhaddr()
                            self.nhaddr.parent = self
                            self._children_name_map["nhaddr"] = "nhaddr"
                            self._segment_path = lambda: "l2fib-mac-learning-mac-ipv6"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6, ['interface_handle', 'address', 'bdid', 'mac_address', 'element_type', 'node_id', 'topology_id', 'mac_address_xr', 'interface_handle_xr', 'xcid', 'generation'], name, value)


                        class Addr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Addr, self).__init__()

                                self.yang_name = "addr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "addr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Addr, ['addr_type', 'ip'], name, value)


                        class Nhaddr(Entity):
                            """
                            IP Address
                            
                            .. attribute:: addr_type
                            
                            	addr type
                            	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                            
                            .. attribute:: ip
                            
                            	ip
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Nhaddr, self).__init__()

                                self.yang_name = "nhaddr"
                                self.yang_parent_name = "l2fib-mac-learning-mac-ipv6"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                    ('ip', YLeaf(YType.str, 'ip')),
                                ])
                                self.addr_type = None
                                self.ip = None
                                self._segment_path = lambda: "nhaddr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMacLearning.L2fibMacLearningMacIpv6s.L2fibMacLearningMacIpv6.Nhaddr, ['addr_type', 'ip'], name, value)


            class L2fibP2mp(Entity):
                """
                p2mp information
                
                .. attribute:: ptrees
                
                	ptree information
                	**type**\:  :py:class:`Ptrees <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibP2mp, self).__init__()

                    self.yang_name = "l2fib-p2mp"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ptrees", ("ptrees", L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees))])
                    self._leafs = OrderedDict()

                    self.ptrees = L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees()
                    self.ptrees.parent = self
                    self._children_name_map["ptrees"] = "ptrees"
                    self._segment_path = lambda: "l2fib-p2mp"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibP2mp, [], name, value)


                class Ptrees(Entity):
                    """
                    ptree information
                    
                    .. attribute:: ptree
                    
                    	P2MP PTree Information
                    	**type**\: list of  		 :py:class:`Ptree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees.Ptree>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees, self).__init__()

                        self.yang_name = "ptrees"
                        self.yang_parent_name = "l2fib-p2mp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ptree", ("ptree", L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees.Ptree))])
                        self._leafs = OrderedDict()

                        self.ptree = YList(self)
                        self._segment_path = lambda: "ptrees"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees, [], name, value)


                    class Ptree(Entity):
                        """
                        P2MP PTree Information
                        
                        .. attribute:: ptree_type
                        
                        	PTree Type
                        	**type**\:  :py:class:`L2vpnp2mpPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnp2mpPtree>`
                        
                        .. attribute:: lsm_id
                        
                        	LSM Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	Tunnel Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_id
                        
                        	P2MP Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extended_tunnel_id
                        
                        	Extended Tunnel Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: lsm_id_xr
                        
                        	MLDP Lsm Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id_xr
                        
                        	RSVPTE Tunnel Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_id_xr
                        
                        	RSVPTE P2MP Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: extended_tunnel_id_xr
                        
                        	RSVPTE Ext Tunnel Id
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees.Ptree, self).__init__()

                            self.yang_name = "ptree"
                            self.yang_parent_name = "ptrees"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                ('p2mp_id', YLeaf(YType.uint32, 'p2mp-id')),
                                ('extended_tunnel_id', YLeaf(YType.uint32, 'extended-tunnel-id')),
                                ('lsm_id_xr', YLeaf(YType.uint32, 'lsm-id-xr')),
                                ('tunnel_id_xr', YLeaf(YType.uint32, 'tunnel-id-xr')),
                                ('p2mp_id_xr', YLeaf(YType.uint32, 'p2mp-id-xr')),
                                ('extended_tunnel_id_xr', YLeaf(YType.str, 'extended-tunnel-id-xr')),
                            ])
                            self.ptree_type = None
                            self.lsm_id = None
                            self.tunnel_id = None
                            self.p2mp_id = None
                            self.extended_tunnel_id = None
                            self.lsm_id_xr = None
                            self.tunnel_id_xr = None
                            self.p2mp_id_xr = None
                            self.extended_tunnel_id_xr = None
                            self._segment_path = lambda: "ptree"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibP2mp.Ptrees.Ptree, ['ptree_type', 'lsm_id', 'tunnel_id', 'p2mp_id', 'extended_tunnel_id', 'lsm_id_xr', 'tunnel_id_xr', 'p2mp_id_xr', 'extended_tunnel_id_xr'], name, value)


            class L2fibEvpnInclMCastHardwareEgresses(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware egress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_egress
                
                	Specify bridge domain name
                	**type**\: list of  		 :py:class:`L2fibEvpnInclMCastHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-cast-hardware-egresses"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast-hardware-egress", ("l2fib_evpn_incl_m_cast_hardware_egress", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress))])
                    self._leafs = OrderedDict()

                    self.l2fib_evpn_incl_m_cast_hardware_egress = YList(self)
                    self._segment_path = lambda: "l2fib-evpn-incl-m-cast-hardware-egresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses, [], name, value)


                class L2fibEvpnInclMCastHardwareEgress(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  (key)
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:  :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.McastReplicationList>`
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:  :py:class:`L2fibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast-hardware-egress"
                        self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['bd_name']
                        self._child_classes = OrderedDict([("mcast-replication-list", ("mcast_replication_list", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.McastReplicationList)), ("l2fib-evpn-incl-m-cast-oles", ("l2fib_evpn_incl_m_cast_oles", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles))])
                        self._leafs = OrderedDict([
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                        ])
                        self.bd_name = None

                        self.mcast_replication_list = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"

                        self.l2fib_evpn_incl_m_cast_oles = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._segment_path = lambda: "l2fib-evpn-incl-m-cast-hardware-egress" + "[bd-name='" + str(self.bd_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress, ['bd_name'], name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\: str
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	xcid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                                ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                            ])
                            self.bridge_domain_name = None
                            self.bridge_domain_id = None
                            self.xcid = None
                            self.is_bound = None
                            self._segment_path = lambda: "mcast-replication-list"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.McastReplicationList, ['bridge_domain_name', 'bridge_domain_id', 'xcid', 'is_bound'], name, value)


                    class L2fibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of  		 :py:class:`L2fibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast-ole", ("l2fib_evpn_incl_m_cast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle))])
                            self._leafs = OrderedDict()

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)
                            self._segment_path = lambda: "l2fib-evpn-incl-m-cast-oles"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles, [], name, value)


                        class L2fibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  (key)
                            
                            	Next Hop Address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['next_hop_address']
                                self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                ])
                                self.next_hop_address = None
                                self.is_bound = None
                                self.next_hop_valid = None

                                self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + str(self.next_hop_address) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, ['next_hop_address', 'is_bound', 'next_hop_valid'], name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                        ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                    ])
                                    self.next_hop_ipv6_addr = None
                                    self.mcast_label = None
                                    self._segment_path = lambda: "mcast-ole"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareEgresses.L2fibEvpnInclMCastHardwareEgress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


            class L2fibmacHardwareIngresses(Entity):
                """
                Bridge Hardware Ingress information
                
                .. attribute:: l2fibmac_hardware_ingress
                
                	MAC Hardware Ingress information
                	**type**\: list of  		 :py:class:`L2fibmacHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses, self).__init__()

                    self.yang_name = "l2fibmac-hardware-ingresses"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibmac-hardware-ingress", ("l2fibmac_hardware_ingress", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress))])
                    self._leafs = OrderedDict()

                    self.l2fibmac_hardware_ingress = YList(self)
                    self._segment_path = lambda: "l2fibmac-hardware-ingresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses, [], name, value)


                class L2fibmacHardwareIngress(Entity):
                    """
                    MAC Hardware Ingress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..27
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Base>`
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment>`
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:  :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx>`
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop>`
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\: str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\: str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\: bool
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\: bool
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\: bool
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress, self).__init__()

                        self.yang_name = "l2fibmac-hardware-ingress"
                        self.yang_parent_name = "l2fibmac-hardware-ingresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Base)), ("segment", ("segment", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment)), ("evpn-ctx", ("evpn_ctx", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop))])
                        self._leafs = OrderedDict([
                            ('address', YLeaf(YType.str, 'address')),
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('platform_is_hw_learn', YLeaf(YType.uint8, 'platform-is-hw-learn')),
                            ('node_id', YLeaf(YType.str, 'node-id')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('bmac_configured', YLeaf(YType.boolean, 'bmac-configured')),
                            ('vni_l3_flag', YLeaf(YType.boolean, 'vni-l3-flag')),
                            ('pbb_bmac', YLeaf(YType.str, 'pbb-bmac')),
                            ('l3_encapsulationvlan_id', YLeaf(YType.uint16, 'l3-encapsulationvlan-id')),
                            ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                            ('peer_vtep_ip', YLeaf(YType.str, 'peer-vtep-ip')),
                            ('flag_extension', YLeaf(YType.uint16, 'flag-extension')),
                            ('vni', YLeaf(YType.uint32, 'vni')),
                        ])
                        self.address = None
                        self.group_name = None
                        self.name = None
                        self.platform_is_hw_learn = None
                        self.node_id = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.bmac_configured = None
                        self.vni_l3_flag = None
                        self.pbb_bmac = None
                        self.l3_encapsulationvlan_id = None
                        self.next_hop_valid = None
                        self.peer_vtep_ip = None
                        self.flag_extension = None
                        self.vni = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"

                        self.evpn_ctx = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"

                        self.next_hop = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "l2fibmac-hardware-ingress"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress, ['address', 'group_name', 'name', 'platform_is_hw_learn', 'node_id', 'bridge_domain_name', 'bridge_id', 'bmac_configured', 'vni_l3_flag', 'pbb_bmac', 'l3_encapsulationvlan_id', 'next_hop_valid', 'peer_vtep_ip', 'flag_extension', 'vni'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Evpn>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Evpn)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ])
                                self.interface_handle = None
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Ac, ['interface_handle'], name, value)


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pbb, ['xcid'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                ])
                                self.xcid = None
                                self.parent_if = None
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Vni, ['xcid', 'parent_if'], name, value)


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Evpn, ['xcid'], name, value)


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                ])
                                self.pw_id = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.Segment.Pw, ['pw_id', 'next_hop_address', 'pseudo_wire_id_type'], name, value)


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx.McastOle>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx.McastOle))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                ('bp_ifh', YLeaf(YType.str, 'bp-ifh')),
                            ])
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.bp_ifh = None

                            self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._segment_path = lambda: "evpn-ctx"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx, ['data_type', 'esi_id', 'local_label', 'bp_ifh'], name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                    ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                ])
                                self.next_hop_ipv6_addr = None
                                self.mcast_label = None
                                self._segment_path = lambda: "mcast-ole"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.EvpnCtx.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop.Base>`
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_address_v6
                        
                        	NHOP Address V6
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ecd_plaformt_data_valid
                        
                        	Is Platform ECD Data Valid
                        	**type**\: bool
                        
                        .. attribute:: ecd_platform_data_length
                        
                        	Platform ECD Data Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop.Base))])
                            self._leafs = OrderedDict([
                                ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                ('children_count', YLeaf(YType.uint32, 'children-count')),
                            ])
                            self.next_hop_address = None
                            self.next_hop_address_v6 = None
                            self.next_hop_internal_label = None
                            self.ecd_plaformt_data_valid = None
                            self.ecd_platform_data_length = None
                            self.children_count = None

                            self.base = L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "next-hop"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareIngresses.L2fibmacHardwareIngress.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "base"


            class L2fibEvpnIp4macs(Entity):
                """
                EVPN IPv4\-MAC Table
                
                .. attribute:: l2fib_evpn_ip4mac
                
                	The attributes for a particular EVPN IPv4\-MAC Entry
                	**type**\: list of  		 :py:class:`L2fibEvpnIp4mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs, self).__init__()

                    self.yang_name = "l2fib-evpn-ip4macs"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-evpn-ip4mac", ("l2fib_evpn_ip4mac", L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac))])
                    self._leafs = OrderedDict()

                    self.l2fib_evpn_ip4mac = YList(self)
                    self._segment_path = lambda: "l2fib-evpn-ip4macs"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs, [], name, value)


                class L2fibEvpnIp4mac(Entity):
                    """
                    The attributes for a particular EVPN IPv4\-MAC
                    Entry
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\: bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:  :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac.IpAddressXr>`
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac, self).__init__()

                        self.yang_name = "l2fib-evpn-ip4mac"
                        self.yang_parent_name = "l2fib-evpn-ip4macs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip-address-xr", ("ip_address_xr", L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac.IpAddressXr))])
                        self._leafs = OrderedDict([
                            ('bdid', YLeaf(YType.uint32, 'bdid')),
                            ('ip_address', YLeaf(YType.str, 'ip-address')),
                            ('is_local', YLeaf(YType.boolean, 'is-local')),
                            ('mac_address', YLeaf(YType.str, 'mac-address')),
                            ('bdid_xr', YLeaf(YType.uint32, 'bdid-xr')),
                            ('mac_address_xr', YLeaf(YType.str, 'mac-address-xr')),
                            ('arp_nd_sync_pending', YLeaf(YType.boolean, 'arp-nd-sync-pending')),
                            ('arp_nd_probe_pending', YLeaf(YType.boolean, 'arp-nd-probe-pending')),
                            ('arp_nd_delete_pending', YLeaf(YType.boolean, 'arp-nd-delete-pending')),
                            ('is_local_xr', YLeaf(YType.boolean, 'is-local-xr')),
                        ])
                        self.bdid = None
                        self.ip_address = None
                        self.is_local = None
                        self.mac_address = None
                        self.bdid_xr = None
                        self.mac_address_xr = None
                        self.arp_nd_sync_pending = None
                        self.arp_nd_probe_pending = None
                        self.arp_nd_delete_pending = None
                        self.is_local_xr = None

                        self.ip_address_xr = L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self._children_name_map["ip_address_xr"] = "ip-address-xr"
                        self._segment_path = lambda: "l2fib-evpn-ip4mac"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac, ['bdid', 'ip_address', 'is_local', 'mac_address', 'bdid_xr', 'mac_address_xr', 'arp_nd_sync_pending', 'arp_nd_probe_pending', 'arp_nd_delete_pending', 'is_local_xr'], name, value)


                    class IpAddressXr(Entity):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac.IpAddressXr, self).__init__()

                            self.yang_name = "ip-address-xr"
                            self.yang_parent_name = "l2fib-evpn-ip4mac"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                ('ip', YLeaf(YType.str, 'ip')),
                            ])
                            self.addr_type = None
                            self.ip = None
                            self._segment_path = lambda: "ip-address-xr"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp4macs.L2fibEvpnIp4mac.IpAddressXr, ['addr_type', 'ip'], name, value)


            class L2fibPwheMainPorts(Entity):
                """
                PWHE Main\-port table
                
                .. attribute:: l2fib_pwhe_main_port
                
                	PWHE Main\-port
                	**type**\: list of  		 :py:class:`L2fibPwheMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts.L2fibPwheMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts, self).__init__()

                    self.yang_name = "l2fib-pwhe-main-ports"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-pwhe-main-port", ("l2fib_pwhe_main_port", L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts.L2fibPwheMainPort))])
                    self._leafs = OrderedDict()

                    self.l2fib_pwhe_main_port = YList(self)
                    self._segment_path = lambda: "l2fib-pwhe-main-ports"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts, [], name, value)


                class L2fibPwheMainPort(Entity):
                    """
                    PWHE Main\-port
                    
                    .. attribute:: interface_name  (key)
                    
                    	PWHE Main\-port
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\: bool
                    
                    .. attribute:: next_hop_address
                    
                    	Next Hop Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pseudo_wire_type
                    
                    	Pseudowire type
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: generic_interface_list_id
                    
                    	Generic Interface List ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: internal_label
                    
                    	Internal label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_label
                    
                    	Remote label
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: control_word_enabled
                    
                    	Control Word Enabled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts.L2fibPwheMainPort, self).__init__()

                        self.yang_name = "l2fib-pwhe-main-port"
                        self.yang_parent_name = "l2fib-pwhe-main-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                            ('pseudo_wire_type', YLeaf(YType.uint32, 'pseudo-wire-type')),
                            ('generic_interface_list_id', YLeaf(YType.uint32, 'generic-interface-list-id')),
                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                            ('control_word_enabled', YLeaf(YType.boolean, 'control-word-enabled')),
                        ])
                        self.interface_name = None
                        self.next_hop_valid = None
                        self.next_hop_address = None
                        self.pseudo_wire_type = None
                        self.generic_interface_list_id = None
                        self.internal_label = None
                        self.remote_label = None
                        self.control_word_enabled = None
                        self._segment_path = lambda: "l2fib-pwhe-main-port" + "[interface-name='" + str(self.interface_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibPwheMainPorts.L2fibPwheMainPort, ['interface_name', 'next_hop_valid', 'next_hop_address', 'pseudo_wire_type', 'generic_interface_list_id', 'internal_label', 'remote_label', 'control_word_enabled'], name, value)


            class L2fibDhcpBindingCount(Entity):
                """
                DHCP binding forwarding total count
                
                .. attribute:: bindings
                
                	DHCP binding count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingCount, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-count"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('bindings', YLeaf(YType.uint32, 'bindings')),
                    ])
                    self.bindings = None
                    self._segment_path = lambda: "l2fib-dhcp-binding-count"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingCount, ['bindings'], name, value)


            class L2fibBridgeDomains(Entity):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain
                
                	Specify Bridge Domain Name
                	**type**\: list of  		 :py:class:`L2fibBridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains, self).__init__()

                    self.yang_name = "l2fib-bridge-domains"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-bridge-domain", ("l2fib_bridge_domain", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain))])
                    self._leafs = OrderedDict()

                    self.l2fib_bridge_domain = YList(self)
                    self._segment_path = lambda: "l2fib-bridge-domains"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains, [], name, value)


                class L2fibBridgeDomain(Entity):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Base>`
                    
                    .. attribute:: oper
                    
                    	Operational information
                    	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper>`
                    
                    .. attribute:: bd_pbb_union
                    
                    	Union of bridge Edge and Core info
                    	**type**\:  :py:class:`BdPbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion>`
                    
                    .. attribute:: bvi_info
                    
                    	BVI Information
                    	**type**\:  :py:class:`BviInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BviInfo>`
                    
                    .. attribute:: p2mppw_info
                    
                    	P2MP PW Information
                    	**type**\:  :py:class:`P2mppwInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\: str
                    
                    .. attribute:: shg_count
                    
                    	Number of split horizon groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_type
                    
                    	Bridge Type
                    	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain, self).__init__()

                        self.yang_name = "l2fib-bridge-domain"
                        self.yang_parent_name = "l2fib-bridge-domains"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Base)), ("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper)), ("bd-pbb-union", ("bd_pbb_union", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion)), ("bvi-info", ("bvi_info", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BviInfo)), ("p2mppw-info", ("p2mppw_info", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo))])
                        self._leafs = OrderedDict([
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                            ('number_of_hwmac', YLeaf(YType.uint32, 'number-of-hwmac')),
                            ('number_of_swmac', YLeaf(YType.uint32, 'number-of-swmac')),
                            ('bridge_name', YLeaf(YType.str, 'bridge-name')),
                            ('shg_count', YLeaf(YType.uint32, 'shg-count')),
                            ('bridge_type', YLeaf(YType.enumeration, 'bridge-type')),
                            ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                        ])
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_id = None
                        self.bridge_port_count = None
                        self.number_of_hwmac = None
                        self.number_of_swmac = None
                        self.bridge_name = None
                        self.shg_count = None
                        self.bridge_type = None
                        self.learn_key = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.oper = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper()
                        self.oper.parent = self
                        self._children_name_map["oper"] = "oper"

                        self.bd_pbb_union = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion()
                        self.bd_pbb_union.parent = self
                        self._children_name_map["bd_pbb_union"] = "bd-pbb-union"

                        self.bvi_info = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BviInfo()
                        self.bvi_info.parent = self
                        self._children_name_map["bvi_info"] = "bvi-info"

                        self.p2mppw_info = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo()
                        self.p2mppw_info.parent = self
                        self._children_name_map["p2mppw_info"] = "p2mppw-info"
                        self._segment_path = lambda: "l2fib-bridge-domain"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain, ['bd_group_name', 'bd_name', 'bridge_id', 'bridge_port_count', 'number_of_hwmac', 'number_of_swmac', 'bridge_name', 'shg_count', 'bridge_type', 'learn_key'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Oper(Entity):
                        """
                        Operational information
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper, self).__init__()

                            self.yang_name = "oper"
                            self.yang_parent_name = "l2fib-bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation))])
                            self._leafs = OrderedDict([
                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                            ])
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None

                            self.operational_information = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation()
                            self.operational_information.parent = self
                            self._children_name_map["operational_information"] = "operational-information"
                            self._segment_path = lambda: "oper"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                        class OperationalInformation(Entity):
                            """
                            L2 operational information
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\: bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\: bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                            
                            .. attribute:: mac_limit_threshold
                            
                            	MAC limit percentage recovery threshold
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: percentage
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_threshold_enabled
                            
                            	Is MAC Secure Threshold Enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\: bool
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\: bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\: bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\: bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\: bool
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\: bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\: bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\: bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\: bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\: bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\: bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\: bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\: bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\: bool
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\: bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation, self).__init__()

                                self.yang_name = "operational-information"
                                self.yang_parent_name = "oper"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature))])
                                self._leafs = OrderedDict([
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                    ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                    ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                    ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                    ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                    ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                    ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                    ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                    ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                    ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                    ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                    ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                    ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                    ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                    ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                    ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                    ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                    ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                    ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                    ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                    ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                    ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                    ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                    ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                    ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                    ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                    ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                    ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                    ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                    ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                    ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                    ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                    ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                    ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                    ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                    ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                    ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                    ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                    ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                    ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                    ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                    ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                    ('msti', YLeaf(YType.uint32, 'msti')),
                                    ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                    ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                    ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                ])
                                self.mtu = None
                                self.mac_aging_time = None
                                self.mac_limit = None
                                self.number_of_macs = None
                                self.admin_disabled = None
                                self.flooding_disabled = None
                                self.flood_unknown_unicast_enabled = None
                                self.mac_limit_action = None
                                self.mac_limit_threshold = None
                                self.mac_learning_disabled = None
                                self.mac_port_down_flush_disabled = None
                                self.mac_limit_notification_type = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.mac_secure_action = None
                                self.is_mac_secure_accept_shutdown = None
                                self.is_mac_secure_threshold_enabled = None
                                self.mac_aging_type = None
                                self.storm_control_unicast_enabled = None
                                self.storm_control_broadcast_enabled = None
                                self.storm_control_multicast_enabled = None
                                self.storm_control_unicast_rate_unit = None
                                self.storm_control_broadcast_rate_unit = None
                                self.storm_control_multicast_rate_unit = None
                                self.dhcp_enabled = None
                                self.dhcp_trusted = None
                                self.is_dai_enabled = None
                                self.is_dai_addr_validation_ipv4_enabled = None
                                self.is_dai_addr_validation_source_mac_enabled = None
                                self.is_dai_addr_validation_destination_mac_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ipsg_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_vpls_flood_optimization_enabled = None
                                self.igmp_snoop_enabled = None
                                self.igmp_snoop_profile_enabled = None
                                self.igmp_flood_forward_enabled = None
                                self.igmp_mroute_port_enabled = None
                                self.igmp_route_guard_enabled = None
                                self.mld_snoop_enabled = None
                                self.mld_snoop_profile_enabled = None
                                self.mld_flood_forward_enabled = None
                                self.mld_mroute_port_enabled = None
                                self.mld_route_guard_enabled = None
                                self.stp_participating = None
                                self.bvi_configured = None
                                self.is_bvi_up = None
                                self.is_vni_enabled = None
                                self.is_evpn_enabled = None
                                self.unknown_unicast_flooding_disabled = None
                                self.is_pbbevpn_enabled = None
                                self.is_swmac_learning = None
                                self.is_evpn_flow_label = None
                                self.is_evpn_cw_disable = None
                                self.msti = None
                                self.is_p2mp_pw_enabled = None
                                self.is_igmp_snoop_enabled = None
                                self.nv_satellite_offload_ipv4_multicast_disabled = None

                                self.feature = YList(self)
                                self._segment_path = lambda: "operational-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                            class Feature(Entity):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Mld>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature, self).__init__()

                                    self.yang_name = "feature"
                                    self.yang_parent_name = "operational-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Mld))])
                                    self._leafs = OrderedDict([
                                        ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                    ])
                                    self.feature_type = None

                                    self.dhcp = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self._children_name_map["dhcp"] = "dhcp"

                                    self.igmp = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self._children_name_map["igmp"] = "igmp"

                                    self.mld = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self
                                    self._children_name_map["mld"] = "mld"
                                    self._segment_path = lambda: "feature"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                class Dhcp(Entity):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                        self.yang_name = "dhcp"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "dhcp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                class Igmp(Entity):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                        self.yang_name = "igmp"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "igmp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                class Mld(Entity):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                        self.yang_name = "mld"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "mld"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                    class BdPbbUnion(Entity):
                        """
                        Union of bridge Edge and Core info
                        
                        .. attribute:: edge
                        
                        	edge
                        	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Edge>`
                        
                        .. attribute:: core
                        
                        	core
                        	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Core>`
                        
                        .. attribute:: pbb_type
                        
                        	PbbType
                        	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion, self).__init__()

                            self.yang_name = "bd-pbb-union"
                            self.yang_parent_name = "l2fib-bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Core))])
                            self._leafs = OrderedDict([
                                ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                            ])
                            self.pbb_type = None

                            self.edge = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Edge()
                            self.edge.parent = self
                            self._children_name_map["edge"] = "edge"

                            self.core = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Core()
                            self.core.parent = self
                            self._children_name_map["core"] = "core"
                            self._segment_path = lambda: "bd-pbb-union"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion, ['pbb_type'], name, value)


                        class Edge(Entity):
                            """
                            edge
                            
                            .. attribute:: i_sid
                            
                            	I SID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: core_bd_name
                            
                            	Core Bridge Domain name
                            	**type**\: str
                            
                            .. attribute:: mirp_lite_rx
                            
                            	MIRP\-lite Rx packet counter
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: mirp_lite_tx
                            
                            	MIRP\-lite Tx packet counter
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bd-pbb-union"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('i_sid', YLeaf(YType.uint32, 'i-sid')),
                                    ('core_bd_name', YLeaf(YType.str, 'core-bd-name')),
                                    ('mirp_lite_rx', YLeaf(YType.uint64, 'mirp-lite-rx')),
                                    ('mirp_lite_tx', YLeaf(YType.uint64, 'mirp-lite-tx')),
                                ])
                                self.i_sid = None
                                self.core_bd_name = None
                                self.mirp_lite_rx = None
                                self.mirp_lite_tx = None
                                self._segment_path = lambda: "edge"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Edge, ['i_sid', 'core_bd_name', 'mirp_lite_rx', 'mirp_lite_tx'], name, value)


                        class Core(Entity):
                            """
                            core
                            
                            .. attribute:: nber_edge_bd
                            
                            	Number of associated pbb\-edge Bds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Core, self).__init__()

                                self.yang_name = "core"
                                self.yang_parent_name = "bd-pbb-union"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nber_edge_bd', YLeaf(YType.uint32, 'nber-edge-bd')),
                                ])
                                self.nber_edge_bd = None
                                self._segment_path = lambda: "core"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BdPbbUnion.Core, ['nber_edge_bd'], name, value)


                    class BviInfo(Entity):
                        """
                        BVI Information
                        
                        .. attribute:: bvi_ifh
                        
                        	BVI interface handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: bvi_xid
                        
                        	BVI xconnect id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bvi_name
                        
                        	BVI name
                        	**type**\: str
                        
                        	**length:** 0..65
                        
                        .. attribute:: bvi_shg_id
                        
                        	BVI Split Horizon Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: byte
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BviInfo, self).__init__()

                            self.yang_name = "bvi-info"
                            self.yang_parent_name = "l2fib-bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bvi_ifh', YLeaf(YType.str, 'bvi-ifh')),
                                ('bvi_xid', YLeaf(YType.uint32, 'bvi-xid')),
                                ('bvi_name', YLeaf(YType.str, 'bvi-name')),
                                ('bvi_shg_id', YLeaf(YType.uint32, 'bvi-shg-id')),
                                ('irb_plat_data_len', YLeaf(YType.uint32, 'irb-plat-data-len')),
                                ('irb_plat_data', YLeaf(YType.str, 'irb-plat-data')),
                            ])
                            self.bvi_ifh = None
                            self.bvi_xid = None
                            self.bvi_name = None
                            self.bvi_shg_id = None
                            self.irb_plat_data_len = None
                            self.irb_plat_data = None
                            self._segment_path = lambda: "bvi-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.BviInfo, ['bvi_ifh', 'bvi_xid', 'bvi_name', 'bvi_shg_id', 'irb_plat_data_len', 'irb_plat_data'], name, value)


                    class P2mppwInfo(Entity):
                        """
                        P2MP PW Information
                        
                        .. attribute:: parent_next_hop
                        
                        	Parent Next Hop for P2MP PW
                        	**type**\:  :py:class:`ParentNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop>`
                        
                        .. attribute:: ptree_type
                        
                        	P2MP ptree type
                        	**type**\:  :py:class:`L2vpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPtree>`
                        
                        .. attribute:: lsm_id
                        
                        	LSM id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_te_interface
                        
                        	P2MP TE ifh
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: parent_nh_valid
                        
                        	Is Parent NH Valid
                        	**type**\: bool
                        
                        .. attribute:: parent_nh_bound
                        
                        	Is Parent NH Bound
                        	**type**\: bool
                        
                        .. attribute:: local_label
                        
                        	Local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo, self).__init__()

                            self.yang_name = "p2mppw-info"
                            self.yang_parent_name = "l2fib-bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("parent-next-hop", ("parent_next_hop", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop))])
                            self._leafs = OrderedDict([
                                ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                ('p2mp_te_interface', YLeaf(YType.str, 'p2mp-te-interface')),
                                ('parent_nh_valid', YLeaf(YType.boolean, 'parent-nh-valid')),
                                ('parent_nh_bound', YLeaf(YType.boolean, 'parent-nh-bound')),
                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                            ])
                            self.ptree_type = None
                            self.lsm_id = None
                            self.p2mp_te_interface = None
                            self.parent_nh_valid = None
                            self.parent_nh_bound = None
                            self.local_label = None

                            self.parent_next_hop = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop()
                            self.parent_next_hop.parent = self
                            self._children_name_map["parent_next_hop"] = "parent-next-hop"
                            self._segment_path = lambda: "p2mppw-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo, ['ptree_type', 'lsm_id', 'p2mp_te_interface', 'parent_nh_valid', 'parent_nh_bound', 'local_label'], name, value)


                        class ParentNextHop(Entity):
                            """
                            Parent Next Hop for P2MP PW
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop.Base>`
                            
                            .. attribute:: next_hop_address
                            
                            	NHOP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: next_hop_address_v6
                            
                            	NHOP Address V6
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: next_hop_internal_label
                            
                            	NHOP Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ecd_plaformt_data_valid
                            
                            	Is Platform ECD Data Valid
                            	**type**\: bool
                            
                            .. attribute:: ecd_platform_data_length
                            
                            	Platform ECD Data Length
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: children_count
                            
                            	Children Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop, self).__init__()

                                self.yang_name = "parent-next-hop"
                                self.yang_parent_name = "p2mppw-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop.Base))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                    ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                    ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                    ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                    ('children_count', YLeaf(YType.uint32, 'children-count')),
                                ])
                                self.next_hop_address = None
                                self.next_hop_address_v6 = None
                                self.next_hop_internal_label = None
                                self.ecd_plaformt_data_valid = None
                                self.ecd_platform_data_length = None
                                self.children_count = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "parent-next-hop"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomains.L2fibBridgeDomain.P2mppwInfo.ParentNextHop.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "parent-next-hop"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


            class L2fibMstpSummaries(Entity):
                """
                MSTP Summary Table
                
                .. attribute:: l2fib_mstp_summary
                
                	MSTP Summary information
                	**type**\: list of  		 :py:class:`L2fibMstpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMstpSummaries, self).__init__()

                    self.yang_name = "l2fib-mstp-summaries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mstp-summary", ("l2fib_mstp_summary", L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary))])
                    self._leafs = OrderedDict()

                    self.l2fib_mstp_summary = YList(self)
                    self._segment_path = lambda: "l2fib-mstp-summaries"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMstpSummaries, [], name, value)


                class L2fibMstpSummary(Entity):
                    """
                    MSTP Summary information
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary.Base>`
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary, self).__init__()

                        self.yang_name = "l2fib-mstp-summary"
                        self.yang_parent_name = "l2fib-mstp-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary.Base))])
                        self._leafs = OrderedDict([
                            ('parent_interface', YLeaf(YType.str, 'parent-interface')),
                            ('msti', YLeaf(YType.uint32, 'msti')),
                            ('parent_interface_xr', YLeaf(YType.str, 'parent-interface-xr')),
                            ('msti_xr', YLeaf(YType.uint32, 'msti-xr')),
                            ('state', YLeaf(YType.uint32, 'state')),
                            ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                        ])
                        self.parent_interface = None
                        self.msti = None
                        self.parent_interface_xr = None
                        self.msti_xr = None
                        self.state = None
                        self.bridge_port_count = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._segment_path = lambda: "l2fib-mstp-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary, ['parent_interface', 'msti', 'parent_interface_xr', 'msti_xr', 'state', 'bridge_port_count'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMstpSummaries.L2fibMstpSummary.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mstp-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


            class L2fibResourceAvailability(Entity):
                """
                Resource availability information
                
                .. attribute:: shm_resource
                
                	Shared memory resource info
                	**type**\:  :py:class:`ShmResource <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.ShmResource>`
                
                .. attribute:: overall_out_of_resource_mode
                
                	Overall OOR mode
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: hardware_resource_mode_information
                
                	Opaque hardware resource info
                	**type**\: str
                
                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                
                .. attribute:: hardware_resource_mode
                
                	Hardware resource mode
                	**type**\: list of  		 :py:class:`HardwareResourceMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.HardwareResourceMode>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability, self).__init__()

                    self.yang_name = "l2fib-resource-availability"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("shm-resource", ("shm_resource", L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.ShmResource)), ("hardware-resource-mode", ("hardware_resource_mode", L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.HardwareResourceMode))])
                    self._leafs = OrderedDict([
                        ('overall_out_of_resource_mode', YLeaf(YType.uint32, 'overall-out-of-resource-mode')),
                        ('hardware_resource_mode_information', YLeaf(YType.str, 'hardware-resource-mode-information')),
                    ])
                    self.overall_out_of_resource_mode = None
                    self.hardware_resource_mode_information = None

                    self.shm_resource = L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.ShmResource()
                    self.shm_resource.parent = self
                    self._children_name_map["shm_resource"] = "shm-resource"

                    self.hardware_resource_mode = YList(self)
                    self._segment_path = lambda: "l2fib-resource-availability"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability, ['overall_out_of_resource_mode', 'hardware_resource_mode_information'], name, value)


                class ShmResource(Entity):
                    """
                    Shared memory resource info
                    
                    .. attribute:: oout_of_resource_mode
                    
                    	OOR mode
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: maximum_available
                    
                    	Maximum bytes available
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: average_available
                    
                    	Average number of bytes available
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    	**units**\: byte
                    
                    .. attribute:: average_utility
                    
                    	Average utilization
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.ShmResource, self).__init__()

                        self.yang_name = "shm-resource"
                        self.yang_parent_name = "l2fib-resource-availability"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('oout_of_resource_mode', YLeaf(YType.uint32, 'oout-of-resource-mode')),
                            ('maximum_available', YLeaf(YType.uint64, 'maximum-available')),
                            ('average_available', YLeaf(YType.uint64, 'average-available')),
                            ('average_utility', YLeaf(YType.uint64, 'average-utility')),
                        ])
                        self.oout_of_resource_mode = None
                        self.maximum_available = None
                        self.average_available = None
                        self.average_utility = None
                        self._segment_path = lambda: "shm-resource"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.ShmResource, ['oout_of_resource_mode', 'maximum_available', 'average_available', 'average_utility'], name, value)


                class HardwareResourceMode(Entity):
                    """
                    Hardware resource mode
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.HardwareResourceMode, self).__init__()

                        self.yang_name = "hardware-resource-mode"
                        self.yang_parent_name = "l2fib-resource-availability"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "hardware-resource-mode"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibResourceAvailability.HardwareResourceMode, ['entry'], name, value)


            class L2fibmacHardwareEgresses(Entity):
                """
                Bridge Hardware Egress information
                
                .. attribute:: l2fibmac_hardware_egress
                
                	MAC Hardware Egress information
                	**type**\: list of  		 :py:class:`L2fibmacHardwareEgress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses, self).__init__()

                    self.yang_name = "l2fibmac-hardware-egresses"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibmac-hardware-egress", ("l2fibmac_hardware_egress", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress))])
                    self._leafs = OrderedDict()

                    self.l2fibmac_hardware_egress = YList(self)
                    self._segment_path = lambda: "l2fibmac-hardware-egresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses, [], name, value)


                class L2fibmacHardwareEgress(Entity):
                    """
                    MAC Hardware Egress information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..27
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Base>`
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment>`
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:  :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx>`
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop>`
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\: str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\: str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\: bool
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\: bool
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\: bool
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress, self).__init__()

                        self.yang_name = "l2fibmac-hardware-egress"
                        self.yang_parent_name = "l2fibmac-hardware-egresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Base)), ("segment", ("segment", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment)), ("evpn-ctx", ("evpn_ctx", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop))])
                        self._leafs = OrderedDict([
                            ('address', YLeaf(YType.str, 'address')),
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('platform_is_hw_learn', YLeaf(YType.uint8, 'platform-is-hw-learn')),
                            ('node_id', YLeaf(YType.str, 'node-id')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('bmac_configured', YLeaf(YType.boolean, 'bmac-configured')),
                            ('vni_l3_flag', YLeaf(YType.boolean, 'vni-l3-flag')),
                            ('pbb_bmac', YLeaf(YType.str, 'pbb-bmac')),
                            ('l3_encapsulationvlan_id', YLeaf(YType.uint16, 'l3-encapsulationvlan-id')),
                            ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                            ('peer_vtep_ip', YLeaf(YType.str, 'peer-vtep-ip')),
                            ('flag_extension', YLeaf(YType.uint16, 'flag-extension')),
                            ('vni', YLeaf(YType.uint32, 'vni')),
                        ])
                        self.address = None
                        self.group_name = None
                        self.name = None
                        self.platform_is_hw_learn = None
                        self.node_id = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.bmac_configured = None
                        self.vni_l3_flag = None
                        self.pbb_bmac = None
                        self.l3_encapsulationvlan_id = None
                        self.next_hop_valid = None
                        self.peer_vtep_ip = None
                        self.flag_extension = None
                        self.vni = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"

                        self.evpn_ctx = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"

                        self.next_hop = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "l2fibmac-hardware-egress"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress, ['address', 'group_name', 'name', 'platform_is_hw_learn', 'node_id', 'bridge_domain_name', 'bridge_id', 'bmac_configured', 'vni_l3_flag', 'pbb_bmac', 'l3_encapsulationvlan_id', 'next_hop_valid', 'peer_vtep_ip', 'flag_extension', 'vni'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Evpn>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Evpn)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ])
                                self.interface_handle = None
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Ac, ['interface_handle'], name, value)


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pbb, ['xcid'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                ])
                                self.xcid = None
                                self.parent_if = None
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Vni, ['xcid', 'parent_if'], name, value)


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Evpn, ['xcid'], name, value)


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                ])
                                self.pw_id = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.Segment.Pw, ['pw_id', 'next_hop_address', 'pseudo_wire_id_type'], name, value)


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx.McastOle>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx.McastOle))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                ('bp_ifh', YLeaf(YType.str, 'bp-ifh')),
                            ])
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.bp_ifh = None

                            self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._segment_path = lambda: "evpn-ctx"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx, ['data_type', 'esi_id', 'local_label', 'bp_ifh'], name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                    ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                ])
                                self.next_hop_ipv6_addr = None
                                self.mcast_label = None
                                self._segment_path = lambda: "mcast-ole"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.EvpnCtx.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop.Base>`
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_address_v6
                        
                        	NHOP Address V6
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ecd_plaformt_data_valid
                        
                        	Is Platform ECD Data Valid
                        	**type**\: bool
                        
                        .. attribute:: ecd_platform_data_length
                        
                        	Platform ECD Data Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-hardware-egress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop.Base))])
                            self._leafs = OrderedDict([
                                ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                ('children_count', YLeaf(YType.uint32, 'children-count')),
                            ])
                            self.next_hop_address = None
                            self.next_hop_address_v6 = None
                            self.next_hop_internal_label = None
                            self.ecd_plaformt_data_valid = None
                            self.ecd_platform_data_length = None
                            self.children_count = None

                            self.base = L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "next-hop"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacHardwareEgresses.L2fibmacHardwareEgress.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "base"


            class L2fibxConL2tpv2s(Entity):
                """
                The L2VPN forwarding XConnect L2TPv2 Detail
                Table
                
                .. attribute:: l2fibx_con_l2tpv2
                
                	Specify Sub Ifh
                	**type**\: list of  		 :py:class:`L2fibxConL2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s, self).__init__()

                    self.yang_name = "l2fibx-con-l2tpv2s"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibx-con-l2tpv2", ("l2fibx_con_l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2))])
                    self._leafs = OrderedDict()

                    self.l2fibx_con_l2tpv2 = YList(self)
                    self._segment_path = lambda: "l2fibx-con-l2tpv2s"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s, [], name, value)


                class L2fibxConL2tpv2(Entity):
                    """
                    Specify Sub Ifh
                    
                    .. attribute:: interface_name  (key)
                    
                    	Interface Name
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Base>`
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\: str
                    
                    	**length:** 0..72
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\: bool
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:  :py:class:`MgmtL2fibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibSwitching>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2, self).__init__()

                        self.yang_name = "l2fibx-con-l2tpv2"
                        self.yang_parent_name = "l2fibx-con-l2tpv2s"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Base)), ("segment1", ("segment1", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1)), ("segment2", ("segment2", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2))])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('xcon_name', YLeaf(YType.str, 'xcon-name')),
                            ('bound', YLeaf(YType.boolean, 'bound')),
                            ('switching_type', YLeaf(YType.enumeration, 'switching-type')),
                        ])
                        self.interface_name = None
                        self.xcon_name = None
                        self.bound = None
                        self.switching_type = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment1 = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"

                        self.segment2 = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._segment_path = lambda: "l2fibx-con-l2tpv2" + "[interface-name='" + str(self.interface_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2, ['interface_name', 'xcon_name', 'bound', 'switching_type'], name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:  :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn)), ("monitor-session", ("monitor_session", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.monitor_session = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.Base>`
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:  :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.Base)), ("pbb-union", ("pbb_union", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('core_pbb_evpn_enabled', YLeaf(YType.boolean, 'core-pbb-evpn-enabled')),
                                ])
                                self.bound = None
                                self.forward_class = None
                                self.core_pbb_evpn_enabled = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.pbb_union = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb, ['bound', 'forward_class', 'core_pbb_evpn_enabled'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Core))])
                                    self._leafs = OrderedDict([
                                        ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                                    ])
                                    self.pbb_type = None

                                    self.edge = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"

                                    self.core = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._segment_path = lambda: "pbb-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion, ['pbb_type'], name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\: bool
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_configured', YLeaf(YType.boolean, 'mac-configured')),
                                            ('mac', YLeaf(YType.str, 'mac')),
                                        ])
                                        self.mac_configured = None
                                        self.mac = None
                                        self._segment_path = lambda: "edge"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Edge, ['mac_configured', 'mac'], name, value)


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ])
                                        self.vlan_id = None
                                        self._segment_path = lambda: "core"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pbb.PbbUnion.Core, ['vlan_id'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni.Base>`
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ingress_replication
                            
                            	Ingress Replication supported on VNI
                            	**type**\: bool
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni.Base))])
                                self._leafs = OrderedDict([
                                    ('srcip', YLeaf(YType.str, 'srcip')),
                                    ('mcastip', YLeaf(YType.str, 'mcastip')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                    ('encap', YLeaf(YType.uint32, 'encap')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('source_vtep_if', YLeaf(YType.str, 'source-vtep-if')),
                                    ('any_cast_ip', YLeaf(YType.str, 'any-cast-ip')),
                                    ('anycast_mcast_ip', YLeaf(YType.str, 'anycast-mcast-ip')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('vx_lan_mode', YLeaf(YType.uint32, 'vx-lan-mode')),
                                ])
                                self.srcip = None
                                self.mcastip = None
                                self.bound = None
                                self.parent_if = None
                                self.encap = None
                                self.udp_port = None
                                self.source_vtep_if = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.ingress_replication = None
                                self.vx_lan_mode = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni, ['srcip', 'mcastip', 'bound', 'parent_if', 'encap', 'udp_port', 'source_vtep_if', 'any_cast_ip', 'anycast_mcast_ip', 'ingress_replication', 'vx_lan_mode'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn.Base))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ])
                                self.bound = None
                                self.evi = None
                                self.forward_class = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn, ['bound', 'evi', 'forward_class'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\: str
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession.Base))])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('session_name', YLeaf(YType.str, 'session-name')),
                                    ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                ])
                                self.xcid = None
                                self.session_name = None
                                self.hardware_information = None
                                self.bound = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "monitor-session"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession, ['xcid', 'session_name', 'hardware_information', 'bound'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment1.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:  :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:  :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con-l2tpv2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac)), ("bp", ("bp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp)), ("fxs", ("fxs", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.bp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"

                            self.fxs = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Base>`
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:  :py:class:`P2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.P2mp>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Base)), ("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper)), ("p2mp", ("p2mp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.P2mp))])
                                self._leafs = OrderedDict([
                                    ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                    ('shg_id', YLeaf(YType.uint32, 'shg-id')),
                                    ('msti_pointer', YLeaf(YType.uint32, 'msti-pointer')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                                ])
                                self.bridge_id = None
                                self.shg_id = None
                                self.msti_pointer = None
                                self.segment_type = None
                                self.mvrp_sequence_number = None
                                self.learn_key = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.oper = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"

                                self.p2mp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.P2mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._segment_path = lambda: "bp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp, ['bridge_id', 'shg_id', 'msti_pointer', 'segment_type', 'mvrp_sequence_number', 'learn_key'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ])
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None

                                    self.operational_information = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._segment_path = lambda: "oper"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC limit percentage recovery threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\: bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\: bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature))])
                                        self._leafs = OrderedDict([
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                            ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                            ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                            ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                            ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                            ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                            ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                            ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                            ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                            ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                            ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                            ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                            ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                            ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                            ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                            ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                            ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                            ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                            ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                            ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                            ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                            ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                            ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                            ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                            ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                            ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                            ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                            ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                            ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                            ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                            ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                            ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                            ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                            ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                            ('msti', YLeaf(YType.uint32, 'msti')),
                                            ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                            ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                        ])
                                        self.mtu = None
                                        self.mac_aging_time = None
                                        self.mac_limit = None
                                        self.number_of_macs = None
                                        self.admin_disabled = None
                                        self.flooding_disabled = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_limit_action = None
                                        self.mac_limit_threshold = None
                                        self.mac_learning_disabled = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_limit_notification_type = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.mac_aging_type = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.is_dai_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.stp_participating = None
                                        self.bvi_configured = None
                                        self.is_bvi_up = None
                                        self.is_vni_enabled = None
                                        self.is_evpn_enabled = None
                                        self.unknown_unicast_flooding_disabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_evpn_flow_label = None
                                        self.is_evpn_cw_disable = None
                                        self.msti = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_igmp_snoop_enabled = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                                        self.feature = YList(self)
                                        self._segment_path = lambda: "operational-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld))])
                                            self._leafs = OrderedDict([
                                                ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                            ])
                                            self.feature_type = None

                                            self.dhcp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"

                                            self.igmp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"

                                            self.mld = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._segment_path = lambda: "feature"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "dhcp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "igmp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "mld"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                            class P2mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:  :py:class:`L2vpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPtree>`
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.P2mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                        ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                        ('tunnel_id', YLeaf(YType.uint16, 'tunnel-id')),
                                        ('p2mp_id', YLeaf(YType.uint16, 'p2mp-id')),
                                        ('extended_tunnel_id', YLeaf(YType.str, 'extended-tunnel-id')),
                                        ('ptree_owner_lmrib', YLeaf(YType.boolean, 'ptree-owner-lmrib')),
                                    ])
                                    self.ptree_type = None
                                    self.lsm_id = None
                                    self.tunnel_id = None
                                    self.p2mp_id = None
                                    self.extended_tunnel_id = None
                                    self.ptree_owner_lmrib = None
                                    self._segment_path = lambda: "p2mp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Bp.P2mp, ['ptree_type', 'lsm_id', 'tunnel_id', 'p2mp_id', 'extended_tunnel_id', 'ptree_owner_lmrib'], name, value)


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs.Base))])
                                self._leafs = OrderedDict([
                                    ('fxs_id', YLeaf(YType.uint32, 'fxs-id')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                ])
                                self.fxs_id = None
                                self.segment_type = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "fxs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs, ['fxs_id', 'segment_type'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxConL2tpv2s.L2fibxConL2tpv2.Segment2.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


            class L2fibMrouteIpv6s(Entity):
                """
                multicast information
                
                .. attribute:: l2fib_mroute_ipv6
                
                	Bridge Domain Multicast Information
                	**type**\: list of  		 :py:class:`L2fibMrouteIpv6 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s, self).__init__()

                    self.yang_name = "l2fib-mroute-ipv6s"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mroute-ipv6", ("l2fib_mroute_ipv6", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6))])
                    self._leafs = OrderedDict()

                    self.l2fib_mroute_ipv6 = YList(self)
                    self._segment_path = lambda: "l2fib-mroute-ipv6s"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s, [], name, value)


                class L2fibMrouteIpv6(Entity):
                    """
                    Bridge Domain Multicast Information
                    
                    .. attribute:: source
                    
                    	Source IPv6 Address
                    	**type**\: str
                    
                    	**length:** 1..128
                    
                    .. attribute:: group
                    
                    	Group IPv6 Address
                    	**type**\: str
                    
                    	**length:** 1..128
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:  :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.MulticastBaseInformation>`
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.SourcePrefix>`
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:  :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats>`
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:  :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\: str
                    
                    	**length:** 0..66
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6, self).__init__()

                        self.yang_name = "l2fib-mroute-ipv6"
                        self.yang_parent_name = "l2fib-mroute-ipv6s"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-base-information", ("multicast_base_information", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.MulticastBaseInformation)), ("source-prefix", ("source_prefix", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.SourcePrefix)), ("destination-prefix", ("destination_prefix", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.DestinationPrefix)), ("forward-stats", ("forward_stats", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats)), ("irb-info", ("irb_info", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo))])
                        self._leafs = OrderedDict([
                            ('source', YLeaf(YType.str, 'source')),
                            ('group', YLeaf(YType.str, 'group')),
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('xid_count', YLeaf(YType.uint16, 'xid-count')),
                            ('platform_data_length', YLeaf(YType.uint8, 'platform-data-length')),
                            ('platform_data', YLeaf(YType.str, 'platform-data')),
                            ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                        ])
                        self.source = None
                        self.group = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_id = None
                        self.xid_count = None
                        self.platform_data_length = None
                        self.platform_data = None
                        self.hardware_information = None
                        self.bridge_domain_name = None

                        self.multicast_base_information = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"

                        self.source_prefix = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"

                        self.destination_prefix = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"

                        self.forward_stats = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"

                        self.irb_info = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._segment_path = lambda: "l2fib-mroute-ipv6"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6, ['source', 'group', 'bd_group_name', 'bd_name', 'bridge_id', 'xid_count', 'platform_data_length', 'platform_data', 'hardware_information', 'bridge_domain_name'], name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mroute-ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "multicast-base-information"


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute-ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "source-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.SourcePrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute-ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "destination-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.DestinationPrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:  :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute-ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forward-stat", ("forward_stat", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat))])
                            self._leafs = OrderedDict()

                            self.forward_stat = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._segment_path = lambda: "forward-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats, [], name, value)


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:  :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast>`
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:  :py:class:`MgmtL2fibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibStatsData>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mulicast", ("mulicast", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast))])
                                self._leafs = OrderedDict([
                                    ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ])
                                self.data_type = None

                                self.mulicast = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._segment_path = lambda: "forward-stat"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat, ['data_type'], name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:  :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:  :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:  :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:  :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:  :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("multicast-forward-stat", ("multicast_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat)), ("received-stat", ("received_stat", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat)), ("punt", ("punt", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt)), ("drop", ("drop", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop)), ("multicast-core-forward-stat", ("multicast_core_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat)), ("core-received-stat", ("core_received_stat", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat))])
                                    self._leafs = OrderedDict()

                                    self.multicast_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"

                                    self.received_stat = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"

                                    self.punt = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"

                                    self.drop = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"

                                    self.multicast_core_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"

                                    self.core_received_stat = L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._segment_path = lambda: "mulicast"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast, [], name, value)


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, ['packets', 'bytes'], name, value)


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.ReceivedStat, ['packets', 'bytes'], name, value)


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "punt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Punt, ['packets', 'bytes'], name, value)


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.Drop, ['packets', 'bytes'], name, value)


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-core-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, ['packets', 'bytes'], name, value)


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "core-received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, ['packets', 'bytes'], name, value)


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\: list of  		 :py:class:`IrbPlatData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo.IrbPlatData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mroute-ipv6"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("irb-plat-data", ("irb_plat_data", L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo.IrbPlatData))])
                            self._leafs = OrderedDict([
                                ('mxid_ac_interface_handle', YLeaf(YType.str, 'mxid-ac-interface-handle')),
                                ('mxid_pw_id', YLeaf(YType.uint32, 'mxid-pw-id')),
                                ('mxid_next_hop_address', YLeaf(YType.str, 'mxid-next-hop-address')),
                                ('irb_plat_data_len', YLeaf(YType.uint16, 'irb-plat-data-len')),
                            ])
                            self.mxid_ac_interface_handle = None
                            self.mxid_pw_id = None
                            self.mxid_next_hop_address = None
                            self.irb_plat_data_len = None

                            self.irb_plat_data = YList(self)
                            self._segment_path = lambda: "irb-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo, ['mxid_ac_interface_handle', 'mxid_pw_id', 'mxid_next_hop_address', 'irb_plat_data_len'], name, value)


                        class IrbPlatData(Entity):
                            """
                            IRB platform data
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo.IrbPlatData, self).__init__()

                                self.yang_name = "irb-plat-data"
                                self.yang_parent_name = "irb-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "irb-plat-data"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMrouteIpv6s.L2fibMrouteIpv6.IrbInfo.IrbPlatData, ['entry'], name, value)


            class L2fibMonSessXCons(Entity):
                """
                The L2VPN forwarding Monitor Session XConnect
                Information
                
                .. attribute:: l2fib_mon_sess_x_con
                
                	Specify Monitor Session Name
                	**type**\: list of  		 :py:class:`L2fibMonSessXCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons, self).__init__()

                    self.yang_name = "l2fib-mon-sess-x-cons"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mon-sess-x-con", ("l2fib_mon_sess_x_con", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon))])
                    self._leafs = OrderedDict()

                    self.l2fib_mon_sess_x_con = YList(self)
                    self._segment_path = lambda: "l2fib-mon-sess-x-cons"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons, [], name, value)


                class L2fibMonSessXCon(Entity):
                    """
                    Specify Monitor Session Name
                    
                    .. attribute:: monitor_session_name  (key)
                    
                    	Monitor Session Name
                    	**type**\: str
                    
                    	**length:** 1..64
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Base>`
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\: str
                    
                    	**length:** 0..72
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\: bool
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:  :py:class:`MgmtL2fibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibSwitching>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon, self).__init__()

                        self.yang_name = "l2fib-mon-sess-x-con"
                        self.yang_parent_name = "l2fib-mon-sess-x-cons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['monitor_session_name']
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Base)), ("segment1", ("segment1", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1)), ("segment2", ("segment2", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2))])
                        self._leafs = OrderedDict([
                            ('monitor_session_name', YLeaf(YType.str, 'monitor-session-name')),
                            ('xcon_name', YLeaf(YType.str, 'xcon-name')),
                            ('bound', YLeaf(YType.boolean, 'bound')),
                            ('switching_type', YLeaf(YType.enumeration, 'switching-type')),
                        ])
                        self.monitor_session_name = None
                        self.xcon_name = None
                        self.bound = None
                        self.switching_type = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment1 = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"

                        self.segment2 = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._segment_path = lambda: "l2fib-mon-sess-x-con" + "[monitor-session-name='" + str(self.monitor_session_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon, ['monitor_session_name', 'xcon_name', 'bound', 'switching_type'], name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:  :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn)), ("monitor-session", ("monitor_session", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.monitor_session = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:  :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.Base)), ("pbb-union", ("pbb_union", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('core_pbb_evpn_enabled', YLeaf(YType.boolean, 'core-pbb-evpn-enabled')),
                                ])
                                self.bound = None
                                self.forward_class = None
                                self.core_pbb_evpn_enabled = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.pbb_union = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb, ['bound', 'forward_class', 'core_pbb_evpn_enabled'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Core))])
                                    self._leafs = OrderedDict([
                                        ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                                    ])
                                    self.pbb_type = None

                                    self.edge = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"

                                    self.core = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._segment_path = lambda: "pbb-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion, ['pbb_type'], name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\: bool
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_configured', YLeaf(YType.boolean, 'mac-configured')),
                                            ('mac', YLeaf(YType.str, 'mac')),
                                        ])
                                        self.mac_configured = None
                                        self.mac = None
                                        self._segment_path = lambda: "edge"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Edge, ['mac_configured', 'mac'], name, value)


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ])
                                        self.vlan_id = None
                                        self._segment_path = lambda: "core"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pbb.PbbUnion.Core, ['vlan_id'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni.Base>`
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ingress_replication
                            
                            	Ingress Replication supported on VNI
                            	**type**\: bool
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni.Base))])
                                self._leafs = OrderedDict([
                                    ('srcip', YLeaf(YType.str, 'srcip')),
                                    ('mcastip', YLeaf(YType.str, 'mcastip')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                    ('encap', YLeaf(YType.uint32, 'encap')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('source_vtep_if', YLeaf(YType.str, 'source-vtep-if')),
                                    ('any_cast_ip', YLeaf(YType.str, 'any-cast-ip')),
                                    ('anycast_mcast_ip', YLeaf(YType.str, 'anycast-mcast-ip')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('vx_lan_mode', YLeaf(YType.uint32, 'vx-lan-mode')),
                                ])
                                self.srcip = None
                                self.mcastip = None
                                self.bound = None
                                self.parent_if = None
                                self.encap = None
                                self.udp_port = None
                                self.source_vtep_if = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.ingress_replication = None
                                self.vx_lan_mode = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni, ['srcip', 'mcastip', 'bound', 'parent_if', 'encap', 'udp_port', 'source_vtep_if', 'any_cast_ip', 'anycast_mcast_ip', 'ingress_replication', 'vx_lan_mode'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn.Base))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ])
                                self.bound = None
                                self.evi = None
                                self.forward_class = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn, ['bound', 'evi', 'forward_class'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\: str
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession.Base))])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('session_name', YLeaf(YType.str, 'session-name')),
                                    ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                ])
                                self.xcid = None
                                self.session_name = None
                                self.hardware_information = None
                                self.bound = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "monitor-session"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession, ['xcid', 'session_name', 'hardware_information', 'bound'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment1.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:  :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:  :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fib-mon-sess-x-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac)), ("bp", ("bp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp)), ("fxs", ("fxs", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.bp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"

                            self.fxs = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Base>`
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:  :py:class:`P2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.P2mp>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Base)), ("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper)), ("p2mp", ("p2mp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.P2mp))])
                                self._leafs = OrderedDict([
                                    ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                    ('shg_id', YLeaf(YType.uint32, 'shg-id')),
                                    ('msti_pointer', YLeaf(YType.uint32, 'msti-pointer')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                                ])
                                self.bridge_id = None
                                self.shg_id = None
                                self.msti_pointer = None
                                self.segment_type = None
                                self.mvrp_sequence_number = None
                                self.learn_key = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.oper = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"

                                self.p2mp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.P2mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._segment_path = lambda: "bp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp, ['bridge_id', 'shg_id', 'msti_pointer', 'segment_type', 'mvrp_sequence_number', 'learn_key'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ])
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None

                                    self.operational_information = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._segment_path = lambda: "oper"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC limit percentage recovery threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\: bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\: bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature))])
                                        self._leafs = OrderedDict([
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                            ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                            ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                            ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                            ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                            ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                            ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                            ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                            ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                            ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                            ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                            ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                            ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                            ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                            ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                            ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                            ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                            ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                            ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                            ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                            ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                            ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                            ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                            ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                            ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                            ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                            ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                            ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                            ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                            ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                            ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                            ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                            ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                            ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                            ('msti', YLeaf(YType.uint32, 'msti')),
                                            ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                            ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                        ])
                                        self.mtu = None
                                        self.mac_aging_time = None
                                        self.mac_limit = None
                                        self.number_of_macs = None
                                        self.admin_disabled = None
                                        self.flooding_disabled = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_limit_action = None
                                        self.mac_limit_threshold = None
                                        self.mac_learning_disabled = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_limit_notification_type = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.mac_aging_type = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.is_dai_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.stp_participating = None
                                        self.bvi_configured = None
                                        self.is_bvi_up = None
                                        self.is_vni_enabled = None
                                        self.is_evpn_enabled = None
                                        self.unknown_unicast_flooding_disabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_evpn_flow_label = None
                                        self.is_evpn_cw_disable = None
                                        self.msti = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_igmp_snoop_enabled = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                                        self.feature = YList(self)
                                        self._segment_path = lambda: "operational-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld))])
                                            self._leafs = OrderedDict([
                                                ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                            ])
                                            self.feature_type = None

                                            self.dhcp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"

                                            self.igmp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"

                                            self.mld = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._segment_path = lambda: "feature"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "dhcp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "igmp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "mld"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                            class P2mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:  :py:class:`L2vpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPtree>`
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.P2mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                        ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                        ('tunnel_id', YLeaf(YType.uint16, 'tunnel-id')),
                                        ('p2mp_id', YLeaf(YType.uint16, 'p2mp-id')),
                                        ('extended_tunnel_id', YLeaf(YType.str, 'extended-tunnel-id')),
                                        ('ptree_owner_lmrib', YLeaf(YType.boolean, 'ptree-owner-lmrib')),
                                    ])
                                    self.ptree_type = None
                                    self.lsm_id = None
                                    self.tunnel_id = None
                                    self.p2mp_id = None
                                    self.extended_tunnel_id = None
                                    self.ptree_owner_lmrib = None
                                    self._segment_path = lambda: "p2mp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Bp.P2mp, ['ptree_type', 'lsm_id', 'tunnel_id', 'p2mp_id', 'extended_tunnel_id', 'ptree_owner_lmrib'], name, value)


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs.Base))])
                                self._leafs = OrderedDict([
                                    ('fxs_id', YLeaf(YType.uint32, 'fxs-id')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                ])
                                self.fxs_id = None
                                self.segment_type = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "fxs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs, ['fxs_id', 'segment_type'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMonSessXCons.L2fibMonSessXCon.Segment2.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


            class L2fibMmrpSummaries(Entity):
                """
                Mmrp Summary Table
                
                .. attribute:: l2fib_mmrp_summary
                
                	Mmrp Summary Information
                	**type**\: list of  		 :py:class:`L2fibMmrpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries, self).__init__()

                    self.yang_name = "l2fib-mmrp-summaries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mmrp-summary", ("l2fib_mmrp_summary", L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary))])
                    self._leafs = OrderedDict()

                    self.l2fib_mmrp_summary = YList(self)
                    self._segment_path = lambda: "l2fib-mmrp-summaries"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries, [], name, value)


                class L2fibMmrpSummary(Entity):
                    """
                    Mmrp Summary Information
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\: str
                    
                    	**length:** 0..66
                    
                    .. attribute:: bridge_domain_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update
                    
                    	Multicast Updates
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: multicast_update_dropped
                    
                    	Multicast Updates
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes
                    
                    	Number of Routes
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_routes_with_ole_offload
                    
                    	Number of Routes with OleOffload
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_mroute_add
                    
                    	Number of Mroutes Added
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_deleted
                    
                    	Number of Mroutes Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroutes_deleted_all
                    
                    	Number of Mroutes All Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_delete_drop
                    
                    	Number of Mroutes Delete droped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_mroute_all_delete_drop
                    
                    	Number of Mroutes All Delete droped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_add
                    
                    	Number of XID Added
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_xid_deleted
                    
                    	Number of XID Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_xid
                    
                    	Number of XIDs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_deleted
                    
                    	Stale Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stale_xid_deleted
                    
                    	Stale XID Deleted
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: message
                    
                    	Global Message Information
                    	**type**\: list of  		 :py:class:`Message <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary.Message>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary, self).__init__()

                        self.yang_name = "l2fib-mmrp-summary"
                        self.yang_parent_name = "l2fib-mmrp-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("message", ("message", L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary.Message))])
                        self._leafs = OrderedDict([
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                            ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                            ('multicast_update', YLeaf(YType.uint32, 'multicast-update')),
                            ('multicast_update_dropped', YLeaf(YType.uint32, 'multicast-update-dropped')),
                            ('number_of_routes', YLeaf(YType.uint32, 'number-of-routes')),
                            ('number_of_routes_with_ole_offload', YLeaf(YType.uint32, 'number-of-routes-with-ole-offload')),
                            ('number_of_mroute_add', YLeaf(YType.uint32, 'number-of-mroute-add')),
                            ('number_mroute_deleted', YLeaf(YType.uint32, 'number-mroute-deleted')),
                            ('number_mroutes_deleted_all', YLeaf(YType.uint32, 'number-mroutes-deleted-all')),
                            ('number_mroute_delete_drop', YLeaf(YType.uint32, 'number-mroute-delete-drop')),
                            ('number_mroute_all_delete_drop', YLeaf(YType.uint32, 'number-mroute-all-delete-drop')),
                            ('number_xid_add', YLeaf(YType.uint32, 'number-xid-add')),
                            ('number_xid_deleted', YLeaf(YType.uint32, 'number-xid-deleted')),
                            ('number_of_xid', YLeaf(YType.uint32, 'number-of-xid')),
                            ('stale_deleted', YLeaf(YType.uint32, 'stale-deleted')),
                            ('stale_xid_deleted', YLeaf(YType.uint32, 'stale-xid-deleted')),
                        ])
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_domain_name = None
                        self.bridge_domain_id = None
                        self.multicast_update = None
                        self.multicast_update_dropped = None
                        self.number_of_routes = None
                        self.number_of_routes_with_ole_offload = None
                        self.number_of_mroute_add = None
                        self.number_mroute_deleted = None
                        self.number_mroutes_deleted_all = None
                        self.number_mroute_delete_drop = None
                        self.number_mroute_all_delete_drop = None
                        self.number_xid_add = None
                        self.number_xid_deleted = None
                        self.number_of_xid = None
                        self.stale_deleted = None
                        self.stale_xid_deleted = None

                        self.message = YList(self)
                        self._segment_path = lambda: "l2fib-mmrp-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary, ['bd_group_name', 'bd_name', 'bridge_domain_name', 'bridge_domain_id', 'multicast_update', 'multicast_update_dropped', 'number_of_routes', 'number_of_routes_with_ole_offload', 'number_of_mroute_add', 'number_mroute_deleted', 'number_mroutes_deleted_all', 'number_mroute_delete_drop', 'number_mroute_all_delete_drop', 'number_xid_add', 'number_xid_deleted', 'number_of_xid', 'stale_deleted', 'stale_xid_deleted'], name, value)


                    class Message(Entity):
                        """
                        Global Message Information
                        
                        .. attribute:: messgae_count
                        
                        	number of message
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time
                        
                        	Time string
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: information1
                        
                        	Extra info 1
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: information2
                        
                        	Extra info 2
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary.Message, self).__init__()

                            self.yang_name = "message"
                            self.yang_parent_name = "l2fib-mmrp-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('messgae_count', YLeaf(YType.uint32, 'messgae-count')),
                                ('time', YLeaf(YType.str, 'time')),
                                ('information1', YLeaf(YType.uint32, 'information1')),
                                ('information2', YLeaf(YType.uint32, 'information2')),
                            ])
                            self.messgae_count = None
                            self.time = None
                            self.information1 = None
                            self.information2 = None
                            self._segment_path = lambda: "message"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrpSummaries.L2fibMmrpSummary.Message, ['messgae_count', 'time', 'information1', 'information2'], name, value)


            class L2fibPwGroups(Entity):
                """
                PW Group Table Information
                
                .. attribute:: l2fib_pw_group
                
                	PW Group Information
                	**type**\: list of  		 :py:class:`L2fibPwGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibPwGroups.L2fibPwGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibPwGroups, self).__init__()

                    self.yang_name = "l2fib-pw-groups"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-pw-group", ("l2fib_pw_group", L2vpnForwarding.Nodes.Node.L2fibPwGroups.L2fibPwGroup))])
                    self._leafs = OrderedDict()

                    self.l2fib_pw_group = YList(self)
                    self._segment_path = lambda: "l2fib-pw-groups"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibPwGroups, [], name, value)


                class L2fibPwGroup(Entity):
                    """
                    PW Group Information
                    
                    .. attribute:: peer_address
                    
                    	Peer IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group_id
                    
                    	Group Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tunnel_if_handle
                    
                    	Tunnel Interface Handle
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: group_state
                    
                    	Group State
                    	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                    
                    .. attribute:: pw_list_count
                    
                    	Dependent PW List Count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibPwGroups.L2fibPwGroup, self).__init__()

                        self.yang_name = "l2fib-pw-group"
                        self.yang_parent_name = "l2fib-pw-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer_address', YLeaf(YType.str, 'peer-address')),
                            ('group_id', YLeaf(YType.uint32, 'group-id')),
                            ('tunnel_if_handle', YLeaf(YType.uint32, 'tunnel-if-handle')),
                            ('group_state', YLeaf(YType.enumeration, 'group-state')),
                            ('pw_list_count', YLeaf(YType.uint32, 'pw-list-count')),
                        ])
                        self.peer_address = None
                        self.group_id = None
                        self.tunnel_if_handle = None
                        self.group_state = None
                        self.pw_list_count = None
                        self._segment_path = lambda: "l2fib-pw-group"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibPwGroups.L2fibPwGroup, ['peer_address', 'group_id', 'tunnel_if_handle', 'group_state', 'pw_list_count'], name, value)


            class L2fibEvpnInclMCastHardwareIngresses(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast hardware ingress Table
                
                .. attribute:: l2fib_evpn_incl_m_cast_hardware_ingress
                
                	Specify bridge domain name
                	**type**\: list of  		 :py:class:`L2fibEvpnInclMCastHardwareIngress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-cast-hardware-ingresses"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast-hardware-ingress", ("l2fib_evpn_incl_m_cast_hardware_ingress", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress))])
                    self._leafs = OrderedDict()

                    self.l2fib_evpn_incl_m_cast_hardware_ingress = YList(self)
                    self._segment_path = lambda: "l2fib-evpn-incl-m-cast-hardware-ingresses"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses, [], name, value)


                class L2fibEvpnInclMCastHardwareIngress(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  (key)
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:  :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.McastReplicationList>`
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:  :py:class:`L2fibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast-hardware-ingress"
                        self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingresses"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['bd_name']
                        self._child_classes = OrderedDict([("mcast-replication-list", ("mcast_replication_list", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.McastReplicationList)), ("l2fib-evpn-incl-m-cast-oles", ("l2fib_evpn_incl_m_cast_oles", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles))])
                        self._leafs = OrderedDict([
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                        ])
                        self.bd_name = None

                        self.mcast_replication_list = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"

                        self.l2fib_evpn_incl_m_cast_oles = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._segment_path = lambda: "l2fib-evpn-incl-m-cast-hardware-ingress" + "[bd-name='" + str(self.bd_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress, ['bd_name'], name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\: str
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	xcid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                                ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                            ])
                            self.bridge_domain_name = None
                            self.bridge_domain_id = None
                            self.xcid = None
                            self.is_bound = None
                            self._segment_path = lambda: "mcast-replication-list"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.McastReplicationList, ['bridge_domain_name', 'bridge_domain_id', 'xcid', 'is_bound'], name, value)


                    class L2fibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of  		 :py:class:`L2fibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast-hardware-ingress"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast-ole", ("l2fib_evpn_incl_m_cast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle))])
                            self._leafs = OrderedDict()

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)
                            self._segment_path = lambda: "l2fib-evpn-incl-m-cast-oles"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles, [], name, value)


                        class L2fibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  (key)
                            
                            	Next Hop Address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['next_hop_address']
                                self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                ])
                                self.next_hop_address = None
                                self.is_bound = None
                                self.next_hop_valid = None

                                self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + str(self.next_hop_address) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, ['next_hop_address', 'is_bound', 'next_hop_valid'], name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                        ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                    ])
                                    self.next_hop_ipv6_addr = None
                                    self.mcast_label = None
                                    self._segment_path = lambda: "mcast-ole"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCastHardwareIngresses.L2fibEvpnInclMCastHardwareIngress.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


            class L2fibDhcpBindingDetails(Entity):
                """
                DHCP binding forwarding detail
                
                .. attribute:: l2fib_dhcp_binding_detail
                
                	Specify DHCP binding detail
                	**type**\: list of  		 :py:class:`L2fibDhcpBindingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-details"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-dhcp-binding-detail", ("l2fib_dhcp_binding_detail", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail))])
                    self._leafs = OrderedDict()

                    self.l2fib_dhcp_binding_detail = YList(self)
                    self._segment_path = lambda: "l2fib-dhcp-binding-details"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails, [], name, value)


                class L2fibDhcpBindingDetail(Entity):
                    """
                    Specify DHCP binding detail
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: neighbor_address
                    
                    	Neighbor IPv4 address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: address
                    
                    	MAC address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Base>`
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail, self).__init__()

                        self.yang_name = "l2fib-dhcp-binding-detail"
                        self.yang_parent_name = "l2fib-dhcp-binding-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Base)), ("port", ("port", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port))])
                        self._leafs = OrderedDict([
                            ('xcid', YLeaf(YType.str, 'xcid')),
                            ('neighbor_address', YLeaf(YType.str, 'neighbor-address')),
                            ('address', YLeaf(YType.str, 'address')),
                        ])
                        self.xcid = None
                        self.neighbor_address = None
                        self.address = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.port = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"
                        self._segment_path = lambda: "l2fib-dhcp-binding-detail"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail, ['xcid', 'neighbor_address', 'address'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-dhcp-binding-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Port(Entity):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Ac>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "l2fib-dhcp-binding-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Ac)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "port"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ])
                                self.interface_handle = None
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Ac, ['interface_handle'], name, value)


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                ])
                                self.pw_id = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingDetails.L2fibDhcpBindingDetail.Port.Pw, ['pw_id', 'next_hop_address', 'pseudo_wire_id_type'], name, value)


            class L2fibxCons(Entity):
                """
                The L2VPN forwarding XConnect Detail Table
                
                .. attribute:: l2fibx_con
                
                	Specify XConnect ID
                	**type**\: list of  		 :py:class:`L2fibxCon <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibxCons, self).__init__()

                    self.yang_name = "l2fibx-cons"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibx-con", ("l2fibx_con", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon))])
                    self._leafs = OrderedDict()

                    self.l2fibx_con = YList(self)
                    self._segment_path = lambda: "l2fibx-cons"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons, [], name, value)


                class L2fibxCon(Entity):
                    """
                    Specify XConnect ID
                    
                    .. attribute:: xcid  (key)
                    
                    	XC ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Base>`
                    
                    .. attribute:: segment1
                    
                    	Segment1 Information
                    	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment2 Information
                    	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2>`
                    
                    .. attribute:: xcon_name
                    
                    	Xconnect name
                    	**type**\: str
                    
                    	**length:** 0..72
                    
                    .. attribute:: bound
                    
                    	Bound
                    	**type**\: bool
                    
                    .. attribute:: switching_type
                    
                    	SW Type
                    	**type**\:  :py:class:`MgmtL2fibSwitching <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibSwitching>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon, self).__init__()

                        self.yang_name = "l2fibx-con"
                        self.yang_parent_name = "l2fibx-cons"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['xcid']
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Base)), ("segment1", ("segment1", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1)), ("segment2", ("segment2", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2))])
                        self._leafs = OrderedDict([
                            ('xcid', YLeaf(YType.str, 'xcid')),
                            ('xcon_name', YLeaf(YType.str, 'xcon-name')),
                            ('bound', YLeaf(YType.boolean, 'bound')),
                            ('switching_type', YLeaf(YType.enumeration, 'switching-type')),
                        ])
                        self.xcid = None
                        self.xcon_name = None
                        self.bound = None
                        self.switching_type = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment1 = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"

                        self.segment2 = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"
                        self._segment_path = lambda: "l2fibx-con" + "[xcid='" + str(self.xcid) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon, ['xcid', 'xcon_name', 'bound', 'switching_type'], name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibx-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment1(Entity):
                        """
                        Segment1 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn>`
                        
                        .. attribute:: monitor_session
                        
                        	monitor session
                        	**type**\:  :py:class:`MonitorSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "l2fibx-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn)), ("monitor-session", ("monitor_session", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.monitor_session = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession()
                            self.monitor_session.parent = self
                            self._children_name_map["monitor_session"] = "monitor-session"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.Base>`
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:  :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.Base)), ("pbb-union", ("pbb_union", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('core_pbb_evpn_enabled', YLeaf(YType.boolean, 'core-pbb-evpn-enabled')),
                                ])
                                self.bound = None
                                self.forward_class = None
                                self.core_pbb_evpn_enabled = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.pbb_union = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb, ['bound', 'forward_class', 'core_pbb_evpn_enabled'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Core))])
                                    self._leafs = OrderedDict([
                                        ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                                    ])
                                    self.pbb_type = None

                                    self.edge = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"

                                    self.core = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._segment_path = lambda: "pbb-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion, ['pbb_type'], name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\: bool
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_configured', YLeaf(YType.boolean, 'mac-configured')),
                                            ('mac', YLeaf(YType.str, 'mac')),
                                        ])
                                        self.mac_configured = None
                                        self.mac = None
                                        self._segment_path = lambda: "edge"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Edge, ['mac_configured', 'mac'], name, value)


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ])
                                        self.vlan_id = None
                                        self._segment_path = lambda: "core"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pbb.PbbUnion.Core, ['vlan_id'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni.Base>`
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ingress_replication
                            
                            	Ingress Replication supported on VNI
                            	**type**\: bool
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni.Base))])
                                self._leafs = OrderedDict([
                                    ('srcip', YLeaf(YType.str, 'srcip')),
                                    ('mcastip', YLeaf(YType.str, 'mcastip')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                    ('encap', YLeaf(YType.uint32, 'encap')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('source_vtep_if', YLeaf(YType.str, 'source-vtep-if')),
                                    ('any_cast_ip', YLeaf(YType.str, 'any-cast-ip')),
                                    ('anycast_mcast_ip', YLeaf(YType.str, 'anycast-mcast-ip')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('vx_lan_mode', YLeaf(YType.uint32, 'vx-lan-mode')),
                                ])
                                self.srcip = None
                                self.mcastip = None
                                self.bound = None
                                self.parent_if = None
                                self.encap = None
                                self.udp_port = None
                                self.source_vtep_if = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.ingress_replication = None
                                self.vx_lan_mode = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni, ['srcip', 'mcastip', 'bound', 'parent_if', 'encap', 'udp_port', 'source_vtep_if', 'any_cast_ip', 'anycast_mcast_ip', 'ingress_replication', 'vx_lan_mode'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn.Base))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ])
                                self.bound = None
                                self.evi = None
                                self.forward_class = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn, ['bound', 'evi', 'forward_class'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class MonitorSession(Entity):
                            """
                            monitor session
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession.Base>`
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: session_name
                            
                            	Monitor Session Name
                            	**type**\: str
                            
                            .. attribute:: hardware_information
                            
                            	hardware Information of Monitor Session
                            	**type**\: str
                            
                            	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession, self).__init__()

                                self.yang_name = "monitor-session"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession.Base))])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('session_name', YLeaf(YType.str, 'session-name')),
                                    ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                ])
                                self.xcid = None
                                self.session_name = None
                                self.hardware_information = None
                                self.bound = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "monitor-session"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession, ['xcid', 'session_name', 'hardware_information', 'bound'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.MonitorSession.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "monitor-session"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment1.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                    class Segment2(Entity):
                        """
                        Segment2 Information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac>`
                        
                        .. attribute:: bp
                        
                        	bp
                        	**type**\:  :py:class:`Bp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp>`
                        
                        .. attribute:: fxs
                        
                        	fxs
                        	**type**\:  :py:class:`Fxs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "l2fibx-con"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac)), ("bp", ("bp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp)), ("fxs", ("fxs", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.bp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp()
                            self.bp.parent = self
                            self._children_name_map["bp"] = "bp"

                            self.fxs = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs()
                            self.fxs.parent = self
                            self._children_name_map["fxs"] = "fxs"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Bp(Entity):
                            """
                            bp
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Base>`
                            
                            .. attribute:: oper
                            
                            	Operational information
                            	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper>`
                            
                            .. attribute:: p2mp
                            
                            	BP P2MP PW Information
                            	**type**\:  :py:class:`P2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.P2mp>`
                            
                            .. attribute:: bridge_id
                            
                            	Bridge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: shg_id
                            
                            	Split horizon group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_pointer
                            
                            	MSTI Pointer
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: learn_key
                            
                            	Learn Key
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp, self).__init__()

                                self.yang_name = "bp"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Base)), ("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper)), ("p2mp", ("p2mp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.P2mp))])
                                self._leafs = OrderedDict([
                                    ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                    ('shg_id', YLeaf(YType.uint32, 'shg-id')),
                                    ('msti_pointer', YLeaf(YType.uint32, 'msti-pointer')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                                ])
                                self.bridge_id = None
                                self.shg_id = None
                                self.msti_pointer = None
                                self.segment_type = None
                                self.mvrp_sequence_number = None
                                self.learn_key = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.oper = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper()
                                self.oper.parent = self
                                self._children_name_map["oper"] = "oper"

                                self.p2mp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.P2mp()
                                self.p2mp.parent = self
                                self._children_name_map["p2mp"] = "p2mp"
                                self._segment_path = lambda: "bp"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp, ['bridge_id', 'shg_id', 'msti_pointer', 'segment_type', 'mvrp_sequence_number', 'learn_key'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class Oper(Entity):
                                """
                                Operational information
                                
                                .. attribute:: operational_information
                                
                                	L2 operational information
                                	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast storm control pps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast storm control kbps
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper, self).__init__()

                                    self.yang_name = "oper"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ])
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None

                                    self.operational_information = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation()
                                    self.operational_information.parent = self
                                    self._children_name_map["operational_information"] = "operational-information"
                                    self._segment_path = lambda: "oper"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                                class OperationalInformation(Entity):
                                    """
                                    L2 operational information
                                    
                                    .. attribute:: mtu
                                    
                                    	MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in minutes
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: minute
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: number_of_macs
                                    
                                    	numberOfMacs
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admin_disabled
                                    
                                    	Is administratively disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flooding_disabled
                                    
                                    	Is flooding disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Is flooding unknown unicast disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC limit percentage recovery threshold
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: mac_learning_disabled
                                    
                                    	Is MAC learning disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_disabled
                                    
                                    	Is MAC port down flush disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_notification_type
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC secure action
                                    	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown
                                    
                                    	Is MAC secure accept shutdown (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_aging_type
                                    
                                    	MAC aging type
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_enabled
                                    
                                    	Is unicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_broadcast_enabled
                                    
                                    	Is broadcast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_multicast_enabled
                                    
                                    	Is multicast storm control enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: storm_control_unicast_rate_unit
                                    
                                    	Storm control unicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_broadcast_rate_unit
                                    
                                    	Storm control broadcast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: storm_control_multicast_rate_unit
                                    
                                    	Storm control multicast rate unit
                                    	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                    
                                    .. attribute:: dhcp_enabled
                                    
                                    	Is DHCP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcp_trusted
                                    
                                    	Is DHCP trusted
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_ipv4_enabled
                                    
                                    	Is DAI IPv4 Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                    
                                    	Is DAI Destination MAC Validation enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vpls_flood_optimization_enabled
                                    
                                    	Is MMRP  Flood Optimization Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_enabled
                                    
                                    	Is IGMP snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_snoop_profile_enabled
                                    
                                    	Is IGMP snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_flood_forward_enabled
                                    
                                    	Is IGMP flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: igmp_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_enabled
                                    
                                    	Is MLD snooping enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_snoop_profile_enabled
                                    
                                    	Is MLD snooping profile enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_flood_forward_enabled
                                    
                                    	Is MLD flood forwarding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_mroute_port_enabled
                                    
                                    	Is mrouter port
                                    	**type**\: bool
                                    
                                    .. attribute:: mld_route_guard_enabled
                                    
                                    	Is router gurad enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: stp_participating
                                    
                                    	Is Spanning Tree Protocol participating
                                    	**type**\: bool
                                    
                                    .. attribute:: bvi_configured
                                    
                                    	Is BVI Interface configured
                                    	**type**\: bool
                                    
                                    .. attribute:: is_bvi_up
                                    
                                    	Is BVI state UP
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vni_enabled
                                    
                                    	Is VNI enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_enabled
                                    
                                    	Is EVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: unknown_unicast_flooding_disabled
                                    
                                    	Unknown Unicast Flooding is disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_pbbevpn_enabled
                                    
                                    	Is PBBEVPN enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_swmac_learning
                                    
                                    	Is SW MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_flow_label
                                    
                                    	Is EVPN Flow Label enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_cw_disable
                                    
                                    	Is EVPN CW disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: msti
                                    
                                    	Multi\-spanning tree instance
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_p2mp_pw_enabled
                                    
                                    	Is P2MP PW enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_igmp_snoop_enabled
                                    
                                    	Is IGMP Snooping admin enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                    
                                    	nV Satellite Offload IPv4 Multicast Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: feature
                                    
                                    	Feature information
                                    	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation, self).__init__()

                                        self.yang_name = "operational-information"
                                        self.yang_parent_name = "oper"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature))])
                                        self._leafs = OrderedDict([
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                            ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                            ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                            ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                            ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                            ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                            ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                            ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                            ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                            ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                            ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                            ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                            ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                            ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                            ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                            ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                            ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                            ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                            ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                            ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                            ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                            ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                            ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                            ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                            ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                            ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                            ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                            ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                            ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                            ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                            ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                            ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                            ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                            ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                            ('msti', YLeaf(YType.uint32, 'msti')),
                                            ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                            ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                        ])
                                        self.mtu = None
                                        self.mac_aging_time = None
                                        self.mac_limit = None
                                        self.number_of_macs = None
                                        self.admin_disabled = None
                                        self.flooding_disabled = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_limit_action = None
                                        self.mac_limit_threshold = None
                                        self.mac_learning_disabled = None
                                        self.mac_port_down_flush_disabled = None
                                        self.mac_limit_notification_type = None
                                        self.is_mac_secure_enabled = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_accept_shutdown = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.mac_aging_type = None
                                        self.storm_control_unicast_enabled = None
                                        self.storm_control_broadcast_enabled = None
                                        self.storm_control_multicast_enabled = None
                                        self.storm_control_unicast_rate_unit = None
                                        self.storm_control_broadcast_rate_unit = None
                                        self.storm_control_multicast_rate_unit = None
                                        self.dhcp_enabled = None
                                        self.dhcp_trusted = None
                                        self.is_dai_enabled = None
                                        self.is_dai_addr_validation_ipv4_enabled = None
                                        self.is_dai_addr_validation_source_mac_enabled = None
                                        self.is_dai_addr_validation_destination_mac_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_ipsg_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_vpls_flood_optimization_enabled = None
                                        self.igmp_snoop_enabled = None
                                        self.igmp_snoop_profile_enabled = None
                                        self.igmp_flood_forward_enabled = None
                                        self.igmp_mroute_port_enabled = None
                                        self.igmp_route_guard_enabled = None
                                        self.mld_snoop_enabled = None
                                        self.mld_snoop_profile_enabled = None
                                        self.mld_flood_forward_enabled = None
                                        self.mld_mroute_port_enabled = None
                                        self.mld_route_guard_enabled = None
                                        self.stp_participating = None
                                        self.bvi_configured = None
                                        self.is_bvi_up = None
                                        self.is_vni_enabled = None
                                        self.is_evpn_enabled = None
                                        self.unknown_unicast_flooding_disabled = None
                                        self.is_pbbevpn_enabled = None
                                        self.is_swmac_learning = None
                                        self.is_evpn_flow_label = None
                                        self.is_evpn_cw_disable = None
                                        self.msti = None
                                        self.is_p2mp_pw_enabled = None
                                        self.is_igmp_snoop_enabled = None
                                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                                        self.feature = YList(self)
                                        self._segment_path = lambda: "operational-information"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                                    class Feature(Entity):
                                        """
                                        Feature information
                                        
                                        .. attribute:: dhcp
                                        
                                        	dhcp
                                        	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp>`
                                        
                                        .. attribute:: igmp
                                        
                                        	igmp
                                        	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp>`
                                        
                                        .. attribute:: mld
                                        
                                        	mld
                                        	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld>`
                                        
                                        .. attribute:: feature_type
                                        
                                        	feature type
                                        	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature, self).__init__()

                                            self.yang_name = "feature"
                                            self.yang_parent_name = "operational-information"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld))])
                                            self._leafs = OrderedDict([
                                                ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                            ])
                                            self.feature_type = None

                                            self.dhcp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp()
                                            self.dhcp.parent = self
                                            self._children_name_map["dhcp"] = "dhcp"

                                            self.igmp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp()
                                            self.igmp.parent = self
                                            self._children_name_map["igmp"] = "igmp"

                                            self.mld = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld()
                                            self.mld.parent = self
                                            self._children_name_map["mld"] = "mld"
                                            self._segment_path = lambda: "feature"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                        class Dhcp(Entity):
                                            """
                                            dhcp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                self.yang_name = "dhcp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "dhcp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                        class Igmp(Entity):
                                            """
                                            igmp
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                self.yang_name = "igmp"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "igmp"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                        class Mld(Entity):
                                            """
                                            mld
                                            
                                            .. attribute:: profile_name
                                            
                                            	Feature profile name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                self.yang_name = "mld"
                                                self.yang_parent_name = "feature"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                ])
                                                self.profile_name = None
                                                self._segment_path = lambda: "mld"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                            class P2mp(Entity):
                                """
                                BP P2MP PW Information
                                
                                .. attribute:: ptree_type
                                
                                	P2MP ptree type
                                	**type**\:  :py:class:`L2vpnPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPtree>`
                                
                                .. attribute:: lsm_id
                                
                                	MLDP LSM id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_id
                                
                                	TE Tunnel Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: p2mp_id
                                
                                	TE P2MP Id
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: extended_tunnel_id
                                
                                	TE Extended Tunnel Id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ptree_owner_lmrib
                                
                                	PTree Owner LMRIB
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.P2mp, self).__init__()

                                    self.yang_name = "p2mp"
                                    self.yang_parent_name = "bp"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ptree_type', YLeaf(YType.enumeration, 'ptree-type')),
                                        ('lsm_id', YLeaf(YType.uint32, 'lsm-id')),
                                        ('tunnel_id', YLeaf(YType.uint16, 'tunnel-id')),
                                        ('p2mp_id', YLeaf(YType.uint16, 'p2mp-id')),
                                        ('extended_tunnel_id', YLeaf(YType.str, 'extended-tunnel-id')),
                                        ('ptree_owner_lmrib', YLeaf(YType.boolean, 'ptree-owner-lmrib')),
                                    ])
                                    self.ptree_type = None
                                    self.lsm_id = None
                                    self.tunnel_id = None
                                    self.p2mp_id = None
                                    self.extended_tunnel_id = None
                                    self.ptree_owner_lmrib = None
                                    self._segment_path = lambda: "p2mp"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Bp.P2mp, ['ptree_type', 'lsm_id', 'tunnel_id', 'p2mp_id', 'extended_tunnel_id', 'ptree_owner_lmrib'], name, value)


                        class Fxs(Entity):
                            """
                            fxs
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs.Base>`
                            
                            .. attribute:: fxs_id
                            
                            	FXS ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: segment_type
                            
                            	Segment type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs, self).__init__()

                                self.yang_name = "fxs"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs.Base))])
                                self._leafs = OrderedDict([
                                    ('fxs_id', YLeaf(YType.uint32, 'fxs-id')),
                                    ('segment_type', YLeaf(YType.uint8, 'segment-type')),
                                ])
                                self.fxs_id = None
                                self.segment_type = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "fxs"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs, ['fxs_id', 'segment_type'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Fxs.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "fxs"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibxCons.L2fibxCon.Segment2.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


            class L2fibMainInterfaces(Entity):
                """
                Main Interface
                
                .. attribute:: l2fib_main_interface
                
                	Main Interface Table
                	**type**\: list of  		 :py:class:`L2fibMainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces, self).__init__()

                    self.yang_name = "l2fib-main-interfaces"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-main-interface", ("l2fib_main_interface", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface))])
                    self._leafs = OrderedDict()

                    self.l2fib_main_interface = YList(self)
                    self._segment_path = lambda: "l2fib-main-interfaces"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces, [], name, value)


                class L2fibMainInterface(Entity):
                    """
                    Main Interface Table
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_detail_info
                    
                    	Main Interface hardware egress detail info
                    	**type**\:  :py:class:`L2fibMainInterfaceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_egress_info
                    
                    	Main Interface hardware egress info
                    	**type**\:  :py:class:`L2fibMainInterfaceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo>`
                    
                    .. attribute:: l2fib_main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:  :py:class:`L2fibMainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances>`
                    
                    .. attribute:: l2fib_main_interface_info
                    
                    	Main Interface info
                    	**type**\:  :py:class:`L2fibMainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo>`
                    
                    .. attribute:: l2fib_main_interface_detail_info
                    
                    	Main Interface detail info
                    	**type**\:  :py:class:`L2fibMainInterfaceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_detail_info
                    
                    	Main Interface hardware ingress detail info
                    	**type**\:  :py:class:`L2fibMainInterfaceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo>`
                    
                    .. attribute:: l2fib_main_interface_hardware_ingress_info
                    
                    	Main Interface hardware ingress info
                    	**type**\:  :py:class:`L2fibMainInterfaceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo>`
                    
                    .. attribute:: main_interface_id
                    
                    	Main interface id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: main_interface_type
                    
                    	Main interface type
                    	**type**\:  :py:class:`EvpnMainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.EvpnMainInterface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface, self).__init__()

                        self.yang_name = "l2fib-main-interface"
                        self.yang_parent_name = "l2fib-main-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2fib-main-interface-hardware-egress-detail-info", ("l2fib_main_interface_hardware_egress_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo)), ("l2fib-main-interface-hardware-egress-info", ("l2fib_main_interface_hardware_egress_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo)), ("l2fib-main-interface-instances", ("l2fib_main_interface_instances", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances)), ("l2fib-main-interface-info", ("l2fib_main_interface_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo)), ("l2fib-main-interface-detail-info", ("l2fib_main_interface_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo)), ("l2fib-main-interface-hardware-ingress-detail-info", ("l2fib_main_interface_hardware_ingress_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo)), ("l2fib-main-interface-hardware-ingress-info", ("l2fib_main_interface_hardware_ingress_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo))])
                        self._leafs = OrderedDict([
                            ('main_interface_id', YLeaf(YType.uint32, 'main-interface-id')),
                            ('main_interface_type', YLeaf(YType.enumeration, 'main-interface-type')),
                        ])
                        self.main_interface_id = None
                        self.main_interface_type = None

                        self.l2fib_main_interface_hardware_egress_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo()
                        self.l2fib_main_interface_hardware_egress_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_egress_detail_info"] = "l2fib-main-interface-hardware-egress-detail-info"

                        self.l2fib_main_interface_hardware_egress_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo()
                        self.l2fib_main_interface_hardware_egress_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_egress_info"] = "l2fib-main-interface-hardware-egress-info"

                        self.l2fib_main_interface_instances = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances()
                        self.l2fib_main_interface_instances.parent = self
                        self._children_name_map["l2fib_main_interface_instances"] = "l2fib-main-interface-instances"

                        self.l2fib_main_interface_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo()
                        self.l2fib_main_interface_info.parent = self
                        self._children_name_map["l2fib_main_interface_info"] = "l2fib-main-interface-info"

                        self.l2fib_main_interface_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo()
                        self.l2fib_main_interface_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_detail_info"] = "l2fib-main-interface-detail-info"

                        self.l2fib_main_interface_hardware_ingress_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo()
                        self.l2fib_main_interface_hardware_ingress_detail_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_ingress_detail_info"] = "l2fib-main-interface-hardware-ingress-detail-info"

                        self.l2fib_main_interface_hardware_ingress_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo()
                        self.l2fib_main_interface_hardware_ingress_info.parent = self
                        self._children_name_map["l2fib_main_interface_hardware_ingress_info"] = "l2fib-main-interface-hardware-ingress-info"
                        self._segment_path = lambda: "l2fib-main-interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface, ['main_interface_id', 'main_interface_type'], name, value)


                    class L2fibMainInterfaceHardwareEgressDetailInfo(Entity):
                        """
                        Main Interface hardware egress detail info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\: str
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesProvisioned>`
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\: list of  		 :py:class:`BridgePortCountInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.BridgePortCountInstance>`
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\: list of  		 :py:class:`EthernetSegmentIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EthernetSegmentIdentifier>`
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of  		 :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-egress-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesProvisioned)), ("bridge-port-count-instance", ("bridge_port_count_instance", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.BridgePortCountInstance)), ("ethernet-segment-identifier", ("ethernet_segment_identifier", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EthernetSegmentIdentifier)), ("evpn-shg-remote-info", ("evpn_shg_remote_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                ('mac', YLeaf(YType.str, 'mac')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('evpn_shg_local_label', YLeaf(YType.uint32, 'evpn-shg-local-label')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None
                            self.mac = None
                            self.esi_id = None
                            self.evpn_shg_local_label = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self.bridge_port_count_instance = YList(self)
                            self.ethernet_segment_identifier = YList(self)
                            self.evpn_shg_remote_info = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-hardware-egress-detail-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'mac', 'esi_id', 'evpn_shg_local_label'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.InstancesProvisioned, ['entry'], name, value)


                        class BridgePortCountInstance(Entity):
                            """
                            Number of bridge ports per instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.BridgePortCountInstance, self).__init__()

                                self.yang_name = "bridge-port-count-instance"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "bridge-port-count-instance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.BridgePortCountInstance, ['entry'], name, value)


                        class EthernetSegmentIdentifier(Entity):
                            """
                            Ethernet Segment Identifier
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EthernetSegmentIdentifier, self).__init__()

                                self.yang_name = "ethernet-segment-identifier"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint8, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "ethernet-segment-identifier"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EthernetSegmentIdentifier, ['entry'], name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:  :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("remote-split-horizon-group-label", ("remote_split_horizon_group_label", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel))])
                                self._leafs = OrderedDict()

                                self.remote_split_horizon_group_label = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._segment_path = lambda: "evpn-shg-remote-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo, [], name, value)


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label', YLeaf(YType.uint32, 'label')),
                                    ])
                                    self.next_hop = None
                                    self.label = None
                                    self._segment_path = lambda: "remote-split-horizon-group-label"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, ['next_hop', 'label'], name, value)


                    class L2fibMainInterfaceHardwareEgressInfo(Entity):
                        """
                        Main Interface hardware egress info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesProvisioned>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-egress-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesProvisioned))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-hardware-egress-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo, ['main_interface', 'main_if_type', 'virtual_if_name'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-hardware-egress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareEgressInfo.InstancesProvisioned, ['entry'], name, value)


                    class L2fibMainInterfaceInstances(Entity):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: l2fib_main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of  		 :py:class:`L2fibMainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances, self).__init__()

                            self.yang_name = "l2fib-main-interface-instances"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("l2fib-main-interface-instance", ("l2fib_main_interface_instance", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance))])
                            self._leafs = OrderedDict()

                            self.l2fib_main_interface_instance = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-instances"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances, [], name, value)


                        class L2fibMainInterfaceInstance(Entity):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2fib_main_interface_instance_detail_info
                            
                            	Main Interface Instance detail info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_port_details
                            
                            	Main Interface Instance Bridge Port detail table
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceBridgePortDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails>`
                            
                            .. attribute:: l2fib_main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_detail_info
                            
                            	Main Interface Instance hardware ingress detail info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceHardwareIngressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressDetailInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_info
                            
                            	Main Interface Instance hardware egress info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceHardwareEgressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_ingress_info
                            
                            	Main Interface Instance hardware ingress info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceHardwareIngressInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressInfo>`
                            
                            .. attribute:: l2fib_main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts>`
                            
                            .. attribute:: l2fib_main_interface_instance_hardware_egress_detail_info
                            
                            	Main Interface Instance hardware egress detail info
                            	**type**\:  :py:class:`L2fibMainInterfaceInstanceHardwareEgressDetailInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressDetailInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance, self).__init__()

                                self.yang_name = "l2fib-main-interface-instance"
                                self.yang_parent_name = "l2fib-main-interface-instances"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("l2fib-main-interface-instance-detail-info", ("l2fib_main_interface_instance_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceDetailInfo)), ("l2fib-main-interface-instance-bridge-port-details", ("l2fib_main_interface_instance_bridge_port_details", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails)), ("l2fib-main-interface-instance-info", ("l2fib_main_interface_instance_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceInfo)), ("l2fib-main-interface-instance-hardware-ingress-detail-info", ("l2fib_main_interface_instance_hardware_ingress_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressDetailInfo)), ("l2fib-main-interface-instance-hardware-egress-info", ("l2fib_main_interface_instance_hardware_egress_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressInfo)), ("l2fib-main-interface-instance-hardware-ingress-info", ("l2fib_main_interface_instance_hardware_ingress_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressInfo)), ("l2fib-main-interface-instance-bridge-ports", ("l2fib_main_interface_instance_bridge_ports", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts)), ("l2fib-main-interface-instance-hardware-egress-detail-info", ("l2fib_main_interface_instance_hardware_egress_detail_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressDetailInfo))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                ])
                                self.instance = None

                                self.l2fib_main_interface_instance_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceDetailInfo()
                                self.l2fib_main_interface_instance_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_detail_info"] = "l2fib-main-interface-instance-detail-info"

                                self.l2fib_main_interface_instance_bridge_port_details = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails()
                                self.l2fib_main_interface_instance_bridge_port_details.parent = self
                                self._children_name_map["l2fib_main_interface_instance_bridge_port_details"] = "l2fib-main-interface-instance-bridge-port-details"

                                self.l2fib_main_interface_instance_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceInfo()
                                self.l2fib_main_interface_instance_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_info"] = "l2fib-main-interface-instance-info"

                                self.l2fib_main_interface_instance_hardware_ingress_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_ingress_detail_info"] = "l2fib-main-interface-instance-hardware-ingress-detail-info"

                                self.l2fib_main_interface_instance_hardware_egress_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressInfo()
                                self.l2fib_main_interface_instance_hardware_egress_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_egress_info"] = "l2fib-main-interface-instance-hardware-egress-info"

                                self.l2fib_main_interface_instance_hardware_ingress_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressInfo()
                                self.l2fib_main_interface_instance_hardware_ingress_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_ingress_info"] = "l2fib-main-interface-instance-hardware-ingress-info"

                                self.l2fib_main_interface_instance_bridge_ports = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts()
                                self.l2fib_main_interface_instance_bridge_ports.parent = self
                                self._children_name_map["l2fib_main_interface_instance_bridge_ports"] = "l2fib-main-interface-instance-bridge-ports"

                                self.l2fib_main_interface_instance_hardware_egress_detail_info = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressDetailInfo()
                                self.l2fib_main_interface_instance_hardware_egress_detail_info.parent = self
                                self._children_name_map["l2fib_main_interface_instance_hardware_egress_detail_info"] = "l2fib-main-interface-instance-hardware-egress-detail-info"
                                self._segment_path = lambda: "l2fib-main-interface-instance" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance, ['instance'], name, value)


                            class L2fibMainInterfaceInstanceDetailInfo(Entity):
                                """
                                Main Interface Instance detail info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-detail-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                            class L2fibMainInterfaceInstanceBridgePortDetails(Entity):
                                """
                                Main Interface Instance Bridge Port detail
                                table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port_detail
                                
                                	Main Interface Bridge Port detail info
                                	**type**\: list of  		 :py:class:`L2fibMainInterfaceInstanceBridgePortDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-bridge-port-details"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2fib-main-interface-instance-bridge-port-detail", ("l2fib_main_interface_instance_bridge_port_detail", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail))])
                                    self._leafs = OrderedDict()

                                    self.l2fib_main_interface_instance_bridge_port_detail = YList(self)
                                    self._segment_path = lambda: "l2fib-main-interface-instance-bridge-port-details"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails, [], name, value)


                                class L2fibMainInterfaceInstanceBridgePortDetail(Entity):
                                    """
                                    Main Interface Bridge Port detail info
                                    
                                    .. attribute:: xcid  (key)
                                    
                                    	Bridge Port
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                                    
                                    .. attribute:: oper
                                    
                                    	Operational information
                                    	**type**\:  :py:class:`Oper <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper>`
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state
                                    
                                    	Instance state
                                    	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\: str
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail, self).__init__()

                                        self.yang_name = "l2fib-main-interface-instance-bridge-port-detail"
                                        self.yang_parent_name = "l2fib-main-interface-instance-bridge-port-details"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['xcid']
                                        self._child_classes = OrderedDict([("oper", ("oper", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper))])
                                        self._leafs = OrderedDict([
                                            ('xcid', YLeaf(YType.str, 'xcid')),
                                            ('bridge_port_id', YLeaf(YType.str, 'bridge-port-id')),
                                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                            ('state', YLeaf(YType.enumeration, 'state')),
                                            ('main_interface', YLeaf(YType.str, 'main-interface')),
                                            ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                            ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                            ('bp_type', YLeaf(YType.uint8, 'bp-type')),
                                        ])
                                        self.xcid = None
                                        self.bridge_port_id = None
                                        self.bridge_id = None
                                        self.state = None
                                        self.main_interface = None
                                        self.main_if_type = None
                                        self.virtual_if_name = None
                                        self.bp_type = None

                                        self.oper = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper()
                                        self.oper.parent = self
                                        self._children_name_map["oper"] = "oper"
                                        self._segment_path = lambda: "l2fib-main-interface-instance-bridge-port-detail" + "[xcid='" + str(self.xcid) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail, ['xcid', 'bridge_port_id', 'bridge_id', 'state', 'main_interface', 'main_if_type', 'virtual_if_name', 'bp_type'], name, value)


                                    class Oper(Entity):
                                        """
                                        Operational information
                                        
                                        .. attribute:: operational_information
                                        
                                        	L2 operational information
                                        	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast storm control pps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast storm control kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast storm control pps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast storm control kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast storm control pps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast storm control kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper, self).__init__()

                                            self.yang_name = "oper"
                                            self.yang_parent_name = "l2fib-main-interface-instance-bridge-port-detail"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation))])
                                            self._leafs = OrderedDict([
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ])
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None

                                            self.operational_information = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation()
                                            self.operational_information.parent = self
                                            self._children_name_map["operational_information"] = "operational-information"
                                            self._segment_path = lambda: "oper"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                                        class OperationalInformation(Entity):
                                            """
                                            L2 operational information
                                            
                                            .. attribute:: mtu
                                            
                                            	MTU
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in minutes
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: minute
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC limit
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: number_of_macs
                                            
                                            	numberOfMacs
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: admin_disabled
                                            
                                            	Is administratively disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: flooding_disabled
                                            
                                            	Is flooding disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Is flooding unknown unicast disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_threshold
                                            
                                            	MAC limit percentage recovery threshold
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: mac_learning_disabled
                                            
                                            	Is MAC learning disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_port_down_flush_disabled
                                            
                                            	Is MAC port down flush disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_notification_type
                                            
                                            	MAC limit notification
                                            	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC secure action
                                            	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown
                                            
                                            	Is MAC secure accept shutdown (BP only)
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_threshold_enabled
                                            
                                            	Is MAC Secure Threshold Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_aging_type
                                            
                                            	MAC aging type
                                            	**type**\: bool
                                            
                                            .. attribute:: storm_control_unicast_enabled
                                            
                                            	Is unicast storm control enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: storm_control_broadcast_enabled
                                            
                                            	Is broadcast storm control enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: storm_control_multicast_enabled
                                            
                                            	Is multicast storm control enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: storm_control_unicast_rate_unit
                                            
                                            	Storm control unicast rate unit
                                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                            
                                            .. attribute:: storm_control_broadcast_rate_unit
                                            
                                            	Storm control broadcast rate unit
                                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                            
                                            .. attribute:: storm_control_multicast_rate_unit
                                            
                                            	Storm control multicast rate unit
                                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                                            
                                            .. attribute:: dhcp_enabled
                                            
                                            	Is DHCP snooping enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: dhcp_trusted
                                            
                                            	Is DHCP trusted
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                                            
                                            	Is DAI IPv4 Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                                            
                                            	Is DAI Destination MAC Validation enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ipsg_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_vpls_flood_optimization_enabled
                                            
                                            	Is MMRP  Flood Optimization Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igmp_snoop_enabled
                                            
                                            	Is IGMP snooping enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igmp_snoop_profile_enabled
                                            
                                            	Is IGMP snooping profile enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igmp_flood_forward_enabled
                                            
                                            	Is IGMP flood forwarding enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igmp_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\: bool
                                            
                                            .. attribute:: igmp_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mld_snoop_enabled
                                            
                                            	Is MLD snooping enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mld_snoop_profile_enabled
                                            
                                            	Is MLD snooping profile enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mld_flood_forward_enabled
                                            
                                            	Is MLD flood forwarding enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mld_mroute_port_enabled
                                            
                                            	Is mrouter port
                                            	**type**\: bool
                                            
                                            .. attribute:: mld_route_guard_enabled
                                            
                                            	Is router gurad enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: stp_participating
                                            
                                            	Is Spanning Tree Protocol participating
                                            	**type**\: bool
                                            
                                            .. attribute:: bvi_configured
                                            
                                            	Is BVI Interface configured
                                            	**type**\: bool
                                            
                                            .. attribute:: is_bvi_up
                                            
                                            	Is BVI state UP
                                            	**type**\: bool
                                            
                                            .. attribute:: is_vni_enabled
                                            
                                            	Is VNI enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_evpn_enabled
                                            
                                            	Is EVPN enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: unknown_unicast_flooding_disabled
                                            
                                            	Unknown Unicast Flooding is disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_pbbevpn_enabled
                                            
                                            	Is PBBEVPN enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_swmac_learning
                                            
                                            	Is SW MAC learning enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_evpn_flow_label
                                            
                                            	Is EVPN Flow Label enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_evpn_cw_disable
                                            
                                            	Is EVPN CW disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: msti
                                            
                                            	Multi\-spanning tree instance
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_p2mp_pw_enabled
                                            
                                            	Is P2MP PW enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_igmp_snoop_enabled
                                            
                                            	Is IGMP Snooping admin enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                                            
                                            	nV Satellite Offload IPv4 Multicast Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: feature
                                            
                                            	Feature information
                                            	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation, self).__init__()

                                                self.yang_name = "operational-information"
                                                self.yang_parent_name = "oper"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature))])
                                                self._leafs = OrderedDict([
                                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                    ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                                    ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                                    ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                    ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                                    ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                                    ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                    ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                    ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                                    ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                                    ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                                    ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                                    ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                                    ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                                    ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                                    ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                                    ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                    ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                                    ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                                    ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                    ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                    ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                                    ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                                    ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                                    ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                                    ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                                    ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                                    ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                                    ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                                    ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                                    ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                                    ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                                    ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                                    ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                                    ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                                    ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                                    ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                                    ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                                    ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                                    ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                                    ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                                    ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                                    ('msti', YLeaf(YType.uint32, 'msti')),
                                                    ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                                    ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                                    ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                                ])
                                                self.mtu = None
                                                self.mac_aging_time = None
                                                self.mac_limit = None
                                                self.number_of_macs = None
                                                self.admin_disabled = None
                                                self.flooding_disabled = None
                                                self.flood_unknown_unicast_enabled = None
                                                self.mac_limit_action = None
                                                self.mac_limit_threshold = None
                                                self.mac_learning_disabled = None
                                                self.mac_port_down_flush_disabled = None
                                                self.mac_limit_notification_type = None
                                                self.is_mac_secure_enabled = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.mac_secure_action = None
                                                self.is_mac_secure_accept_shutdown = None
                                                self.is_mac_secure_threshold_enabled = None
                                                self.mac_aging_type = None
                                                self.storm_control_unicast_enabled = None
                                                self.storm_control_broadcast_enabled = None
                                                self.storm_control_multicast_enabled = None
                                                self.storm_control_unicast_rate_unit = None
                                                self.storm_control_broadcast_rate_unit = None
                                                self.storm_control_multicast_rate_unit = None
                                                self.dhcp_enabled = None
                                                self.dhcp_trusted = None
                                                self.is_dai_enabled = None
                                                self.is_dai_addr_validation_ipv4_enabled = None
                                                self.is_dai_addr_validation_source_mac_enabled = None
                                                self.is_dai_addr_validation_destination_mac_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_ipsg_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_vpls_flood_optimization_enabled = None
                                                self.igmp_snoop_enabled = None
                                                self.igmp_snoop_profile_enabled = None
                                                self.igmp_flood_forward_enabled = None
                                                self.igmp_mroute_port_enabled = None
                                                self.igmp_route_guard_enabled = None
                                                self.mld_snoop_enabled = None
                                                self.mld_snoop_profile_enabled = None
                                                self.mld_flood_forward_enabled = None
                                                self.mld_mroute_port_enabled = None
                                                self.mld_route_guard_enabled = None
                                                self.stp_participating = None
                                                self.bvi_configured = None
                                                self.is_bvi_up = None
                                                self.is_vni_enabled = None
                                                self.is_evpn_enabled = None
                                                self.unknown_unicast_flooding_disabled = None
                                                self.is_pbbevpn_enabled = None
                                                self.is_swmac_learning = None
                                                self.is_evpn_flow_label = None
                                                self.is_evpn_cw_disable = None
                                                self.msti = None
                                                self.is_p2mp_pw_enabled = None
                                                self.is_igmp_snoop_enabled = None
                                                self.nv_satellite_offload_ipv4_multicast_disabled = None

                                                self.feature = YList(self)
                                                self._segment_path = lambda: "operational-information"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                                            class Feature(Entity):
                                                """
                                                Feature information
                                                
                                                .. attribute:: dhcp
                                                
                                                	dhcp
                                                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp>`
                                                
                                                .. attribute:: igmp
                                                
                                                	igmp
                                                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp>`
                                                
                                                .. attribute:: mld
                                                
                                                	mld
                                                	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld>`
                                                
                                                .. attribute:: feature_type
                                                
                                                	feature type
                                                	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature, self).__init__()

                                                    self.yang_name = "feature"
                                                    self.yang_parent_name = "operational-information"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld))])
                                                    self._leafs = OrderedDict([
                                                        ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                                    ])
                                                    self.feature_type = None

                                                    self.dhcp = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp()
                                                    self.dhcp.parent = self
                                                    self._children_name_map["dhcp"] = "dhcp"

                                                    self.igmp = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp()
                                                    self.igmp.parent = self
                                                    self._children_name_map["igmp"] = "igmp"

                                                    self.mld = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld()
                                                    self.mld.parent = self
                                                    self._children_name_map["mld"] = "mld"
                                                    self._segment_path = lambda: "feature"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature, ['feature_type'], name, value)


                                                class Dhcp(Entity):
                                                    """
                                                    dhcp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp, self).__init__()

                                                        self.yang_name = "dhcp"
                                                        self.yang_parent_name = "feature"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                        ])
                                                        self.profile_name = None
                                                        self._segment_path = lambda: "dhcp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                                class Igmp(Entity):
                                                    """
                                                    igmp
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp, self).__init__()

                                                        self.yang_name = "igmp"
                                                        self.yang_parent_name = "feature"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                        ])
                                                        self.profile_name = None
                                                        self._segment_path = lambda: "igmp"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                                class Mld(Entity):
                                                    """
                                                    mld
                                                    
                                                    .. attribute:: profile_name
                                                    
                                                    	Feature profile name
                                                    	**type**\: str
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld, self).__init__()

                                                        self.yang_name = "mld"
                                                        self.yang_parent_name = "feature"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                                        ])
                                                        self.profile_name = None
                                                        self._segment_path = lambda: "mld"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePortDetails.L2fibMainInterfaceInstanceBridgePortDetail.Oper.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


                            class L2fibMainInterfaceInstanceInfo(Entity):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                            class L2fibMainInterfaceInstanceHardwareIngressDetailInfo(Entity):
                                """
                                Main Interface Instance hardware ingress
                                detail info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-ingress-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-hardware-ingress-detail-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                            class L2fibMainInterfaceInstanceHardwareEgressInfo(Entity):
                                """
                                Main Interface Instance hardware egress
                                info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-egress-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-hardware-egress-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                            class L2fibMainInterfaceInstanceHardwareIngressInfo(Entity):
                                """
                                Main Interface Instance hardware ingress
                                info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-ingress-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-hardware-ingress-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareIngressInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                            class L2fibMainInterfaceInstanceBridgePorts(Entity):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: l2fib_main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of  		 :py:class:`L2fibMainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts.L2fibMainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-bridge-ports"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("l2fib-main-interface-instance-bridge-port", ("l2fib_main_interface_instance_bridge_port", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts.L2fibMainInterfaceInstanceBridgePort))])
                                    self._leafs = OrderedDict()

                                    self.l2fib_main_interface_instance_bridge_port = YList(self)
                                    self._segment_path = lambda: "l2fib-main-interface-instance-bridge-ports"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts, [], name, value)


                                class L2fibMainInterfaceInstanceBridgePort(Entity):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: xcid  (key)
                                    
                                    	Bridge Port
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                                    
                                    .. attribute:: bridge_port_id
                                    
                                    	Bridge Port ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: bridge_id
                                    
                                    	Bridge ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: main_interface
                                    
                                    	Main interface ID
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: main_if_type
                                    
                                    	Main Interface Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: virtual_if_name
                                    
                                    	Virtual Main IfName
                                    	**type**\: str
                                    
                                    .. attribute:: bp_type
                                    
                                    	Bridge Port Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts.L2fibMainInterfaceInstanceBridgePort, self).__init__()

                                        self.yang_name = "l2fib-main-interface-instance-bridge-port"
                                        self.yang_parent_name = "l2fib-main-interface-instance-bridge-ports"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['xcid']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xcid', YLeaf(YType.str, 'xcid')),
                                            ('bridge_port_id', YLeaf(YType.str, 'bridge-port-id')),
                                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                                            ('main_interface', YLeaf(YType.str, 'main-interface')),
                                            ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                            ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                            ('bp_type', YLeaf(YType.uint8, 'bp-type')),
                                        ])
                                        self.xcid = None
                                        self.bridge_port_id = None
                                        self.bridge_id = None
                                        self.main_interface = None
                                        self.main_if_type = None
                                        self.virtual_if_name = None
                                        self.bp_type = None
                                        self._segment_path = lambda: "l2fib-main-interface-instance-bridge-port" + "[xcid='" + str(self.xcid) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceBridgePorts.L2fibMainInterfaceInstanceBridgePort, ['xcid', 'bridge_port_id', 'bridge_id', 'main_interface', 'main_if_type', 'virtual_if_name', 'bp_type'], name, value)


                            class L2fibMainInterfaceInstanceHardwareEgressDetailInfo(Entity):
                                """
                                Main Interface Instance hardware egress
                                detail info
                                
                                .. attribute:: main_interface
                                
                                	Main interface ID
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: main_if_type
                                
                                	Main Interface Type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: virtual_if_name
                                
                                	Virtual Main IfName
                                	**type**\: str
                                
                                .. attribute:: instance
                                
                                	Interface instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	Instance state
                                	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                                
                                .. attribute:: bridge_port_count
                                
                                	Number of bridge ports
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_provisioned
                                
                                	Instances provisioned flag
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressDetailInfo, self).__init__()

                                    self.yang_name = "l2fib-main-interface-instance-hardware-egress-detail-info"
                                    self.yang_parent_name = "l2fib-main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('main_interface', YLeaf(YType.str, 'main-interface')),
                                        ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                        ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                                        ('instance_provisioned', YLeaf(YType.boolean, 'instance-provisioned')),
                                    ])
                                    self.main_interface = None
                                    self.main_if_type = None
                                    self.virtual_if_name = None
                                    self.instance = None
                                    self.state = None
                                    self.bridge_port_count = None
                                    self.instance_provisioned = None
                                    self._segment_path = lambda: "l2fib-main-interface-instance-hardware-egress-detail-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInstances.L2fibMainInterfaceInstance.L2fibMainInterfaceInstanceHardwareEgressDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'instance', 'state', 'bridge_port_count', 'instance_provisioned'], name, value)


                    class L2fibMainInterfaceInfo(Entity):
                        """
                        Main Interface info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesProvisioned>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesProvisioned))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo, ['main_interface', 'main_if_type', 'virtual_if_name'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceInfo.InstancesProvisioned, ['entry'], name, value)


                    class L2fibMainInterfaceDetailInfo(Entity):
                        """
                        Main Interface detail info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\: str
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesProvisioned>`
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\: list of  		 :py:class:`BridgePortCountInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.BridgePortCountInstance>`
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\: list of  		 :py:class:`EthernetSegmentIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EthernetSegmentIdentifier>`
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of  		 :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesProvisioned)), ("bridge-port-count-instance", ("bridge_port_count_instance", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.BridgePortCountInstance)), ("ethernet-segment-identifier", ("ethernet_segment_identifier", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EthernetSegmentIdentifier)), ("evpn-shg-remote-info", ("evpn_shg_remote_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                ('mac', YLeaf(YType.str, 'mac')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('evpn_shg_local_label', YLeaf(YType.uint32, 'evpn-shg-local-label')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None
                            self.mac = None
                            self.esi_id = None
                            self.evpn_shg_local_label = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self.bridge_port_count_instance = YList(self)
                            self.ethernet_segment_identifier = YList(self)
                            self.evpn_shg_remote_info = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-detail-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'mac', 'esi_id', 'evpn_shg_local_label'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.InstancesProvisioned, ['entry'], name, value)


                        class BridgePortCountInstance(Entity):
                            """
                            Number of bridge ports per instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.BridgePortCountInstance, self).__init__()

                                self.yang_name = "bridge-port-count-instance"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "bridge-port-count-instance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.BridgePortCountInstance, ['entry'], name, value)


                        class EthernetSegmentIdentifier(Entity):
                            """
                            Ethernet Segment Identifier
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EthernetSegmentIdentifier, self).__init__()

                                self.yang_name = "ethernet-segment-identifier"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint8, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "ethernet-segment-identifier"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EthernetSegmentIdentifier, ['entry'], name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:  :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("remote-split-horizon-group-label", ("remote_split_horizon_group_label", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel))])
                                self._leafs = OrderedDict()

                                self.remote_split_horizon_group_label = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._segment_path = lambda: "evpn-shg-remote-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo, [], name, value)


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label', YLeaf(YType.uint32, 'label')),
                                    ])
                                    self.next_hop = None
                                    self.label = None
                                    self._segment_path = lambda: "remote-split-horizon-group-label"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, ['next_hop', 'label'], name, value)


                    class L2fibMainInterfaceHardwareIngressDetailInfo(Entity):
                        """
                        Main Interface hardware ingress detail info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: mac
                        
                        	MAC Address
                        	**type**\: str
                        
                        .. attribute:: esi_id
                        
                        	Ethernet segment ID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: evpn_shg_local_label
                        
                        	EVPN split horizon group local label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesProvisioned>`
                        
                        .. attribute:: bridge_port_count_instance
                        
                        	Number of bridge ports per instance
                        	**type**\: list of  		 :py:class:`BridgePortCountInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.BridgePortCountInstance>`
                        
                        .. attribute:: ethernet_segment_identifier
                        
                        	Ethernet Segment Identifier
                        	**type**\: list of  		 :py:class:`EthernetSegmentIdentifier <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EthernetSegmentIdentifier>`
                        
                        .. attribute:: evpn_shg_remote_info
                        
                        	EVPN split horizon group remote info
                        	**type**\: list of  		 :py:class:`EvpnShgRemoteInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-ingress-detail-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesProvisioned)), ("bridge-port-count-instance", ("bridge_port_count_instance", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.BridgePortCountInstance)), ("ethernet-segment-identifier", ("ethernet_segment_identifier", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EthernetSegmentIdentifier)), ("evpn-shg-remote-info", ("evpn_shg_remote_info", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                                ('mac', YLeaf(YType.str, 'mac')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('evpn_shg_local_label', YLeaf(YType.uint32, 'evpn-shg-local-label')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None
                            self.mac = None
                            self.esi_id = None
                            self.evpn_shg_local_label = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self.bridge_port_count_instance = YList(self)
                            self.ethernet_segment_identifier = YList(self)
                            self.evpn_shg_remote_info = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-hardware-ingress-detail-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo, ['main_interface', 'main_if_type', 'virtual_if_name', 'mac', 'esi_id', 'evpn_shg_local_label'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.InstancesProvisioned, ['entry'], name, value)


                        class BridgePortCountInstance(Entity):
                            """
                            Number of bridge ports per instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.BridgePortCountInstance, self).__init__()

                                self.yang_name = "bridge-port-count-instance"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "bridge-port-count-instance"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.BridgePortCountInstance, ['entry'], name, value)


                        class EthernetSegmentIdentifier(Entity):
                            """
                            Ethernet Segment Identifier
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EthernetSegmentIdentifier, self).__init__()

                                self.yang_name = "ethernet-segment-identifier"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint8, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "ethernet-segment-identifier"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EthernetSegmentIdentifier, ['entry'], name, value)


                        class EvpnShgRemoteInfo(Entity):
                            """
                            EVPN split horizon group remote info
                            
                            .. attribute:: remote_split_horizon_group_label
                            
                            	Remote split horizon group label
                            	**type**\:  :py:class:`RemoteSplitHorizonGroupLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo, self).__init__()

                                self.yang_name = "evpn-shg-remote-info"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-detail-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("remote-split-horizon-group-label", ("remote_split_horizon_group_label", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel))])
                                self._leafs = OrderedDict()

                                self.remote_split_horizon_group_label = L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel()
                                self.remote_split_horizon_group_label.parent = self
                                self._children_name_map["remote_split_horizon_group_label"] = "remote-split-horizon-group-label"
                                self._segment_path = lambda: "evpn-shg-remote-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo, [], name, value)


                            class RemoteSplitHorizonGroupLabel(Entity):
                                """
                                Remote split horizon group label
                                
                                .. attribute:: next_hop
                                
                                	Next\-hop IP address (v6 format)
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label
                                
                                	Split horizon label associated with next\-hop address
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, self).__init__()

                                    self.yang_name = "remote-split-horizon-group-label"
                                    self.yang_parent_name = "evpn-shg-remote-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label', YLeaf(YType.uint32, 'label')),
                                    ])
                                    self.next_hop = None
                                    self.label = None
                                    self._segment_path = lambda: "remote-split-horizon-group-label"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressDetailInfo.EvpnShgRemoteInfo.RemoteSplitHorizonGroupLabel, ['next_hop', 'label'], name, value)


                    class L2fibMainInterfaceHardwareIngressInfo(Entity):
                        """
                        Main Interface hardware ingress info
                        
                        .. attribute:: main_interface
                        
                        	Main Interface ID
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: main_if_type
                        
                        	Main Interface Type
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: virtual_if_name
                        
                        	Virtual Main IfName
                        	**type**\: str
                        
                        .. attribute:: instance_id
                        
                        	Instance IDs
                        	**type**\: list of  		 :py:class:`InstanceId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstanceId>`
                        
                        .. attribute:: instances_state
                        
                        	State for each instance
                        	**type**\: list of  		 :py:class:`InstancesState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesState>`
                        
                        .. attribute:: instances_provisioned
                        
                        	Instances provisioned flag
                        	**type**\: list of  		 :py:class:`InstancesProvisioned <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesProvisioned>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo, self).__init__()

                            self.yang_name = "l2fib-main-interface-hardware-ingress-info"
                            self.yang_parent_name = "l2fib-main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("instance-id", ("instance_id", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstanceId)), ("instances-state", ("instances_state", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesState)), ("instances-provisioned", ("instances_provisioned", L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesProvisioned))])
                            self._leafs = OrderedDict([
                                ('main_interface', YLeaf(YType.str, 'main-interface')),
                                ('main_if_type', YLeaf(YType.uint8, 'main-if-type')),
                                ('virtual_if_name', YLeaf(YType.str, 'virtual-if-name')),
                            ])
                            self.main_interface = None
                            self.main_if_type = None
                            self.virtual_if_name = None

                            self.instance_id = YList(self)
                            self.instances_state = YList(self)
                            self.instances_provisioned = YList(self)
                            self._segment_path = lambda: "l2fib-main-interface-hardware-ingress-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo, ['main_interface', 'main_if_type', 'virtual_if_name'], name, value)


                        class InstanceId(Entity):
                            """
                            Instance IDs
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstanceId, self).__init__()

                                self.yang_name = "instance-id"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instance-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstanceId, ['entry'], name, value)


                        class InstancesState(Entity):
                            """
                            State for each instance
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\:  :py:class:`L2fibMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesState, self).__init__()

                                self.yang_name = "instances-state"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.enumeration, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-state"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesState, ['entry'], name, value)


                        class InstancesProvisioned(Entity):
                            """
                            Instances provisioned flag
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesProvisioned, self).__init__()

                                self.yang_name = "instances-provisioned"
                                self.yang_parent_name = "l2fib-main-interface-hardware-ingress-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.boolean, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "instances-provisioned"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMainInterfaces.L2fibMainInterface.L2fibMainInterfaceHardwareIngressInfo.InstancesProvisioned, ['entry'], name, value)


            class L2fibMstpDetails(Entity):
                """
                MSTP Detail Table
                
                .. attribute:: l2fib_mstp_detail
                
                	MSTP Detail information
                	**type**\: list of  		 :py:class:`L2fibMstpDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMstpDetails, self).__init__()

                    self.yang_name = "l2fib-mstp-details"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mstp-detail", ("l2fib_mstp_detail", L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail))])
                    self._leafs = OrderedDict()

                    self.l2fib_mstp_detail = YList(self)
                    self._segment_path = lambda: "l2fib-mstp-details"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMstpDetails, [], name, value)


                class L2fibMstpDetail(Entity):
                    """
                    MSTP Detail information
                    
                    .. attribute:: parent_interface
                    
                    	Parent interface context
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: msti
                    
                    	MSTI context
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.Base>`
                    
                    .. attribute:: parent_interface_xr
                    
                    	main port ID
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: msti_xr
                    
                    	multi\-spanning tree instance configured value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: internal_msti
                    
                    	multi\-spanning tree instance internal value
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	MSTI state
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: learn_key
                    
                    	Learn Key
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: bridge_port_array
                    
                    	Bridge port
                    	**type**\: list of  		 :py:class:`BridgePortArray <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.BridgePortArray>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail, self).__init__()

                        self.yang_name = "l2fib-mstp-detail"
                        self.yang_parent_name = "l2fib-mstp-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.Base)), ("bridge-port-array", ("bridge_port_array", L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.BridgePortArray))])
                        self._leafs = OrderedDict([
                            ('parent_interface', YLeaf(YType.str, 'parent-interface')),
                            ('msti', YLeaf(YType.uint32, 'msti')),
                            ('parent_interface_xr', YLeaf(YType.str, 'parent-interface-xr')),
                            ('msti_xr', YLeaf(YType.uint32, 'msti-xr')),
                            ('internal_msti', YLeaf(YType.uint32, 'internal-msti')),
                            ('state', YLeaf(YType.uint32, 'state')),
                            ('learn_key', YLeaf(YType.uint8, 'learn-key')),
                        ])
                        self.parent_interface = None
                        self.msti = None
                        self.parent_interface_xr = None
                        self.msti_xr = None
                        self.internal_msti = None
                        self.state = None
                        self.learn_key = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.bridge_port_array = YList(self)
                        self._segment_path = lambda: "l2fib-mstp-detail"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail, ['parent_interface', 'msti', 'parent_interface_xr', 'msti_xr', 'internal_msti', 'state', 'learn_key'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fib-mstp-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class BridgePortArray(Entity):
                        """
                        Bridge port
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.BridgePortArray, self).__init__()

                            self.yang_name = "bridge-port-array"
                            self.yang_parent_name = "l2fib-mstp-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.str, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "bridge-port-array"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMstpDetails.L2fibMstpDetail.BridgePortArray, ['entry'], name, value)


            class L2fibL2tp(Entity):
                """
                L2TP
                
                .. attribute:: l2tpv3_sessions
                
                	L2TPV3 Session table
                	**type**\:  :py:class:`L2tpv3Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions>`
                
                .. attribute:: l2tpv2_sessions
                
                	L2TPV2 Session table
                	**type**\:  :py:class:`L2tpv2Sessions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibL2tp, self).__init__()

                    self.yang_name = "l2fib-l2tp"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2tpv3-sessions", ("l2tpv3_sessions", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions)), ("l2tpv2-sessions", ("l2tpv2_sessions", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions))])
                    self._leafs = OrderedDict()

                    self.l2tpv3_sessions = L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions()
                    self.l2tpv3_sessions.parent = self
                    self._children_name_map["l2tpv3_sessions"] = "l2tpv3-sessions"

                    self.l2tpv2_sessions = L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions()
                    self.l2tpv2_sessions.parent = self
                    self._children_name_map["l2tpv2_sessions"] = "l2tpv2-sessions"
                    self._segment_path = lambda: "l2fib-l2tp"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibL2tp, [], name, value)


                class L2tpv3Sessions(Entity):
                    """
                    L2TPV3 Session table
                    
                    .. attribute:: l2tpv3_session
                    
                    	L2TPV3 Session
                    	**type**\: list of  		 :py:class:`L2tpv3Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions, self).__init__()

                        self.yang_name = "l2tpv3-sessions"
                        self.yang_parent_name = "l2fib-l2tp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2tpv3-session", ("l2tpv3_session", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session))])
                        self._leafs = OrderedDict()

                        self.l2tpv3_session = YList(self)
                        self._segment_path = lambda: "l2tpv3-sessions"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions, [], name, value)


                    class L2tpv3Session(Entity):
                        """
                        L2TPV3 Session
                        
                        .. attribute:: session_id  (key)
                        
                        	SessionID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session.Base>`
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\: bool
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:  :py:class:`L2fibL2tpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibL2tpSession>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session, self).__init__()

                            self.yang_name = "l2tpv3-session"
                            self.yang_parent_name = "l2tpv3-sessions"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['session_id']
                            self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session.Base))])
                            self._leafs = OrderedDict([
                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                ('session_id_xr', YLeaf(YType.uint32, 'session-id-xr')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('sub_interface_name', YLeaf(YType.str, 'sub-interface-name')),
                                ('source_address', YLeaf(YType.str, 'source-address')),
                                ('bound', YLeaf(YType.boolean, 'bound')),
                                ('tunnel_id_xr', YLeaf(YType.uint32, 'tunnel-id-xr')),
                                ('ipv4_table_id', YLeaf(YType.uint32, 'ipv4-table-id')),
                                ('ipv6_table_id', YLeaf(YType.uint32, 'ipv6-table-id')),
                                ('nhop_ip_addr', YLeaf(YType.str, 'nhop-ip-addr')),
                                ('session_type', YLeaf(YType.enumeration, 'session-type')),
                            ])
                            self.session_id = None
                            self.session_id_xr = None
                            self.interface_handle = None
                            self.sub_interface_name = None
                            self.source_address = None
                            self.bound = None
                            self.tunnel_id_xr = None
                            self.ipv4_table_id = None
                            self.ipv6_table_id = None
                            self.nhop_ip_addr = None
                            self.session_type = None

                            self.base = L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "l2tpv3-session" + "[session-id='" + str(self.session_id) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session, ['session_id', 'session_id_xr', 'interface_handle', 'sub_interface_name', 'source_address', 'bound', 'tunnel_id_xr', 'ipv4_table_id', 'ipv6_table_id', 'nhop_ip_addr', 'session_type'], name, value)


                        class Base(Entity):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv3Sessions.L2tpv3Session.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "l2tpv3-session"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "base"


                class L2tpv2Sessions(Entity):
                    """
                    L2TPV2 Session table
                    
                    .. attribute:: l2tpv2_session
                    
                    	L2TPV2 Session
                    	**type**\: list of  		 :py:class:`L2tpv2Session <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions, self).__init__()

                        self.yang_name = "l2tpv2-sessions"
                        self.yang_parent_name = "l2fib-l2tp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2tpv2-session", ("l2tpv2_session", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session))])
                        self._leafs = OrderedDict()

                        self.l2tpv2_session = YList(self)
                        self._segment_path = lambda: "l2tpv2-sessions"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions, [], name, value)


                    class L2tpv2Session(Entity):
                        """
                        L2TPV2 Session
                        
                        .. attribute:: session_id
                        
                        	SessionID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tunnel_id
                        
                        	TunnelID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: base
                        
                        	Base information
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session.Base>`
                        
                        .. attribute:: session_id_xr
                        
                        	Local Session Id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_handle
                        
                        	Interface handle of egress main interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: sub_interface_name
                        
                        	SubInterface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: source_address
                        
                        	Source/Local IP address of the tunnel
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: bound
                        
                        	Bind status
                        	**type**\: bool
                        
                        .. attribute:: tunnel_id_xr
                        
                        	Tunnel ID, l2tpv2
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv4_table_id
                        
                        	IPv4 Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ipv6_table_id
                        
                        	IPv6 Table ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nhop_ip_addr
                        
                        	NHOP IP Address of the tunnel
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: session_type
                        
                        	L2tp or L2tpv2 session
                        	**type**\:  :py:class:`L2fibL2tpSession <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibL2tpSession>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session, self).__init__()

                            self.yang_name = "l2tpv2-session"
                            self.yang_parent_name = "l2tpv2-sessions"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session.Base))])
                            self._leafs = OrderedDict([
                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                ('session_id_xr', YLeaf(YType.uint32, 'session-id-xr')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('sub_interface_name', YLeaf(YType.str, 'sub-interface-name')),
                                ('source_address', YLeaf(YType.str, 'source-address')),
                                ('bound', YLeaf(YType.boolean, 'bound')),
                                ('tunnel_id_xr', YLeaf(YType.uint32, 'tunnel-id-xr')),
                                ('ipv4_table_id', YLeaf(YType.uint32, 'ipv4-table-id')),
                                ('ipv6_table_id', YLeaf(YType.uint32, 'ipv6-table-id')),
                                ('nhop_ip_addr', YLeaf(YType.str, 'nhop-ip-addr')),
                                ('session_type', YLeaf(YType.enumeration, 'session-type')),
                            ])
                            self.session_id = None
                            self.tunnel_id = None
                            self.session_id_xr = None
                            self.interface_handle = None
                            self.sub_interface_name = None
                            self.source_address = None
                            self.bound = None
                            self.tunnel_id_xr = None
                            self.ipv4_table_id = None
                            self.ipv6_table_id = None
                            self.nhop_ip_addr = None
                            self.session_type = None

                            self.base = L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "l2tpv2-session"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session, ['session_id', 'tunnel_id', 'session_id_xr', 'interface_handle', 'sub_interface_name', 'source_address', 'bound', 'tunnel_id_xr', 'ipv4_table_id', 'ipv6_table_id', 'nhop_ip_addr', 'session_type'], name, value)


                        class Base(Entity):
                            """
                            Base information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibL2tp.L2tpv2Sessions.L2tpv2Session.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "l2tpv2-session"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "base"


            class L2fibG8032(Entity):
                """
                G8032 information
                
                .. attribute:: l2fib_g8032_rings
                
                	G8032 Ring table
                	**type**\:  :py:class:`L2fibG8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibG8032, self).__init__()

                    self.yang_name = "l2fib-g8032"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-g8032-rings", ("l2fib_g8032_rings", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings))])
                    self._leafs = OrderedDict()

                    self.l2fib_g8032_rings = L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings()
                    self.l2fib_g8032_rings.parent = self
                    self._children_name_map["l2fib_g8032_rings"] = "l2fib-g8032-rings"
                    self._segment_path = lambda: "l2fib-g8032"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032, [], name, value)


                class L2fibG8032Rings(Entity):
                    """
                    G8032 Ring table
                    
                    .. attribute:: l2fib_g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of  		 :py:class:`L2fibG8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings, self).__init__()

                        self.yang_name = "l2fib-g8032-rings"
                        self.yang_parent_name = "l2fib-g8032"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2fib-g8032-ring", ("l2fib_g8032_ring", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring))])
                        self._leafs = OrderedDict()

                        self.l2fib_g8032_ring = YList(self)
                        self._segment_path = lambda: "l2fib-g8032-rings"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings, [], name, value)


                    class L2fibG8032Ring(Entity):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  (key)
                        
                        	Ring Name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: l2fib_g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:  :py:class:`L2fibG8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingDetail>`
                        
                        .. attribute:: l2fib_g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:  :py:class:`L2fibG8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingSummary>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:  :py:class:`L2fibG8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries>`
                        
                        .. attribute:: l2fib_g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:  :py:class:`L2fibG8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring, self).__init__()

                            self.yang_name = "l2fib-g8032-ring"
                            self.yang_parent_name = "l2fib-g8032-rings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ring_name']
                            self._child_classes = OrderedDict([("l2fib-g8032-ring-detail", ("l2fib_g8032_ring_detail", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingDetail)), ("l2fib-g8032-ring-summary", ("l2fib_g8032_ring_summary", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingSummary)), ("l2fib-g8032-ring-instance-summaries", ("l2fib_g8032_ring_instance_summaries", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries)), ("l2fib-g8032-ring-instance-details", ("l2fib_g8032_ring_instance_details", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails))])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                            ])
                            self.ring_name = None

                            self.l2fib_g8032_ring_detail = L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingDetail()
                            self.l2fib_g8032_ring_detail.parent = self
                            self._children_name_map["l2fib_g8032_ring_detail"] = "l2fib-g8032-ring-detail"

                            self.l2fib_g8032_ring_summary = L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingSummary()
                            self.l2fib_g8032_ring_summary.parent = self
                            self._children_name_map["l2fib_g8032_ring_summary"] = "l2fib-g8032-ring-summary"

                            self.l2fib_g8032_ring_instance_summaries = L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries()
                            self.l2fib_g8032_ring_instance_summaries.parent = self
                            self._children_name_map["l2fib_g8032_ring_instance_summaries"] = "l2fib-g8032-ring-instance-summaries"

                            self.l2fib_g8032_ring_instance_details = L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails()
                            self.l2fib_g8032_ring_instance_details.parent = self
                            self._children_name_map["l2fib_g8032_ring_instance_details"] = "l2fib-g8032-ring-instance-details"
                            self._segment_path = lambda: "l2fib-g8032-ring" + "[ring-name='" + str(self.ring_name) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring, ['ring_name'], name, value)


                        class L2fibG8032RingDetail(Entity):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\: str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\: str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\: str
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\: str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\: str
                            
                            .. attribute:: is_open_ring
                            
                            	Open Ring
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingDetail, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-detail"
                                self.yang_parent_name = "l2fib-g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ring_name', YLeaf(YType.str, 'ring-name')),
                                    ('port0', YLeaf(YType.str, 'port0')),
                                    ('port1', YLeaf(YType.str, 'port1')),
                                    ('monitor0', YLeaf(YType.str, 'monitor0')),
                                    ('monitor1', YLeaf(YType.str, 'monitor1')),
                                    ('is_open_ring', YLeaf(YType.boolean, 'is-open-ring')),
                                ])
                                self.ring_name = None
                                self.port0 = None
                                self.port1 = None
                                self.monitor0 = None
                                self.monitor1 = None
                                self.is_open_ring = None
                                self._segment_path = lambda: "l2fib-g8032-ring-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingDetail, ['ring_name', 'port0', 'port1', 'monitor0', 'monitor1', 'is_open_ring'], name, value)


                        class L2fibG8032RingSummary(Entity):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\: str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\: str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingSummary, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-summary"
                                self.yang_parent_name = "l2fib-g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ring_name', YLeaf(YType.str, 'ring-name')),
                                    ('port0', YLeaf(YType.str, 'port0')),
                                    ('port1', YLeaf(YType.str, 'port1')),
                                ])
                                self.ring_name = None
                                self.port0 = None
                                self.port1 = None
                                self._segment_path = lambda: "l2fib-g8032-ring-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingSummary, ['ring_name', 'port0', 'port1'], name, value)


                        class L2fibG8032RingInstanceSummaries(Entity):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: l2fib_g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of  		 :py:class:`L2fibG8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries.L2fibG8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-instance-summaries"
                                self.yang_parent_name = "l2fib-g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("l2fib-g8032-ring-instance-summary", ("l2fib_g8032_ring_instance_summary", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries.L2fibG8032RingInstanceSummary))])
                                self._leafs = OrderedDict()

                                self.l2fib_g8032_ring_instance_summary = YList(self)
                                self._segment_path = lambda: "l2fib-g8032-ring-instance-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries, [], name, value)


                            class L2fibG8032RingInstanceSummary(Entity):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  (key)
                                
                                	Instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries.L2fibG8032RingInstanceSummary, self).__init__()

                                    self.yang_name = "l2fib-g8032-ring-instance-summary"
                                    self.yang_parent_name = "l2fib-g8032-ring-instance-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                        ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                        ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                    ])
                                    self.instance = None
                                    self.ring_instance = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self._segment_path = lambda: "l2fib-g8032-ring-instance-summary" + "[instance='" + str(self.instance) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceSummaries.L2fibG8032RingInstanceSummary, ['instance', 'ring_instance', 'aps_port0', 'aps_port1'], name, value)


                        class L2fibG8032RingInstanceDetails(Entity):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: l2fib_g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of  		 :py:class:`L2fibG8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails.L2fibG8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails, self).__init__()

                                self.yang_name = "l2fib-g8032-ring-instance-details"
                                self.yang_parent_name = "l2fib-g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("l2fib-g8032-ring-instance-detail", ("l2fib_g8032_ring_instance_detail", L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails.L2fibG8032RingInstanceDetail))])
                                self._leafs = OrderedDict()

                                self.l2fib_g8032_ring_instance_detail = YList(self)
                                self._segment_path = lambda: "l2fib-g8032-ring-instance-details"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails, [], name, value)


                            class L2fibG8032RingInstanceDetail(Entity):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  (key)
                                
                                	Instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_ids
                                
                                	Vlan Ids
                                	**type**\: str
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\: str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:  :py:class:`L2fibG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibG8032Rpl>`
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: aps_port_status0
                                
                                	Status of Port 0
                                	**type**\:  :py:class:`L2fibG8032ApsPortStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibG8032ApsPortStatus>`
                                
                                .. attribute:: aps_port_status1
                                
                                	Status of Port 1
                                	**type**\:  :py:class:`L2fibG8032ApsPortStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibG8032ApsPortStatus>`
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails.L2fibG8032RingInstanceDetail, self).__init__()

                                    self.yang_name = "l2fib-g8032-ring-instance-detail"
                                    self.yang_parent_name = "l2fib-g8032-ring-instance-details"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                        ('vlan_ids', YLeaf(YType.str, 'vlan-ids')),
                                        ('ring_profile', YLeaf(YType.str, 'ring-profile')),
                                        ('rpl', YLeaf(YType.enumeration, 'rpl')),
                                        ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                        ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                        ('aps_port_status0', YLeaf(YType.enumeration, 'aps-port-status0')),
                                        ('aps_port_status1', YLeaf(YType.enumeration, 'aps-port-status1')),
                                        ('aps_channel_level', YLeaf(YType.uint32, 'aps-channel-level')),
                                    ])
                                    self.instance = None
                                    self.ring_instance = None
                                    self.vlan_ids = None
                                    self.ring_profile = None
                                    self.rpl = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.aps_port_status0 = None
                                    self.aps_port_status1 = None
                                    self.aps_channel_level = None
                                    self._segment_path = lambda: "l2fib-g8032-ring-instance-detail" + "[instance='" + str(self.instance) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibG8032.L2fibG8032Rings.L2fibG8032Ring.L2fibG8032RingInstanceDetails.L2fibG8032RingInstanceDetail, ['instance', 'ring_instance', 'vlan_ids', 'ring_profile', 'rpl', 'aps_port0', 'aps_port1', 'aps_port_status0', 'aps_port_status1', 'aps_channel_level'], name, value)


            class L2fibBridgePorts(Entity):
                """
                Bridge Port forwarding detail
                
                .. attribute:: l2fib_bridge_port
                
                	Specify Bridge Domain Name and XC ID
                	**type**\: list of  		 :py:class:`L2fibBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts, self).__init__()

                    self.yang_name = "l2fib-bridge-ports"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-bridge-port", ("l2fib_bridge_port", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort))])
                    self._leafs = OrderedDict()

                    self.l2fib_bridge_port = YList(self)
                    self._segment_path = lambda: "l2fib-bridge-ports"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts, [], name, value)


                class L2fibBridgePort(Entity):
                    """
                    Specify Bridge Domain Name and XC ID
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment>`
                    
                    .. attribute:: bridge_port_operational_info
                    
                    	Bridge port operational information
                    	**type**\:  :py:class:`BridgePortOperationalInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: shg_id
                    
                    	Split horizon group ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xc_id
                    
                    	xconnect ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_hw_mac
                    
                    	Number of HW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_sw_mac
                    
                    	Number of SW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                    
                    .. attribute:: flooding_disabled
                    
                    	Is flooding disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\: bool
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort, self).__init__()

                        self.yang_name = "l2fib-bridge-port"
                        self.yang_parent_name = "l2fib-bridge-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("segment", ("segment", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment)), ("bridge-port-operational-info", ("bridge_port_operational_info", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo))])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('xc_uint_id', YLeaf(YType.str, 'xc-uint-id')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('shg_id', YLeaf(YType.uint32, 'shg-id')),
                            ('xc_id', YLeaf(YType.uint32, 'xc-id')),
                            ('number_of_hw_mac', YLeaf(YType.uint32, 'number-of-hw-mac')),
                            ('number_of_sw_mac', YLeaf(YType.uint32, 'number-of-sw-mac')),
                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                            ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                            ('aging_time_out', YLeaf(YType.uint32, 'aging-time-out')),
                        ])
                        self.group_name = None
                        self.bd_name = None
                        self.xc_uint_id = None
                        self.bridge_id = None
                        self.shg_id = None
                        self.xc_id = None
                        self.number_of_hw_mac = None
                        self.number_of_sw_mac = None
                        self.mac_limit = None
                        self.mac_limit_action = None
                        self.flooding_disabled = None
                        self.mac_learning_disabled = None
                        self.mac_port_down_flush_disabled = None
                        self.mtu = None
                        self.aging_time_out = None

                        self.segment = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"

                        self.bridge_port_operational_info = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo()
                        self.bridge_port_operational_info.parent = self
                        self._children_name_map["bridge_port_operational_info"] = "bridge-port-operational-info"
                        self._segment_path = lambda: "l2fib-bridge-port"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort, ['group_name', 'bd_name', 'xc_uint_id', 'bridge_id', 'shg_id', 'xc_id', 'number_of_hw_mac', 'number_of_sw_mac', 'mac_limit', 'mac_limit_action', 'flooding_disabled', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mtu', 'aging_time_out'], name, value)


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fib-bridge-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.Base>`
                            
                            .. attribute:: fxc_next_hop
                            
                            	Flexible XConnect Service Next Hop
                            	**type**\:  :py:class:`FxcNextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop>`
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: sub_interface_handle
                            
                            	Sub Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit_id
                            
                            	Attachment Circuit ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attachment_circuit_mtu
                            
                            	MTU of Attachment Circuit
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: actype
                            
                            	Attachment Circuit Type
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: inter_working_mode
                            
                            	Interworking Mode
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: adjacency_valid
                            
                            	Adjacency Valid
                            	**type**\: bool
                            
                            .. attribute:: adjacency_address
                            
                            	Adjacency Valid
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: ip_inter_working_mac
                            
                            	IP Interworking MAC
                            	**type**\: str
                            
                            .. attribute:: redundancy_group_id
                            
                            	ICCP Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_object_id
                            
                            	ICCP Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: fxc_next_hop_valid
                            
                            	Is Flexible XConnect Service Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.Base)), ("fxc-next-hop", ("fxc_next_hop", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop))])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('sub_interface_handle', YLeaf(YType.str, 'sub-interface-handle')),
                                    ('attachment_circuit_id', YLeaf(YType.uint32, 'attachment-circuit-id')),
                                    ('attachment_circuit_mtu', YLeaf(YType.uint16, 'attachment-circuit-mtu')),
                                    ('actype', YLeaf(YType.uint8, 'actype')),
                                    ('inter_working_mode', YLeaf(YType.uint8, 'inter-working-mode')),
                                    ('adjacency_valid', YLeaf(YType.boolean, 'adjacency-valid')),
                                    ('adjacency_address', YLeaf(YType.str, 'adjacency-address')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('ip_inter_working_mac', YLeaf(YType.str, 'ip-inter-working-mac')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ('fxc_next_hop_valid', YLeaf(YType.boolean, 'fxc-next-hop-valid')),
                                ])
                                self.interface_handle = None
                                self.sub_interface_handle = None
                                self.attachment_circuit_id = None
                                self.attachment_circuit_mtu = None
                                self.actype = None
                                self.inter_working_mode = None
                                self.adjacency_valid = None
                                self.adjacency_address = None
                                self.bound = None
                                self.ip_inter_working_mac = None
                                self.redundancy_group_id = None
                                self.redundancy_object_id = None
                                self.evpn_internal_label = None
                                self.fxc_next_hop_valid = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.fxc_next_hop = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop()
                                self.fxc_next_hop.parent = self
                                self._children_name_map["fxc_next_hop"] = "fxc-next-hop"
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac, ['interface_handle', 'sub_interface_handle', 'attachment_circuit_id', 'attachment_circuit_mtu', 'actype', 'inter_working_mode', 'adjacency_valid', 'adjacency_address', 'bound', 'ip_inter_working_mac', 'redundancy_group_id', 'redundancy_object_id', 'evpn_internal_label', 'fxc_next_hop_valid'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class FxcNextHop(Entity):
                                """
                                Flexible XConnect Service Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop, self).__init__()

                                    self.yang_name = "fxc-next-hop"
                                    self.yang_parent_name = "ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "fxc-next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Ac.FxcNextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "fxc-next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.Base>`
                            
                            .. attribute:: pbb_union
                            
                            	Union of Edge and Core
                            	**type**\:  :py:class:`PbbUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: core_pbb_evpn_enabled
                            
                            	Core PBB\-EVPN enabled
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.Base)), ("pbb-union", ("pbb_union", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('core_pbb_evpn_enabled', YLeaf(YType.boolean, 'core-pbb-evpn-enabled')),
                                ])
                                self.bound = None
                                self.forward_class = None
                                self.core_pbb_evpn_enabled = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.pbb_union = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion()
                                self.pbb_union.parent = self
                                self._children_name_map["pbb_union"] = "pbb-union"
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb, ['bound', 'forward_class', 'core_pbb_evpn_enabled'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class PbbUnion(Entity):
                                """
                                Union of Edge and Core
                                
                                .. attribute:: edge
                                
                                	edge
                                	**type**\:  :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Edge>`
                                
                                .. attribute:: core
                                
                                	core
                                	**type**\:  :py:class:`Core <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Core>`
                                
                                .. attribute:: pbb_type
                                
                                	PbbType
                                	**type**\:  :py:class:`MgmtL2fibBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridge>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion, self).__init__()

                                    self.yang_name = "pbb-union"
                                    self.yang_parent_name = "pbb"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge", ("edge", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Edge)), ("core", ("core", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Core))])
                                    self._leafs = OrderedDict([
                                        ('pbb_type', YLeaf(YType.enumeration, 'pbb-type')),
                                    ])
                                    self.pbb_type = None

                                    self.edge = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Edge()
                                    self.edge.parent = self
                                    self._children_name_map["edge"] = "edge"

                                    self.core = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Core()
                                    self.core.parent = self
                                    self._children_name_map["core"] = "core"
                                    self._segment_path = lambda: "pbb-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion, ['pbb_type'], name, value)


                                class Edge(Entity):
                                    """
                                    edge
                                    
                                    .. attribute:: mac_configured
                                    
                                    	Configured MAC
                                    	**type**\: bool
                                    
                                    .. attribute:: mac
                                    
                                    	unknown unicast bmac
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Edge, self).__init__()

                                        self.yang_name = "edge"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('mac_configured', YLeaf(YType.boolean, 'mac-configured')),
                                            ('mac', YLeaf(YType.str, 'mac')),
                                        ])
                                        self.mac_configured = None
                                        self.mac = None
                                        self._segment_path = lambda: "edge"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Edge, ['mac_configured', 'mac'], name, value)


                                class Core(Entity):
                                    """
                                    core
                                    
                                    .. attribute:: vlan_id
                                    
                                    	vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Core, self).__init__()

                                        self.yang_name = "core"
                                        self.yang_parent_name = "pbb-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ])
                                        self.vlan_id = None
                                        self._segment_path = lambda: "core"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pbb.PbbUnion.Core, ['vlan_id'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni.Base>`
                            
                            .. attribute:: srcip
                            
                            	VNI Src IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcastip
                            
                            	VNI Mcast IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: encap
                            
                            	Encap type of VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: source_vtep_if
                            
                            	Source IF Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: any_cast_ip
                            
                            	Anycast VTEP IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_ip
                            
                            	Anycast Multicast IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ingress_replication
                            
                            	Ingress Replication supported on VNI
                            	**type**\: bool
                            
                            .. attribute:: vx_lan_mode
                            
                            	Vxlan mode
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni.Base))])
                                self._leafs = OrderedDict([
                                    ('srcip', YLeaf(YType.str, 'srcip')),
                                    ('mcastip', YLeaf(YType.str, 'mcastip')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                    ('encap', YLeaf(YType.uint32, 'encap')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('source_vtep_if', YLeaf(YType.str, 'source-vtep-if')),
                                    ('any_cast_ip', YLeaf(YType.str, 'any-cast-ip')),
                                    ('anycast_mcast_ip', YLeaf(YType.str, 'anycast-mcast-ip')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('vx_lan_mode', YLeaf(YType.uint32, 'vx-lan-mode')),
                                ])
                                self.srcip = None
                                self.mcastip = None
                                self.bound = None
                                self.parent_if = None
                                self.encap = None
                                self.udp_port = None
                                self.source_vtep_if = None
                                self.any_cast_ip = None
                                self.anycast_mcast_ip = None
                                self.ingress_replication = None
                                self.vx_lan_mode = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni, ['srcip', 'mcastip', 'bound', 'parent_if', 'encap', 'udp_port', 'source_vtep_if', 'any_cast_ip', 'anycast_mcast_ip', 'ingress_replication', 'vx_lan_mode'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Vni.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "vni"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn.Base>`
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: evi
                            
                            	EVPN ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn.Base))])
                                self._leafs = OrderedDict([
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ])
                                self.bound = None
                                self.evi = None
                                self.forward_class = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn, ['bound', 'evi', 'forward_class'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Evpn.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "evpn"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: base
                            
                            	Base Information
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.Base>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop>`
                            
                            .. attribute:: pseudo_wire_union
                            
                            	Union of MPLS or L2TP
                            	**type**\:  :py:class:`PseudoWireUnion <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion>`
                            
                            .. attribute:: backup_pseudo_wire
                            
                            	Backup Pseudowire
                            	**type**\:  :py:class:`BackupPseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire>`
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: signal_capability_flags
                            
                            	Sig Capability flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: context
                            
                            	Context
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: sequence_resync_threshold
                            
                            	Sequence Resync Threshold
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: bound
                            
                            	Bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            .. attribute:: backup_configured
                            
                            	Backup Pseudowire Configured
                            	**type**\: bool
                            
                            .. attribute:: redundancy_role
                            
                            	Redundancy Role
                            	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                            
                            .. attribute:: active
                            
                            	PW is active and forwarding
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            .. attribute:: pw_load_balance_type
                            
                            	Type of load\-balancing
                            	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                            
                            .. attribute:: pw_flow_label_tx
                            
                            	Pseudowire flow label TX enabled
                            	**type**\: bool
                            
                            .. attribute:: grouping_supported
                            
                            	Grouping supported
                            	**type**\: bool
                            
                            .. attribute:: group_id
                            
                            	PW Group Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: group_state
                            
                            	Group State
                            	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                            
                            .. attribute:: global_id
                            
                            	Global Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ac_id
                            
                            	Ac Id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.Base)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop)), ("pseudo-wire-union", ("pseudo_wire_union", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion)), ("backup-pseudo-wire", ("backup_pseudo_wire", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire))])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('signal_capability_flags', YLeaf(YType.uint32, 'signal-capability-flags')),
                                    ('context', YLeaf(YType.uint16, 'context')),
                                    ('sequence_resync_threshold', YLeaf(YType.uint16, 'sequence-resync-threshold')),
                                    ('bound', YLeaf(YType.boolean, 'bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                    ('backup_configured', YLeaf(YType.boolean, 'backup-configured')),
                                    ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                    ('pw_load_balance_type', YLeaf(YType.enumeration, 'pw-load-balance-type')),
                                    ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                    ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ('global_id', YLeaf(YType.uint32, 'global-id')),
                                    ('ac_id', YLeaf(YType.uint32, 'ac-id')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ])
                                self.pw_id = None
                                self.signal_capability_flags = None
                                self.context = None
                                self.sequence_resync_threshold = None
                                self.bound = None
                                self.next_hop_valid = None
                                self.backup_configured = None
                                self.redundancy_role = None
                                self.active = None
                                self.pseudo_wire_id_type = None
                                self.pw_load_balance_type = None
                                self.pw_flow_label_tx = None
                                self.grouping_supported = None
                                self.group_id = None
                                self.group_state = None
                                self.global_id = None
                                self.ac_id = None
                                self.forward_class = None
                                self.next_hop_address = None

                                self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"

                                self.pseudo_wire_union = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion()
                                self.pseudo_wire_union.parent = self
                                self._children_name_map["pseudo_wire_union"] = "pseudo-wire-union"

                                self.backup_pseudo_wire = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire()
                                self.backup_pseudo_wire.parent = self
                                self._children_name_map["backup_pseudo_wire"] = "backup-pseudo-wire"
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw, ['pw_id', 'signal_capability_flags', 'context', 'sequence_resync_threshold', 'bound', 'next_hop_valid', 'backup_configured', 'redundancy_role', 'active', 'pseudo_wire_id_type', 'pw_load_balance_type', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state', 'global_id', 'ac_id', 'forward_class', 'next_hop_address'], name, value)


                            class Base(Entity):
                                """
                                Base Information
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict()
                                    self._segment_path = lambda: "base"


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"


                            class PseudoWireUnion(Entity):
                                """
                                Union of MPLS or L2TP
                                
                                .. attribute:: mpls
                                
                                	mpls
                                	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.Mpls>`
                                
                                .. attribute:: l2tp
                                
                                	l2tp
                                	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp>`
                                
                                .. attribute:: l2tpv2
                                
                                	l2tpv2
                                	**type**\:  :py:class:`L2tpv2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2>`
                                
                                .. attribute:: l2tp_ipv6_ts
                                
                                	l2tp ipv6 ts
                                	**type**\:  :py:class:`L2tpIpv6Ts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts>`
                                
                                .. attribute:: data_type
                                
                                	DataType
                                	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion, self).__init__()

                                    self.yang_name = "pseudo-wire-union"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp)), ("l2tpv2", ("l2tpv2", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2)), ("l2tp-ipv6-ts", ("l2tp_ipv6_ts", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts))])
                                    self._leafs = OrderedDict([
                                        ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                    ])
                                    self.data_type = None

                                    self.mpls = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.Mpls()
                                    self.mpls.parent = self
                                    self._children_name_map["mpls"] = "mpls"

                                    self.l2tp = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp()
                                    self.l2tp.parent = self
                                    self._children_name_map["l2tp"] = "l2tp"

                                    self.l2tpv2 = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2()
                                    self.l2tpv2.parent = self
                                    self._children_name_map["l2tpv2"] = "l2tpv2"

                                    self.l2tp_ipv6_ts = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts()
                                    self.l2tp_ipv6_ts.parent = self
                                    self._children_name_map["l2tp_ipv6_ts"] = "l2tp-ipv6-ts"
                                    self._segment_path = lambda: "pseudo-wire-union"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion, ['data_type'], name, value)


                                class Mpls(Entity):
                                    """
                                    mpls
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.Mpls, self).__init__()

                                        self.yang_name = "mpls"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "mpls"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.Mpls, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                                class L2tp(Entity):
                                    """
                                    l2tp
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp, self).__init__()

                                        self.yang_name = "l2tp"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Local, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tp.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                                class L2tpv2(Entity):
                                    """
                                    l2tpv2
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Remote>`
                                    
                                    .. attribute:: pw_flags
                                    
                                    	L2TPv2 PW flags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL [Hops number]
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU [Bytes]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol [UDP RFC\-768]
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rem_udp_port
                                    
                                    	Remote UDP Port
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop_address
                                    
                                    	Next Hop Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: source_address
                                    
                                    	Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2, self).__init__()

                                        self.yang_name = "l2tpv2"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Remote))])
                                        self._leafs = OrderedDict([
                                            ('pw_flags', YLeaf(YType.uint8, 'pw-flags')),
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('protocol', YLeaf(YType.uint16, 'protocol')),
                                            ('rem_udp_port', YLeaf(YType.uint16, 'rem-udp-port')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                        ])
                                        self.pw_flags = None
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.protocol = None
                                        self.rem_udp_port = None
                                        self.xconnect_id = None
                                        self.next_hop_address = None
                                        self.source_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tpv2"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2, ['pw_flags', 'tos_val', 'ttl', 'path_mtu', 'protocol', 'rem_udp_port', 'xconnect_id', 'next_hop_address', 'source_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Local, ['session_id', 'tunnel_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TPv2 session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tunnel_id
                                        
                                        	L2TPv2 tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tpv2"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('tunnel_id', YLeaf(YType.uint32, 'tunnel-id')),
                                            ])
                                            self.session_id = None
                                            self.tunnel_id = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpv2.Remote, ['session_id', 'tunnel_id'], name, value)


                                class L2tpIpv6Ts(Entity):
                                    """
                                    l2tp ipv6 ts
                                    
                                    .. attribute:: local
                                    
                                    	Local session info
                                    	**type**\:  :py:class:`Local <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Local>`
                                    
                                    .. attribute:: remote
                                    
                                    	Remote session info
                                    	**type**\:  :py:class:`Remote <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote>`
                                    
                                    .. attribute:: tos_val
                                    
                                    	TOS val
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	TTL
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: path_mtu
                                    
                                    	Path MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	Number of sequence sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	Number of sequence expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts, self).__init__()

                                        self.yang_name = "l2tp-ipv6-ts"
                                        self.yang_parent_name = "pseudo-wire-union"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local", ("local", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Local)), ("remote", ("remote", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote))])
                                        self._leafs = OrderedDict([
                                            ('tos_val', YLeaf(YType.uint8, 'tos-val')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('path_mtu', YLeaf(YType.uint16, 'path-mtu')),
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ])
                                        self.tos_val = None
                                        self.ttl = None
                                        self.path_mtu = None
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.local_address = None
                                        self.remote_address = None

                                        self.local = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Local()
                                        self.local.parent = self
                                        self._children_name_map["local"] = "local"

                                        self.remote = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote()
                                        self.remote.parent = self
                                        self._children_name_map["remote"] = "remote"
                                        self._segment_path = lambda: "l2tp-ipv6-ts"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts, ['tos_val', 'ttl', 'path_mtu', 'sequence_number_sent', 'sequence_number_expected', 'local_address', 'remote_address'], name, value)


                                    class Local(Entity):
                                        """
                                        Local session info
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_size
                                        
                                        	Secondary Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: secondary_cookie_low_value
                                        
                                        	Secondary Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: secondary_cookie_high_value
                                        
                                        	Secondary Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, self).__init__()

                                            self.yang_name = "local"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                                ('secondary_cookie_size', YLeaf(YType.uint8, 'secondary-cookie-size')),
                                                ('secondary_cookie_low_value', YLeaf(YType.uint32, 'secondary-cookie-low-value')),
                                                ('secondary_cookie_high_value', YLeaf(YType.uint32, 'secondary-cookie-high-value')),
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                            ])
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self.secondary_cookie_size = None
                                            self.secondary_cookie_low_value = None
                                            self.secondary_cookie_high_value = None
                                            self.session_id = None
                                            self._segment_path = lambda: "local"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Local, ['cookie_size', 'cookie_low_value', 'cookie_high_value', 'secondary_cookie_size', 'secondary_cookie_low_value', 'secondary_cookie_high_value', 'session_id'], name, value)


                                    class Remote(Entity):
                                        """
                                        Remote session info
                                        
                                        .. attribute:: session_id
                                        
                                        	L2TP session ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_size
                                        
                                        	Cookie size
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cookie_low_value
                                        
                                        	Cookie low value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: cookie_high_value
                                        
                                        	Cookie high value
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, self).__init__()

                                            self.yang_name = "remote"
                                            self.yang_parent_name = "l2tp-ipv6-ts"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('session_id', YLeaf(YType.uint32, 'session-id')),
                                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                                ('cookie_low_value', YLeaf(YType.uint32, 'cookie-low-value')),
                                                ('cookie_high_value', YLeaf(YType.uint32, 'cookie-high-value')),
                                            ])
                                            self.session_id = None
                                            self.cookie_size = None
                                            self.cookie_low_value = None
                                            self.cookie_high_value = None
                                            self._segment_path = lambda: "remote"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.PseudoWireUnion.L2tpIpv6Ts.Remote, ['session_id', 'cookie_size', 'cookie_low_value', 'cookie_high_value'], name, value)


                            class BackupPseudoWire(Entity):
                                """
                                Backup Pseudowire
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire.Atom>`
                                
                                .. attribute:: backup_next_hop
                                
                                	Backup Next Hop
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: backup_pseudo_wire_id_type
                                
                                	Pseudowire ID type
                                	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                                
                                .. attribute:: backup_pseudo_wire_id
                                
                                	Backup Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_role
                                
                                	Redundancy Role
                                	**type**\:  :py:class:`L2fibPwRedundancyRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwRedundancyRole>`
                                
                                .. attribute:: active
                                
                                	PW is active and forwarding
                                	**type**\: bool
                                
                                .. attribute:: bound
                                
                                	Bound
                                	**type**\: bool
                                
                                .. attribute:: pw_flow_label_tx
                                
                                	Pseudowire flow label TX enabled
                                	**type**\: bool
                                
                                .. attribute:: grouping_supported
                                
                                	Grouping supported
                                	**type**\: bool
                                
                                .. attribute:: group_id
                                
                                	PW Group Id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: group_state
                                
                                	Group State
                                	**type**\:  :py:class:`L2fibGroupState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibGroupState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire, self).__init__()

                                    self.yang_name = "backup-pseudo-wire"
                                    self.yang_parent_name = "pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire.Atom))])
                                    self._leafs = OrderedDict([
                                        ('backup_next_hop', YLeaf(YType.str, 'backup-next-hop')),
                                        ('backup_pseudo_wire_id_type', YLeaf(YType.enumeration, 'backup-pseudo-wire-id-type')),
                                        ('backup_pseudo_wire_id', YLeaf(YType.uint32, 'backup-pseudo-wire-id')),
                                        ('redundancy_role', YLeaf(YType.enumeration, 'redundancy-role')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                        ('bound', YLeaf(YType.boolean, 'bound')),
                                        ('pw_flow_label_tx', YLeaf(YType.boolean, 'pw-flow-label-tx')),
                                        ('grouping_supported', YLeaf(YType.boolean, 'grouping-supported')),
                                        ('group_id', YLeaf(YType.uint32, 'group-id')),
                                        ('group_state', YLeaf(YType.enumeration, 'group-state')),
                                    ])
                                    self.backup_next_hop = None
                                    self.backup_pseudo_wire_id_type = None
                                    self.backup_pseudo_wire_id = None
                                    self.redundancy_role = None
                                    self.active = None
                                    self.bound = None
                                    self.pw_flow_label_tx = None
                                    self.grouping_supported = None
                                    self.group_id = None
                                    self.group_state = None

                                    self.atom = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"
                                    self._segment_path = lambda: "backup-pseudo-wire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire, ['backup_next_hop', 'backup_pseudo_wire_id_type', 'backup_pseudo_wire_id', 'redundancy_role', 'active', 'bound', 'pw_flow_label_tx', 'grouping_supported', 'group_id', 'group_state'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: pw_label
                                    
                                    	PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_local_label
                                    
                                    	Local PW Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_tunnel_interface
                                    
                                    	PW tunnel interface
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pw_xcid
                                    
                                    	PW XCID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "backup-pseudo-wire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_label', YLeaf(YType.uint32, 'pw-label')),
                                            ('pw_local_label', YLeaf(YType.uint32, 'pw-local-label')),
                                            ('pw_tunnel_interface', YLeaf(YType.uint32, 'pw-tunnel-interface')),
                                            ('pw_xcid', YLeaf(YType.uint32, 'pw-xcid')),
                                        ])
                                        self.pw_label = None
                                        self.pw_local_label = None
                                        self.pw_tunnel_interface = None
                                        self.pw_xcid = None
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.Segment.Pw.BackupPseudoWire.Atom, ['pw_label', 'pw_local_label', 'pw_tunnel_interface', 'pw_xcid'], name, value)


                    class BridgePortOperationalInfo(Entity):
                        """
                        Bridge port operational information
                        
                        .. attribute:: operational_information
                        
                        	L2 operational information
                        	**type**\:  :py:class:`OperationalInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation>`
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast storm control pps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast storm control kbps
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo, self).__init__()

                            self.yang_name = "bridge-port-operational-info"
                            self.yang_parent_name = "l2fib-bridge-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("operational-information", ("operational_information", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation))])
                            self._leafs = OrderedDict([
                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                            ])
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_kb_ps = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_kb_ps = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None

                            self.operational_information = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation()
                            self.operational_information.parent = self
                            self._children_name_map["operational_information"] = "operational-information"
                            self._segment_path = lambda: "bridge-port-operational-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo, ['unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps'], name, value)


                        class OperationalInformation(Entity):
                            """
                            L2 operational information
                            
                            .. attribute:: mtu
                            
                            	MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in minutes
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: minute
                            
                            .. attribute:: mac_limit
                            
                            	MAC limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_of_macs
                            
                            	numberOfMacs
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admin_disabled
                            
                            	Is administratively disabled
                            	**type**\: bool
                            
                            .. attribute:: flooding_disabled
                            
                            	Is flooding disabled
                            	**type**\: bool
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Is flooding unknown unicast disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                            
                            .. attribute:: mac_limit_threshold
                            
                            	MAC limit percentage recovery threshold
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: percentage
                            
                            .. attribute:: mac_learning_disabled
                            
                            	Is MAC learning disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_port_down_flush_disabled
                            
                            	Is MAC port down flush disabled
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_notification_type
                            
                            	MAC limit notification
                            	**type**\:  :py:class:`MgmtL2fibMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitNotify>`
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC secure action
                            	**type**\:  :py:class:`MgmtL2fibMacSecAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacSecAction>`
                            
                            .. attribute:: is_mac_secure_accept_shutdown
                            
                            	Is MAC secure accept shutdown (BP only)
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_threshold_enabled
                            
                            	Is MAC Secure Threshold Enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_aging_type
                            
                            	MAC aging type
                            	**type**\: bool
                            
                            .. attribute:: storm_control_unicast_enabled
                            
                            	Is unicast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_broadcast_enabled
                            
                            	Is broadcast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_multicast_enabled
                            
                            	Is multicast storm control enabled
                            	**type**\: bool
                            
                            .. attribute:: storm_control_unicast_rate_unit
                            
                            	Storm control unicast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_broadcast_rate_unit
                            
                            	Storm control broadcast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: storm_control_multicast_rate_unit
                            
                            	Storm control multicast rate unit
                            	**type**\:  :py:class:`L2fibStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibStormControlRateUnit>`
                            
                            .. attribute:: dhcp_enabled
                            
                            	Is DHCP snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: dhcp_trusted
                            
                            	Is DHCP trusted
                            	**type**\: bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_ipv4_enabled
                            
                            	Is DAI IPv4 Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validation_destination_mac_enabled
                            
                            	Is DAI Destination MAC Validation enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_ipsg_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_vpls_flood_optimization_enabled
                            
                            	Is MMRP  Flood Optimization Enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_snoop_enabled
                            
                            	Is IGMP snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_snoop_profile_enabled
                            
                            	Is IGMP snooping profile enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_flood_forward_enabled
                            
                            	Is IGMP flood forwarding enabled
                            	**type**\: bool
                            
                            .. attribute:: igmp_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\: bool
                            
                            .. attribute:: igmp_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_snoop_enabled
                            
                            	Is MLD snooping enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_snoop_profile_enabled
                            
                            	Is MLD snooping profile enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_flood_forward_enabled
                            
                            	Is MLD flood forwarding enabled
                            	**type**\: bool
                            
                            .. attribute:: mld_mroute_port_enabled
                            
                            	Is mrouter port
                            	**type**\: bool
                            
                            .. attribute:: mld_route_guard_enabled
                            
                            	Is router gurad enabled
                            	**type**\: bool
                            
                            .. attribute:: stp_participating
                            
                            	Is Spanning Tree Protocol participating
                            	**type**\: bool
                            
                            .. attribute:: bvi_configured
                            
                            	Is BVI Interface configured
                            	**type**\: bool
                            
                            .. attribute:: is_bvi_up
                            
                            	Is BVI state UP
                            	**type**\: bool
                            
                            .. attribute:: is_vni_enabled
                            
                            	Is VNI enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_enabled
                            
                            	Is EVPN enabled
                            	**type**\: bool
                            
                            .. attribute:: unknown_unicast_flooding_disabled
                            
                            	Unknown Unicast Flooding is disabled
                            	**type**\: bool
                            
                            .. attribute:: is_pbbevpn_enabled
                            
                            	Is PBBEVPN enabled
                            	**type**\: bool
                            
                            .. attribute:: is_swmac_learning
                            
                            	Is SW MAC learning enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_flow_label
                            
                            	Is EVPN Flow Label enabled
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_cw_disable
                            
                            	Is EVPN CW disabled
                            	**type**\: bool
                            
                            .. attribute:: msti
                            
                            	Multi\-spanning tree instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_p2mp_pw_enabled
                            
                            	Is P2MP PW enabled
                            	**type**\: bool
                            
                            .. attribute:: is_igmp_snoop_enabled
                            
                            	Is IGMP Snooping admin enabled
                            	**type**\: bool
                            
                            .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                            
                            	nV Satellite Offload IPv4 Multicast Disabled
                            	**type**\: bool
                            
                            .. attribute:: feature
                            
                            	Feature information
                            	**type**\: list of  		 :py:class:`Feature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation, self).__init__()

                                self.yang_name = "operational-information"
                                self.yang_parent_name = "bridge-port-operational-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("feature", ("feature", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature))])
                                self._leafs = OrderedDict([
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                    ('number_of_macs', YLeaf(YType.uint32, 'number-of-macs')),
                                    ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                                    ('flooding_disabled', YLeaf(YType.boolean, 'flooding-disabled')),
                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                    ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                                    ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                                    ('mac_limit_notification_type', YLeaf(YType.enumeration, 'mac-limit-notification-type')),
                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                    ('is_mac_secure_accept_shutdown', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown')),
                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                    ('mac_aging_type', YLeaf(YType.boolean, 'mac-aging-type')),
                                    ('storm_control_unicast_enabled', YLeaf(YType.boolean, 'storm-control-unicast-enabled')),
                                    ('storm_control_broadcast_enabled', YLeaf(YType.boolean, 'storm-control-broadcast-enabled')),
                                    ('storm_control_multicast_enabled', YLeaf(YType.boolean, 'storm-control-multicast-enabled')),
                                    ('storm_control_unicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-unicast-rate-unit')),
                                    ('storm_control_broadcast_rate_unit', YLeaf(YType.enumeration, 'storm-control-broadcast-rate-unit')),
                                    ('storm_control_multicast_rate_unit', YLeaf(YType.enumeration, 'storm-control-multicast-rate-unit')),
                                    ('dhcp_enabled', YLeaf(YType.boolean, 'dhcp-enabled')),
                                    ('dhcp_trusted', YLeaf(YType.boolean, 'dhcp-trusted')),
                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                    ('is_dai_addr_validation_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-ipv4-enabled')),
                                    ('is_dai_addr_validation_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-source-mac-enabled')),
                                    ('is_dai_addr_validation_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validation-destination-mac-enabled')),
                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                    ('is_ipsg_enabled', YLeaf(YType.boolean, 'is-ipsg-enabled')),
                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                    ('is_vpls_flood_optimization_enabled', YLeaf(YType.boolean, 'is-vpls-flood-optimization-enabled')),
                                    ('igmp_snoop_enabled', YLeaf(YType.boolean, 'igmp-snoop-enabled')),
                                    ('igmp_snoop_profile_enabled', YLeaf(YType.boolean, 'igmp-snoop-profile-enabled')),
                                    ('igmp_flood_forward_enabled', YLeaf(YType.boolean, 'igmp-flood-forward-enabled')),
                                    ('igmp_mroute_port_enabled', YLeaf(YType.boolean, 'igmp-mroute-port-enabled')),
                                    ('igmp_route_guard_enabled', YLeaf(YType.boolean, 'igmp-route-guard-enabled')),
                                    ('mld_snoop_enabled', YLeaf(YType.boolean, 'mld-snoop-enabled')),
                                    ('mld_snoop_profile_enabled', YLeaf(YType.boolean, 'mld-snoop-profile-enabled')),
                                    ('mld_flood_forward_enabled', YLeaf(YType.boolean, 'mld-flood-forward-enabled')),
                                    ('mld_mroute_port_enabled', YLeaf(YType.boolean, 'mld-mroute-port-enabled')),
                                    ('mld_route_guard_enabled', YLeaf(YType.boolean, 'mld-route-guard-enabled')),
                                    ('stp_participating', YLeaf(YType.boolean, 'stp-participating')),
                                    ('bvi_configured', YLeaf(YType.boolean, 'bvi-configured')),
                                    ('is_bvi_up', YLeaf(YType.boolean, 'is-bvi-up')),
                                    ('is_vni_enabled', YLeaf(YType.boolean, 'is-vni-enabled')),
                                    ('is_evpn_enabled', YLeaf(YType.boolean, 'is-evpn-enabled')),
                                    ('unknown_unicast_flooding_disabled', YLeaf(YType.boolean, 'unknown-unicast-flooding-disabled')),
                                    ('is_pbbevpn_enabled', YLeaf(YType.boolean, 'is-pbbevpn-enabled')),
                                    ('is_swmac_learning', YLeaf(YType.boolean, 'is-swmac-learning')),
                                    ('is_evpn_flow_label', YLeaf(YType.boolean, 'is-evpn-flow-label')),
                                    ('is_evpn_cw_disable', YLeaf(YType.boolean, 'is-evpn-cw-disable')),
                                    ('msti', YLeaf(YType.uint32, 'msti')),
                                    ('is_p2mp_pw_enabled', YLeaf(YType.boolean, 'is-p2mp-pw-enabled')),
                                    ('is_igmp_snoop_enabled', YLeaf(YType.boolean, 'is-igmp-snoop-enabled')),
                                    ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                                ])
                                self.mtu = None
                                self.mac_aging_time = None
                                self.mac_limit = None
                                self.number_of_macs = None
                                self.admin_disabled = None
                                self.flooding_disabled = None
                                self.flood_unknown_unicast_enabled = None
                                self.mac_limit_action = None
                                self.mac_limit_threshold = None
                                self.mac_learning_disabled = None
                                self.mac_port_down_flush_disabled = None
                                self.mac_limit_notification_type = None
                                self.is_mac_secure_enabled = None
                                self.is_mac_secure_logging_enabled = None
                                self.mac_secure_action = None
                                self.is_mac_secure_accept_shutdown = None
                                self.is_mac_secure_threshold_enabled = None
                                self.mac_aging_type = None
                                self.storm_control_unicast_enabled = None
                                self.storm_control_broadcast_enabled = None
                                self.storm_control_multicast_enabled = None
                                self.storm_control_unicast_rate_unit = None
                                self.storm_control_broadcast_rate_unit = None
                                self.storm_control_multicast_rate_unit = None
                                self.dhcp_enabled = None
                                self.dhcp_trusted = None
                                self.is_dai_enabled = None
                                self.is_dai_addr_validation_ipv4_enabled = None
                                self.is_dai_addr_validation_source_mac_enabled = None
                                self.is_dai_addr_validation_destination_mac_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_ipsg_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_vpls_flood_optimization_enabled = None
                                self.igmp_snoop_enabled = None
                                self.igmp_snoop_profile_enabled = None
                                self.igmp_flood_forward_enabled = None
                                self.igmp_mroute_port_enabled = None
                                self.igmp_route_guard_enabled = None
                                self.mld_snoop_enabled = None
                                self.mld_snoop_profile_enabled = None
                                self.mld_flood_forward_enabled = None
                                self.mld_mroute_port_enabled = None
                                self.mld_route_guard_enabled = None
                                self.stp_participating = None
                                self.bvi_configured = None
                                self.is_bvi_up = None
                                self.is_vni_enabled = None
                                self.is_evpn_enabled = None
                                self.unknown_unicast_flooding_disabled = None
                                self.is_pbbevpn_enabled = None
                                self.is_swmac_learning = None
                                self.is_evpn_flow_label = None
                                self.is_evpn_cw_disable = None
                                self.msti = None
                                self.is_p2mp_pw_enabled = None
                                self.is_igmp_snoop_enabled = None
                                self.nv_satellite_offload_ipv4_multicast_disabled = None

                                self.feature = YList(self)
                                self._segment_path = lambda: "operational-information"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation, ['mtu', 'mac_aging_time', 'mac_limit', 'number_of_macs', 'admin_disabled', 'flooding_disabled', 'flood_unknown_unicast_enabled', 'mac_limit_action', 'mac_limit_threshold', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'mac_limit_notification_type', 'is_mac_secure_enabled', 'is_mac_secure_logging_enabled', 'mac_secure_action', 'is_mac_secure_accept_shutdown', 'is_mac_secure_threshold_enabled', 'mac_aging_type', 'storm_control_unicast_enabled', 'storm_control_broadcast_enabled', 'storm_control_multicast_enabled', 'storm_control_unicast_rate_unit', 'storm_control_broadcast_rate_unit', 'storm_control_multicast_rate_unit', 'dhcp_enabled', 'dhcp_trusted', 'is_dai_enabled', 'is_dai_addr_validation_ipv4_enabled', 'is_dai_addr_validation_source_mac_enabled', 'is_dai_addr_validation_destination_mac_enabled', 'is_dai_logging_enabled', 'is_ipsg_enabled', 'is_ipsg_logging_enabled', 'is_vpls_flood_optimization_enabled', 'igmp_snoop_enabled', 'igmp_snoop_profile_enabled', 'igmp_flood_forward_enabled', 'igmp_mroute_port_enabled', 'igmp_route_guard_enabled', 'mld_snoop_enabled', 'mld_snoop_profile_enabled', 'mld_flood_forward_enabled', 'mld_mroute_port_enabled', 'mld_route_guard_enabled', 'stp_participating', 'bvi_configured', 'is_bvi_up', 'is_vni_enabled', 'is_evpn_enabled', 'unknown_unicast_flooding_disabled', 'is_pbbevpn_enabled', 'is_swmac_learning', 'is_evpn_flow_label', 'is_evpn_cw_disable', 'msti', 'is_p2mp_pw_enabled', 'is_igmp_snoop_enabled', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                            class Feature(Entity):
                                """
                                Feature information
                                
                                .. attribute:: dhcp
                                
                                	dhcp
                                	**type**\:  :py:class:`Dhcp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp>`
                                
                                .. attribute:: igmp
                                
                                	igmp
                                	**type**\:  :py:class:`Igmp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp>`
                                
                                .. attribute:: mld
                                
                                	mld
                                	**type**\:  :py:class:`Mld <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld>`
                                
                                .. attribute:: feature_type
                                
                                	feature type
                                	**type**\:  :py:class:`L2fibFeature <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibFeature>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature, self).__init__()

                                    self.yang_name = "feature"
                                    self.yang_parent_name = "operational-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("dhcp", ("dhcp", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp)), ("igmp", ("igmp", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp)), ("mld", ("mld", L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld))])
                                    self._leafs = OrderedDict([
                                        ('feature_type', YLeaf(YType.enumeration, 'feature-type')),
                                    ])
                                    self.feature_type = None

                                    self.dhcp = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp()
                                    self.dhcp.parent = self
                                    self._children_name_map["dhcp"] = "dhcp"

                                    self.igmp = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp()
                                    self.igmp.parent = self
                                    self._children_name_map["igmp"] = "igmp"

                                    self.mld = L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld()
                                    self.mld.parent = self
                                    self._children_name_map["mld"] = "mld"
                                    self._segment_path = lambda: "feature"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature, ['feature_type'], name, value)


                                class Dhcp(Entity):
                                    """
                                    dhcp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp, self).__init__()

                                        self.yang_name = "dhcp"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "dhcp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Dhcp, ['profile_name'], name, value)


                                class Igmp(Entity):
                                    """
                                    igmp
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp, self).__init__()

                                        self.yang_name = "igmp"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "igmp"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Igmp, ['profile_name'], name, value)


                                class Mld(Entity):
                                    """
                                    mld
                                    
                                    .. attribute:: profile_name
                                    
                                    	Feature profile name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld, self).__init__()

                                        self.yang_name = "mld"
                                        self.yang_parent_name = "feature"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('profile_name', YLeaf(YType.str, 'profile-name')),
                                        ])
                                        self.profile_name = None
                                        self._segment_path = lambda: "mld"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgePorts.L2fibBridgePort.BridgePortOperationalInfo.OperationalInformation.Feature.Mld, ['profile_name'], name, value)


            class L2fibmacDetails(Entity):
                """
                Bridge MAC detail information
                
                .. attribute:: l2fibmac_detail
                
                	MAC Detail information
                	**type**\: list of  		 :py:class:`L2fibmacDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibmacDetails, self).__init__()

                    self.yang_name = "l2fibmac-details"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fibmac-detail", ("l2fibmac_detail", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail))])
                    self._leafs = OrderedDict()

                    self.l2fibmac_detail = YList(self)
                    self._segment_path = lambda: "l2fibmac-details"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails, [], name, value)


                class L2fibmacDetail(Entity):
                    """
                    MAC Detail information
                    
                    .. attribute:: address
                    
                    	Static MAC address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: base
                    
                    	Base information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Base>`
                    
                    .. attribute:: segment
                    
                    	Segment
                    	**type**\:  :py:class:`Segment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment>`
                    
                    .. attribute:: evpn_ctx
                    
                    	Evpn Context
                    	**type**\:  :py:class:`EvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx>`
                    
                    .. attribute:: next_hop
                    
                    	Next Hop
                    	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop>`
                    
                    .. attribute:: platform_is_hw_learn
                    
                    	Platform is HW Learn
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: node_id
                    
                    	Nodeid list
                    	**type**\: str
                    
                    	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge name
                    	**type**\: str
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bmac_configured
                    
                    	Flag\: Configured BMAC
                    	**type**\: bool
                    
                    .. attribute:: vni_l3_flag
                    
                    	Flag\: L3 Vxlan
                    	**type**\: bool
                    
                    .. attribute:: pbb_bmac
                    
                    	Backbone MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: l3_encapsulationvlan_id
                    
                    	L3 encapsulation Vlan ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: next_hop_valid
                    
                    	IS Next Hop Valid
                    	**type**\: bool
                    
                    .. attribute:: peer_vtep_ip
                    
                    	Peer VTEP IP for this MAC Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: flag_extension
                    
                    	MAC Flag Extension
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: vni
                    
                    	VNI Information
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail, self).__init__()

                        self.yang_name = "l2fibmac-detail"
                        self.yang_parent_name = "l2fibmac-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Base)), ("segment", ("segment", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment)), ("evpn-ctx", ("evpn_ctx", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop))])
                        self._leafs = OrderedDict([
                            ('address', YLeaf(YType.str, 'address')),
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('platform_is_hw_learn', YLeaf(YType.uint8, 'platform-is-hw-learn')),
                            ('node_id', YLeaf(YType.str, 'node-id')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('bmac_configured', YLeaf(YType.boolean, 'bmac-configured')),
                            ('vni_l3_flag', YLeaf(YType.boolean, 'vni-l3-flag')),
                            ('pbb_bmac', YLeaf(YType.str, 'pbb-bmac')),
                            ('l3_encapsulationvlan_id', YLeaf(YType.uint16, 'l3-encapsulationvlan-id')),
                            ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                            ('peer_vtep_ip', YLeaf(YType.str, 'peer-vtep-ip')),
                            ('flag_extension', YLeaf(YType.uint16, 'flag-extension')),
                            ('vni', YLeaf(YType.uint32, 'vni')),
                        ])
                        self.address = None
                        self.group_name = None
                        self.name = None
                        self.platform_is_hw_learn = None
                        self.node_id = None
                        self.bridge_domain_name = None
                        self.bridge_id = None
                        self.bmac_configured = None
                        self.vni_l3_flag = None
                        self.pbb_bmac = None
                        self.l3_encapsulationvlan_id = None
                        self.next_hop_valid = None
                        self.peer_vtep_ip = None
                        self.flag_extension = None
                        self.vni = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"

                        self.segment = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment()
                        self.segment.parent = self
                        self._children_name_map["segment"] = "segment"

                        self.evpn_ctx = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx()
                        self.evpn_ctx.parent = self
                        self._children_name_map["evpn_ctx"] = "evpn-ctx"

                        self.next_hop = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop()
                        self.next_hop.parent = self
                        self._children_name_map["next_hop"] = "next-hop"
                        self._segment_path = lambda: "l2fibmac-detail"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail, ['address', 'group_name', 'name', 'platform_is_hw_learn', 'node_id', 'bridge_domain_name', 'bridge_id', 'bmac_configured', 'vni_l3_flag', 'pbb_bmac', 'l3_encapsulationvlan_id', 'next_hop_valid', 'peer_vtep_ip', 'flag_extension', 'vni'], name, value)


                    class Base(Entity):
                        """
                        Base information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "l2fibmac-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                    class Segment(Entity):
                        """
                        Segment
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Ac>`
                        
                        .. attribute:: pbb
                        
                        	pbb
                        	**type**\:  :py:class:`Pbb <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pbb>`
                        
                        .. attribute:: vni
                        
                        	vni
                        	**type**\:  :py:class:`Vni <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Vni>`
                        
                        .. attribute:: evpn
                        
                        	evpn
                        	**type**\:  :py:class:`Evpn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Evpn>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment, self).__init__()

                            self.yang_name = "segment"
                            self.yang_parent_name = "l2fibmac-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Ac)), ("pbb", ("pbb", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pbb)), ("vni", ("vni", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Vni)), ("evpn", ("evpn", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Evpn)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pbb = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pbb()
                            self.pbb.parent = self
                            self._children_name_map["pbb"] = "pbb"

                            self.vni = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Vni()
                            self.vni.parent = self
                            self._children_name_map["vni"] = "vni"

                            self.evpn = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Evpn()
                            self.evpn.parent = self
                            self._children_name_map["evpn"] = "evpn"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "segment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ])
                                self.interface_handle = None
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Ac, ['interface_handle'], name, value)


                        class Pbb(Entity):
                            """
                            pbb
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pbb, self).__init__()

                                self.yang_name = "pbb"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "pbb"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pbb, ['xcid'], name, value)


                        class Vni(Entity):
                            """
                            vni
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: parent_if
                            
                            	Parent NVE Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Vni, self).__init__()

                                self.yang_name = "vni"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                    ('parent_if', YLeaf(YType.str, 'parent-if')),
                                ])
                                self.xcid = None
                                self.parent_if = None
                                self._segment_path = lambda: "vni"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Vni, ['xcid', 'parent_if'], name, value)


                        class Evpn(Entity):
                            """
                            evpn
                            
                            .. attribute:: xcid
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Evpn, self).__init__()

                                self.yang_name = "evpn"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ])
                                self.xcid = None
                                self._segment_path = lambda: "evpn"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Evpn, ['xcid'], name, value)


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                ])
                                self.pw_id = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.Segment.Pw, ['pw_id', 'next_hop_address', 'pseudo_wire_id_type'], name, value)


                    class EvpnCtx(Entity):
                        """
                        Evpn Context
                        
                        .. attribute:: mcast_ole
                        
                        	mcast ole
                        	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx.McastOle>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibBridgeMacEvpnCtx <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibBridgeMacEvpnCtx>`
                        
                        .. attribute:: esi_id
                        
                        	EsiID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: local_label
                        
                        	LocalLabel
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bp_ifh
                        
                        	BP IFH
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx, self).__init__()

                            self.yang_name = "evpn-ctx"
                            self.yang_parent_name = "l2fibmac-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx.McastOle))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ('esi_id', YLeaf(YType.uint16, 'esi-id')),
                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                ('bp_ifh', YLeaf(YType.str, 'bp-ifh')),
                            ])
                            self.data_type = None
                            self.esi_id = None
                            self.local_label = None
                            self.bp_ifh = None

                            self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx.McastOle()
                            self.mcast_ole.parent = self
                            self._children_name_map["mcast_ole"] = "mcast-ole"
                            self._segment_path = lambda: "evpn-ctx"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx, ['data_type', 'esi_id', 'local_label', 'bp_ifh'], name, value)


                        class McastOle(Entity):
                            """
                            mcast ole
                            
                            .. attribute:: next_hop_ipv6_addr
                            
                            	Next Hop IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_label
                            
                            	Inclusive mcast label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx.McastOle, self).__init__()

                                self.yang_name = "mcast-ole"
                                self.yang_parent_name = "evpn-ctx"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                    ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                ])
                                self.next_hop_ipv6_addr = None
                                self.mcast_label = None
                                self._segment_path = lambda: "mcast-ole"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.EvpnCtx.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                    class NextHop(Entity):
                        """
                        Next Hop
                        
                        .. attribute:: base
                        
                        	Base Information
                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop.Base>`
                        
                        .. attribute:: next_hop_address
                        
                        	NHOP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_address_v6
                        
                        	NHOP Address V6
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: next_hop_internal_label
                        
                        	NHOP Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ecd_plaformt_data_valid
                        
                        	Is Platform ECD Data Valid
                        	**type**\: bool
                        
                        .. attribute:: ecd_platform_data_length
                        
                        	Platform ECD Data Length
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: children_count
                        
                        	Children Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop, self).__init__()

                            self.yang_name = "next-hop"
                            self.yang_parent_name = "l2fibmac-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop.Base))])
                            self._leafs = OrderedDict([
                                ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                ('children_count', YLeaf(YType.uint32, 'children-count')),
                            ])
                            self.next_hop_address = None
                            self.next_hop_address_v6 = None
                            self.next_hop_internal_label = None
                            self.ecd_plaformt_data_valid = None
                            self.ecd_platform_data_length = None
                            self.children_count = None

                            self.base = L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop.Base()
                            self.base.parent = self
                            self._children_name_map["base"] = "base"
                            self._segment_path = lambda: "next-hop"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                        class Base(Entity):
                            """
                            Base Information
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibmacDetails.L2fibmacDetail.NextHop.Base, self).__init__()

                                self.yang_name = "base"
                                self.yang_parent_name = "next-hop"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict()
                                self._segment_path = lambda: "base"


            class L2fibBridgeDomainNames(Entity):
                """
                Bridge Domain forwarding detail
                
                .. attribute:: l2fib_bridge_domain_name
                
                	Specify Bridge Domain Name
                	**type**\: list of  		 :py:class:`L2fibBridgeDomainName <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames.L2fibBridgeDomainName>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames, self).__init__()

                    self.yang_name = "l2fib-bridge-domain-names"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-bridge-domain-name", ("l2fib_bridge_domain_name", L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames.L2fibBridgeDomainName))])
                    self._leafs = OrderedDict()

                    self.l2fib_bridge_domain_name = YList(self)
                    self._segment_path = lambda: "l2fib-bridge-domain-names"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames, [], name, value)


                class L2fibBridgeDomainName(Entity):
                    """
                    Specify Bridge Domain Name
                    
                    .. attribute:: bd_group_name
                    
                    	Name of the Bridge group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_name
                    
                    	Bridge name
                    	**type**\: str
                    
                    .. attribute:: mac_limit
                    
                    	MAC limit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_limit_action
                    
                    	MAC limit action
                    	**type**\:  :py:class:`MgmtL2fibMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibMacLimitAction>`
                    
                    .. attribute:: flood_disabled
                    
                    	Is flooding disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_learning_disabled
                    
                    	Is MAC learning disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_port_down_flush_disabled
                    
                    	Is MAC port down flush disabled
                    	**type**\: bool
                    
                    .. attribute:: admin_disabled
                    
                    	Is administratively disabled
                    	**type**\: bool
                    
                    .. attribute:: bridge_port_count
                    
                    	Number of bridge ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_shg
                    
                    	Number of split horizon groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_hwmac
                    
                    	Number of HW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_swmac
                    
                    	Number of SW MAC addresses
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mtu
                    
                    	MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: aging_time_out
                    
                    	Aging timeout
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti
                    
                    	multi\-spanning tree instance
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames.L2fibBridgeDomainName, self).__init__()

                        self.yang_name = "l2fib-bridge-domain-name"
                        self.yang_parent_name = "l2fib-bridge-domain-names"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('bridge_name', YLeaf(YType.str, 'bridge-name')),
                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                            ('flood_disabled', YLeaf(YType.boolean, 'flood-disabled')),
                            ('mac_learning_disabled', YLeaf(YType.boolean, 'mac-learning-disabled')),
                            ('mac_port_down_flush_disabled', YLeaf(YType.boolean, 'mac-port-down-flush-disabled')),
                            ('admin_disabled', YLeaf(YType.boolean, 'admin-disabled')),
                            ('bridge_port_count', YLeaf(YType.uint32, 'bridge-port-count')),
                            ('number_of_shg', YLeaf(YType.uint32, 'number-of-shg')),
                            ('number_of_hwmac', YLeaf(YType.uint32, 'number-of-hwmac')),
                            ('number_of_swmac', YLeaf(YType.uint32, 'number-of-swmac')),
                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                            ('aging_time_out', YLeaf(YType.uint32, 'aging-time-out')),
                            ('msti', YLeaf(YType.uint32, 'msti')),
                        ])
                        self.bd_group_name = None
                        self.name = None
                        self.bridge_id = None
                        self.bridge_name = None
                        self.mac_limit = None
                        self.mac_limit_action = None
                        self.flood_disabled = None
                        self.mac_learning_disabled = None
                        self.mac_port_down_flush_disabled = None
                        self.admin_disabled = None
                        self.bridge_port_count = None
                        self.number_of_shg = None
                        self.number_of_hwmac = None
                        self.number_of_swmac = None
                        self.mtu = None
                        self.aging_time_out = None
                        self.msti = None
                        self._segment_path = lambda: "l2fib-bridge-domain-name"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibBridgeDomainNames.L2fibBridgeDomainName, ['bd_group_name', 'name', 'bridge_id', 'bridge_name', 'mac_limit', 'mac_limit_action', 'flood_disabled', 'mac_learning_disabled', 'mac_port_down_flush_disabled', 'admin_disabled', 'bridge_port_count', 'number_of_shg', 'number_of_hwmac', 'number_of_swmac', 'mtu', 'aging_time_out', 'msti'], name, value)


            class L2fibMroutePorts(Entity):
                """
                multicast bridge port information 
                
                .. attribute:: l2fib_mroute_port
                
                	Multicast Port Information
                	**type**\: list of  		 :py:class:`L2fibMroutePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts, self).__init__()

                    self.yang_name = "l2fib-mroute-ports"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mroute-port", ("l2fib_mroute_port", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort))])
                    self._leafs = OrderedDict()

                    self.l2fib_mroute_port = YList(self)
                    self._segment_path = lambda: "l2fib-mroute-ports"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts, [], name, value)


                class L2fibMroutePort(Entity):
                    """
                    Multicast Port Information
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: xcid
                    
                    	XConnect ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: source
                    
                    	Source IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: group
                    
                    	Group IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: base_information
                    
                    	Base Information
                    	**type**\:  :py:class:`BaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.BaseInformation>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:  :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats>`
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.SourcePrefix>`
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.DestinationPrefix>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_interface_handle
                    
                    	AC If handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: leaf_pointer
                    
                    	Leaf Ptr
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_id
                    
                    	PW ID
                    	**type**\: str
                    
                    	**length:** 0..40
                    
                    .. attribute:: next_hop_address
                    
                    	NHOP IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: isid
                    
                    	Isid Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: csfl
                    
                    	Csfl Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sat_id
                    
                    	Sat Id
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: is_ole_offloaded
                    
                    	Ole Offloaded
                    	**type**\: bool
                    
                    .. attribute:: is_ole_master
                    
                    	Ole Master
                    	**type**\: bool
                    
                    .. attribute:: is_topo_hub_and_spoke
                    
                    	Topo HubAndSpoke
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort, self).__init__()

                        self.yang_name = "l2fib-mroute-port"
                        self.yang_parent_name = "l2fib-mroute-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base-information", ("base_information", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.BaseInformation)), ("forward-stats", ("forward_stats", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats)), ("source-prefix", ("source_prefix", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.SourcePrefix)), ("destination-prefix", ("destination_prefix", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.DestinationPrefix))])
                        self._leafs = OrderedDict([
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('xcid', YLeaf(YType.str, 'xcid')),
                            ('source', YLeaf(YType.str, 'source')),
                            ('group', YLeaf(YType.str, 'group')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('ac_interface_handle', YLeaf(YType.str, 'ac-interface-handle')),
                            ('leaf_pointer', YLeaf(YType.uint32, 'leaf-pointer')),
                            ('pw_id', YLeaf(YType.str, 'pw-id')),
                            ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                            ('isid', YLeaf(YType.uint32, 'isid')),
                            ('csfl', YLeaf(YType.uint32, 'csfl')),
                            ('sat_id', YLeaf(YType.uint16, 'sat-id')),
                            ('is_ole_offloaded', YLeaf(YType.boolean, 'is-ole-offloaded')),
                            ('is_ole_master', YLeaf(YType.boolean, 'is-ole-master')),
                            ('is_topo_hub_and_spoke', YLeaf(YType.boolean, 'is-topo-hub-and-spoke')),
                        ])
                        self.bd_name = None
                        self.xcid = None
                        self.source = None
                        self.group = None
                        self.bridge_id = None
                        self.ac_interface_handle = None
                        self.leaf_pointer = None
                        self.pw_id = None
                        self.next_hop_address = None
                        self.isid = None
                        self.csfl = None
                        self.sat_id = None
                        self.is_ole_offloaded = None
                        self.is_ole_master = None
                        self.is_topo_hub_and_spoke = None

                        self.base_information = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.BaseInformation()
                        self.base_information.parent = self
                        self._children_name_map["base_information"] = "base-information"

                        self.forward_stats = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"

                        self.source_prefix = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"

                        self.destination_prefix = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"
                        self._segment_path = lambda: "l2fib-mroute-port"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort, ['bd_name', 'xcid', 'source', 'group', 'bridge_id', 'ac_interface_handle', 'leaf_pointer', 'pw_id', 'next_hop_address', 'isid', 'csfl', 'sat_id', 'is_ole_offloaded', 'is_ole_master', 'is_topo_hub_and_spoke'], name, value)


                    class BaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.BaseInformation, self).__init__()

                            self.yang_name = "base-information"
                            self.yang_parent_name = "l2fib-mroute-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base-information"


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:  :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mroute-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forward-stat", ("forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat))])
                            self._leafs = OrderedDict()

                            self.forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._segment_path = lambda: "forward-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats, [], name, value)


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:  :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast>`
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:  :py:class:`MgmtL2fibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibStatsData>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mulicast", ("mulicast", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast))])
                                self._leafs = OrderedDict([
                                    ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ])
                                self.data_type = None

                                self.mulicast = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._segment_path = lambda: "forward-stat"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat, ['data_type'], name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:  :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:  :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:  :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:  :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:  :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("multicast-forward-stat", ("multicast_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat)), ("received-stat", ("received_stat", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat)), ("punt", ("punt", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt)), ("drop", ("drop", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop)), ("multicast-core-forward-stat", ("multicast_core_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat)), ("core-received-stat", ("core_received_stat", L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat))])
                                    self._leafs = OrderedDict()

                                    self.multicast_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"

                                    self.received_stat = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"

                                    self.punt = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"

                                    self.drop = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"

                                    self.multicast_core_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"

                                    self.core_received_stat = L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._segment_path = lambda: "mulicast"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast, [], name, value)


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, ['packets', 'bytes'], name, value)


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.ReceivedStat, ['packets', 'bytes'], name, value)


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "punt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Punt, ['packets', 'bytes'], name, value)


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.Drop, ['packets', 'bytes'], name, value)


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-core-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, ['packets', 'bytes'], name, value)


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "core-received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, ['packets', 'bytes'], name, value)


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mroute-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "source-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.SourcePrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mroute-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "destination-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMroutePorts.L2fibMroutePort.DestinationPrefix, ['proto', 'prefix_length', 'prefix'], name, value)


            class L2fibSummary(Entity):
                """
                L2FIB Summary information
                
                .. attribute:: xconnect_summary
                
                	xconnect db summary info
                	**type**\:  :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.XconnectSummary>`
                
                .. attribute:: next_hop_summary
                
                	nhop db summry info
                	**type**\:  :py:class:`NextHopSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary>`
                
                .. attribute:: l2tp_disposition_summary
                
                	L2TP disposition object summary
                	**type**\:  :py:class:`L2tpDispositionSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.L2tpDispositionSummary>`
                
                .. attribute:: bridge_domain_summary
                
                	Bridge\-domain summary info
                	**type**\:  :py:class:`BridgeDomainSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.BridgeDomainSummary>`
                
                .. attribute:: mac_summary
                
                	mac summary info
                	**type**\:  :py:class:`MacSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.MacSummary>`
                
                .. attribute:: queue_summary
                
                	queue summary info
                	**type**\:  :py:class:`QueueSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.QueueSummary>`
                
                .. attribute:: evpn_summary
                
                	evpn summary info
                	**type**\:  :py:class:`EvpnSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.EvpnSummary>`
                
                .. attribute:: global_cfg
                
                	Global configuration
                	**type**\:  :py:class:`GlobalCfg <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg>`
                
                .. attribute:: ptree_summary
                
                	P2MP PTree summary info
                	**type**\:  :py:class:`PtreeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.PtreeSummary>`
                
                .. attribute:: pw_group_summary
                
                	PWGroup summary info
                	**type**\:  :py:class:`PwGroupSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.PwGroupSummary>`
                
                .. attribute:: pwhe_mp_summary
                
                	PWHE Main\-port summary info
                	**type**\:  :py:class:`PwheMpSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.PwheMpSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibSummary, self).__init__()

                    self.yang_name = "l2fib-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("xconnect-summary", ("xconnect_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.XconnectSummary)), ("next-hop-summary", ("next_hop_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary)), ("l2tp-disposition-summary", ("l2tp_disposition_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.L2tpDispositionSummary)), ("bridge-domain-summary", ("bridge_domain_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.BridgeDomainSummary)), ("mac-summary", ("mac_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.MacSummary)), ("queue-summary", ("queue_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.QueueSummary)), ("evpn-summary", ("evpn_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.EvpnSummary)), ("global-cfg", ("global_cfg", L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg)), ("ptree-summary", ("ptree_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.PtreeSummary)), ("pw-group-summary", ("pw_group_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.PwGroupSummary)), ("pwhe-mp-summary", ("pwhe_mp_summary", L2vpnForwarding.Nodes.Node.L2fibSummary.PwheMpSummary))])
                    self._leafs = OrderedDict()

                    self.xconnect_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.XconnectSummary()
                    self.xconnect_summary.parent = self
                    self._children_name_map["xconnect_summary"] = "xconnect-summary"

                    self.next_hop_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary()
                    self.next_hop_summary.parent = self
                    self._children_name_map["next_hop_summary"] = "next-hop-summary"

                    self.l2tp_disposition_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.L2tpDispositionSummary()
                    self.l2tp_disposition_summary.parent = self
                    self._children_name_map["l2tp_disposition_summary"] = "l2tp-disposition-summary"

                    self.bridge_domain_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.BridgeDomainSummary()
                    self.bridge_domain_summary.parent = self
                    self._children_name_map["bridge_domain_summary"] = "bridge-domain-summary"

                    self.mac_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.MacSummary()
                    self.mac_summary.parent = self
                    self._children_name_map["mac_summary"] = "mac-summary"

                    self.queue_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.QueueSummary()
                    self.queue_summary.parent = self
                    self._children_name_map["queue_summary"] = "queue-summary"

                    self.evpn_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.EvpnSummary()
                    self.evpn_summary.parent = self
                    self._children_name_map["evpn_summary"] = "evpn-summary"

                    self.global_cfg = L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg()
                    self.global_cfg.parent = self
                    self._children_name_map["global_cfg"] = "global-cfg"

                    self.ptree_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.PtreeSummary()
                    self.ptree_summary.parent = self
                    self._children_name_map["ptree_summary"] = "ptree-summary"

                    self.pw_group_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.PwGroupSummary()
                    self.pw_group_summary.parent = self
                    self._children_name_map["pw_group_summary"] = "pw-group-summary"

                    self.pwhe_mp_summary = L2vpnForwarding.Nodes.Node.L2fibSummary.PwheMpSummary()
                    self.pwhe_mp_summary.parent = self
                    self._children_name_map["pwhe_mp_summary"] = "pwhe-mp-summary"
                    self._segment_path = lambda: "l2fib-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary, [], name, value)


                class XconnectSummary(Entity):
                    """
                    xconnect db summary info
                    
                    .. attribute:: xconnect_count
                    
                    	total number of entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_up_count
                    
                    	number of up entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xconnect_down_count
                    
                    	number of down entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_mpls
                    
                    	number of ac\->pw\-mpls entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp
                    
                    	number of ac\->pw\-l2tp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tp_ip_v6
                    
                    	number of ac\->pw\-l2tp\-ipv6 entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_pw_count_l2tpv2
                    
                    	number of ac\->pw\-l2tpv2 entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_ac_count
                    
                    	number of ac\->ac entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_unknown_count
                    
                    	number of ac\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_pw_count
                    
                    	number of monitor\_session\->pw entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mon_sess_to_unknown_count
                    
                    	number of monitor\_session\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_to_bp_count
                    
                    	number of ac\->bp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_bp_count
                    
                    	number of pw\->bp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_to_unknown_count
                    
                    	number of pw\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_bp_count
                    
                    	number of pbb\->bp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_to_unknown_count
                    
                    	number of pbb\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_bp_count
                    
                    	number of vni\->bp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_to_unknown_count
                    
                    	number of vni\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_bp_count
                    
                    	number of evpn\->bp entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_to_unknown_count
                    
                    	number of evpn\->unknown type entries
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_aib
                    
                    	number of down acs with reason aib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l2vpn
                    
                    	number of down acs with reason l2vpn
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_l3fib
                    
                    	number of down acs with reason fib
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ac_down_count_vpdn
                    
                    	number of down acs with reason vpdn
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpws_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPWS PW invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VPLS PW invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_ac_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to Virtual AC invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pbb_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to PBB invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vni_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to VNI invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_invalid_xid_drop_count
                    
                    	number of xc updates dropped due to EVPN invalid xid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpls_pw_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max VPLS PWs exceeded
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bundle_ac_max_exceeded_drop_cnt
                    
                    	number of xc updates dropped due to max Bundle ACs exceeded
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: p2p_count
                    
                    	number of p2p xconnects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bp_count
                    
                    	number of bridge\-port xconnects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pwhe_l2_if_count
                    
                    	number of PWHE L2IF xconnects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.XconnectSummary, self).__init__()

                        self.yang_name = "xconnect-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('xconnect_count', YLeaf(YType.uint32, 'xconnect-count')),
                            ('xconnect_up_count', YLeaf(YType.uint32, 'xconnect-up-count')),
                            ('xconnect_down_count', YLeaf(YType.uint32, 'xconnect-down-count')),
                            ('ac_to_pw_count_mpls', YLeaf(YType.uint32, 'ac-to-pw-count-mpls')),
                            ('ac_to_pw_count_l2tp', YLeaf(YType.uint32, 'ac-to-pw-count-l2tp')),
                            ('ac_to_pw_count_l2tp_ip_v6', YLeaf(YType.uint32, 'ac-to-pw-count-l2tp-ip-v6')),
                            ('ac_to_pw_count_l2tpv2', YLeaf(YType.uint32, 'ac-to-pw-count-l2tpv2')),
                            ('ac_to_ac_count', YLeaf(YType.uint32, 'ac-to-ac-count')),
                            ('ac_to_unknown_count', YLeaf(YType.uint32, 'ac-to-unknown-count')),
                            ('mon_sess_to_pw_count', YLeaf(YType.uint32, 'mon-sess-to-pw-count')),
                            ('mon_sess_to_unknown_count', YLeaf(YType.uint32, 'mon-sess-to-unknown-count')),
                            ('ac_to_bp_count', YLeaf(YType.uint32, 'ac-to-bp-count')),
                            ('pw_to_bp_count', YLeaf(YType.uint32, 'pw-to-bp-count')),
                            ('pw_to_unknown_count', YLeaf(YType.uint32, 'pw-to-unknown-count')),
                            ('pbb_to_bp_count', YLeaf(YType.uint32, 'pbb-to-bp-count')),
                            ('pbb_to_unknown_count', YLeaf(YType.uint32, 'pbb-to-unknown-count')),
                            ('vni_to_bp_count', YLeaf(YType.uint32, 'vni-to-bp-count')),
                            ('vni_to_unknown_count', YLeaf(YType.uint32, 'vni-to-unknown-count')),
                            ('evpn_to_bp_count', YLeaf(YType.uint32, 'evpn-to-bp-count')),
                            ('evpn_to_unknown_count', YLeaf(YType.uint32, 'evpn-to-unknown-count')),
                            ('ac_down_count_aib', YLeaf(YType.uint32, 'ac-down-count-aib')),
                            ('ac_down_count_l2vpn', YLeaf(YType.uint32, 'ac-down-count-l2vpn')),
                            ('ac_down_count_l3fib', YLeaf(YType.uint32, 'ac-down-count-l3fib')),
                            ('ac_down_count_vpdn', YLeaf(YType.uint32, 'ac-down-count-vpdn')),
                            ('vpws_pw_invalid_xid_drop_count', YLeaf(YType.uint32, 'vpws-pw-invalid-xid-drop-count')),
                            ('vpls_pw_invalid_xid_drop_count', YLeaf(YType.uint32, 'vpls-pw-invalid-xid-drop-count')),
                            ('virtual_ac_invalid_xid_drop_count', YLeaf(YType.uint32, 'virtual-ac-invalid-xid-drop-count')),
                            ('pbb_invalid_xid_drop_count', YLeaf(YType.uint32, 'pbb-invalid-xid-drop-count')),
                            ('vni_invalid_xid_drop_count', YLeaf(YType.uint32, 'vni-invalid-xid-drop-count')),
                            ('evpn_invalid_xid_drop_count', YLeaf(YType.uint32, 'evpn-invalid-xid-drop-count')),
                            ('vpls_pw_max_exceeded_drop_cnt', YLeaf(YType.uint32, 'vpls-pw-max-exceeded-drop-cnt')),
                            ('bundle_ac_max_exceeded_drop_cnt', YLeaf(YType.uint32, 'bundle-ac-max-exceeded-drop-cnt')),
                            ('p2p_count', YLeaf(YType.uint32, 'p2p-count')),
                            ('bp_count', YLeaf(YType.uint32, 'bp-count')),
                            ('pwhe_l2_if_count', YLeaf(YType.uint32, 'pwhe-l2-if-count')),
                        ])
                        self.xconnect_count = None
                        self.xconnect_up_count = None
                        self.xconnect_down_count = None
                        self.ac_to_pw_count_mpls = None
                        self.ac_to_pw_count_l2tp = None
                        self.ac_to_pw_count_l2tp_ip_v6 = None
                        self.ac_to_pw_count_l2tpv2 = None
                        self.ac_to_ac_count = None
                        self.ac_to_unknown_count = None
                        self.mon_sess_to_pw_count = None
                        self.mon_sess_to_unknown_count = None
                        self.ac_to_bp_count = None
                        self.pw_to_bp_count = None
                        self.pw_to_unknown_count = None
                        self.pbb_to_bp_count = None
                        self.pbb_to_unknown_count = None
                        self.vni_to_bp_count = None
                        self.vni_to_unknown_count = None
                        self.evpn_to_bp_count = None
                        self.evpn_to_unknown_count = None
                        self.ac_down_count_aib = None
                        self.ac_down_count_l2vpn = None
                        self.ac_down_count_l3fib = None
                        self.ac_down_count_vpdn = None
                        self.vpws_pw_invalid_xid_drop_count = None
                        self.vpls_pw_invalid_xid_drop_count = None
                        self.virtual_ac_invalid_xid_drop_count = None
                        self.pbb_invalid_xid_drop_count = None
                        self.vni_invalid_xid_drop_count = None
                        self.evpn_invalid_xid_drop_count = None
                        self.vpls_pw_max_exceeded_drop_cnt = None
                        self.bundle_ac_max_exceeded_drop_cnt = None
                        self.p2p_count = None
                        self.bp_count = None
                        self.pwhe_l2_if_count = None
                        self._segment_path = lambda: "xconnect-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.XconnectSummary, ['xconnect_count', 'xconnect_up_count', 'xconnect_down_count', 'ac_to_pw_count_mpls', 'ac_to_pw_count_l2tp', 'ac_to_pw_count_l2tp_ip_v6', 'ac_to_pw_count_l2tpv2', 'ac_to_ac_count', 'ac_to_unknown_count', 'mon_sess_to_pw_count', 'mon_sess_to_unknown_count', 'ac_to_bp_count', 'pw_to_bp_count', 'pw_to_unknown_count', 'pbb_to_bp_count', 'pbb_to_unknown_count', 'vni_to_bp_count', 'vni_to_unknown_count', 'evpn_to_bp_count', 'evpn_to_unknown_count', 'ac_down_count_aib', 'ac_down_count_l2vpn', 'ac_down_count_l3fib', 'ac_down_count_vpdn', 'vpws_pw_invalid_xid_drop_count', 'vpls_pw_invalid_xid_drop_count', 'virtual_ac_invalid_xid_drop_count', 'pbb_invalid_xid_drop_count', 'vni_invalid_xid_drop_count', 'evpn_invalid_xid_drop_count', 'vpls_pw_max_exceeded_drop_cnt', 'bundle_ac_max_exceeded_drop_cnt', 'p2p_count', 'bp_count', 'pwhe_l2_if_count'], name, value)


                class NextHopSummary(Entity):
                    """
                    nhop db summry info
                    
                    .. attribute:: mpls_il
                    
                    	MPLS Internal Label nexthop summary
                    	**type**\:  :py:class:`MplsIl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.MplsIl>`
                    
                    .. attribute:: mpls
                    
                    	MPLS nexthop summary
                    	**type**\:  :py:class:`Mpls <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Mpls>`
                    
                    .. attribute:: l2tp
                    
                    	L2TP nexthop summary
                    	**type**\:  :py:class:`L2tp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.L2tp>`
                    
                    .. attribute:: lsm
                    
                    	LSM nexthop summary
                    	**type**\:  :py:class:`Lsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Lsm>`
                    
                    .. attribute:: p2mp_tunnels
                    
                    	P2MPtun nexthop summary
                    	**type**\:  :py:class:`P2mpTunnels <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.P2mpTunnels>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary, self).__init__()

                        self.yang_name = "next-hop-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mpls-il", ("mpls_il", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.MplsIl)), ("mpls", ("mpls", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Mpls)), ("l2tp", ("l2tp", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.L2tp)), ("lsm", ("lsm", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Lsm)), ("p2mp-tunnels", ("p2mp_tunnels", L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.P2mpTunnels))])
                        self._leafs = OrderedDict()

                        self.mpls_il = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.MplsIl()
                        self.mpls_il.parent = self
                        self._children_name_map["mpls_il"] = "mpls-il"

                        self.mpls = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Mpls()
                        self.mpls.parent = self
                        self._children_name_map["mpls"] = "mpls"

                        self.l2tp = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.L2tp()
                        self.l2tp.parent = self
                        self._children_name_map["l2tp"] = "l2tp"

                        self.lsm = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Lsm()
                        self.lsm.parent = self
                        self._children_name_map["lsm"] = "lsm"

                        self.p2mp_tunnels = L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.P2mpTunnels()
                        self.p2mp_tunnels.parent = self
                        self._children_name_map["p2mp_tunnels"] = "p2mp-tunnels"
                        self._segment_path = lambda: "next-hop-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary, [], name, value)


                    class MplsIl(Entity):
                        """
                        MPLS Internal Label nexthop summary
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.MplsIl, self).__init__()

                            self.yang_name = "mpls-il"
                            self.yang_parent_name = "next-hop-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('next_hop_count', YLeaf(YType.uint32, 'next-hop-count')),
                                ('bound_next_hop_count', YLeaf(YType.uint32, 'bound-next-hop-count')),
                                ('unbound_next_hop_count', YLeaf(YType.uint32, 'unbound-next-hop-count')),
                                ('next_hop_pending_registration_count', YLeaf(YType.uint32, 'next-hop-pending-registration-count')),
                            ])
                            self.next_hop_count = None
                            self.bound_next_hop_count = None
                            self.unbound_next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self._segment_path = lambda: "mpls-il"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.MplsIl, ['next_hop_count', 'bound_next_hop_count', 'unbound_next_hop_count', 'next_hop_pending_registration_count'], name, value)


                    class Mpls(Entity):
                        """
                        MPLS nexthop summary
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Mpls, self).__init__()

                            self.yang_name = "mpls"
                            self.yang_parent_name = "next-hop-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('next_hop_count', YLeaf(YType.uint32, 'next-hop-count')),
                                ('bound_next_hop_count', YLeaf(YType.uint32, 'bound-next-hop-count')),
                                ('unbound_next_hop_count', YLeaf(YType.uint32, 'unbound-next-hop-count')),
                                ('next_hop_pending_registration_count', YLeaf(YType.uint32, 'next-hop-pending-registration-count')),
                            ])
                            self.next_hop_count = None
                            self.bound_next_hop_count = None
                            self.unbound_next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self._segment_path = lambda: "mpls"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Mpls, ['next_hop_count', 'bound_next_hop_count', 'unbound_next_hop_count', 'next_hop_pending_registration_count'], name, value)


                    class L2tp(Entity):
                        """
                        L2TP nexthop summary
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.L2tp, self).__init__()

                            self.yang_name = "l2tp"
                            self.yang_parent_name = "next-hop-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('next_hop_count', YLeaf(YType.uint32, 'next-hop-count')),
                                ('bound_next_hop_count', YLeaf(YType.uint32, 'bound-next-hop-count')),
                                ('unbound_next_hop_count', YLeaf(YType.uint32, 'unbound-next-hop-count')),
                                ('next_hop_pending_registration_count', YLeaf(YType.uint32, 'next-hop-pending-registration-count')),
                            ])
                            self.next_hop_count = None
                            self.bound_next_hop_count = None
                            self.unbound_next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self._segment_path = lambda: "l2tp"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.L2tp, ['next_hop_count', 'bound_next_hop_count', 'unbound_next_hop_count', 'next_hop_pending_registration_count'], name, value)


                    class Lsm(Entity):
                        """
                        LSM nexthop summary
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Lsm, self).__init__()

                            self.yang_name = "lsm"
                            self.yang_parent_name = "next-hop-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('next_hop_count', YLeaf(YType.uint32, 'next-hop-count')),
                                ('bound_next_hop_count', YLeaf(YType.uint32, 'bound-next-hop-count')),
                                ('unbound_next_hop_count', YLeaf(YType.uint32, 'unbound-next-hop-count')),
                                ('next_hop_pending_registration_count', YLeaf(YType.uint32, 'next-hop-pending-registration-count')),
                            ])
                            self.next_hop_count = None
                            self.bound_next_hop_count = None
                            self.unbound_next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self._segment_path = lambda: "lsm"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.Lsm, ['next_hop_count', 'bound_next_hop_count', 'unbound_next_hop_count', 'next_hop_pending_registration_count'], name, value)


                    class P2mpTunnels(Entity):
                        """
                        P2MPtun nexthop summary
                        
                        .. attribute:: next_hop_count
                        
                        	total number of nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bound_next_hop_count
                        
                        	number of bound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: unbound_next_hop_count
                        
                        	number of unbound nhops
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: next_hop_pending_registration_count
                        
                        	number of nhops pending registration with fib 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.P2mpTunnels, self).__init__()

                            self.yang_name = "p2mp-tunnels"
                            self.yang_parent_name = "next-hop-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('next_hop_count', YLeaf(YType.uint32, 'next-hop-count')),
                                ('bound_next_hop_count', YLeaf(YType.uint32, 'bound-next-hop-count')),
                                ('unbound_next_hop_count', YLeaf(YType.uint32, 'unbound-next-hop-count')),
                                ('next_hop_pending_registration_count', YLeaf(YType.uint32, 'next-hop-pending-registration-count')),
                            ])
                            self.next_hop_count = None
                            self.bound_next_hop_count = None
                            self.unbound_next_hop_count = None
                            self.next_hop_pending_registration_count = None
                            self._segment_path = lambda: "p2mp-tunnels"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.NextHopSummary.P2mpTunnels, ['next_hop_count', 'bound_next_hop_count', 'unbound_next_hop_count', 'next_hop_pending_registration_count'], name, value)


                class L2tpDispositionSummary(Entity):
                    """
                    L2TP disposition object summary
                    
                    .. attribute:: l2tp_disposition_session_count
                    
                    	number of l2tp disposition session objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bound_l2tp_disposition_session_count
                    
                    	number of bound l2tp dispostion objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unbound_l2tp_disposition_session_count
                    
                    	number of unbound l2tp disposition objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.L2tpDispositionSummary, self).__init__()

                        self.yang_name = "l2tp-disposition-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('l2tp_disposition_session_count', YLeaf(YType.uint32, 'l2tp-disposition-session-count')),
                            ('bound_l2tp_disposition_session_count', YLeaf(YType.uint32, 'bound-l2tp-disposition-session-count')),
                            ('unbound_l2tp_disposition_session_count', YLeaf(YType.uint32, 'unbound-l2tp-disposition-session-count')),
                        ])
                        self.l2tp_disposition_session_count = None
                        self.bound_l2tp_disposition_session_count = None
                        self.unbound_l2tp_disposition_session_count = None
                        self._segment_path = lambda: "l2tp-disposition-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.L2tpDispositionSummary, ['l2tp_disposition_session_count', 'bound_l2tp_disposition_session_count', 'unbound_l2tp_disposition_session_count'], name, value)


                class BridgeDomainSummary(Entity):
                    """
                    Bridge\-domain summary info
                    
                    .. attribute:: bridge_domain_count
                    
                    	Number of bridge\-domains
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_drop_count
                    
                    	Number of bridge\-domain updates dropped
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_bvi_count
                    
                    	Number of bridge\-domains with BVI
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_p2mp_enabled
                    
                    	Number of bridge\-domains with P2MP enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_pbbevpn_enabled
                    
                    	Number of bridge\-domains with PBB EVPN enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_domain_with_evpn_enabled
                    
                    	Number of bridge\-domains with EVPN enabled
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.BridgeDomainSummary, self).__init__()

                        self.yang_name = "bridge-domain-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('bridge_domain_count', YLeaf(YType.uint32, 'bridge-domain-count')),
                            ('bridge_domain_drop_count', YLeaf(YType.uint32, 'bridge-domain-drop-count')),
                            ('bridge_domain_with_bvi_count', YLeaf(YType.uint32, 'bridge-domain-with-bvi-count')),
                            ('bridge_domain_with_p2mp_enabled', YLeaf(YType.uint32, 'bridge-domain-with-p2mp-enabled')),
                            ('bridge_domain_with_pbbevpn_enabled', YLeaf(YType.uint32, 'bridge-domain-with-pbbevpn-enabled')),
                            ('bridge_domain_with_evpn_enabled', YLeaf(YType.uint32, 'bridge-domain-with-evpn-enabled')),
                        ])
                        self.bridge_domain_count = None
                        self.bridge_domain_drop_count = None
                        self.bridge_domain_with_bvi_count = None
                        self.bridge_domain_with_p2mp_enabled = None
                        self.bridge_domain_with_pbbevpn_enabled = None
                        self.bridge_domain_with_evpn_enabled = None
                        self._segment_path = lambda: "bridge-domain-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.BridgeDomainSummary, ['bridge_domain_count', 'bridge_domain_drop_count', 'bridge_domain_with_bvi_count', 'bridge_domain_with_p2mp_enabled', 'bridge_domain_with_pbbevpn_enabled', 'bridge_domain_with_evpn_enabled'], name, value)


                class MacSummary(Entity):
                    """
                    mac summary info
                    
                    .. attribute:: mac_counts_invalid
                    
                    	Flag to show if MAC counts aren't valid
                    	**type**\: bool
                    
                    .. attribute:: local_mac_count
                    
                    	number of locally learnt macs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: remote_mac_count
                    
                    	number of remotely learned macs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: static_mac_count
                    
                    	number of static macs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: routed_mac_count
                    
                    	number of routed macs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_count
                    
                    	number of all macs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sbmac_count
                    
                    	number of Source BMACs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bmac_count
                    
                    	number of BMACs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.MacSummary, self).__init__()

                        self.yang_name = "mac-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('mac_counts_invalid', YLeaf(YType.boolean, 'mac-counts-invalid')),
                            ('local_mac_count', YLeaf(YType.uint32, 'local-mac-count')),
                            ('remote_mac_count', YLeaf(YType.uint32, 'remote-mac-count')),
                            ('static_mac_count', YLeaf(YType.uint32, 'static-mac-count')),
                            ('routed_mac_count', YLeaf(YType.uint32, 'routed-mac-count')),
                            ('mac_count', YLeaf(YType.uint32, 'mac-count')),
                            ('sbmac_count', YLeaf(YType.uint32, 'sbmac-count')),
                            ('bmac_count', YLeaf(YType.uint32, 'bmac-count')),
                        ])
                        self.mac_counts_invalid = None
                        self.local_mac_count = None
                        self.remote_mac_count = None
                        self.static_mac_count = None
                        self.routed_mac_count = None
                        self.mac_count = None
                        self.sbmac_count = None
                        self.bmac_count = None
                        self._segment_path = lambda: "mac-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.MacSummary, ['mac_counts_invalid', 'local_mac_count', 'remote_mac_count', 'static_mac_count', 'routed_mac_count', 'mac_count', 'sbmac_count', 'bmac_count'], name, value)


                class QueueSummary(Entity):
                    """
                    queue summary info
                    
                    .. attribute:: inline_cnt
                    
                    	number of objects in inline queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: retry_cnt
                    
                    	number of objects in retry queue
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: update_cnt
                    
                    	number of objects in update queues
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: del_cnt
                    
                    	number of objects in delete queues
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.QueueSummary, self).__init__()

                        self.yang_name = "queue-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('inline_cnt', YLeaf(YType.uint32, 'inline-cnt')),
                            ('retry_cnt', YLeaf(YType.uint32, 'retry-cnt')),
                            ('update_cnt', YLeaf(YType.uint32, 'update-cnt')),
                            ('del_cnt', YLeaf(YType.uint32, 'del-cnt')),
                        ])
                        self.inline_cnt = None
                        self.retry_cnt = None
                        self.update_cnt = None
                        self.del_cnt = None
                        self._segment_path = lambda: "queue-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.QueueSummary, ['inline_cnt', 'retry_cnt', 'update_cnt', 'del_cnt'], name, value)


                class EvpnSummary(Entity):
                    """
                    evpn summary info
                    
                    .. attribute:: total_count
                    
                    	Number of EVPN Multicast Replication lists
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: isid_count
                    
                    	Number of ISID leaves
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: default_count
                    
                    	Number of default leaves
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: stitching_count
                    
                    	Number of stitching leaves
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.EvpnSummary, self).__init__()

                        self.yang_name = "evpn-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total_count', YLeaf(YType.uint32, 'total-count')),
                            ('isid_count', YLeaf(YType.uint32, 'isid-count')),
                            ('default_count', YLeaf(YType.uint32, 'default-count')),
                            ('stitching_count', YLeaf(YType.uint32, 'stitching-count')),
                        ])
                        self.total_count = None
                        self.isid_count = None
                        self.default_count = None
                        self.stitching_count = None
                        self._segment_path = lambda: "evpn-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.EvpnSummary, ['total_count', 'isid_count', 'default_count', 'stitching_count'], name, value)


                class GlobalCfg(Entity):
                    """
                    Global configuration
                    
                    .. attribute:: base
                    
                    	Base Information
                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg.Base>`
                    
                    .. attribute:: load_balance_type
                    
                    	Type of Load\-Balancing
                    	**type**\:  :py:class:`L2fibLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibLoadBal>`
                    
                    .. attribute:: evpn_imc_label_block_base
                    
                    	Base of label range in use for EVPN IMC PD
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: evpn_imc_label_block_size
                    
                    	Size of label range in use for EVPN IMC PD
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg, self).__init__()

                        self.yang_name = "global-cfg"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg.Base))])
                        self._leafs = OrderedDict([
                            ('load_balance_type', YLeaf(YType.enumeration, 'load-balance-type')),
                            ('evpn_imc_label_block_base', YLeaf(YType.uint32, 'evpn-imc-label-block-base')),
                            ('evpn_imc_label_block_size', YLeaf(YType.uint16, 'evpn-imc-label-block-size')),
                        ])
                        self.load_balance_type = None
                        self.evpn_imc_label_block_base = None
                        self.evpn_imc_label_block_size = None

                        self.base = L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg.Base()
                        self.base.parent = self
                        self._children_name_map["base"] = "base"
                        self._segment_path = lambda: "global-cfg"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg, ['load_balance_type', 'evpn_imc_label_block_base', 'evpn_imc_label_block_size'], name, value)


                    class Base(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibSummary.GlobalCfg.Base, self).__init__()

                            self.yang_name = "base"
                            self.yang_parent_name = "global-cfg"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "base"


                class PtreeSummary(Entity):
                    """
                    P2MP PTree summary info
                    
                    .. attribute:: total_ptree_count
                    
                    	Number of PTree objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mldp_enabled_ptree_count
                    
                    	Number of MLDP enabled PTree objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lmrib_mldp_ptree_count
                    
                    	Number of MLDP PTree Objects owned by LMRIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rsvp_te_enabled_ptree_count
                    
                    	Number of RSVP\-TE enabled PTree objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: lmrib_rsvp_te_ptree_count
                    
                    	Number of RSVP\-TE PTree Objects owned by LMRIB
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.PtreeSummary, self).__init__()

                        self.yang_name = "ptree-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total_ptree_count', YLeaf(YType.uint32, 'total-ptree-count')),
                            ('mldp_enabled_ptree_count', YLeaf(YType.uint32, 'mldp-enabled-ptree-count')),
                            ('lmrib_mldp_ptree_count', YLeaf(YType.uint32, 'lmrib-mldp-ptree-count')),
                            ('rsvp_te_enabled_ptree_count', YLeaf(YType.uint32, 'rsvp-te-enabled-ptree-count')),
                            ('lmrib_rsvp_te_ptree_count', YLeaf(YType.uint32, 'lmrib-rsvp-te-ptree-count')),
                        ])
                        self.total_ptree_count = None
                        self.mldp_enabled_ptree_count = None
                        self.lmrib_mldp_ptree_count = None
                        self.rsvp_te_enabled_ptree_count = None
                        self.lmrib_rsvp_te_ptree_count = None
                        self._segment_path = lambda: "ptree-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.PtreeSummary, ['total_ptree_count', 'mldp_enabled_ptree_count', 'lmrib_mldp_ptree_count', 'rsvp_te_enabled_ptree_count', 'lmrib_rsvp_te_ptree_count'], name, value)


                class PwGroupSummary(Entity):
                    """
                    PWGroup summary info
                    
                    .. attribute:: plat_grouping_supported
                    
                    	Platform supports Grouping
                    	**type**\: bool
                    
                    .. attribute:: total_pw_groups
                    
                    	Total number of PWGROUP objects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pw_groups_down
                    
                    	Number of PWGROUP objects down
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.PwGroupSummary, self).__init__()

                        self.yang_name = "pw-group-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('plat_grouping_supported', YLeaf(YType.boolean, 'plat-grouping-supported')),
                            ('total_pw_groups', YLeaf(YType.uint32, 'total-pw-groups')),
                            ('pw_groups_down', YLeaf(YType.uint32, 'pw-groups-down')),
                        ])
                        self.plat_grouping_supported = None
                        self.total_pw_groups = None
                        self.pw_groups_down = None
                        self._segment_path = lambda: "pw-group-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.PwGroupSummary, ['plat_grouping_supported', 'total_pw_groups', 'pw_groups_down'], name, value)


                class PwheMpSummary(Entity):
                    """
                    PWHE Main\-port summary info
                    
                    .. attribute:: total_count
                    
                    	Number of PWHE Main\-ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibSummary.PwheMpSummary, self).__init__()

                        self.yang_name = "pwhe-mp-summary"
                        self.yang_parent_name = "l2fib-summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('total_count', YLeaf(YType.uint32, 'total-count')),
                        ])
                        self.total_count = None
                        self._segment_path = lambda: "pwhe-mp-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibSummary.PwheMpSummary, ['total_count'], name, value)


            class L2fibNvePeers(Entity):
                """
                NVE Peer Table
                
                .. attribute:: l2fib_nve_peer
                
                	The attributes for a particular NVE Peer
                	**type**\: list of  		 :py:class:`L2fibNvePeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibNvePeers.L2fibNvePeer>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibNvePeers, self).__init__()

                    self.yang_name = "l2fib-nve-peers"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-nve-peer", ("l2fib_nve_peer", L2vpnForwarding.Nodes.Node.L2fibNvePeers.L2fibNvePeer))])
                    self._leafs = OrderedDict()

                    self.l2fib_nve_peer = YList(self)
                    self._segment_path = lambda: "l2fib-nve-peers"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibNvePeers, [], name, value)


                class L2fibNvePeer(Entity):
                    """
                    The attributes for a particular NVE Peer
                    
                    .. attribute:: xc_uint_id
                    
                    	XC ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: vniid
                    
                    	VNI ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: vtep_address
                    
                    	VTEP IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: nve_if
                    
                    	Parent NVE IF Handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: vn_iid
                    
                    	VNI ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vte_pip
                    
                    	Peer VTEP IP Address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibNvePeers.L2fibNvePeer, self).__init__()

                        self.yang_name = "l2fib-nve-peer"
                        self.yang_parent_name = "l2fib-nve-peers"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('xc_uint_id', YLeaf(YType.str, 'xc-uint-id')),
                            ('vniid', YLeaf(YType.str, 'vniid')),
                            ('vtep_address', YLeaf(YType.str, 'vtep-address')),
                            ('nve_if', YLeaf(YType.str, 'nve-if')),
                            ('vn_iid', YLeaf(YType.uint32, 'vn-iid')),
                            ('vte_pip', YLeaf(YType.str, 'vte-pip')),
                        ])
                        self.xc_uint_id = None
                        self.vniid = None
                        self.vtep_address = None
                        self.nve_if = None
                        self.vn_iid = None
                        self.vte_pip = None
                        self._segment_path = lambda: "l2fib-nve-peer"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibNvePeers.L2fibNvePeer, ['xc_uint_id', 'vniid', 'vtep_address', 'nve_if', 'vn_iid', 'vte_pip'], name, value)


            class L2fibMmrps(Entity):
                """
                mmmrp information
                
                .. attribute:: l2fib_mmrp
                
                	Bridge Domain Mmrp Information
                	**type**\: list of  		 :py:class:`L2fibMmrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibMmrps, self).__init__()

                    self.yang_name = "l2fib-mmrps"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-mmrp", ("l2fib_mmrp", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp))])
                    self._leafs = OrderedDict()

                    self.l2fib_mmrp = YList(self)
                    self._segment_path = lambda: "l2fib-mmrps"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps, [], name, value)


                class L2fibMmrp(Entity):
                    """
                    Bridge Domain Mmrp Information
                    
                    .. attribute:: source
                    
                    	src Mac Address
                    	**type**\: str
                    
                    	**length:** 1..15
                    
                    .. attribute:: group
                    
                    	Group Mac Address
                    	**type**\: str
                    
                    	**length:** 1..15
                    
                    .. attribute:: bd_group_name
                    
                    	Bridge Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bd_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: multicast_base_information
                    
                    	Base Information
                    	**type**\:  :py:class:`MulticastBaseInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.MulticastBaseInformation>`
                    
                    .. attribute:: source_prefix
                    
                    	Source Prefix
                    	**type**\:  :py:class:`SourcePrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.SourcePrefix>`
                    
                    .. attribute:: destination_prefix
                    
                    	Destination Prefix
                    	**type**\:  :py:class:`DestinationPrefix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.DestinationPrefix>`
                    
                    .. attribute:: forward_stats
                    
                    	Forwarding Statistics
                    	**type**\:  :py:class:`ForwardStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats>`
                    
                    .. attribute:: irb_info
                    
                    	IRB Information
                    	**type**\:  :py:class:`IrbInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo>`
                    
                    .. attribute:: bridge_id
                    
                    	Bridge ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: xid_count
                    
                    	Count of XIDs
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: platform_data_length
                    
                    	The mcast platform data len
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: platform_data
                    
                    	The mcast platform data
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: hardware_information
                    
                    	Platform Hardware info
                    	**type**\: str
                    
                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Name
                    	**type**\: str
                    
                    	**length:** 0..66
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp, self).__init__()

                        self.yang_name = "l2fib-mmrp"
                        self.yang_parent_name = "l2fib-mmrps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("multicast-base-information", ("multicast_base_information", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.MulticastBaseInformation)), ("source-prefix", ("source_prefix", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.SourcePrefix)), ("destination-prefix", ("destination_prefix", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.DestinationPrefix)), ("forward-stats", ("forward_stats", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats)), ("irb-info", ("irb_info", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo))])
                        self._leafs = OrderedDict([
                            ('source', YLeaf(YType.str, 'source')),
                            ('group', YLeaf(YType.str, 'group')),
                            ('bd_group_name', YLeaf(YType.str, 'bd-group-name')),
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                            ('bridge_id', YLeaf(YType.uint32, 'bridge-id')),
                            ('xid_count', YLeaf(YType.uint16, 'xid-count')),
                            ('platform_data_length', YLeaf(YType.uint8, 'platform-data-length')),
                            ('platform_data', YLeaf(YType.str, 'platform-data')),
                            ('hardware_information', YLeaf(YType.str, 'hardware-information')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                        ])
                        self.source = None
                        self.group = None
                        self.bd_group_name = None
                        self.bd_name = None
                        self.bridge_id = None
                        self.xid_count = None
                        self.platform_data_length = None
                        self.platform_data = None
                        self.hardware_information = None
                        self.bridge_domain_name = None

                        self.multicast_base_information = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.MulticastBaseInformation()
                        self.multicast_base_information.parent = self
                        self._children_name_map["multicast_base_information"] = "multicast-base-information"

                        self.source_prefix = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.SourcePrefix()
                        self.source_prefix.parent = self
                        self._children_name_map["source_prefix"] = "source-prefix"

                        self.destination_prefix = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.DestinationPrefix()
                        self.destination_prefix.parent = self
                        self._children_name_map["destination_prefix"] = "destination-prefix"

                        self.forward_stats = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats()
                        self.forward_stats.parent = self
                        self._children_name_map["forward_stats"] = "forward-stats"

                        self.irb_info = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo()
                        self.irb_info.parent = self
                        self._children_name_map["irb_info"] = "irb-info"
                        self._segment_path = lambda: "l2fib-mmrp"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp, ['source', 'group', 'bd_group_name', 'bd_name', 'bridge_id', 'xid_count', 'platform_data_length', 'platform_data', 'hardware_information', 'bridge_domain_name'], name, value)


                    class MulticastBaseInformation(Entity):
                        """
                        Base Information
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.MulticastBaseInformation, self).__init__()

                            self.yang_name = "multicast-base-information"
                            self.yang_parent_name = "l2fib-mmrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict()
                            self._segment_path = lambda: "multicast-base-information"


                    class SourcePrefix(Entity):
                        """
                        Source Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.SourcePrefix, self).__init__()

                            self.yang_name = "source-prefix"
                            self.yang_parent_name = "l2fib-mmrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "source-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.SourcePrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class DestinationPrefix(Entity):
                        """
                        Destination Prefix
                        
                        .. attribute:: proto
                        
                        	The prefix protocol
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: prefix_length
                        
                        	The prefix length
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: prefix
                        
                        	The prefix
                        	**type**\: str
                        
                        	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.DestinationPrefix, self).__init__()

                            self.yang_name = "destination-prefix"
                            self.yang_parent_name = "l2fib-mmrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('proto', YLeaf(YType.uint8, 'proto')),
                                ('prefix_length', YLeaf(YType.uint16, 'prefix-length')),
                                ('prefix', YLeaf(YType.str, 'prefix')),
                            ])
                            self.proto = None
                            self.prefix_length = None
                            self.prefix = None
                            self._segment_path = lambda: "destination-prefix"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.DestinationPrefix, ['proto', 'prefix_length', 'prefix'], name, value)


                    class ForwardStats(Entity):
                        """
                        Forwarding Statistics
                        
                        .. attribute:: forward_stat
                        
                        	fwd stats
                        	**type**\:  :py:class:`ForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats, self).__init__()

                            self.yang_name = "forward-stats"
                            self.yang_parent_name = "l2fib-mmrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("forward-stat", ("forward_stat", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat))])
                            self._leafs = OrderedDict()

                            self.forward_stat = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat()
                            self.forward_stat.parent = self
                            self._children_name_map["forward_stat"] = "forward-stat"
                            self._segment_path = lambda: "forward-stats"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats, [], name, value)


                        class ForwardStat(Entity):
                            """
                            fwd stats
                            
                            .. attribute:: mulicast
                            
                            	mulicast
                            	**type**\:  :py:class:`Mulicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast>`
                            
                            .. attribute:: data_type
                            
                            	DataType
                            	**type**\:  :py:class:`MgmtL2fibStatsData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibStatsData>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat, self).__init__()

                                self.yang_name = "forward-stat"
                                self.yang_parent_name = "forward-stats"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mulicast", ("mulicast", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast))])
                                self._leafs = OrderedDict([
                                    ('data_type', YLeaf(YType.enumeration, 'data-type')),
                                ])
                                self.data_type = None

                                self.mulicast = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast()
                                self.mulicast.parent = self
                                self._children_name_map["mulicast"] = "mulicast"
                                self._segment_path = lambda: "forward-stat"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat, ['data_type'], name, value)


                            class Mulicast(Entity):
                                """
                                mulicast
                                
                                .. attribute:: multicast_forward_stat
                                
                                	forwarded stats
                                	**type**\:  :py:class:`MulticastForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat>`
                                
                                .. attribute:: received_stat
                                
                                	received stats
                                	**type**\:  :py:class:`ReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat>`
                                
                                .. attribute:: punt
                                
                                	punted stats
                                	**type**\:  :py:class:`Punt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Punt>`
                                
                                .. attribute:: drop
                                
                                	dropped stats
                                	**type**\:  :py:class:`Drop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Drop>`
                                
                                .. attribute:: multicast_core_forward_stat
                                
                                	core forwarded stats
                                	**type**\:  :py:class:`MulticastCoreForwardStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat>`
                                
                                .. attribute:: core_received_stat
                                
                                	core received stats
                                	**type**\:  :py:class:`CoreReceivedStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast, self).__init__()

                                    self.yang_name = "mulicast"
                                    self.yang_parent_name = "forward-stat"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("multicast-forward-stat", ("multicast_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat)), ("received-stat", ("received_stat", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat)), ("punt", ("punt", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Punt)), ("drop", ("drop", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Drop)), ("multicast-core-forward-stat", ("multicast_core_forward_stat", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat)), ("core-received-stat", ("core_received_stat", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat))])
                                    self._leafs = OrderedDict()

                                    self.multicast_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat()
                                    self.multicast_forward_stat.parent = self
                                    self._children_name_map["multicast_forward_stat"] = "multicast-forward-stat"

                                    self.received_stat = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat()
                                    self.received_stat.parent = self
                                    self._children_name_map["received_stat"] = "received-stat"

                                    self.punt = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Punt()
                                    self.punt.parent = self
                                    self._children_name_map["punt"] = "punt"

                                    self.drop = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Drop()
                                    self.drop.parent = self
                                    self._children_name_map["drop"] = "drop"

                                    self.multicast_core_forward_stat = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat()
                                    self.multicast_core_forward_stat.parent = self
                                    self._children_name_map["multicast_core_forward_stat"] = "multicast-core-forward-stat"

                                    self.core_received_stat = L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat()
                                    self.core_received_stat.parent = self
                                    self._children_name_map["core_received_stat"] = "core-received-stat"
                                    self._segment_path = lambda: "mulicast"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast, [], name, value)


                                class MulticastForwardStat(Entity):
                                    """
                                    forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, self).__init__()

                                        self.yang_name = "multicast-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastForwardStat, ['packets', 'bytes'], name, value)


                                class ReceivedStat(Entity):
                                    """
                                    received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat, self).__init__()

                                        self.yang_name = "received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.ReceivedStat, ['packets', 'bytes'], name, value)


                                class Punt(Entity):
                                    """
                                    punted stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Punt, self).__init__()

                                        self.yang_name = "punt"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "punt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Punt, ['packets', 'bytes'], name, value)


                                class Drop(Entity):
                                    """
                                    dropped stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Drop, self).__init__()

                                        self.yang_name = "drop"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.Drop, ['packets', 'bytes'], name, value)


                                class MulticastCoreForwardStat(Entity):
                                    """
                                    core forwarded stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, self).__init__()

                                        self.yang_name = "multicast-core-forward-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "multicast-core-forward-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.MulticastCoreForwardStat, ['packets', 'bytes'], name, value)


                                class CoreReceivedStat(Entity):
                                    """
                                    core received stats
                                    
                                    .. attribute:: packets
                                    
                                    	Number of packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bytes
                                    
                                    	Number of bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, self).__init__()

                                        self.yang_name = "core-received-stat"
                                        self.yang_parent_name = "mulicast"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packets', YLeaf(YType.uint64, 'packets')),
                                            ('bytes', YLeaf(YType.uint64, 'bytes')),
                                        ])
                                        self.packets = None
                                        self.bytes = None
                                        self._segment_path = lambda: "core-received-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.ForwardStats.ForwardStat.Mulicast.CoreReceivedStat, ['packets', 'bytes'], name, value)


                    class IrbInfo(Entity):
                        """
                        IRB Information
                        
                        .. attribute:: mxid_ac_interface_handle
                        
                        	Master XID AC If handle
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mxid_pw_id
                        
                        	Master XID PW ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mxid_next_hop_address
                        
                        	Master XID NHOP IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: irb_plat_data_len
                        
                        	Platform data bytes
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        	**units**\: byte
                        
                        .. attribute:: irb_plat_data
                        
                        	IRB platform data
                        	**type**\: list of  		 :py:class:`IrbPlatData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo.IrbPlatData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo, self).__init__()

                            self.yang_name = "irb-info"
                            self.yang_parent_name = "l2fib-mmrp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("irb-plat-data", ("irb_plat_data", L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo.IrbPlatData))])
                            self._leafs = OrderedDict([
                                ('mxid_ac_interface_handle', YLeaf(YType.str, 'mxid-ac-interface-handle')),
                                ('mxid_pw_id', YLeaf(YType.uint32, 'mxid-pw-id')),
                                ('mxid_next_hop_address', YLeaf(YType.str, 'mxid-next-hop-address')),
                                ('irb_plat_data_len', YLeaf(YType.uint16, 'irb-plat-data-len')),
                            ])
                            self.mxid_ac_interface_handle = None
                            self.mxid_pw_id = None
                            self.mxid_next_hop_address = None
                            self.irb_plat_data_len = None

                            self.irb_plat_data = YList(self)
                            self._segment_path = lambda: "irb-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo, ['mxid_ac_interface_handle', 'mxid_pw_id', 'mxid_next_hop_address', 'irb_plat_data_len'], name, value)


                        class IrbPlatData(Entity):
                            """
                            IRB platform data
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo.IrbPlatData, self).__init__()

                                self.yang_name = "irb-plat-data"
                                self.yang_parent_name = "irb-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "irb-plat-data"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibMmrps.L2fibMmrp.IrbInfo.IrbPlatData, ['entry'], name, value)


            class L2fibEvpnIp6macs(Entity):
                """
                EVPN IPv6\-MAC Table
                
                .. attribute:: l2fib_evpn_ip6mac
                
                	The attributes for a particular EVPN IPv6\-MAC Entry
                	**type**\: list of  		 :py:class:`L2fibEvpnIp6mac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs, self).__init__()

                    self.yang_name = "l2fib-evpn-ip6macs"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-evpn-ip6mac", ("l2fib_evpn_ip6mac", L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac))])
                    self._leafs = OrderedDict()

                    self.l2fib_evpn_ip6mac = YList(self)
                    self._segment_path = lambda: "l2fib-evpn-ip6macs"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs, [], name, value)


                class L2fibEvpnIp6mac(Entity):
                    """
                    The attributes for a particular EVPN IPv6\-MAC
                    Entry
                    
                    .. attribute:: bdid
                    
                    	BD ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_address
                    
                    	IP Address
                    	**type**\: union of the below types:
                    
                    		**type**\: str
                    
                    			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    		**type**\: str
                    
                    			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: is_local
                    
                    	Entry is locally learned
                    	**type**\: bool
                    
                    .. attribute:: mac_address
                    
                    	MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: ip_address_xr
                    
                    	IP Address
                    	**type**\:  :py:class:`IpAddressXr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac.IpAddressXr>`
                    
                    .. attribute:: bdid_xr
                    
                    	BD ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: mac_address_xr
                    
                    	MAC Address
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                    
                    .. attribute:: arp_nd_sync_pending
                    
                    	Sync to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: arp_nd_probe_pending
                    
                    	Probe to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: arp_nd_delete_pending
                    
                    	Delete to ARP/ND Process Pending
                    	**type**\: bool
                    
                    .. attribute:: is_local_xr
                    
                    	IP\-MAC Route is locally learned
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac, self).__init__()

                        self.yang_name = "l2fib-evpn-ip6mac"
                        self.yang_parent_name = "l2fib-evpn-ip6macs"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ip-address-xr", ("ip_address_xr", L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac.IpAddressXr))])
                        self._leafs = OrderedDict([
                            ('bdid', YLeaf(YType.uint32, 'bdid')),
                            ('ip_address', YLeaf(YType.str, 'ip-address')),
                            ('is_local', YLeaf(YType.boolean, 'is-local')),
                            ('mac_address', YLeaf(YType.str, 'mac-address')),
                            ('bdid_xr', YLeaf(YType.uint32, 'bdid-xr')),
                            ('mac_address_xr', YLeaf(YType.str, 'mac-address-xr')),
                            ('arp_nd_sync_pending', YLeaf(YType.boolean, 'arp-nd-sync-pending')),
                            ('arp_nd_probe_pending', YLeaf(YType.boolean, 'arp-nd-probe-pending')),
                            ('arp_nd_delete_pending', YLeaf(YType.boolean, 'arp-nd-delete-pending')),
                            ('is_local_xr', YLeaf(YType.boolean, 'is-local-xr')),
                        ])
                        self.bdid = None
                        self.ip_address = None
                        self.is_local = None
                        self.mac_address = None
                        self.bdid_xr = None
                        self.mac_address_xr = None
                        self.arp_nd_sync_pending = None
                        self.arp_nd_probe_pending = None
                        self.arp_nd_delete_pending = None
                        self.is_local_xr = None

                        self.ip_address_xr = L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac.IpAddressXr()
                        self.ip_address_xr.parent = self
                        self._children_name_map["ip_address_xr"] = "ip-address-xr"
                        self._segment_path = lambda: "l2fib-evpn-ip6mac"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac, ['bdid', 'ip_address', 'is_local', 'mac_address', 'bdid_xr', 'mac_address_xr', 'arp_nd_sync_pending', 'arp_nd_probe_pending', 'arp_nd_delete_pending', 'is_local_xr'], name, value)


                    class IpAddressXr(Entity):
                        """
                        IP Address
                        
                        .. attribute:: addr_type
                        
                        	addr type
                        	**type**\:  :py:class:`L2fibIpAddr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibIpAddr>`
                        
                        .. attribute:: ip
                        
                        	ip
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac.IpAddressXr, self).__init__()

                            self.yang_name = "ip-address-xr"
                            self.yang_parent_name = "l2fib-evpn-ip6mac"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('addr_type', YLeaf(YType.enumeration, 'addr-type')),
                                ('ip', YLeaf(YType.str, 'ip')),
                            ])
                            self.addr_type = None
                            self.ip = None
                            self._segment_path = lambda: "ip-address-xr"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnIp6macs.L2fibEvpnIp6mac.IpAddressXr, ['addr_type', 'ip'], name, value)


            class L2fibDhcpBindingSummaries(Entity):
                """
                DHCP binding forwarding summary
                
                .. attribute:: l2fib_dhcp_binding_summary
                
                	Specify DHCP binding summary
                	**type**\: list of  		 :py:class:`L2fibDhcpBindingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries, self).__init__()

                    self.yang_name = "l2fib-dhcp-binding-summaries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-dhcp-binding-summary", ("l2fib_dhcp_binding_summary", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary))])
                    self._leafs = OrderedDict()

                    self.l2fib_dhcp_binding_summary = YList(self)
                    self._segment_path = lambda: "l2fib-dhcp-binding-summaries"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries, [], name, value)


                class L2fibDhcpBindingSummary(Entity):
                    """
                    Specify DHCP binding summary
                    
                    .. attribute:: xcid  (key)
                    
                    	XConnect ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: port
                    
                    	Union of Port information
                    	**type**\:  :py:class:`Port <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port>`
                    
                    .. attribute:: bindings
                    
                    	DHCP binding count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary, self).__init__()

                        self.yang_name = "l2fib-dhcp-binding-summary"
                        self.yang_parent_name = "l2fib-dhcp-binding-summaries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['xcid']
                        self._child_classes = OrderedDict([("port", ("port", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port))])
                        self._leafs = OrderedDict([
                            ('xcid', YLeaf(YType.str, 'xcid')),
                            ('bindings', YLeaf(YType.uint32, 'bindings')),
                        ])
                        self.xcid = None
                        self.bindings = None

                        self.port = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port()
                        self.port.parent = self
                        self._children_name_map["port"] = "port"
                        self._segment_path = lambda: "l2fib-dhcp-binding-summary" + "[xcid='" + str(self.xcid) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary, ['xcid', 'bindings'], name, value)


                    class Port(Entity):
                        """
                        Union of Port information
                        
                        .. attribute:: ac
                        
                        	ac
                        	**type**\:  :py:class:`Ac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Ac>`
                        
                        .. attribute:: pw
                        
                        	pw
                        	**type**\:  :py:class:`Pw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Pw>`
                        
                        .. attribute:: data_type
                        
                        	DataType
                        	**type**\:  :py:class:`MgmtL2fibData <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.MgmtL2fibData>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port, self).__init__()

                            self.yang_name = "port"
                            self.yang_parent_name = "l2fib-dhcp-binding-summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac", ("ac", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Ac)), ("pw", ("pw", L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Pw))])
                            self._leafs = OrderedDict([
                                ('data_type', YLeaf(YType.enumeration, 'data-type')),
                            ])
                            self.data_type = None

                            self.ac = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Ac()
                            self.ac.parent = self
                            self._children_name_map["ac"] = "ac"

                            self.pw = L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Pw()
                            self.pw.parent = self
                            self._children_name_map["pw"] = "pw"
                            self._segment_path = lambda: "port"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port, ['data_type'], name, value)


                        class Ac(Entity):
                            """
                            ac
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handle
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Ac, self).__init__()

                                self.yang_name = "ac"
                                self.yang_parent_name = "port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ])
                                self.interface_handle = None
                                self._segment_path = lambda: "ac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Ac, ['interface_handle'], name, value)


                        class Pw(Entity):
                            """
                            pw
                            
                            .. attribute:: pw_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: next_hop_address
                            
                            	Next Hop Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id_type
                            
                            	Pseudowire ID type
                            	**type**\:  :py:class:`L2fibPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2fibPwId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Pw, self).__init__()

                                self.yang_name = "pw"
                                self.yang_parent_name = "port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('pw_id', YLeaf(YType.uint64, 'pw-id')),
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('pseudo_wire_id_type', YLeaf(YType.enumeration, 'pseudo-wire-id-type')),
                                ])
                                self.pw_id = None
                                self.next_hop_address = None
                                self.pseudo_wire_id_type = None
                                self._segment_path = lambda: "pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibDhcpBindingSummaries.L2fibDhcpBindingSummary.Port.Pw, ['pw_id', 'next_hop_address', 'pseudo_wire_id_type'], name, value)


            class L2fibEvpnInclMCasts(Entity):
                """
                L2VPN forwarding bridge\-domain evpn inclusive
                multicast Table
                
                .. attribute:: l2fib_evpn_incl_m_cast
                
                	Specify bridge domain name
                	**type**\: list of  		 :py:class:`L2fibEvpnInclMCast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts, self).__init__()

                    self.yang_name = "l2fib-evpn-incl-m-casts"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast", ("l2fib_evpn_incl_m_cast", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast))])
                    self._leafs = OrderedDict()

                    self.l2fib_evpn_incl_m_cast = YList(self)
                    self._segment_path = lambda: "l2fib-evpn-incl-m-casts"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts, [], name, value)


                class L2fibEvpnInclMCast(Entity):
                    """
                    Specify bridge domain name
                    
                    .. attribute:: bd_name  (key)
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..65
                    
                    .. attribute:: mcast_replication_list
                    
                    	Information of pbb\-evpn/evpn ingress mcast replication list for a particular bridge domain
                    	**type**\:  :py:class:`McastReplicationList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.McastReplicationList>`
                    
                    .. attribute:: l2fib_evpn_incl_m_cast_oles
                    
                    	EVPN ingress mcast ole Information
                    	**type**\:  :py:class:`L2fibEvpnInclMCastOles <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast, self).__init__()

                        self.yang_name = "l2fib-evpn-incl-m-cast"
                        self.yang_parent_name = "l2fib-evpn-incl-m-casts"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['bd_name']
                        self._child_classes = OrderedDict([("mcast-replication-list", ("mcast_replication_list", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.McastReplicationList)), ("l2fib-evpn-incl-m-cast-oles", ("l2fib_evpn_incl_m_cast_oles", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles))])
                        self._leafs = OrderedDict([
                            ('bd_name', YLeaf(YType.str, 'bd-name')),
                        ])
                        self.bd_name = None

                        self.mcast_replication_list = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.McastReplicationList()
                        self.mcast_replication_list.parent = self
                        self._children_name_map["mcast_replication_list"] = "mcast-replication-list"

                        self.l2fib_evpn_incl_m_cast_oles = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles()
                        self.l2fib_evpn_incl_m_cast_oles.parent = self
                        self._children_name_map["l2fib_evpn_incl_m_cast_oles"] = "l2fib-evpn-incl-m-cast-oles"
                        self._segment_path = lambda: "l2fib-evpn-incl-m-cast" + "[bd-name='" + str(self.bd_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast, ['bd_name'], name, value)


                    class McastReplicationList(Entity):
                        """
                        Information of pbb\-evpn/evpn ingress mcast
                        replication list for a particular bridge domain
                        
                        .. attribute:: bridge_domain_name
                        
                        	Bridge\-domain name
                        	**type**\: str
                        
                        .. attribute:: bridge_domain_id
                        
                        	bdid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: xcid
                        
                        	xcid value
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_bound
                        
                        	Is bound
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.McastReplicationList, self).__init__()

                            self.yang_name = "mcast-replication-list"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                                ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                                ('xcid', YLeaf(YType.uint32, 'xcid')),
                                ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                            ])
                            self.bridge_domain_name = None
                            self.bridge_domain_id = None
                            self.xcid = None
                            self.is_bound = None
                            self._segment_path = lambda: "mcast-replication-list"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.McastReplicationList, ['bridge_domain_name', 'bridge_domain_id', 'xcid', 'is_bound'], name, value)


                    class L2fibEvpnInclMCastOles(Entity):
                        """
                        EVPN ingress mcast ole Information
                        
                        .. attribute:: l2fib_evpn_incl_m_cast_ole
                        
                        	Information on a particular output path of the pbb\-evpn/evpn ingress replication list
                        	**type**\: list of  		 :py:class:`L2fibEvpnInclMCastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles, self).__init__()

                            self.yang_name = "l2fib-evpn-incl-m-cast-oles"
                            self.yang_parent_name = "l2fib-evpn-incl-m-cast"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("l2fib-evpn-incl-m-cast-ole", ("l2fib_evpn_incl_m_cast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle))])
                            self._leafs = OrderedDict()

                            self.l2fib_evpn_incl_m_cast_ole = YList(self)
                            self._segment_path = lambda: "l2fib-evpn-incl-m-cast-oles"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles, [], name, value)


                        class L2fibEvpnInclMCastOle(Entity):
                            """
                            Information on a particular output path of the
                            pbb\-evpn/evpn ingress replication list
                            
                            .. attribute:: next_hop_address  (key)
                            
                            	Next Hop Address
                            	**type**\: union of the below types:
                            
                            		**type**\: str
                            
                            			**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            		**type**\: str
                            
                            			**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: mcast_ole
                            
                            	Mcast Ole Info
                            	**type**\:  :py:class:`McastOle <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle>`
                            
                            .. attribute:: next_hop
                            
                            	Next Hop
                            	**type**\:  :py:class:`NextHop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop>`
                            
                            .. attribute:: is_bound
                            
                            	Is bound
                            	**type**\: bool
                            
                            .. attribute:: next_hop_valid
                            
                            	IS Next Hop Valid
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, self).__init__()

                                self.yang_name = "l2fib-evpn-incl-m-cast-ole"
                                self.yang_parent_name = "l2fib-evpn-incl-m-cast-oles"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['next_hop_address']
                                self._child_classes = OrderedDict([("mcast-ole", ("mcast_ole", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle)), ("next-hop", ("next_hop", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop))])
                                self._leafs = OrderedDict([
                                    ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                    ('is_bound', YLeaf(YType.boolean, 'is-bound')),
                                    ('next_hop_valid', YLeaf(YType.boolean, 'next-hop-valid')),
                                ])
                                self.next_hop_address = None
                                self.is_bound = None
                                self.next_hop_valid = None

                                self.mcast_ole = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle()
                                self.mcast_ole.parent = self
                                self._children_name_map["mcast_ole"] = "mcast-ole"

                                self.next_hop = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop()
                                self.next_hop.parent = self
                                self._children_name_map["next_hop"] = "next-hop"
                                self._segment_path = lambda: "l2fib-evpn-incl-m-cast-ole" + "[next-hop-address='" + str(self.next_hop_address) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle, ['next_hop_address', 'is_bound', 'next_hop_valid'], name, value)


                            class McastOle(Entity):
                                """
                                Mcast Ole Info
                                
                                .. attribute:: next_hop_ipv6_addr
                                
                                	Next Hop IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: mcast_label
                                
                                	Inclusive mcast label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, self).__init__()

                                    self.yang_name = "mcast-ole"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('next_hop_ipv6_addr', YLeaf(YType.str, 'next-hop-ipv6-addr')),
                                        ('mcast_label', YLeaf(YType.uint32, 'mcast-label')),
                                    ])
                                    self.next_hop_ipv6_addr = None
                                    self.mcast_label = None
                                    self._segment_path = lambda: "mcast-ole"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.McastOle, ['next_hop_ipv6_addr', 'mcast_label'], name, value)


                            class NextHop(Entity):
                                """
                                Next Hop
                                
                                .. attribute:: base
                                
                                	Base Information
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base>`
                                
                                .. attribute:: next_hop_address
                                
                                	NHOP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_address_v6
                                
                                	NHOP Address V6
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: next_hop_internal_label
                                
                                	NHOP Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ecd_plaformt_data_valid
                                
                                	Is Platform ECD Data Valid
                                	**type**\: bool
                                
                                .. attribute:: ecd_platform_data_length
                                
                                	Platform ECD Data Length
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: children_count
                                
                                	Children Count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, self).__init__()

                                    self.yang_name = "next-hop"
                                    self.yang_parent_name = "l2fib-evpn-incl-m-cast-ole"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base))])
                                    self._leafs = OrderedDict([
                                        ('next_hop_address', YLeaf(YType.str, 'next-hop-address')),
                                        ('next_hop_address_v6', YLeaf(YType.str, 'next-hop-address-v6')),
                                        ('next_hop_internal_label', YLeaf(YType.uint32, 'next-hop-internal-label')),
                                        ('ecd_plaformt_data_valid', YLeaf(YType.boolean, 'ecd-plaformt-data-valid')),
                                        ('ecd_platform_data_length', YLeaf(YType.uint32, 'ecd-platform-data-length')),
                                        ('children_count', YLeaf(YType.uint32, 'children-count')),
                                    ])
                                    self.next_hop_address = None
                                    self.next_hop_address_v6 = None
                                    self.next_hop_internal_label = None
                                    self.ecd_plaformt_data_valid = None
                                    self.ecd_platform_data_length = None
                                    self.children_count = None

                                    self.base = L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"
                                    self._segment_path = lambda: "next-hop"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop, ['next_hop_address', 'next_hop_address_v6', 'next_hop_internal_label', 'ecd_plaformt_data_valid', 'ecd_platform_data_length', 'children_count'], name, value)


                                class Base(Entity):
                                    """
                                    Base Information
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnForwarding.Nodes.Node.L2fibEvpnInclMCasts.L2fibEvpnInclMCast.L2fibEvpnInclMCastOles.L2fibEvpnInclMCastOle.NextHop.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "next-hop"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict()
                                        self._segment_path = lambda: "base"

    def clone_ptr(self):
        self._top_entity = L2vpnForwarding()
        return self._top_entity

class L2vpnv2(Entity):
    """
    l2vpnv2
    
    .. attribute:: standby
    
    	Standby L2VPN operational data
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby>`
    
    .. attribute:: active
    
    	Active L2VPN operational data
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active>`
    
    .. attribute:: nodes
    
    	Table of L2VPN operational data for a particular node
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(L2vpnv2, self).__init__()
        self._top_entity = None

        self.yang_name = "l2vpnv2"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("standby", ("standby", L2vpnv2.Standby)), ("active", ("active", L2vpnv2.Active)), ("nodes", ("nodes", L2vpnv2.Nodes))])
        self._leafs = OrderedDict()

        self.standby = L2vpnv2.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"

        self.active = L2vpnv2.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"

        self.nodes = L2vpnv2.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"
        self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2"

    def __setattr__(self, name, value):
        self._perform_setattr(L2vpnv2, [], name, value)


    class Standby(Entity):
        """
        Standby L2VPN operational data
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:  :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:  :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServiceSummary>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:  :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:  :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:  :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeSummary>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr>`
        
        .. attribute:: preferred_paths
        
        	Preferred path Table
        	**type**\:  :py:class:`PreferredPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PreferredPaths>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:  :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GlobalSettings>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:  :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:  :py:class:`XconnectMp2mpCe2ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mpCe2ces>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:  :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:  :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:  :py:class:`XconnectMp2mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:  :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Indexes>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:  :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectSummary>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:  :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:  :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpPorts>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:  :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:  :py:class:`L2vpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.L2vpnResourceState>`
        
        .. attribute:: bridge_domains
        
        	Bridge Domain Information
        	**type**\:  :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:  :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.DiscoverySummary>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:  :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:  :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:  :py:class:`L2vpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.L2vpnCollaborators>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp>`
        
        .. attribute:: generic_interface_lists
        
        	L2VPN generic interface list Table
        	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceLists>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:  :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpVlans>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:  :py:class:`L2vpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.L2vpnPbbBsa>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:  :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:  :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(L2vpnv2.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "l2vpnv2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("discoveries", ("discoveries", L2vpnv2.Standby.Discoveries)), ("flexible-xconnect-service-summary", ("flexible_xconnect_service_summary", L2vpnv2.Standby.FlexibleXconnectServiceSummary)), ("main-interfaces", ("main_interfaces", L2vpnv2.Standby.MainInterfaces)), ("iccp-sm", ("iccp_sm", L2vpnv2.Standby.IccpSm)), ("bridge-summary", ("bridge_summary", L2vpnv2.Standby.BridgeSummary)), ("nsr", ("nsr", L2vpnv2.Standby.Nsr)), ("preferred-paths", ("preferred_paths", L2vpnv2.Standby.PreferredPaths)), ("global-settings", ("global_settings", L2vpnv2.Standby.GlobalSettings)), ("pwr", ("pwr", L2vpnv2.Standby.Pwr)), ("xconnect-mp2mp-ce2ces", ("xconnect_mp2mp_ce2ces", L2vpnv2.Standby.XconnectMp2mpCe2ces)), ("xconnects", ("xconnects", L2vpnv2.Standby.Xconnects)), ("xconnect-groups", ("xconnect_groups", L2vpnv2.Standby.XconnectGroups)), ("xconnect-mp2mps", ("xconnect_mp2mps", L2vpnv2.Standby.XconnectMp2mps)), ("indexes", ("indexes", L2vpnv2.Standby.Indexes)), ("xconnect-summary", ("xconnect_summary", L2vpnv2.Standby.XconnectSummary)), ("proc-fsm", ("proc_fsm", L2vpnv2.Standby.ProcFsm)), ("mstp-ports", ("mstp_ports", L2vpnv2.Standby.MstpPorts)), ("generic-interface-list-details", ("generic_interface_list_details", L2vpnv2.Standby.GenericInterfaceListDetails)), ("l2vpn-resource-state", ("l2vpn_resource_state", L2vpnv2.Standby.L2vpnResourceState)), ("bridge-domains", ("bridge_domains", L2vpnv2.Standby.BridgeDomains)), ("discovery-summary", ("discovery_summary", L2vpnv2.Standby.DiscoverySummary)), ("g8032", ("g8032", L2vpnv2.Standby.G8032)), ("pseudowire-classes", ("pseudowire_classes", L2vpnv2.Standby.PseudowireClasses)), ("l2vpn-collaborators", ("l2vpn_collaborators", L2vpnv2.Standby.L2vpnCollaborators)), ("mvrp", ("mvrp", L2vpnv2.Standby.Mvrp)), ("generic-interface-lists", ("generic_interface_lists", L2vpnv2.Standby.GenericInterfaceLists)), ("mstp-vlans", ("mstp_vlans", L2vpnv2.Standby.MstpVlans)), ("l2vpn-pbb-bsa", ("l2vpn_pbb_bsa", L2vpnv2.Standby.L2vpnPbbBsa)), ("flexible-xconnect-services", ("flexible_xconnect_services", L2vpnv2.Standby.FlexibleXconnectServices)), ("xconnect-brief", ("xconnect_brief", L2vpnv2.Standby.XconnectBrief))])
            self._leafs = OrderedDict()

            self.discoveries = L2vpnv2.Standby.Discoveries()
            self.discoveries.parent = self
            self._children_name_map["discoveries"] = "discoveries"

            self.flexible_xconnect_service_summary = L2vpnv2.Standby.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"

            self.main_interfaces = L2vpnv2.Standby.MainInterfaces()
            self.main_interfaces.parent = self
            self._children_name_map["main_interfaces"] = "main-interfaces"

            self.iccp_sm = L2vpnv2.Standby.IccpSm()
            self.iccp_sm.parent = self
            self._children_name_map["iccp_sm"] = "iccp-sm"

            self.bridge_summary = L2vpnv2.Standby.BridgeSummary()
            self.bridge_summary.parent = self
            self._children_name_map["bridge_summary"] = "bridge-summary"

            self.nsr = L2vpnv2.Standby.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"

            self.preferred_paths = L2vpnv2.Standby.PreferredPaths()
            self.preferred_paths.parent = self
            self._children_name_map["preferred_paths"] = "preferred-paths"

            self.global_settings = L2vpnv2.Standby.GlobalSettings()
            self.global_settings.parent = self
            self._children_name_map["global_settings"] = "global-settings"

            self.pwr = L2vpnv2.Standby.Pwr()
            self.pwr.parent = self
            self._children_name_map["pwr"] = "pwr"

            self.xconnect_mp2mp_ce2ces = L2vpnv2.Standby.XconnectMp2mpCe2ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"

            self.xconnects = L2vpnv2.Standby.Xconnects()
            self.xconnects.parent = self
            self._children_name_map["xconnects"] = "xconnects"

            self.xconnect_groups = L2vpnv2.Standby.XconnectGroups()
            self.xconnect_groups.parent = self
            self._children_name_map["xconnect_groups"] = "xconnect-groups"

            self.xconnect_mp2mps = L2vpnv2.Standby.XconnectMp2mps()
            self.xconnect_mp2mps.parent = self
            self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"

            self.indexes = L2vpnv2.Standby.Indexes()
            self.indexes.parent = self
            self._children_name_map["indexes"] = "indexes"

            self.xconnect_summary = L2vpnv2.Standby.XconnectSummary()
            self.xconnect_summary.parent = self
            self._children_name_map["xconnect_summary"] = "xconnect-summary"

            self.proc_fsm = L2vpnv2.Standby.ProcFsm()
            self.proc_fsm.parent = self
            self._children_name_map["proc_fsm"] = "proc-fsm"

            self.mstp_ports = L2vpnv2.Standby.MstpPorts()
            self.mstp_ports.parent = self
            self._children_name_map["mstp_ports"] = "mstp-ports"

            self.generic_interface_list_details = L2vpnv2.Standby.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"

            self.l2vpn_resource_state = L2vpnv2.Standby.L2vpnResourceState()
            self.l2vpn_resource_state.parent = self
            self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"

            self.bridge_domains = L2vpnv2.Standby.BridgeDomains()
            self.bridge_domains.parent = self
            self._children_name_map["bridge_domains"] = "bridge-domains"

            self.discovery_summary = L2vpnv2.Standby.DiscoverySummary()
            self.discovery_summary.parent = self
            self._children_name_map["discovery_summary"] = "discovery-summary"

            self.g8032 = L2vpnv2.Standby.G8032()
            self.g8032.parent = self
            self._children_name_map["g8032"] = "g8032"

            self.pseudowire_classes = L2vpnv2.Standby.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self._children_name_map["pseudowire_classes"] = "pseudowire-classes"

            self.l2vpn_collaborators = L2vpnv2.Standby.L2vpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"

            self.mvrp = L2vpnv2.Standby.Mvrp()
            self.mvrp.parent = self
            self._children_name_map["mvrp"] = "mvrp"

            self.generic_interface_lists = L2vpnv2.Standby.GenericInterfaceLists()
            self.generic_interface_lists.parent = self
            self._children_name_map["generic_interface_lists"] = "generic-interface-lists"

            self.mstp_vlans = L2vpnv2.Standby.MstpVlans()
            self.mstp_vlans.parent = self
            self._children_name_map["mstp_vlans"] = "mstp-vlans"

            self.l2vpn_pbb_bsa = L2vpnv2.Standby.L2vpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"

            self.flexible_xconnect_services = L2vpnv2.Standby.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"

            self.xconnect_brief = L2vpnv2.Standby.XconnectBrief()
            self.xconnect_brief.parent = self
            self._children_name_map["xconnect_brief"] = "xconnect-brief"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(L2vpnv2.Standby, [], name, value)


        class Discoveries(Entity):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of  		 :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Discoveries, self).__init__()

                self.yang_name = "discoveries"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Standby.Discoveries.Discovery))])
                self._leafs = OrderedDict()

                self.discovery = YList(self)
                self._segment_path = lambda: "discoveries"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Discoveries, [], name, value)


            class Discovery(Entity):
                """
                VPLS Discovery information
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:  :py:class:`L2vpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnService>`
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\: str
                
                	**length:** 1..27
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:  :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\: bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\: str
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\: str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Discoveries.Discovery, self).__init__()

                    self.yang_name = "discovery"
                    self.yang_parent_name = "discoveries"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("signalling-info", ("signalling_info", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo))])
                    self._leafs = OrderedDict([
                        ('service_name', YLeaf(YType.enumeration, 'service-name')),
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('vpn_name', YLeaf(YType.str, 'vpn-name')),
                        ('mtu_mismatch_ignore', YLeaf(YType.boolean, 'mtu-mismatch-ignore')),
                        ('number_vpn', YLeaf(YType.uint32, 'number-vpn')),
                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                        ('service_name_xr', YLeaf(YType.str, 'service-name-xr')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('vpn_name_xr', YLeaf(YType.str, 'vpn-name-xr')),
                        ('is_service_connected', YLeaf(YType.boolean, 'is-service-connected')),
                    ])
                    self.service_name = None
                    self.group_name = None
                    self.vpn_name = None
                    self.mtu_mismatch_ignore = None
                    self.number_vpn = None
                    self.vpn_id = None
                    self.service_name_xr = None
                    self.group_name_xr = None
                    self.vpn_name_xr = None
                    self.is_service_connected = None

                    self.signalling_info = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self._children_name_map["signalling_info"] = "signalling-info"
                    self._segment_path = lambda: "discovery"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery, ['service_name', 'group_name', 'vpn_name', 'mtu_mismatch_ignore', 'number_vpn', 'vpn_id', 'service_name_xr', 'group_name_xr', 'vpn_name_xr', 'is_service_connected'], name, value)


                class SignallingInfo(Entity):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:  :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:  :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:  :py:class:`L2vpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdSigMethod>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo, self).__init__()

                        self.yang_name = "signalling-info"
                        self.yang_parent_name = "discovery"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-sig-info", ("bgp_sig_info", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo)), ("ldp-sig-info", ("ldp_sig_info", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo))])
                        self._leafs = OrderedDict([
                            ('ad_signalling_method', YLeaf(YType.enumeration, 'ad-signalling-method')),
                        ])
                        self.ad_signalling_method = None

                        self.bgp_sig_info = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self._children_name_map["bgp_sig_info"] = "bgp-sig-info"

                        self.ldp_sig_info = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self
                        self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                        self._segment_path = lambda: "signalling-info"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo, ['ad_signalling_method'], name, value)


                    class BgpSigInfo(Entity):
                        """
                        bgp sig info
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of  		 :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of  		 :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                            self.yang_name = "bgp-sig-info"
                            self.yang_parent_name = "signalling-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("edge", ("edge", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge)), ("redge", ("redge", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge))])
                            self._leafs = OrderedDict([
                                ('number_edges', YLeaf(YType.uint32, 'number-edges')),
                                ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                            ])
                            self.number_edges = None
                            self.number_remote_edges = None

                            self.edge = YList(self)
                            self.redge = YList(self)
                            self._segment_path = lambda: "bgp-sig-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo, ['number_edges', 'number_remote_edges'], name, value)


                        class Edge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bgp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock))])
                                self._leafs = OrderedDict([
                                    ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                    ('label_count', YLeaf(YType.uint32, 'label-count')),
                                ])
                                self.edge_id = None
                                self.label_count = None

                                self.label_block = YList(self)
                                self._segment_path = lambda: "edge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, ['edge_id', 'label_count'], name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "edge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector))])
                                    self._leafs = OrderedDict([
                                        ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                        ('label_base', YLeaf(YType.uint32, 'label-base')),
                                        ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                        ('block_size', YLeaf(YType.uint32, 'block-size')),
                                        ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                    ])
                                    self.label_time_created = None
                                    self.label_base = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.label_error = None

                                    self.status_vector = YList(self)
                                    self._segment_path = lambda: "label-block"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/edge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                class StatusVector(Entity):
                                    """
                                    Status Vector
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, self).__init__()

                                        self.yang_name = "status-vector"
                                        self.yang_parent_name = "label-block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint8, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "status-vector"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/edge/label-block/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, ['entry'], name, value)


                        class Redge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                self.yang_name = "redge"
                                self.yang_parent_name = "bgp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock))])
                                self._leafs = OrderedDict([
                                    ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                    ('label_count', YLeaf(YType.uint32, 'label-count')),
                                ])
                                self.edge_id = None
                                self.label_count = None

                                self.label_block = YList(self)
                                self._segment_path = lambda: "redge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, ['edge_id', 'label_count'], name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "redge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector))])
                                    self._leafs = OrderedDict([
                                        ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                        ('label_base', YLeaf(YType.uint32, 'label-base')),
                                        ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                        ('block_size', YLeaf(YType.uint32, 'block-size')),
                                        ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                    ])
                                    self.label_time_created = None
                                    self.label_base = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.label_error = None

                                    self.status_vector = YList(self)
                                    self._segment_path = lambda: "label-block"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/redge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                class StatusVector(Entity):
                                    """
                                    Status Vector
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, self).__init__()

                                        self.yang_name = "status-vector"
                                        self.yang_parent_name = "label-block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint8, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "status-vector"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/bgp-sig-info/redge/label-block/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, ['entry'], name, value)


                    class LdpSigInfo(Entity):
                        """
                        ldp sig info
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:  :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of  		 :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                            self.yang_name = "ldp-sig-info"
                            self.yang_parent_name = "signalling-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("local-vpls-id", ("local_vpls_id", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId)), ("remote-nlri", ("remote_nlri", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri))])
                            self._leafs = OrderedDict([
                                ('local_l2_router_id', YLeaf(YType.str, 'local-l2-router-id')),
                                ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                            ])
                            self.local_l2_router_id = None
                            self.number_remote_edges = None

                            self.local_vpls_id = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self._children_name_map["local_vpls_id"] = "local-vpls-id"

                            self.remote_nlri = YList(self)
                            self._segment_path = lambda: "ldp-sig-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo, ['local_l2_router_id', 'number_remote_edges'], name, value)


                        class LocalVplsId(Entity):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                self.yang_name = "local-vpls-id"
                                self.yang_parent_name = "ldp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr))])
                                self._leafs = OrderedDict([
                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                ])
                                self.vpls_id_type = None

                                self.auto = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"

                                self.two_byte_as = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.v4_addr = L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._segment_path = lambda: "local-vpls-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, ['vpls_id_type'], name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ])
                                    self.asn = None
                                    self.vpn_id = None
                                    self._segment_path = lambda: "auto"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, ['asn', 'vpn_id'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class RemoteNlri(Entity):
                            """
                            List of NLRIs
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                self.yang_name = "remote-nlri"
                                self.yang_parent_name = "ldp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nlri_time_created', YLeaf(YType.uint32, 'nlri-time-created')),
                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                    ('remote_l2_router_id', YLeaf(YType.str, 'remote-l2-router-id')),
                                ])
                                self.nlri_time_created = None
                                self.local_address = None
                                self.remote_address = None
                                self.remote_l2_router_id = None
                                self._segment_path = lambda: "remote-nlri"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, ['nlri_time_created', 'local_address', 'remote_address', 'remote_l2_router_id'], name, value)


        class FlexibleXconnectServiceSummary(Entity):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.FlexibleXconnectServiceSummary, self).__init__()

                self.yang_name = "flexible-xconnect-service-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_fxc', YLeaf(YType.uint32, 'number-fxc')),
                    ('number_fxc_up', YLeaf(YType.uint32, 'number-fxc-up')),
                    ('number_fxc_down', YLeaf(YType.uint32, 'number-fxc-down')),
                ])
                self.number_fxc = None
                self.number_fxc_up = None
                self.number_fxc_down = None
                self._segment_path = lambda: "flexible-xconnect-service-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServiceSummary, ['number_fxc', 'number_fxc_up', 'number_fxc_down'], name, value)


        class MainInterfaces(Entity):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of  		 :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.MainInterfaces, self).__init__()

                self.yang_name = "main-interfaces"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("main-interface", ("main_interface", L2vpnv2.Standby.MainInterfaces.MainInterface))])
                self._leafs = OrderedDict()

                self.main_interface = YList(self)
                self._segment_path = lambda: "main-interfaces"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.MainInterfaces, [], name, value)


            class MainInterface(Entity):
                """
                Main Interface Table
                
                .. attribute:: interface_name  (key)
                
                	Main interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:  :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:  :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.MainInterfaces.MainInterface, self).__init__()

                    self.yang_name = "main-interface"
                    self.yang_parent_name = "main-interfaces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_name']
                    self._child_classes = OrderedDict([("main-interface-instances", ("main_interface_instances", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances)), ("main-interface-info", ("main_interface_info", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo))])
                    self._leafs = OrderedDict([
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                    ])
                    self.interface_name = None

                    self.main_interface_instances = L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self
                    self._children_name_map["main_interface_instances"] = "main-interface-instances"

                    self.main_interface_info = L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self._children_name_map["main_interface_info"] = "main-interface-info"
                    self._segment_path = lambda: "main-interface" + "[interface-name='" + str(self.interface_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/main-interfaces/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface, ['interface_name'], name, value)


                class MainInterfaceInstances(Entity):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of  		 :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                        self.yang_name = "main-interface-instances"
                        self.yang_parent_name = "main-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("main-interface-instance", ("main_interface_instance", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance))])
                        self._leafs = OrderedDict()

                        self.main_interface_instance = YList(self)
                        self._segment_path = lambda: "main-interface-instances"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances, [], name, value)


                    class MainInterfaceInstance(Entity):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  (key)
                        
                        	Instance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:  :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:  :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                            self.yang_name = "main-interface-instance"
                            self.yang_parent_name = "main-interface-instances"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([("main-interface-instance-info", ("main_interface_instance_info", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo)), ("main-interface-instance-bridge-ports", ("main_interface_instance_bridge_ports", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts))])
                            self._leafs = OrderedDict([
                                ('instance', YLeaf(YType.uint32, 'instance')),
                            ])
                            self.instance = None

                            self.main_interface_instance_info = L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self
                            self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"

                            self.main_interface_instance_bridge_ports = L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                            self._segment_path = lambda: "main-interface-instance" + "[instance='" + str(self.instance) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, ['instance'], name, value)


                        class MainInterfaceInstanceInfo(Entity):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:  :py:class:`L2vpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                self.yang_name = "main-interface-instance-info"
                                self.yang_parent_name = "main-interface-instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('configured_instance', YLeaf(YType.uint32, 'configured-instance')),
                                    ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                                    ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                                    ('instance_flags', YLeaf(YType.uint32, 'instance-flags')),
                                    ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                    ('instance_state', YLeaf(YType.enumeration, 'instance-state')),
                                ])
                                self.configured_instance = None
                                self.flush_count = None
                                self.interface_count = None
                                self.instance_flags = None
                                self.instance_id = None
                                self.instance_state = None
                                self._segment_path = lambda: "main-interface-instance-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, ['configured_instance', 'flush_count', 'interface_count', 'instance_flags', 'instance_id', 'instance_state'], name, value)


                        class MainInterfaceInstanceBridgePorts(Entity):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of  		 :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                self.yang_name = "main-interface-instance-bridge-ports"
                                self.yang_parent_name = "main-interface-instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("main-interface-instance-bridge-port", ("main_interface_instance_bridge_port", L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort))])
                                self._leafs = OrderedDict()

                                self.main_interface_instance_bridge_port = YList(self)
                                self._segment_path = lambda: "main-interface-instance-bridge-ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, [], name, value)


                            class MainInterfaceInstanceBridgePort(Entity):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  (key)
                                
                                	Bridge Port
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-port"
                                    self.yang_parent_name = "main-interface-instance-bridge-ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['bridge_port']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bridge_port', YLeaf(YType.str, 'bridge-port')),
                                        ('bridge_port_xr', YLeaf(YType.str, 'bridge-port-xr')),
                                        ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                    ])
                                    self.bridge_port = None
                                    self.bridge_port_xr = None
                                    self.instance_id = None
                                    self._segment_path = lambda: "main-interface-instance-bridge-port" + "[bridge-port='" + str(self.bridge_port) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, ['bridge_port', 'bridge_port_xr', 'instance_id'], name, value)


                class MainInterfaceInfo(Entity):
                    """
                    Main Interface info
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:  :py:class:`L2vpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfProtectected>`
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                        self.yang_name = "main-interface-info"
                        self.yang_parent_name = "main-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('main_interface_handle', YLeaf(YType.str, 'main-interface-handle')),
                            ('protected', YLeaf(YType.enumeration, 'protected')),
                            ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                        ])
                        self.main_interface_handle = None
                        self.protected = None
                        self.interface_count = None
                        self._segment_path = lambda: "main-interface-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.MainInterfaces.MainInterface.MainInterfaceInfo, ['main_interface_handle', 'protected', 'interface_count'], name, value)


        class IccpSm(Entity):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:  :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpSmSummary>`
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:  :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.IccpSm, self).__init__()

                self.yang_name = "iccp-sm"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("iccp-sm-summary", ("iccp_sm_summary", L2vpnv2.Standby.IccpSm.IccpSmSummary)), ("iccp-groups", ("iccp_groups", L2vpnv2.Standby.IccpSm.IccpGroups))])
                self._leafs = OrderedDict()

                self.iccp_sm_summary = L2vpnv2.Standby.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self
                self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"

                self.iccp_groups = L2vpnv2.Standby.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self._children_name_map["iccp_groups"] = "iccp-groups"
                self._segment_path = lambda: "iccp-sm"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.IccpSm, [], name, value)


            class IccpSmSummary(Entity):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.IccpSm.IccpSmSummary, self).__init__()

                    self.yang_name = "iccp-sm-summary"
                    self.yang_parent_name = "iccp-sm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('groups', YLeaf(YType.uint32, 'groups')),
                        ('unresolved_groups', YLeaf(YType.uint32, 'unresolved-groups')),
                        ('provisioned_groups', YLeaf(YType.uint32, 'provisioned-groups')),
                        ('connecting_groups', YLeaf(YType.uint32, 'connecting-groups')),
                        ('connected_groups', YLeaf(YType.uint32, 'connected-groups')),
                        ('synchronizing_groups', YLeaf(YType.uint32, 'synchronizing-groups')),
                        ('synchronized_groups', YLeaf(YType.uint32, 'synchronized-groups')),
                        ('ports', YLeaf(YType.uint32, 'ports')),
                        ('operational_ports', YLeaf(YType.uint32, 'operational-ports')),
                        ('failed_ports', YLeaf(YType.uint32, 'failed-ports')),
                        ('unknown_ports', YLeaf(YType.uint32, 'unknown-ports')),
                        ('unconfigured_ports', YLeaf(YType.uint32, 'unconfigured-ports')),
                        ('unsynchronized_ports', YLeaf(YType.uint32, 'unsynchronized-ports')),
                        ('reverting_ports', YLeaf(YType.uint32, 'reverting-ports')),
                    ])
                    self.groups = None
                    self.unresolved_groups = None
                    self.provisioned_groups = None
                    self.connecting_groups = None
                    self.connected_groups = None
                    self.synchronizing_groups = None
                    self.synchronized_groups = None
                    self.ports = None
                    self.operational_ports = None
                    self.failed_ports = None
                    self.unknown_ports = None
                    self.unconfigured_ports = None
                    self.unsynchronized_ports = None
                    self.reverting_ports = None
                    self._segment_path = lambda: "iccp-sm-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpSmSummary, ['groups', 'unresolved_groups', 'provisioned_groups', 'connecting_groups', 'connected_groups', 'synchronizing_groups', 'synchronized_groups', 'ports', 'operational_ports', 'failed_ports', 'unknown_ports', 'unconfigured_ports', 'unsynchronized_ports', 'reverting_ports'], name, value)


            class IccpGroups(Entity):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of  		 :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.IccpSm.IccpGroups, self).__init__()

                    self.yang_name = "iccp-groups"
                    self.yang_parent_name = "iccp-sm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iccp-group", ("iccp_group", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup))])
                    self._leafs = OrderedDict()

                    self.iccp_group = YList(self)
                    self._segment_path = lambda: "iccp-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups, [], name, value)


                class IccpGroup(Entity):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  (key)
                    
                    	Group ID
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:  :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:  :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup, self).__init__()

                        self.yang_name = "iccp-group"
                        self.yang_parent_name = "iccp-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("iccp-group-info", ("iccp_group_info", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo)), ("iccp-ports", ("iccp_ports", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts))])
                        self._leafs = OrderedDict([
                            ('group_id', YLeaf(YType.uint32, 'group-id')),
                        ])
                        self.group_id = None

                        self.iccp_group_info = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self._children_name_map["iccp_group_info"] = "iccp-group-info"

                        self.iccp_ports = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self
                        self._children_name_map["iccp_ports"] = "iccp-ports"
                        self._segment_path = lambda: "iccp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/iccp-sm/iccp-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup, ['group_id'], name, value)


                    class IccpGroupInfo(Entity):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\: bool
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\: bool
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of  		 :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                            self.yang_name = "iccp-group-info"
                            self.yang_parent_name = "iccp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ports", ("ports", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports))])
                            self._leafs = OrderedDict([
                                ('group_id', YLeaf(YType.uint32, 'group-id')),
                                ('local_node_id', YLeaf(YType.uint8, 'local-node-id')),
                                ('remote_node_id', YLeaf(YType.uint8, 'remote-node-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('iccp_transport_up', YLeaf(YType.boolean, 'iccp-transport-up')),
                                ('iccp_member_up', YLeaf(YType.boolean, 'iccp-member-up')),
                            ])
                            self.group_id = None
                            self.local_node_id = None
                            self.remote_node_id = None
                            self.state = None
                            self.iccp_transport_up = None
                            self.iccp_member_up = None

                            self.ports = YList(self)
                            self._segment_path = lambda: "iccp-group-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, ['group_id', 'local_node_id', 'remote_node_id', 'state', 'iccp_transport_up', 'iccp_member_up'], name, value)


                        class Ports(Entity):
                            """
                            List of ports in the group
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                self.yang_name = "ports"
                                self.yang_parent_name = "iccp-group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                ])
                                self.interface_name = None
                                self.mac_flush_tcn = None

                                self.local_port = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"

                                self.remote_port = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._segment_path = lambda: "ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, ['interface_name', 'mac_flush_tcn'], name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "local-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "remote-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                    class IccpPorts(Entity):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of  		 :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                            self.yang_name = "iccp-ports"
                            self.yang_parent_name = "iccp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("iccp-port", ("iccp_port", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort))])
                            self._leafs = OrderedDict()

                            self.iccp_port = YList(self)
                            self._segment_path = lambda: "iccp-ports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts, [], name, value)


                        class IccpPort(Entity):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  (key)
                            
                            	Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                self.yang_name = "iccp-port"
                                self.yang_parent_name = "iccp-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort))])
                                self._leafs = OrderedDict([
                                    ('interface', YLeaf(YType.str, 'interface')),
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                ])
                                self.interface = None
                                self.interface_name = None
                                self.mac_flush_tcn = None

                                self.local_port = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"

                                self.remote_port = L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._segment_path = lambda: "iccp-port" + "[interface='" + str(self.interface) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, ['interface', 'interface_name', 'mac_flush_tcn'], name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "iccp-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "local-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "iccp-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "remote-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


        class BridgeSummary(Entity):
            """
            Bridge Domain summary information
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_down
            
            	Number of attachment circuits whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_down
            
            	Number of pseudowires whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.BridgeSummary, self).__init__()

                self.yang_name = "bridge-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                    ('number_bridge_domains', YLeaf(YType.uint32, 'number-bridge-domains')),
                    ('number_bridge_domains_up', YLeaf(YType.uint32, 'number-bridge-domains-up')),
                    ('number_bridge_domains_shut', YLeaf(YType.uint32, 'number-bridge-domains-shut')),
                    ('number_default_bridge_doamins', YLeaf(YType.uint32, 'number-default-bridge-doamins')),
                    ('number_pbb_edge', YLeaf(YType.uint32, 'number-pbb-edge')),
                    ('number_pbb_core', YLeaf(YType.uint32, 'number-pbb-core')),
                    ('number_p2mp', YLeaf(YType.uint32, 'number-p2mp')),
                    ('number_p2mp_up', YLeaf(YType.uint32, 'number-p2mp-up')),
                    ('number_p2mp_down', YLeaf(YType.uint32, 'number-p2mp-down')),
                    ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                    ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                    ('number_a_cs_down', YLeaf(YType.uint32, 'number-a-cs-down')),
                    ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                    ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                    ('number_p_ws_down', YLeaf(YType.uint32, 'number-p-ws-down')),
                    ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                    ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                    ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                    ('num_vn_is_down', YLeaf(YType.uint32, 'num-vn-is-down')),
                    ('num_vn_is_unresolved', YLeaf(YType.uint32, 'num-vn-is-unresolved')),
                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                    ('partially_programmed_bridges', YLeaf(YType.uint32, 'partially-programmed-bridges')),
                    ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                    ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                ])
                self.number_groups = None
                self.number_bridge_domains = None
                self.number_bridge_domains_up = None
                self.number_bridge_domains_shut = None
                self.number_default_bridge_doamins = None
                self.number_pbb_edge = None
                self.number_pbb_core = None
                self.number_p2mp = None
                self.number_p2mp_up = None
                self.number_p2mp_down = None
                self.number_a_cs = None
                self.number_a_cs_up = None
                self.number_a_cs_down = None
                self.number_pseudowires = None
                self.number_p_ws_up = None
                self.number_p_ws_down = None
                self.standby_pseudowires = None
                self.num_vn_is = None
                self.num_vn_is_up = None
                self.num_vn_is_down = None
                self.num_vn_is_unresolved = None
                self.out_of_memory_state = None
                self.partially_programmed_bridges = None
                self.partially_programmed_pseudowires = None
                self.partially_programmed_a_cs = None
                self._segment_path = lambda: "bridge-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.BridgeSummary, ['number_groups', 'number_bridge_domains', 'number_bridge_domains_up', 'number_bridge_domains_shut', 'number_default_bridge_doamins', 'number_pbb_edge', 'number_pbb_core', 'number_p2mp', 'number_p2mp_up', 'number_p2mp_down', 'number_a_cs', 'number_a_cs_up', 'number_a_cs_down', 'number_pseudowires', 'number_p_ws_up', 'number_p_ws_down', 'standby_pseudowires', 'num_vn_is', 'num_vn_is_up', 'num_vn_is_down', 'num_vn_is_unresolved', 'out_of_memory_state', 'partially_programmed_bridges', 'partially_programmed_pseudowires', 'partially_programmed_a_cs'], name, value)


        class Nsr(Entity):
            """
            L2VPN NSR information
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.FailoverStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.NsrStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.IssuStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\: bool
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.StateTransitionTime>`
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.XidInfo>`
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.ReportCard>`
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.EventHistory>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Standby.Nsr.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Standby.Nsr.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Standby.Nsr.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Standby.Nsr.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Standby.Nsr.XidInfo)), ("report-card", ("report_card", L2vpnv2.Standby.Nsr.ReportCard)), ("event-history", ("event_history", L2vpnv2.Standby.Nsr.EventHistory))])
                self._leafs = OrderedDict([
                    ('process_role', YLeaf(YType.uint8, 'process-role')),
                    ('process_state', YLeaf(YType.uint8, 'process-state')),
                    ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                    ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                ])
                self.process_role = None
                self.process_state = None
                self.sync_flags = None
                self.sw_install_in_progress = None

                self.failover_status = L2vpnv2.Standby.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"

                self.nsr_status = L2vpnv2.Standby.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"

                self.issu_status = L2vpnv2.Standby.Nsr.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"

                self.state_transition_time = YList(self)
                self.xid_info = YList(self)
                self.report_card = YList(self)
                self.event_history = YList(self)
                self._segment_path = lambda: "nsr"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Nsr, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: master_time
                
                	Master time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                        ('start_time', YLeaf(YType.uint32, 'start-time')),
                        ('master_time', YLeaf(YType.uint32, 'master-time')),
                    ])
                    self.triggered_time = None
                    self.start_time = None
                    self.master_time = None
                    self._segment_path = lambda: "failover-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Standby.Nsr.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Standby.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "nsr-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.NsrStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Nsr.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Nsr.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Nsr.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Standby.Nsr.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Standby.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "issu-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.IssuStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Nsr.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Nsr.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Nsr.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class StateTransitionTime(Entity):
                """
                Transition time for all states
                
                .. attribute:: entry
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.StateTransitionTime, self).__init__()

                    self.yang_name = "state-transition-time"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('entry', YLeaf(YType.uint32, 'entry')),
                    ])
                    self.entry = None
                    self._segment_path = lambda: "state-transition-time"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.StateTransitionTime, ['entry'], name, value)


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('app_type', YLeaf(YType.enumeration, 'app-type')),
                        ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                    ])
                    self.app_type = None
                    self.sent_ids = None
                    self._segment_path = lambda: "xid-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.XidInfo, ['app_type', 'sent_ids'], name, value)


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\: bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\: bool
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                        ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                        ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                        ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                        ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                    ])
                    self.collaborator_is_connected = None
                    self.connection_change_time = None
                    self.collaborator_idt_done = None
                    self.idt_time = None
                    self.collaborator_skipped = None
                    self._segment_path = lambda: "report-card"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: new_state
                
                	New state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_event
                
                	Process event
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Nsr.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                        ('new_state', YLeaf(YType.uint8, 'new-state')),
                        ('process_event', YLeaf(YType.uint16, 'process-event')),
                        ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                        ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                    ])
                    self.previous_state = None
                    self.new_state = None
                    self.process_event = None
                    self.process_collaborator = None
                    self.event_timestamp = None
                    self._segment_path = lambda: "event-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Nsr.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


        class PreferredPaths(Entity):
            """
            Preferred path Table
            
            .. attribute:: preferred_path
            
            	Preferred path information
            	**type**\: list of  		 :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PreferredPaths.PreferredPath>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.PreferredPaths, self).__init__()

                self.yang_name = "preferred-paths"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("preferred-path", ("preferred_path", L2vpnv2.Standby.PreferredPaths.PreferredPath))])
                self._leafs = OrderedDict()

                self.preferred_path = YList(self)
                self._segment_path = lambda: "preferred-paths"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.PreferredPaths, [], name, value)


            class PreferredPath(Entity):
                """
                Preferred path information
                
                .. attribute:: preferred_type
                
                	Preferred type
                	**type**\:  :py:class:`PreferredPathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PreferredPathOption>`
                
                .. attribute:: interface_name
                
                	Main interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: type
                
                	Preferred type
                	**type**\:  :py:class:`L2vpnPreferred <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPreferred>`
                
                .. attribute:: interface_name_xr
                
                	Interface name
                	**type**\: str
                
                	**length:** 0..65
                
                .. attribute:: total_bandwidth
                
                	TotalBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: available_bandwidth
                
                	AvailableBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: reserved_bandwidth
                
                	ReservedBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_circuit
                
                	virtual circuit
                	**type**\: list of  		 :py:class:`VirtualCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PreferredPaths.PreferredPath.VirtualCircuit>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.PreferredPaths.PreferredPath, self).__init__()

                    self.yang_name = "preferred-path"
                    self.yang_parent_name = "preferred-paths"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual-circuit", ("virtual_circuit", L2vpnv2.Standby.PreferredPaths.PreferredPath.VirtualCircuit))])
                    self._leafs = OrderedDict([
                        ('preferred_type', YLeaf(YType.enumeration, 'preferred-type')),
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ('type', YLeaf(YType.enumeration, 'type')),
                        ('interface_name_xr', YLeaf(YType.str, 'interface-name-xr')),
                        ('total_bandwidth', YLeaf(YType.uint32, 'total-bandwidth')),
                        ('available_bandwidth', YLeaf(YType.uint32, 'available-bandwidth')),
                        ('reserved_bandwidth', YLeaf(YType.uint32, 'reserved-bandwidth')),
                    ])
                    self.preferred_type = None
                    self.interface_name = None
                    self.type = None
                    self.interface_name_xr = None
                    self.total_bandwidth = None
                    self.available_bandwidth = None
                    self.reserved_bandwidth = None

                    self.virtual_circuit = YList(self)
                    self._segment_path = lambda: "preferred-path"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/preferred-paths/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.PreferredPaths.PreferredPath, ['preferred_type', 'interface_name', 'type', 'interface_name_xr', 'total_bandwidth', 'available_bandwidth', 'reserved_bandwidth'], name, value)


                class VirtualCircuit(Entity):
                    """
                    virtual circuit
                    
                    .. attribute:: peer_id
                    
                    	PeerID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_address
                    
                    	SourceAddress
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pwid_type
                    
                    	pwid type
                    	**type**\:  :py:class:`L2vpnPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwId>`
                    
                    .. attribute:: pwid
                    
                    	PWID
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: fe_ctype
                    
                    	FECType
                    	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.PreferredPaths.PreferredPath.VirtualCircuit, self).__init__()

                        self.yang_name = "virtual-circuit"
                        self.yang_parent_name = "preferred-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer_id', YLeaf(YType.str, 'peer-id')),
                            ('source_address', YLeaf(YType.str, 'source-address')),
                            ('pwid_type', YLeaf(YType.enumeration, 'pwid-type')),
                            ('pwid', YLeaf(YType.uint64, 'pwid')),
                            ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                        ])
                        self.peer_id = None
                        self.source_address = None
                        self.pwid_type = None
                        self.pwid = None
                        self.fe_ctype = None
                        self._segment_path = lambda: "virtual-circuit"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/preferred-paths/preferred-path/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.PreferredPaths.PreferredPath.VirtualCircuit, ['peer_id', 'source_address', 'pwid_type', 'pwid', 'fe_ctype'], name, value)


        class GlobalSettings(Entity):
            """
            L2VPN global settings
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\: bool
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\: bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\: bool
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\: bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\: bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\: str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\: str
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\: str
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\: bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.GlobalSettings, self).__init__()

                self.yang_name = "global-settings"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('pw_grouping_enabled', YLeaf(YType.boolean, 'pw-grouping-enabled')),
                    ('pw_status_enabled', YLeaf(YType.boolean, 'pw-status-enabled')),
                    ('logging_pw_enabled', YLeaf(YType.boolean, 'logging-pw-enabled')),
                    ('logging_bd_enabled', YLeaf(YType.boolean, 'logging-bd-enabled')),
                    ('logging_vfi_enabled', YLeaf(YType.boolean, 'logging-vfi-enabled')),
                    ('logging_nsr_enabled', YLeaf(YType.boolean, 'logging-nsr-enabled')),
                    ('logging_df_election_enabled', YLeaf(YType.boolean, 'logging-df-election-enabled')),
                    ('tcn_propagation_enabled', YLeaf(YType.boolean, 'tcn-propagation-enabled')),
                    ('pw_oam_refresh_transmit_time', YLeaf(YType.uint32, 'pw-oam-refresh-transmit-time')),
                    ('ha_role', YLeaf(YType.str, 'ha-role')),
                    ('issu_role', YLeaf(YType.str, 'issu-role')),
                    ('process_fsm', YLeaf(YType.str, 'process-fsm')),
                    ('going_active', YLeaf(YType.boolean, 'going-active')),
                ])
                self.pw_grouping_enabled = None
                self.pw_status_enabled = None
                self.logging_pw_enabled = None
                self.logging_bd_enabled = None
                self.logging_vfi_enabled = None
                self.logging_nsr_enabled = None
                self.logging_df_election_enabled = None
                self.tcn_propagation_enabled = None
                self.pw_oam_refresh_transmit_time = None
                self.ha_role = None
                self.issu_role = None
                self.process_fsm = None
                self.going_active = None
                self._segment_path = lambda: "global-settings"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.GlobalSettings, ['pw_grouping_enabled', 'pw_status_enabled', 'logging_pw_enabled', 'logging_bd_enabled', 'logging_vfi_enabled', 'logging_nsr_enabled', 'logging_df_election_enabled', 'tcn_propagation_enabled', 'pw_oam_refresh_transmit_time', 'ha_role', 'issu_role', 'process_fsm', 'going_active'], name, value)


        class Pwr(Entity):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Pwr, self).__init__()

                self.yang_name = "pwr"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Standby.Pwr.Summary))])
                self._leafs = OrderedDict()

                self.summary = L2vpnv2.Standby.Pwr.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._segment_path = lambda: "pwr"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Pwr, [], name, value)


            class Summary(Entity):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:  :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:  :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdConfigured>`
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Pwr.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "pwr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rd-auto", ("rd_auto", L2vpnv2.Standby.Pwr.Summary.RdAuto)), ("rd-configured", ("rd_configured", L2vpnv2.Standby.Pwr.Summary.RdConfigured))])
                    self._leafs = OrderedDict([
                        ('bgp_router_id', YLeaf(YType.str, 'bgp-router-id')),
                        ('cfg_router_id', YLeaf(YType.str, 'cfg-router-id')),
                        ('bgp_as', YLeaf(YType.uint32, 'bgp-as')),
                        ('cfg_global_id', YLeaf(YType.uint32, 'cfg-global-id')),
                        ('l2vpn_has_bgp_eod', YLeaf(YType.boolean, 'l2vpn-has-bgp-eod')),
                    ])
                    self.bgp_router_id = None
                    self.cfg_router_id = None
                    self.bgp_as = None
                    self.cfg_global_id = None
                    self.l2vpn_has_bgp_eod = None

                    self.rd_auto = L2vpnv2.Standby.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self._children_name_map["rd_auto"] = "rd-auto"

                    self.rd_configured = L2vpnv2.Standby.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self
                    self._children_name_map["rd_configured"] = "rd-configured"
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Pwr.Summary, ['bgp_router_id', 'cfg_router_id', 'bgp_as', 'cfg_global_id', 'l2vpn_has_bgp_eod'], name, value)


                class RdAuto(Entity):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Pwr.Summary.RdAuto, self).__init__()

                        self.yang_name = "rd-auto"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Pwr.Summary.RdAuto.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr))])
                        self._leafs = OrderedDict([
                            ('rd', YLeaf(YType.enumeration, 'rd')),
                        ])
                        self.rd = None

                        self.auto = L2vpnv2.Standby.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"

                        self.two_byte_as = L2vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"

                        self.four_byte_as = L2vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"

                        self.v4_addr = L2vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._segment_path = lambda: "rd-auto"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdAuto, ['rd'], name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdAuto.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('router_id', YLeaf(YType.str, 'router-id')),
                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                            ])
                            self.router_id = None
                            self.auto_index = None
                            self._segment_path = lambda: "auto"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdAuto.Auto, ['router_id', 'auto_index'], name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                            ])
                            self.two_byte_as = None
                            self.four_byte_index = None
                            self._segment_path = lambda: "two-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdAuto.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.four_byte_as = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "four-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdAuto.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.ipv4_address = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "v4-addr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdAuto.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                class RdConfigured(Entity):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Pwr.Summary.RdConfigured, self).__init__()

                        self.yang_name = "rd-configured"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Pwr.Summary.RdConfigured.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr))])
                        self._leafs = OrderedDict([
                            ('rd', YLeaf(YType.enumeration, 'rd')),
                        ])
                        self.rd = None

                        self.auto = L2vpnv2.Standby.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"

                        self.two_byte_as = L2vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"

                        self.four_byte_as = L2vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"

                        self.v4_addr = L2vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._segment_path = lambda: "rd-configured"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdConfigured, ['rd'], name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdConfigured.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('router_id', YLeaf(YType.str, 'router-id')),
                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                            ])
                            self.router_id = None
                            self.auto_index = None
                            self._segment_path = lambda: "auto"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdConfigured.Auto, ['router_id', 'auto_index'], name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                            ])
                            self.two_byte_as = None
                            self.four_byte_index = None
                            self._segment_path = lambda: "two-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdConfigured.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.four_byte_as = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "four-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdConfigured.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.ipv4_address = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "v4-addr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Pwr.Summary.RdConfigured.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


        class XconnectMp2mpCe2ces(Entity):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of  		 :py:class:`XconnectMp2mpCe2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.XconnectMp2mpCe2ces, self).__init__()

                self.yang_name = "xconnect-mp2mp-ce2ces"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-mp2mp-ce2ce", ("xconnect_mp2mp_ce2ce", L2vpnv2.Standby.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce))])
                self._leafs = OrderedDict()

                self.xconnect_mp2mp_ce2ce = YList(self)
                self._segment_path = lambda: "xconnect-mp2mp-ce2ces"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mpCe2ces, [], name, value)


            class XconnectMp2mpCe2ce(Entity):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\: str
                
                	**length:** 1..26
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ce"
                    self.yang_parent_name = "xconnect-mp2mp-ce2ces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                        ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                        ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                        ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                    ])
                    self.group_name = None
                    self.mp2_mp_name = None
                    self.local_ceid = None
                    self.remote_ceid = None
                    self.local_customer_edge_id = None
                    self.remote_customer_edge_id = None
                    self.ce_added = None
                    self._segment_path = lambda: "xconnect-mp2mp-ce2ce"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mp-ce2ces/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, ['group_name', 'mp2_mp_name', 'local_ceid', 'remote_ceid', 'local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


        class Xconnects(Entity):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of  		 :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Xconnects, self).__init__()

                self.yang_name = "xconnects"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect", ("xconnect", L2vpnv2.Standby.Xconnects.Xconnect))])
                self._leafs = OrderedDict()

                self.xconnect = YList(self)
                self._segment_path = lambda: "xconnects"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Xconnects, [], name, value)


            class Xconnect(Entity):
                """
                XConnect information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\: str
                
                	**length:** 1..38
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup>`
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:  :py:class:`Ce2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Ce2ce>`
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\: str
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: description
                
                	P2P Description
                	**type**\: str
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\: bool
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of  		 :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Xconnects.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "xconnects"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("backup", ("backup", L2vpnv2.Standby.Xconnects.Xconnect.Backup)), ("segment1", ("segment1", L2vpnv2.Standby.Xconnects.Xconnect.Segment1)), ("segment2", ("segment2", L2vpnv2.Standby.Xconnects.Xconnect.Segment2)), ("ce2ce", ("ce2ce", L2vpnv2.Standby.Xconnects.Xconnect.Ce2ce)), ("backup-segment", ("backup_segment", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment))])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('xconnect_name', YLeaf(YType.str, 'xconnect-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('xconnect_name_xr', YLeaf(YType.str, 'xconnect-name-xr')),
                        ('number_of_backup_p_ws', YLeaf(YType.uint32, 'number-of-backup-p-ws')),
                        ('state', YLeaf(YType.enumeration, 'state')),
                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                        ('diag_mask', YLeaf(YType.uint32, 'diag-mask')),
                        ('description', YLeaf(YType.str, 'description')),
                        ('is_mp2mp', YLeaf(YType.boolean, 'is-mp2mp')),
                    ])
                    self.group_name = None
                    self.xconnect_name = None
                    self.group_name_xr = None
                    self.xconnect_name_xr = None
                    self.number_of_backup_p_ws = None
                    self.state = None
                    self.interworking = None
                    self.diag_mask = None
                    self.description = None
                    self.is_mp2mp = None

                    self.backup = L2vpnv2.Standby.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"

                    self.segment1 = L2vpnv2.Standby.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self._children_name_map["segment1"] = "segment1"

                    self.segment2 = L2vpnv2.Standby.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self._children_name_map["segment2"] = "segment2"

                    self.ce2ce = L2vpnv2.Standby.Xconnects.Xconnect.Ce2ce()
                    self.ce2ce.parent = self
                    self._children_name_map["ce2ce"] = "ce2ce"

                    self.backup_segment = YList(self)
                    self._segment_path = lambda: "xconnect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect, ['group_name', 'xconnect_name', 'group_name_xr', 'xconnect_name_xr', 'number_of_backup_p_ws', 'state', 'interworking', 'diag_mask', 'description', 'is_mp2mp'], name, value)


                class Backup(Entity):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "backup"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Segment1(Entity):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1, self).__init__()

                        self.yang_name = "segment1"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "segment1"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Segment2(Entity):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2, self).__init__()

                        self.yang_name = "segment2"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "segment2"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Ce2ce(Entity):
                    """
                    CE2CE
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Xconnects.Xconnect.Ce2ce, self).__init__()

                        self.yang_name = "ce2ce"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                            ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                            ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                        ])
                        self.local_customer_edge_id = None
                        self.remote_customer_edge_id = None
                        self.ce_added = None
                        self._segment_path = lambda: "ce2ce"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.Ce2ce, ['local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


                class BackupSegment(Entity):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment, self).__init__()

                        self.yang_name = "backup-segment"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "backup-segment"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


        class XconnectGroups(Entity):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of  		 :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.XconnectGroups, self).__init__()

                self.yang_name = "xconnect-groups"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-group", ("xconnect_group", L2vpnv2.Standby.XconnectGroups.XconnectGroup))])
                self._leafs = OrderedDict()

                self.xconnect_group = YList(self)
                self._segment_path = lambda: "xconnect-groups"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.XconnectGroups, [], name, value)


            class XconnectGroup(Entity):
                """
                XConnect group information
                
                .. attribute:: group_name  (key)
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.XconnectGroups.XconnectGroup, self).__init__()

                    self.yang_name = "xconnect-group"
                    self.yang_parent_name = "xconnect-groups"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['group_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                    ])
                    self.group_name = None
                    self.group_name_xr = None
                    self.number_xconnects = None
                    self._segment_path = lambda: "xconnect-group" + "[group-name='" + str(self.group_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-groups/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.XconnectGroups.XconnectGroup, ['group_name', 'group_name_xr', 'number_xconnects'], name, value)


        class XconnectMp2mps(Entity):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of  		 :py:class:`XconnectMp2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.XconnectMp2mps, self).__init__()

                self.yang_name = "xconnect-mp2mps"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-mp2mp", ("xconnect_mp2mp", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp))])
                self._leafs = OrderedDict()

                self.xconnect_mp2mp = YList(self)
                self._segment_path = lambda: "xconnect-mp2mps"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps, [], name, value)


            class XconnectMp2mp(Entity):
                """
                XConnect MP2MP information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\: str
                
                	**length:** 1..26
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery>`
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\: str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:  :py:class:`L2vpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagAdEncap>`
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp, self).__init__()

                    self.yang_name = "xconnect-mp2mp"
                    self.yang_parent_name = "xconnect-mp2mps"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery))])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('mp2mp_name', YLeaf(YType.str, 'mp2mp-name')),
                        ('mp2mpid', YLeaf(YType.uint32, 'mp2mpid')),
                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                        ('vpn_mtu', YLeaf(YType.uint32, 'vpn-mtu')),
                        ('l2_encapsulation', YLeaf(YType.enumeration, 'l2-encapsulation')),
                        ('xconnect_shutdown', YLeaf(YType.boolean, 'xconnect-shutdown')),
                    ])
                    self.group_name = None
                    self.mp2_mp_name = None
                    self.group_name_xr = None
                    self.mp2mp_name = None
                    self.mp2mpid = None
                    self.vpn_id = None
                    self.vpn_mtu = None
                    self.l2_encapsulation = None
                    self.xconnect_shutdown = None

                    self.discovery = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery()
                    self.discovery.parent = self
                    self._children_name_map["discovery"] = "discovery"
                    self._segment_path = lambda: "xconnect-mp2mp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp, ['group_name', 'mp2_mp_name', 'group_name_xr', 'mp2mp_name', 'mp2mpid', 'vpn_id', 'vpn_mtu', 'l2_encapsulation', 'xconnect_shutdown'], name, value)


                class Discovery(Entity):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue>`
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\: bool
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\: bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\: str
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt>`
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "xconnect-mp2mp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue)), ("import-rt", ("import_rt", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt))])
                        self._leafs = OrderedDict([
                            ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                            ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                            ('ad_service_connected', YLeaf(YType.boolean, 'ad-service-connected')),
                            ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                            ('ce_range', YLeaf(YType.uint16, 'ce-range')),
                            ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                            ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                            ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                            ('number_ce2ce_advertised', YLeaf(YType.uint32, 'number-ce2ce-advertised')),
                            ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                            ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ('number_ce2c_es', YLeaf(YType.uint32, 'number-ce2c-es')),
                        ])
                        self.ad_method = None
                        self.vpn_added = None
                        self.ad_service_connected = None
                        self.ad_signalling_method = None
                        self.ce_range = None
                        self.export_route_policy = None
                        self.number_a_cs_up = None
                        self.number_p_ws_up = None
                        self.number_ce2ce_advertised = None
                        self.number_a_cs = None
                        self.number_pseudowires = None
                        self.number_ce2c_es = None

                        self.rd_value = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self._children_name_map["rd_value"] = "rd-value"

                        self.import_rt = YList(self)
                        self.export_rt = YList(self)
                        self._segment_path = lambda: "discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery, ['ad_method', 'vpn_added', 'ad_service_connected', 'ad_signalling_method', 'ce_range', 'export_route_policy', 'number_a_cs_up', 'number_p_ws_up', 'number_ce2ce_advertised', 'number_a_cs', 'number_pseudowires', 'number_ce2c_es'], name, value)


                    class RdValue(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, self).__init__()

                            self.yang_name = "rd-value"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd-value"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                    class ImportRt(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr>`
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, self).__init__()

                            self.yang_name = "import-rt"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport))])
                            self._leafs = OrderedDict([
                                ('rt', YLeaf(YType.enumeration, 'rt')),
                            ])
                            self.rt = None

                            self.two_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"

                            self.es_import = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._segment_path = lambda: "import-rt"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, ['rt'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                    ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                ])
                                self.high_bytes = None
                                self.low_bytes = None
                                self._segment_path = lambda: "es-import"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                    class ExportRt(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr>`
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, self).__init__()

                            self.yang_name = "export-rt"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport))])
                            self._leafs = OrderedDict([
                                ('rt', YLeaf(YType.enumeration, 'rt')),
                            ])
                            self.rt = None

                            self.two_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"

                            self.es_import = L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._segment_path = lambda: "export-rt"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, ['rt'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                    ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                ])
                                self.high_bytes = None
                                self.low_bytes = None
                                self._segment_path = lambda: "es-import"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


        class Indexes(Entity):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of  		 :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Indexes, self).__init__()

                self.yang_name = "indexes"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("index", ("index", L2vpnv2.Standby.Indexes.Index))])
                self._leafs = OrderedDict()

                self.index = YList(self)
                self._segment_path = lambda: "indexes"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Indexes, [], name, value)


            class Index(Entity):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  (key)
                
                	Pool ID
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Indexes.Index, self).__init__()

                    self.yang_name = "index"
                    self.yang_parent_name = "indexes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pool_id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pool_id', YLeaf(YType.str, 'pool-id')),
                        ('pool_id_xr', YLeaf(YType.uint32, 'pool-id-xr')),
                        ('application_type', YLeaf(YType.enumeration, 'application-type')),
                        ('allocated_ids', YLeaf(YType.uint32, 'allocated-ids')),
                        ('zombied_ids', YLeaf(YType.uint32, 'zombied-ids')),
                        ('pool_size', YLeaf(YType.uint32, 'pool-size')),
                        ('max_num_id_mgr', YLeaf(YType.uint32, 'max-num-id-mgr')),
                        ('num_id_mgr_in_use', YLeaf(YType.uint32, 'num-id-mgr-in-use')),
                    ])
                    self.pool_id = None
                    self.pool_id_xr = None
                    self.application_type = None
                    self.allocated_ids = None
                    self.zombied_ids = None
                    self.pool_size = None
                    self.max_num_id_mgr = None
                    self.num_id_mgr_in_use = None
                    self._segment_path = lambda: "index" + "[pool-id='" + str(self.pool_id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/indexes/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Indexes.Index, ['pool_id', 'pool_id_xr', 'application_type', 'allocated_ids', 'zombied_ids', 'pool_size', 'max_num_id_mgr', 'num_id_mgr_in_use'], name, value)


        class XconnectSummary(Entity):
            """
            XConnect summary information
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.XconnectSummary, self).__init__()

                self.yang_name = "xconnect-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                    ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                    ('number_xconnects_up', YLeaf(YType.uint32, 'number-xconnects-up')),
                    ('number_xconnects_down', YLeaf(YType.uint32, 'number-xconnects-down')),
                    ('number_xconnects_unresolved', YLeaf(YType.uint32, 'number-xconnects-unresolved')),
                    ('number_xconnects_administratively_down', YLeaf(YType.uint32, 'number-xconnects-administratively-down')),
                    ('number_xconnects_type_attachment_circuit_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-attachment-circuit-to-pseudo-wire')),
                    ('number_xconnects_type_monitor_session_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-monitor-session-to-pseudo-wire')),
                    ('number_xconnects_locally_switched', YLeaf(YType.uint32, 'number-xconnects-locally-switched')),
                    ('number_xconnects_with_backup_pw', YLeaf(YType.uint32, 'number-xconnects-with-backup-pw')),
                    ('number_xconnects_currently_using_backup', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup')),
                    ('down_backup_xconnects', YLeaf(YType.uint32, 'down-backup-xconnects')),
                    ('admin_down_backup_xconnects', YLeaf(YType.uint32, 'admin-down-backup-xconnects')),
                    ('unresolved_backup_xconnects', YLeaf(YType.uint32, 'unresolved-backup-xconnects')),
                    ('standby_backup_xconnects', YLeaf(YType.uint32, 'standby-backup-xconnects')),
                    ('standby_ready_backup_xconnects', YLeaf(YType.uint32, 'standby-ready-backup-xconnects')),
                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                    ('number_xconnects_type_pseudo_wire_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-pseudo-wire-to-pseudo-wire')),
                    ('number_mp2mp_xconnects', YLeaf(YType.uint32, 'number-mp2mp-xconnects')),
                    ('number_mp2mp_xconnects_up', YLeaf(YType.uint32, 'number-mp2mp-xconnects-up')),
                    ('number_mp2mp_xconnects_down', YLeaf(YType.uint32, 'number-mp2mp-xconnects-down')),
                    ('number_mp2mp_xconnects_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnects-advertised')),
                    ('number_mp2mp_xconnectss_not_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnectss-not-advertised')),
                    ('number_ce2_ceconnections', YLeaf(YType.uint32, 'number-ce2-ceconnections')),
                    ('number_ce2ce_advertized', YLeaf(YType.uint32, 'number-ce2ce-advertized')),
                    ('number_ce2ce_not_advertized', YLeaf(YType.uint32, 'number-ce2ce-not-advertized')),
                    ('partially_programmed_xconnects', YLeaf(YType.uint32, 'partially-programmed-xconnects')),
                    ('number_xconnects_with_backup_interface', YLeaf(YType.uint32, 'number-xconnects-with-backup-interface')),
                    ('number_xconnects_currently_using_backup_interface', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup-interface')),
                    ('down_backup_interface_xconnects', YLeaf(YType.uint32, 'down-backup-interface-xconnects')),
                    ('admin_down_backup_interface_xconnects', YLeaf(YType.uint32, 'admin-down-backup-interface-xconnects')),
                    ('unresolved_backup_interface_xconnects', YLeaf(YType.uint32, 'unresolved-backup-interface-xconnects')),
                    ('standby_backup_interface_xconnects', YLeaf(YType.uint32, 'standby-backup-interface-xconnects')),
                ])
                self.number_groups = None
                self.number_xconnects = None
                self.number_xconnects_up = None
                self.number_xconnects_down = None
                self.number_xconnects_unresolved = None
                self.number_xconnects_administratively_down = None
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                self.number_xconnects_locally_switched = None
                self.number_xconnects_with_backup_pw = None
                self.number_xconnects_currently_using_backup = None
                self.down_backup_xconnects = None
                self.admin_down_backup_xconnects = None
                self.unresolved_backup_xconnects = None
                self.standby_backup_xconnects = None
                self.standby_ready_backup_xconnects = None
                self.out_of_memory_state = None
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                self.number_mp2mp_xconnects = None
                self.number_mp2mp_xconnects_up = None
                self.number_mp2mp_xconnects_down = None
                self.number_mp2mp_xconnects_advertised = None
                self.number_mp2mp_xconnectss_not_advertised = None
                self.number_ce2_ceconnections = None
                self.number_ce2ce_advertized = None
                self.number_ce2ce_not_advertized = None
                self.partially_programmed_xconnects = None
                self.number_xconnects_with_backup_interface = None
                self.number_xconnects_currently_using_backup_interface = None
                self.down_backup_interface_xconnects = None
                self.admin_down_backup_interface_xconnects = None
                self.unresolved_backup_interface_xconnects = None
                self.standby_backup_interface_xconnects = None
                self._segment_path = lambda: "xconnect-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.XconnectSummary, ['number_groups', 'number_xconnects', 'number_xconnects_up', 'number_xconnects_down', 'number_xconnects_unresolved', 'number_xconnects_administratively_down', 'number_xconnects_type_attachment_circuit_to_pseudo_wire', 'number_xconnects_type_monitor_session_to_pseudo_wire', 'number_xconnects_locally_switched', 'number_xconnects_with_backup_pw', 'number_xconnects_currently_using_backup', 'down_backup_xconnects', 'admin_down_backup_xconnects', 'unresolved_backup_xconnects', 'standby_backup_xconnects', 'standby_ready_backup_xconnects', 'out_of_memory_state', 'number_xconnects_type_pseudo_wire_to_pseudo_wire', 'number_mp2mp_xconnects', 'number_mp2mp_xconnects_up', 'number_mp2mp_xconnects_down', 'number_mp2mp_xconnects_advertised', 'number_mp2mp_xconnectss_not_advertised', 'number_ce2_ceconnections', 'number_ce2ce_advertized', 'number_ce2ce_not_advertized', 'partially_programmed_xconnects', 'number_xconnects_with_backup_interface', 'number_xconnects_currently_using_backup_interface', 'down_backup_interface_xconnects', 'admin_down_backup_interface_xconnects', 'unresolved_backup_interface_xconnects', 'standby_backup_interface_xconnects'], name, value)


        class ProcFsm(Entity):
            """
            L2VPN Process FSM information
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.FailoverStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.NsrStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.IssuStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\: bool
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.StateTransitionTime>`
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.XidInfo>`
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.ReportCard>`
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.EventHistory>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.ProcFsm, self).__init__()

                self.yang_name = "proc-fsm"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Standby.ProcFsm.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Standby.ProcFsm.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Standby.ProcFsm.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Standby.ProcFsm.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Standby.ProcFsm.XidInfo)), ("report-card", ("report_card", L2vpnv2.Standby.ProcFsm.ReportCard)), ("event-history", ("event_history", L2vpnv2.Standby.ProcFsm.EventHistory))])
                self._leafs = OrderedDict([
                    ('process_role', YLeaf(YType.uint8, 'process-role')),
                    ('process_state', YLeaf(YType.uint8, 'process-state')),
                    ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                    ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                ])
                self.process_role = None
                self.process_state = None
                self.sync_flags = None
                self.sw_install_in_progress = None

                self.failover_status = L2vpnv2.Standby.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"

                self.nsr_status = L2vpnv2.Standby.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"

                self.issu_status = L2vpnv2.Standby.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"

                self.state_transition_time = YList(self)
                self.xid_info = YList(self)
                self.report_card = YList(self)
                self.event_history = YList(self)
                self._segment_path = lambda: "proc-fsm"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.ProcFsm, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: master_time
                
                	Master time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                        ('start_time', YLeaf(YType.uint32, 'start-time')),
                        ('master_time', YLeaf(YType.uint32, 'master-time')),
                    ])
                    self.triggered_time = None
                    self.start_time = None
                    self.master_time = None
                    self._segment_path = lambda: "failover-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "nsr-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.NsrStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.ProcFsm.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.ProcFsm.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "issu-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.IssuStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.ProcFsm.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.ProcFsm.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class StateTransitionTime(Entity):
                """
                Transition time for all states
                
                .. attribute:: entry
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.StateTransitionTime, self).__init__()

                    self.yang_name = "state-transition-time"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('entry', YLeaf(YType.uint32, 'entry')),
                    ])
                    self.entry = None
                    self._segment_path = lambda: "state-transition-time"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.StateTransitionTime, ['entry'], name, value)


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('app_type', YLeaf(YType.enumeration, 'app-type')),
                        ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                    ])
                    self.app_type = None
                    self.sent_ids = None
                    self._segment_path = lambda: "xid-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.XidInfo, ['app_type', 'sent_ids'], name, value)


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\: bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\: bool
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                        ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                        ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                        ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                        ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                    ])
                    self.collaborator_is_connected = None
                    self.connection_change_time = None
                    self.collaborator_idt_done = None
                    self.idt_time = None
                    self.collaborator_skipped = None
                    self._segment_path = lambda: "report-card"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: new_state
                
                	New state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_event
                
                	Process event
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.ProcFsm.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                        ('new_state', YLeaf(YType.uint8, 'new-state')),
                        ('process_event', YLeaf(YType.uint16, 'process-event')),
                        ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                        ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                    ])
                    self.previous_state = None
                    self.new_state = None
                    self.process_event = None
                    self.process_collaborator = None
                    self.event_timestamp = None
                    self._segment_path = lambda: "event-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.ProcFsm.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


        class MstpPorts(Entity):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of  		 :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.MstpPorts, self).__init__()

                self.yang_name = "mstp-ports"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mstp-port", ("mstp_port", L2vpnv2.Standby.MstpPorts.MstpPort))])
                self._leafs = OrderedDict()

                self.mstp_port = YList(self)
                self._segment_path = lambda: "mstp-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.MstpPorts, [], name, value)


            class MstpPort(Entity):
                """
                MSTP Port information
                
                .. attribute:: interface  (key)
                
                	Interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\: str
                
                .. attribute:: protected
                
                	Protected
                	**type**\: bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of  		 :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.MstpPorts.MstpPort, self).__init__()

                    self.yang_name = "mstp-port"
                    self.yang_parent_name = "mstp-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface']
                    self._child_classes = OrderedDict([("msti-entry", ("msti_entry", L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry))])
                    self._leafs = OrderedDict([
                        ('interface', YLeaf(YType.str, 'interface')),
                        ('mstp_interface_handle', YLeaf(YType.str, 'mstp-interface-handle')),
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ('protected', YLeaf(YType.boolean, 'protected')),
                        ('reference_count', YLeaf(YType.uint32, 'reference-count')),
                    ])
                    self.interface = None
                    self.mstp_interface_handle = None
                    self.interface_name = None
                    self.protected = None
                    self.reference_count = None

                    self.msti_entry = YList(self)
                    self._segment_path = lambda: "mstp-port" + "[interface='" + str(self.interface) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mstp-ports/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.MstpPorts.MstpPort, ['interface', 'mstp_interface_handle', 'interface_name', 'protected', 'reference_count'], name, value)


                class MstiEntry(Entity):
                    """
                    MSTI
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:  :py:class:`L2vpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMstiState>`
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of  		 :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry, self).__init__()

                        self.yang_name = "msti-entry"
                        self.yang_parent_name = "mstp-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bd-entry", ("bd_entry", L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry))])
                        self._leafs = OrderedDict([
                            ('cfg_ms_ti', YLeaf(YType.uint32, 'cfg-ms-ti')),
                            ('rcv_count', YLeaf(YType.uint32, 'rcv-count')),
                            ('ack_count', YLeaf(YType.uint32, 'ack-count')),
                            ('nack_count', YLeaf(YType.uint32, 'nack-count')),
                            ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                            ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                            ('bd_count', YLeaf(YType.uint32, 'bd-count')),
                            ('msti_flags', YLeaf(YType.uint32, 'msti-flags')),
                            ('msti_state', YLeaf(YType.enumeration, 'msti-state')),
                        ])
                        self.cfg_ms_ti = None
                        self.rcv_count = None
                        self.ack_count = None
                        self.nack_count = None
                        self.flush_count = None
                        self.interface_count = None
                        self.bd_count = None
                        self.msti_flags = None
                        self.msti_state = None

                        self.bd_entry = YList(self)
                        self._segment_path = lambda: "msti-entry"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry, ['cfg_ms_ti', 'rcv_count', 'ack_count', 'nack_count', 'flush_count', 'interface_count', 'bd_count', 'msti_flags', 'msti_state'], name, value)


                    class BdEntry(Entity):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                            self.yang_name = "bd-entry"
                            self.yang_parent_name = "msti-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bdid', YLeaf(YType.uint32, 'bdid')),
                                ('bdif_count', YLeaf(YType.uint32, 'bdif-count')),
                            ])
                            self.bdid = None
                            self.bdif_count = None
                            self._segment_path = lambda: "bd-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.MstpPorts.MstpPort.MstiEntry.BdEntry, ['bdid', 'bdif_count'], name, value)


        class GenericInterfaceListDetails(Entity):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of  		 :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.GenericInterfaceListDetails, self).__init__()

                self.yang_name = "generic-interface-list-details"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list-detail", ("generic_interface_list_detail", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail))])
                self._leafs = OrderedDict()

                self.generic_interface_list_detail = YList(self)
                self._segment_path = lambda: "generic-interface-list-details"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails, [], name, value)


            class GenericInterfaceListDetail(Entity):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                .. attribute:: items
                
                	Number of items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\: bool
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of  		 :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of  		 :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                    self.yang_name = "generic-interface-list-detail"
                    self.yang_parent_name = "generic-interface-list-details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_list_name']
                    self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary)), ("interface", ("interface", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface)), ("pseudowire-ether-range", ("pseudowire_ether_range", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange)), ("pseudowire-iw-range", ("pseudowire_iw_range", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange))])
                    self._leafs = OrderedDict([
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('items', YLeaf(YType.uint32, 'items')),
                        ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                        ('psedowire_ether_items', YLeaf(YType.uint32, 'psedowire-ether-items')),
                        ('pseudowire_iw_items', YLeaf(YType.uint32, 'pseudowire-iw-items')),
                    ])
                    self.interface_list_name = None
                    self.items = None
                    self.is_provisioned = None
                    self.psedowire_ether_items = None
                    self.pseudowire_iw_items = None

                    self.summary = L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.interface = YList(self)
                    self.pseudowire_ether_range = YList(self)
                    self.pseudowire_iw_range = YList(self)
                    self._segment_path = lambda: "generic-interface-list-detail" + "[interface-list-name='" + str(self.interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/generic-interface-list-details/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail, ['interface_list_name', 'items', 'is_provisioned', 'psedowire_ether_items', 'pseudowire_iw_items'], name, value)


                class Summary(Entity):
                    """
                    Summary information
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface))])
                        self._leafs = OrderedDict([
                            ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                            ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                            ('items', YLeaf(YType.uint32, 'items')),
                        ])
                        self.interface_list_name_xr = None
                        self.interface_list_id = None
                        self.number_of_interfaces = None
                        self.items = None

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, ['interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                            ])
                            self.interface_name = None
                            self.pending_replications = None
                            self.not_supported_replications = None
                            self.is_fib_downloaded = None
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                class PseudowireEtherRange(Entity):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                        self.yang_name = "pseudowire-ether-range"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lower', YLeaf(YType.uint16, 'lower')),
                            ('upper', YLeaf(YType.uint16, 'upper')),
                        ])
                        self.lower = None
                        self.upper = None
                        self._segment_path = lambda: "pseudowire-ether-range"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, ['lower', 'upper'], name, value)


                class PseudowireIwRange(Entity):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                        self.yang_name = "pseudowire-iw-range"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lower', YLeaf(YType.uint16, 'lower')),
                            ('upper', YLeaf(YType.uint16, 'upper')),
                        ])
                        self.lower = None
                        self.upper = None
                        self._segment_path = lambda: "pseudowire-iw-range"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, ['lower', 'upper'], name, value)


        class L2vpnResourceState(Entity):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.L2vpnResourceState, self).__init__()

                self.yang_name = "l2vpn-resource-state"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('resource_out_of_memory_state', YLeaf(YType.uint32, 'resource-out-of-memory-state')),
                ])
                self.resource_out_of_memory_state = None
                self._segment_path = lambda: "l2vpn-resource-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.L2vpnResourceState, ['resource_out_of_memory_state'], name, value)


        class BridgeDomains(Entity):
            """
            Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	Bridge Domain Information
            	**type**\: list of  		 :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.BridgeDomains, self).__init__()

                self.yang_name = "bridge-domains"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bridge-domain", ("bridge_domain", L2vpnv2.Standby.BridgeDomains.BridgeDomain))])
                self._leafs = OrderedDict()

                self.bridge_domain = YList(self)
                self._segment_path = lambda: "bridge-domains"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.BridgeDomains, [], name, value)


            class BridgeDomain(Entity):
                """
                Bridge Domain Information
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:  :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:  :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_acs
                
                	Bridge Domain Attachment Circuit Table
                	**type**\:  :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_access_pws
                
                	Bridge Domain Access Pseudowire Table
                	**type**\:  :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_domain_info
                
                	Bridge Domain Information
                	**type**\:  :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\: str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain, self).__init__()

                    self.yang_name = "bridge-domain"
                    self.yang_parent_name = "bridge-domains"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bridge-access-vfi-table", ("bridge_access_vfi_table", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable)), ("bridge-core-vfi-table", ("bridge_core_vfi_table", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable)), ("bridge-acs", ("bridge_acs", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs)), ("bridge-access-pws", ("bridge_access_pws", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws)), ("bridge-domain-info", ("bridge_domain_info", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo))])
                    self._leafs = OrderedDict([
                        ('bridge_domain_group_name', YLeaf(YType.str, 'bridge-domain-group-name')),
                        ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                    ])
                    self.bridge_domain_group_name = None
                    self.bridge_domain_name = None

                    self.bridge_access_vfi_table = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"

                    self.bridge_core_vfi_table = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"

                    self.bridge_acs = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self._children_name_map["bridge_acs"] = "bridge-acs"

                    self.bridge_access_pws = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self._children_name_map["bridge_access_pws"] = "bridge-access-pws"

                    self.bridge_domain_info = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                    self._segment_path = lambda: "bridge-domain"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain, ['bridge_domain_group_name', 'bridge_domain_name'], name, value)


                class BridgeAccessVfiTable(Entity):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                        self.yang_name = "bridge-access-vfi-table"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws))])
                        self._leafs = OrderedDict()

                        self.bridge_pws = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._segment_path = lambda: "bridge-access-vfi-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, [], name, value)


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	Bridge Domain Pseudowire
                        	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-access-vfi-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw))])
                            self._leafs = OrderedDict()

                            self.bridge_pw = YList(self)
                            self._segment_path = lambda: "bridge-pws"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, [], name, value)


                        class BridgePw(Entity):
                            """
                            Bridge Domain Pseudowire
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\: bool
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                    ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                    ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                    ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                    ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                    ('is_access', YLeaf(YType.boolean, 'is-access')),
                                ])
                                self.neighbor = None
                                self.pw_type = None
                                self.pseudowire_id = None
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None
                                self.is_access = None

                                self.pseudowire = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"

                                self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "bridge-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\: bool
                                
                                .. attribute:: is_evpn_vpws_type
                                
                                	is EVPN VPWS
                                	**type**\: bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\: bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\: bool
                                
                                .. attribute:: data_path_down
                                
                                	True if LSP down
                                	**type**\: bool
                                
                                .. attribute:: use_tunnel_path
                                
                                	True if using TE tunnel
                                	**type**\: bool
                                
                                .. attribute:: odn_configured
                                
                                	True if ODN is configured
                                	**type**\: bool
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\: bool
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\: bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\: bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\: bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\: bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\: bool
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\: bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\: bool
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\: bool
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\: bool
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\: bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\: bool
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\: bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\: bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\: bool
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\: bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\: bool
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\: bool
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\: bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\: bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\: bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\: bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\: bool
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                    self._leafs = OrderedDict([
                                        ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                        ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                        ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                        ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                        ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                        ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                        ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                        ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                        ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                        ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                        ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                        ('time_created', YLeaf(YType.str, 'time-created')),
                                        ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                        ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                        ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                        ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                        ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                        ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                        ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                        ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                        ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                        ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                        ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                        ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                        ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                        ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                        ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                        ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                        ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                        ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                        ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                        ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                        ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                        ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                        ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                        ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                        ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                        ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                        ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                        ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                        ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                        ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                        ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                        ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                        ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                        ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                        ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                        ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                        ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                        ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                        ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                        ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                        ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                        ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                        ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                        ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                    ])
                                    self.local_source_address = None
                                    self.ipv6_local_source_address = None
                                    self.pseudo_wire_id = None
                                    self.is_pwr_type = None
                                    self.is_evpn_vpws_type = None
                                    self.xconnect_id = None
                                    self.state = None
                                    self.pseudo_wire_state = None
                                    self.protocol = None
                                    self.pw_class_name = None
                                    self.tag_rewrite = None
                                    self.interworking = None
                                    self.fe_ctype = None
                                    self.evpn_src_acid = None
                                    self.sequencing_type = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.local_control_word = None
                                    self.remote_control_word = None
                                    self.local_pseudo_wire_type = None
                                    self.remote_pseudo_wire_type = None
                                    self.imposed_vlan_id = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.last_time_status_changed = None
                                    self.time_elapsed_status_changed = None
                                    self.last_time_status_down = None
                                    self.time_elapsed_status_down = None
                                    self.shutdown = None
                                    self.data_path_down = None
                                    self.use_tunnel_path = None
                                    self.odn_configured = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.payload_bytes_mismatched = None
                                    self.bitrate_mismatched = None
                                    self.rtp_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.sig_pkts_mismatched = None
                                    self.cas_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.freq_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.mtu_mismatched = None
                                    self.illegal_control_word = None
                                    self.ad_remote_down = None
                                    self.not_supported_qinq = None
                                    self.local_label_failed = None
                                    self.remote_label_failed = None
                                    self.preferred_path_disable_fallback = None
                                    self.backup_pw = None
                                    self.primary_pw = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.disable_never = None
                                    self.disable_delay = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.out_of_memory_state = None
                                    self.transport_lsp_down = None
                                    self.mac_limit_oper_down = None
                                    self.pw_status_use = None
                                    self.auto_discovery = None
                                    self.ad_method = None
                                    self.pwlsd_rewrite_failed = None
                                    self.ldp_label_advertise_failed = None
                                    self.is_vfi = None
                                    self.is_multi_segment_pseudowire = None
                                    self.pw_redundancy_one_way = None
                                    self.load_balance = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.is_flow_label_static = None
                                    self.is_partially_programmed = None
                                    self.pw_redundancy_initial_delay = None
                                    self.bridge_pw_type_mismatch = None
                                    self.required_bw = None
                                    self.admited_bw = None
                                    self.forward_class = None
                                    self.table_policy_name = None

                                    self.peer_id = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"

                                    self.encapsulation_info = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                    self.local_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"

                                    self.remote_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"

                                    self.preferred_path = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"

                                    self.local_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"

                                    self.remote_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"

                                    self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.p2mp_pw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._segment_path = lambda: "pseudowire"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                            ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                            ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.type = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.internal_label = None
                                        self._segment_path = lambda: "peer-id"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                        self._leafs = OrderedDict([
                                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                        ])
                                        self.encapsulation = None

                                        self.atom = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"

                                        self.l2tpv3 = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._segment_path = lambda: "encapsulation-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                            self._leafs = OrderedDict([
                                                ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                ('saii', YLeaf(YType.str, 'saii')),
                                                ('taii', YLeaf(YType.str, 'taii')),
                                                ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                            ])
                                            self.is_pseudowire_headend = None
                                            self.local_label = None
                                            self.remote_label = None
                                            self.local_group_id = None
                                            self.remote_group_id = None
                                            self.local_cv_type = None
                                            self.local_c_ctype = None
                                            self.remote_cv_type = None
                                            self.remote_c_ctype = None
                                            self.local_veid = None
                                            self.remote_veid = None
                                            self.local_ceid = None
                                            self.remote_ceid = None
                                            self.source_address = None
                                            self.remote_source_address = None
                                            self.local_ldp_id = None
                                            self.remote_ldp_id = None
                                            self.saii = None
                                            self.taii = None
                                            self.is_sai_itype2 = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.is_tai_itype2 = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.rem_saii = None
                                            self.rem_taii = None
                                            self.lsd_rewrite_failed = None
                                            self.ldp_label_advertisment_failed = None

                                            self.local_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"

                                            self.remote_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"

                                            self.multi_segment_pseudowire_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._segment_path = lambda: "atom"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "local-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "remote-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                    ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                ])
                                                self.received_packets = None
                                                self.received_bytes = None
                                                self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                    class L2tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\: str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\: bool
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\: bool
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                            ])
                                            self.l2tp_class_name = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.dont_fragment_bit = None
                                            self.tos_mode = None
                                            self.tos = None
                                            self.ttl = None
                                            self.local_session_id = None
                                            self.remote_session_id = None
                                            self.local_cookie_size = None
                                            self.remote_cookie_size = None
                                            self.local_cookie_low_value = None
                                            self.remote_cookie_low_value = None
                                            self.local_cookie_high_value = None
                                            self.remote_cookie_high_value = None
                                            self.remote_circuit_status_up = None
                                            self.tunnel_state = None
                                            self.local_secondary_cookie_size = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_high_value = None
                                            self._segment_path = lambda: "l2tpv3"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "local-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "remote-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: srte_policy
                                    
                                    	srte policy
                                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                        self._leafs = OrderedDict([
                                            ('option', YLeaf(YType.enumeration, 'option')),
                                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                        ])
                                        self.option = None
                                        self.next_hop_ip = None
                                        self.te_tunnel_interface_number = None
                                        self.ip_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                        self.srte_policy = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                        self.srte_policy.parent = self
                                        self._children_name_map["srte_policy"] = "srte-policy"
                                        self._segment_path = lambda: "preferred-path"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                    class SrtePolicy(Entity):
                                        """
                                        srte policy
                                        
                                        .. attribute:: policy_name
                                        
                                        	SR TE Policy Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                            self.yang_name = "srte-policy"
                                            self.yang_parent_name = "preferred-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                                            ])
                                            self.policy_name = None
                                            self._segment_path = lambda: "srte-policy"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "local-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "remote-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class P2mpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_available', YLeaf(YType.boolean, 'local-available')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                            ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                            ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                            ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                            ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                            ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                            ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                            ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                            ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                            ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                        ])
                                        self.local_available = None
                                        self.local_label = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.local_extended_tunnel_id = None
                                        self.local_p2mp_id = None
                                        self.local_flags = None
                                        self.remote_available = None
                                        self.remote_label = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_p2mp_id = None
                                        self.remote_flags = None
                                        self._segment_path = lambda: "p2mp-pw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeCoreVfiTable(Entity):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                        self.yang_name = "bridge-core-vfi-table"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws))])
                        self._leafs = OrderedDict()

                        self.bridge_pws = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._segment_path = lambda: "bridge-core-vfi-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, [], name, value)


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	Bridge Domain Pseudowire
                        	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-core-vfi-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw))])
                            self._leafs = OrderedDict()

                            self.bridge_pw = YList(self)
                            self._segment_path = lambda: "bridge-pws"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, [], name, value)


                        class BridgePw(Entity):
                            """
                            Bridge Domain Pseudowire
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\: bool
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                    ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                    ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                    ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                    ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                    ('is_access', YLeaf(YType.boolean, 'is-access')),
                                ])
                                self.neighbor = None
                                self.pw_type = None
                                self.pseudowire_id = None
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None
                                self.is_access = None

                                self.pseudowire = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"

                                self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "bridge-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\: bool
                                
                                .. attribute:: is_evpn_vpws_type
                                
                                	is EVPN VPWS
                                	**type**\: bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\: bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\: bool
                                
                                .. attribute:: data_path_down
                                
                                	True if LSP down
                                	**type**\: bool
                                
                                .. attribute:: use_tunnel_path
                                
                                	True if using TE tunnel
                                	**type**\: bool
                                
                                .. attribute:: odn_configured
                                
                                	True if ODN is configured
                                	**type**\: bool
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\: bool
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\: bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\: bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\: bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\: bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\: bool
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\: bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\: bool
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\: bool
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\: bool
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\: bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\: bool
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\: bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\: bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\: bool
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\: bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\: bool
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\: bool
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\: bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\: bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\: bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\: bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\: bool
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                    self._leafs = OrderedDict([
                                        ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                        ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                        ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                        ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                        ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                        ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                        ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                        ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                        ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                        ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                        ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                        ('time_created', YLeaf(YType.str, 'time-created')),
                                        ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                        ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                        ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                        ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                        ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                        ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                        ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                        ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                        ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                        ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                        ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                        ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                        ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                        ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                        ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                        ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                        ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                        ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                        ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                        ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                        ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                        ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                        ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                        ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                        ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                        ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                        ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                        ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                        ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                        ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                        ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                        ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                        ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                        ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                        ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                        ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                        ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                        ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                        ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                        ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                        ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                        ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                        ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                        ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                    ])
                                    self.local_source_address = None
                                    self.ipv6_local_source_address = None
                                    self.pseudo_wire_id = None
                                    self.is_pwr_type = None
                                    self.is_evpn_vpws_type = None
                                    self.xconnect_id = None
                                    self.state = None
                                    self.pseudo_wire_state = None
                                    self.protocol = None
                                    self.pw_class_name = None
                                    self.tag_rewrite = None
                                    self.interworking = None
                                    self.fe_ctype = None
                                    self.evpn_src_acid = None
                                    self.sequencing_type = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.local_control_word = None
                                    self.remote_control_word = None
                                    self.local_pseudo_wire_type = None
                                    self.remote_pseudo_wire_type = None
                                    self.imposed_vlan_id = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.last_time_status_changed = None
                                    self.time_elapsed_status_changed = None
                                    self.last_time_status_down = None
                                    self.time_elapsed_status_down = None
                                    self.shutdown = None
                                    self.data_path_down = None
                                    self.use_tunnel_path = None
                                    self.odn_configured = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.payload_bytes_mismatched = None
                                    self.bitrate_mismatched = None
                                    self.rtp_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.sig_pkts_mismatched = None
                                    self.cas_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.freq_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.mtu_mismatched = None
                                    self.illegal_control_word = None
                                    self.ad_remote_down = None
                                    self.not_supported_qinq = None
                                    self.local_label_failed = None
                                    self.remote_label_failed = None
                                    self.preferred_path_disable_fallback = None
                                    self.backup_pw = None
                                    self.primary_pw = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.disable_never = None
                                    self.disable_delay = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.out_of_memory_state = None
                                    self.transport_lsp_down = None
                                    self.mac_limit_oper_down = None
                                    self.pw_status_use = None
                                    self.auto_discovery = None
                                    self.ad_method = None
                                    self.pwlsd_rewrite_failed = None
                                    self.ldp_label_advertise_failed = None
                                    self.is_vfi = None
                                    self.is_multi_segment_pseudowire = None
                                    self.pw_redundancy_one_way = None
                                    self.load_balance = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.is_flow_label_static = None
                                    self.is_partially_programmed = None
                                    self.pw_redundancy_initial_delay = None
                                    self.bridge_pw_type_mismatch = None
                                    self.required_bw = None
                                    self.admited_bw = None
                                    self.forward_class = None
                                    self.table_policy_name = None

                                    self.peer_id = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"

                                    self.encapsulation_info = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                    self.local_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"

                                    self.remote_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"

                                    self.preferred_path = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"

                                    self.local_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"

                                    self.remote_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"

                                    self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.p2mp_pw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._segment_path = lambda: "pseudowire"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                            ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                            ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.type = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.internal_label = None
                                        self._segment_path = lambda: "peer-id"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                        self._leafs = OrderedDict([
                                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                        ])
                                        self.encapsulation = None

                                        self.atom = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"

                                        self.l2tpv3 = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._segment_path = lambda: "encapsulation-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                            self._leafs = OrderedDict([
                                                ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                ('saii', YLeaf(YType.str, 'saii')),
                                                ('taii', YLeaf(YType.str, 'taii')),
                                                ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                            ])
                                            self.is_pseudowire_headend = None
                                            self.local_label = None
                                            self.remote_label = None
                                            self.local_group_id = None
                                            self.remote_group_id = None
                                            self.local_cv_type = None
                                            self.local_c_ctype = None
                                            self.remote_cv_type = None
                                            self.remote_c_ctype = None
                                            self.local_veid = None
                                            self.remote_veid = None
                                            self.local_ceid = None
                                            self.remote_ceid = None
                                            self.source_address = None
                                            self.remote_source_address = None
                                            self.local_ldp_id = None
                                            self.remote_ldp_id = None
                                            self.saii = None
                                            self.taii = None
                                            self.is_sai_itype2 = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.is_tai_itype2 = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.rem_saii = None
                                            self.rem_taii = None
                                            self.lsd_rewrite_failed = None
                                            self.ldp_label_advertisment_failed = None

                                            self.local_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"

                                            self.remote_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"

                                            self.multi_segment_pseudowire_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._segment_path = lambda: "atom"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "local-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "remote-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                    ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                ])
                                                self.received_packets = None
                                                self.received_bytes = None
                                                self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                    class L2tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\: str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\: bool
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\: bool
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                            ])
                                            self.l2tp_class_name = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.dont_fragment_bit = None
                                            self.tos_mode = None
                                            self.tos = None
                                            self.ttl = None
                                            self.local_session_id = None
                                            self.remote_session_id = None
                                            self.local_cookie_size = None
                                            self.remote_cookie_size = None
                                            self.local_cookie_low_value = None
                                            self.remote_cookie_low_value = None
                                            self.local_cookie_high_value = None
                                            self.remote_cookie_high_value = None
                                            self.remote_circuit_status_up = None
                                            self.tunnel_state = None
                                            self.local_secondary_cookie_size = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_high_value = None
                                            self._segment_path = lambda: "l2tpv3"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "local-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "remote-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: srte_policy
                                    
                                    	srte policy
                                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                        self._leafs = OrderedDict([
                                            ('option', YLeaf(YType.enumeration, 'option')),
                                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                        ])
                                        self.option = None
                                        self.next_hop_ip = None
                                        self.te_tunnel_interface_number = None
                                        self.ip_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                        self.srte_policy = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                        self.srte_policy.parent = self
                                        self._children_name_map["srte_policy"] = "srte-policy"
                                        self._segment_path = lambda: "preferred-path"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                    class SrtePolicy(Entity):
                                        """
                                        srte policy
                                        
                                        .. attribute:: policy_name
                                        
                                        	SR TE Policy Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                            self.yang_name = "srte-policy"
                                            self.yang_parent_name = "preferred-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                                            ])
                                            self.policy_name = None
                                            self._segment_path = lambda: "srte-policy"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "local-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "remote-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class P2mpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_available', YLeaf(YType.boolean, 'local-available')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                            ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                            ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                            ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                            ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                            ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                            ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                            ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                            ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                            ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                        ])
                                        self.local_available = None
                                        self.local_label = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.local_extended_tunnel_id = None
                                        self.local_p2mp_id = None
                                        self.local_flags = None
                                        self.remote_available = None
                                        self.remote_label = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_p2mp_id = None
                                        self.remote_flags = None
                                        self._segment_path = lambda: "p2mp-pw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeAcs(Entity):
                    """
                    Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	Bridge Domain Attachment Circuit
                    	**type**\: list of  		 :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                        self.yang_name = "bridge-acs"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-ac", ("bridge_ac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc))])
                        self._leafs = OrderedDict()

                        self.bridge_ac = YList(self)
                        self._segment_path = lambda: "bridge-acs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs, [], name, value)


                    class BridgeAc(Entity):
                        """
                        Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of  		 :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                            self.yang_name = "bridge-ac"
                            self.yang_parent_name = "bridge-acs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit)), ("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac)), ("bvimac", ("bvimac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac))])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('bvi_mac_index', YLeaf(YType.uint16, 'bvi-mac-index')),
                            ])
                            self.interface_name = None
                            self.bvi_mac_index = None

                            self.attachment_circuit = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.static_mac = YList(self)
                            self.bvimac = YList(self)
                            self._segment_path = lambda: "bridge-ac" + "[interface-name='" + str(self.interface_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-acs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, ['interface_name', 'bvi_mac_index'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class Bvimac(Entity):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                self.yang_name = "bvimac"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "bvimac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeAccessPws(Entity):
                    """
                    Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	Bridge Domain Access Pseudowire
                    	**type**\: list of  		 :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                        self.yang_name = "bridge-access-pws"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-access-pw", ("bridge_access_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw))])
                        self._leafs = OrderedDict()

                        self.bridge_access_pw = YList(self)
                        self._segment_path = lambda: "bridge-access-pws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws, [], name, value)


                    class BridgeAccessPw(Entity):
                        """
                        Bridge Domain Access Pseudowire
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\: bool
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                            self.yang_name = "bridge-access-pw"
                            self.yang_parent_name = "bridge-access-pws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac))])
                            self._leafs = OrderedDict([
                                ('neighbor', YLeaf(YType.str, 'neighbor')),
                                ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                ('is_access', YLeaf(YType.boolean, 'is-access')),
                            ])
                            self.neighbor = None
                            self.pw_type = None
                            self.pseudowire_id = None
                            self.ve_id_vpls_id_0_3 = None
                            self.vpls_id_4_7 = None
                            self.is_access = None

                            self.pseudowire = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"

                            self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.static_mac = YList(self)
                            self._segment_path = lambda: "bridge-access-pw"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudowire"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/base/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeDomainInfo(Entity):
                    """
                    Bridge Domain Information
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:  :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:  :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:  :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\: str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\: str
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:  :py:class:`L2vpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeCoupledState>`
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\: bool
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\: bool
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:  :py:class:`L2vpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacWithdrawOption>`
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\: bool
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\: str
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\: bool
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\: bool
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of  		 :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of  		 :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of  		 :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                        self.yang_name = "bridge-domain-info"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters)), ("pbb-parameters", ("pbb_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters)), ("evpn-parameters", ("evpn_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters)), ("vni-parameters", ("vni_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters)), ("rd", ("rd", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd)), ("mac-filter", ("mac_filter", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter)), ("bridge-vfi", ("bridge_vfi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi)), ("bridge-access-vfi", ("bridge_access_vfi", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi))])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('bridge_name', YLeaf(YType.str, 'bridge-name')),
                            ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                            ('bridge_description', YLeaf(YType.str, 'bridge-description')),
                            ('bridge_state', YLeaf(YType.enumeration, 'bridge-state')),
                            ('bridge_coupled_state', YLeaf(YType.enumeration, 'bridge-coupled-state')),
                            ('bridge_shg_id', YLeaf(YType.uint32, 'bridge-shg-id')),
                            ('bridge_msti', YLeaf(YType.uint32, 'bridge-msti')),
                            ('acpwup', YLeaf(YType.uint32, 'acpwup')),
                            ('bridge_internal_msti', YLeaf(YType.uint32, 'bridge-internal-msti')),
                            ('configured', YLeaf(YType.boolean, 'configured')),
                            ('number_vf_is', YLeaf(YType.uint32, 'number-vf-is')),
                            ('number_access_vf_is', YLeaf(YType.uint32, 'number-access-vf-is')),
                            ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                            ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                            ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                            ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                            ('number_pb_bs', YLeaf(YType.uint8, 'number-pb-bs')),
                            ('number_pb_bs_up', YLeaf(YType.uint8, 'number-pb-bs-up')),
                            ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                            ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                            ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                            ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                            ('bridge_mtu', YLeaf(YType.uint32, 'bridge-mtu')),
                            ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                            ('mac_limit_down', YLeaf(YType.boolean, 'mac-limit-down')),
                            ('flodd_group_id_down', YLeaf(YType.boolean, 'flodd-group-id-down')),
                            ('mac_withdraw', YLeaf(YType.boolean, 'mac-withdraw')),
                            ('mac_withdraw_access', YLeaf(YType.boolean, 'mac-withdraw-access')),
                            ('mac_withdraw_relay', YLeaf(YType.boolean, 'mac-withdraw-relay')),
                            ('mac_withdraw_option', YLeaf(YType.enumeration, 'mac-withdraw-option')),
                            ('p2mp_enabled', YLeaf(YType.boolean, 'p2mp-enabled')),
                            ('bridge_type', YLeaf(YType.enumeration, 'bridge-type')),
                            ('vine_fsm_state', YLeaf(YType.str, 'vine-fsm-state')),
                            ('time_created', YLeaf(YType.str, 'time-created')),
                            ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                            ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                            ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                            ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                            ('is_bridge_partially_programmed', YLeaf(YType.boolean, 'is-bridge-partially-programmed')),
                            ('evi', YLeaf(YType.uint32, 'evi')),
                            ('is_rd_configured', YLeaf(YType.boolean, 'is-rd-configured')),
                            ('imposition_pkt_count', YLeaf(YType.uint64, 'imposition-pkt-count')),
                            ('imposition_byte_count', YLeaf(YType.uint64, 'imposition-byte-count')),
                            ('disposition_pkt_count', YLeaf(YType.uint64, 'disposition-pkt-count')),
                            ('disposition_bytecount', YLeaf(YType.uint64, 'disposition-bytecount')),
                            ('as_', YLeaf(YType.uint32, 'as')),
                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                        ])
                        self.group_name = None
                        self.bridge_name = None
                        self.bridge_domain_id = None
                        self.bridge_description = None
                        self.bridge_state = None
                        self.bridge_coupled_state = None
                        self.bridge_shg_id = None
                        self.bridge_msti = None
                        self.acpwup = None
                        self.bridge_internal_msti = None
                        self.configured = None
                        self.number_vf_is = None
                        self.number_access_vf_is = None
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_pseudowires = None
                        self.number_p_ws_up = None
                        self.standby_pseudowires = None
                        self.number_pb_bs = None
                        self.number_pb_bs_up = None
                        self.num_vn_is = None
                        self.num_vn_is_up = None
                        self.partially_programmed_pseudowires = None
                        self.partially_programmed_a_cs = None
                        self.bridge_mtu = None
                        self.shutdown = None
                        self.mac_limit_down = None
                        self.flodd_group_id_down = None
                        self.mac_withdraw = None
                        self.mac_withdraw_access = None
                        self.mac_withdraw_relay = None
                        self.mac_withdraw_option = None
                        self.p2mp_enabled = None
                        self.bridge_type = None
                        self.vine_fsm_state = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.last_time_status_changed = None
                        self.time_elapsed_status_changed = None
                        self.load_balance = None
                        self.is_bridge_partially_programmed = None
                        self.evi = None
                        self.is_rd_configured = None
                        self.imposition_pkt_count = None
                        self.imposition_byte_count = None
                        self.disposition_pkt_count = None
                        self.disposition_bytecount = None
                        self.as_ = None
                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                        self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"

                        self.pbb_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self._children_name_map["pbb_parameters"] = "pbb-parameters"

                        self.evpn_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self._children_name_map["evpn_parameters"] = "evpn-parameters"

                        self.vni_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self
                        self._children_name_map["vni_parameters"] = "vni-parameters"

                        self.rd = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self._children_name_map["rd"] = "rd"

                        self.mac_filter = YList(self)
                        self.bridge_vfi = YList(self)
                        self.bridge_access_vfi = YList(self)
                        self._segment_path = lambda: "bridge-domain-info"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo, ['group_name', 'bridge_name', 'bridge_domain_id', 'bridge_description', 'bridge_state', 'bridge_coupled_state', 'bridge_shg_id', 'bridge_msti', 'acpwup', 'bridge_internal_msti', 'configured', 'number_vf_is', 'number_access_vf_is', 'number_a_cs', 'number_a_cs_up', 'number_pseudowires', 'number_p_ws_up', 'standby_pseudowires', 'number_pb_bs', 'number_pb_bs_up', 'num_vn_is', 'num_vn_is_up', 'partially_programmed_pseudowires', 'partially_programmed_a_cs', 'bridge_mtu', 'shutdown', 'mac_limit_down', 'flodd_group_id_down', 'mac_withdraw', 'mac_withdraw_access', 'mac_withdraw_relay', 'mac_withdraw_option', 'p2mp_enabled', 'bridge_type', 'vine_fsm_state', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'load_balance', 'is_bridge_partially_programmed', 'evi', 'is_rd_configured', 'imposition_pkt_count', 'imposition_byte_count', 'disposition_pkt_count', 'disposition_bytecount', 'as_', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                    class SecurityParameters(Entity):
                        """
                        Security parameters
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\: bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\: bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_threshold
                        
                        	MAC Limit Threshold Percentage
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: percentage
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\: bool
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_threshold_enabled
                        
                        	Is MAC Secure Threshold Enabled
                        	**type**\: bool
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\: bool
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\: str
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\: bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\: str
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\: str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\: bool
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl))])
                            self._leafs = OrderedDict([
                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                            ])
                            self.mac_limit = None
                            self.mac_limit_action = None
                            self.mac_limit_notification = None
                            self.mac_aging_time = None
                            self.mac_aging_mode = None
                            self.mac_flooding = None
                            self.mac_learning = None
                            self.learn_disabled_mac_limit_action = None
                            self.flood_uu_disabled_mac_limit_action = None
                            self.mac_limit_reached = None
                            self.mac_limit_threshold = None
                            self.flood_unknown_unicast_enabled = None
                            self.mac_port_down_flush_enabled = None
                            self.split_horizon_group_id = None
                            self.is_ip_source_guard_enabled = None
                            self.is_ipsg_logging_enabled = None
                            self.is_dai_enabled = None
                            self.is_dai_logging_enabled = None
                            self.is_dai_addr_validate_source_mac_enabled = None
                            self.is_dai_addr_validate_destination_mac_enabled = None
                            self.is_dai_addr_validate_ipv4_enabled = None
                            self.is_mac_secure_enabled = None
                            self.mac_secure_action = None
                            self.is_mac_secure_logging_enabled = None
                            self.is_mac_secure_accept_shutdown_enabled = None
                            self.is_mac_secure_threshold_enabled = None
                            self.dai_address_validation_mask = None
                            self.dhcpv4_snoop = None
                            self.dhcpv4_profile_name = None
                            self.igm_pv4_disabled = None
                            self.igm_pv4_profile_name = None
                            self.mld_profile_name = None
                            self.mmrp_flood_optimization = None
                            self.unicast_storm_control_rate_unit = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_kb_ps = None
                            self.multicast_storm_control_rate_unit = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_kb_ps = None

                            self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._segment_path = lambda: "security-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\: bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\: bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\: bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                ])
                                self.bd_policer = None
                                self.unicast = None
                                self.multicast = None
                                self.broadcast = None
                                self._segment_path = lambda: "storm-control"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/security-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                    class PbbParameters(Entity):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:  :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:  :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                            self.yang_name = "pbb-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pbb-edge", ("pbb_edge", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge)), ("pbb-core", ("pbb_core", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore))])
                            self._leafs = OrderedDict([
                                ('type', YLeaf(YType.enumeration, 'type')),
                            ])
                            self.type = None

                            self.pbb_edge = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self._children_name_map["pbb_edge"] = "pbb-edge"

                            self.pbb_core = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self._children_name_map["pbb_core"] = "pbb-core"
                            self._segment_path = lambda: "pbb-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, ['type'], name, value)


                        class PbbEdge(Entity):
                            """
                            PBB Edge
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:  :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\: str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:  :py:class:`L2vpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteStatus>`
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:  :py:class:`L2vpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteProtocolInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                self.yang_name = "pbb-edge"
                                self.yang_parent_name = "pbb-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("edge-port", ("edge_port", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort))])
                                self._leafs = OrderedDict([
                                    ('i_sid', YLeaf(YType.uint32, 'i-sid')),
                                    ('core_bridge_name', YLeaf(YType.str, 'core-bridge-name')),
                                    ('core_bridge_state', YLeaf(YType.enumeration, 'core-bridge-state')),
                                    ('mirp_lite_status', YLeaf(YType.enumeration, 'mirp-lite-status')),
                                    ('mirp_lite_protocol', YLeaf(YType.enumeration, 'mirp-lite-protocol')),
                                ])
                                self.i_sid = None
                                self.core_bridge_name = None
                                self.core_bridge_state = None
                                self.mirp_lite_status = None
                                self.mirp_lite_protocol = None

                                self.edge_port = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self._children_name_map["edge_port"] = "edge-port"
                                self._segment_path = lambda: "pbb-edge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, ['i_sid', 'core_bridge_name', 'core_bridge_state', 'mirp_lite_status', 'mirp_lite_protocol'], name, value)


                            class EdgePort(Entity):
                                """
                                PBB Edge Port
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\: bool
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of  		 :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                    self.yang_name = "edge-port"
                                    self.yang_parent_name = "pbb-edge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics)), ("bmac-mapping", ("bmac_mapping", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping))])
                                    self._leafs = OrderedDict([
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('unknown_unicast_mac_set', YLeaf(YType.boolean, 'unknown-unicast-mac-set')),
                                        ('unknown_unicast_mac', YLeaf(YType.str, 'unknown-unicast-mac')),
                                        ('edge_port_state', YLeaf(YType.enumeration, 'edge-port-state')),
                                    ])
                                    self.xconnect_id = None
                                    self.unknown_unicast_mac_set = None
                                    self.unknown_unicast_mac = None
                                    self.edge_port_state = None

                                    self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"

                                    self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.bmac_mapping = YList(self)
                                    self._segment_path = lambda: "edge-port"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, ['xconnect_id', 'unknown_unicast_mac_set', 'unknown_unicast_mac', 'edge_port_state'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/base/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class BmacMapping(Entity):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                        self.yang_name = "bmac-mapping"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', YLeaf(YType.str, 'address')),
                                            ('bmac', YLeaf(YType.str, 'bmac')),
                                            ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                        ])
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None
                                        self._segment_path = lambda: "bmac-mapping"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class PbbCore(Entity):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:  :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                self.yang_name = "pbb-core"
                                self.yang_parent_name = "pbb-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("core-port", ("core_port", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort))])
                                self._leafs = OrderedDict([
                                    ('num_ass_edge', YLeaf(YType.uint32, 'num-ass-edge')),
                                ])
                                self.num_ass_edge = None

                                self.core_port = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self._children_name_map["core_port"] = "core-port"
                                self._segment_path = lambda: "pbb-core"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, ['num_ass_edge'], name, value)


                            class CorePort(Entity):
                                """
                                PBB Core Port
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                    self.yang_name = "core-port"
                                    self.yang_parent_name = "pbb-core"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters))])
                                    self._leafs = OrderedDict([
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ('core_port_state', YLeaf(YType.enumeration, 'core-port-state')),
                                    ])
                                    self.xconnect_id = None
                                    self.vlan_id = None
                                    self.core_port_state = None

                                    self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._segment_path = lambda: "core-port"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, ['xconnect_id', 'vlan_id', 'core_port_state'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "core-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/base/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                    class EvpnParameters(Entity):
                        """
                        EVPN parameters
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:  :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                            self.yang_name = "evpn-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("evpn-port", ("evpn_port", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort))])
                            self._leafs = OrderedDict([
                                ('evi', YLeaf(YType.uint32, 'evi')),
                            ])
                            self.evi = None

                            self.evpn_port = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self
                            self._children_name_map["evpn_port"] = "evpn-port"
                            self._segment_path = lambda: "evpn-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, ['evi'], name, value)


                        class EvpnPort(Entity):
                            """
                            EVPN Port
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                self.yang_name = "evpn-port"
                                self.yang_parent_name = "evpn-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics))])
                                self._leafs = OrderedDict([
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('evpn_port_state', YLeaf(YType.enumeration, 'evpn-port-state')),
                                ])
                                self.xconnect_id = None
                                self.evpn_port_state = None

                                self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._segment_path = lambda: "evpn-port"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, ['xconnect_id', 'evpn_port_state'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "evpn-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "evpn-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                    class VniParameters(Entity):
                        """
                        VNI parameters
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\: str
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:  :py:class:`L2vpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniEncaps>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:  :py:class:`L2vpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniMode>`
                        
                        .. attribute:: ingress_replication
                        
                        	VNI Ingress Replication is enabled
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                            self.yang_name = "vni-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics)), ("static-mac", ("static_mac", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac))])
                            self._leafs = OrderedDict([
                                ('vni', YLeaf(YType.uint32, 'vni')),
                                ('overlay', YLeaf(YType.str, 'overlay')),
                                ('source_ip_addr', YLeaf(YType.str, 'source-ip-addr')),
                                ('multicast_group_addr', YLeaf(YType.str, 'multicast-group-addr')),
                                ('anycast_vtep_ip_addr', YLeaf(YType.str, 'anycast-vtep-ip-addr')),
                                ('anycast_mcast_group_addr', YLeaf(YType.str, 'anycast-mcast-group-addr')),
                                ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                ('vni_encap_type', YLeaf(YType.enumeration, 'vni-encap-type')),
                                ('vni_port_state', YLeaf(YType.enumeration, 'vni-port-state')),
                                ('vni_mode', YLeaf(YType.enumeration, 'vni-mode')),
                                ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                            ])
                            self.vni = None
                            self.overlay = None
                            self.source_ip_addr = None
                            self.multicast_group_addr = None
                            self.anycast_vtep_ip_addr = None
                            self.anycast_mcast_group_addr = None
                            self.udp_port = None
                            self.vni_encap_type = None
                            self.vni_port_state = None
                            self.vni_mode = None
                            self.ingress_replication = None
                            self.xconnect_id = None

                            self.security_parameters = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.statistics = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.static_mac = YList(self)
                            self._segment_path = lambda: "vni-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, ['vni', 'overlay', 'source_ip_addr', 'multicast_group_addr', 'anycast_vtep_ip_addr', 'anycast_mcast_group_addr', 'udp_port', 'vni_encap_type', 'vni_port_state', 'vni_mode', 'ingress_replication', 'xconnect_id'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/base/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class Rd(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                            self.yang_name = "rd"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                    class MacFilter(Entity):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                            self.yang_name = "mac-filter"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', YLeaf(YType.str, 'address')),
                                ('bmac', YLeaf(YType.str, 'bmac')),
                                ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                            ])
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None
                            self._segment_path = lambda: "mac-filter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeVfi(Entity):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\: bool
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                            self.yang_name = "bridge-vfi"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation))])
                            self._leafs = OrderedDict([
                                ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('access', YLeaf(YType.boolean, 'access')),
                                ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ])
                            self.vfi_name = None
                            self.shutdown = None
                            self.access = None
                            self.vfi_state = None
                            self.number_pseudowires = None

                            self.discovery_information = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"

                            self.p2mp_information = YList(self)
                            self._segment_path = lambda: "bridge-vfi"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\: bool
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\: bool
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\: bool
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\: str
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt))])
                                self._leafs = OrderedDict([
                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('ve_id', YLeaf(YType.uint32, 've-id')),
                                    ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                    ('ve_range', YLeaf(YType.uint16, 've-range')),
                                    ('as_number', YLeaf(YType.uint32, 'as-number')),
                                    ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                    ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                    ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                    ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                    ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                ])
                                self.vpn_id = None
                                self.ad_signalling_method = None
                                self.ad_method = None
                                self.ve_id = None
                                self.provisioned_ve_id = None
                                self.ve_range = None
                                self.as_number = None
                                self.l2vpn_router_id = None
                                self.vpn_added = None
                                self.service_connected = None
                                self.vpls_id_conflict = None
                                self.export_route_policy = None

                                self.rd_value = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"

                                self.vpls_id = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"

                                self.import_rt = YList(self)
                                self.export_rt = YList(self)
                                self._segment_path = lambda: "discovery-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('rd', YLeaf(YType.enumeration, 'rd')),
                                    ])
                                    self.rd = None

                                    self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "rd-value"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('router_id', YLeaf(YType.str, 'router-id')),
                                            ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                        ])
                                        self.router_id = None
                                        self.auto_index = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                    ])
                                    self.vpls_id_type = None

                                    self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "vpls-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ])
                                        self.asn = None
                                        self.vpn_id = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "import-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "export-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                        class P2mpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\: str
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('transport', YLeaf(YType.enumeration, 'transport')),
                                    ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                    ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                    ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                    ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                ])
                                self.transport = None
                                self.signaling = None
                                self.ptree_id = None
                                self.attribute_set_name = None
                                self.transport_status = None
                                self.local_label = None
                                self.tunnel_interface = None
                                self._segment_path = lambda: "p2mp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


                    class BridgeAccessVfi(Entity):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\: bool
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                            self.yang_name = "bridge-access-vfi"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation))])
                            self._leafs = OrderedDict([
                                ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('access', YLeaf(YType.boolean, 'access')),
                                ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ])
                            self.vfi_name = None
                            self.shutdown = None
                            self.access = None
                            self.vfi_state = None
                            self.number_pseudowires = None

                            self.discovery_information = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"

                            self.p2mp_information = YList(self)
                            self._segment_path = lambda: "bridge-access-vfi"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\: bool
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\: bool
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\: bool
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\: str
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-access-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt))])
                                self._leafs = OrderedDict([
                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('ve_id', YLeaf(YType.uint32, 've-id')),
                                    ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                    ('ve_range', YLeaf(YType.uint16, 've-range')),
                                    ('as_number', YLeaf(YType.uint32, 'as-number')),
                                    ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                    ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                    ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                    ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                    ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                ])
                                self.vpn_id = None
                                self.ad_signalling_method = None
                                self.ad_method = None
                                self.ve_id = None
                                self.provisioned_ve_id = None
                                self.ve_range = None
                                self.as_number = None
                                self.l2vpn_router_id = None
                                self.vpn_added = None
                                self.service_connected = None
                                self.vpls_id_conflict = None
                                self.export_route_policy = None

                                self.rd_value = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"

                                self.vpls_id = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"

                                self.import_rt = YList(self)
                                self.export_rt = YList(self)
                                self._segment_path = lambda: "discovery-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('rd', YLeaf(YType.enumeration, 'rd')),
                                    ])
                                    self.rd = None

                                    self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "rd-value"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('router_id', YLeaf(YType.str, 'router-id')),
                                            ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                        ])
                                        self.router_id = None
                                        self.auto_index = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                    ])
                                    self.vpls_id_type = None

                                    self.auto = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "vpls-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ])
                                        self.asn = None
                                        self.vpn_id = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "import-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "export-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                        class P2mpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\: str
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-access-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('transport', YLeaf(YType.enumeration, 'transport')),
                                    ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                    ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                    ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                    ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                ])
                                self.transport = None
                                self.signaling = None
                                self.ptree_id = None
                                self.attribute_set_name = None
                                self.transport_status = None
                                self.local_label = None
                                self.tunnel_interface = None
                                self._segment_path = lambda: "p2mp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


        class DiscoverySummary(Entity):
            """
            Discovery summary information
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\: bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\: bool
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\: bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\: bool
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:  :py:class:`L2vpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIpcTransportMode>`
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.DiscoverySummary, self).__init__()

                self.yang_name = "discovery-summary"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_bridge_domainvpns', YLeaf(YType.uint32, 'number-bridge-domainvpns')),
                    ('number_mp2m_pxconnect_vpns', YLeaf(YType.uint32, 'number-mp2m-pxconnect-vpns')),
                    ('number_local_edges_bridge_domain', YLeaf(YType.uint32, 'number-local-edges-bridge-domain')),
                    ('number_remote_edges_bridge_domain', YLeaf(YType.uint32, 'number-remote-edges-bridge-domain')),
                    ('number_nlri_bridge_domain', YLeaf(YType.uint32, 'number-nlri-bridge-domain')),
                    ('number_local_edges_xconnect', YLeaf(YType.uint32, 'number-local-edges-xconnect')),
                    ('number_remote_edges_xconnect', YLeaf(YType.uint32, 'number-remote-edges-xconnect')),
                    ('number_nlri_xconnect', YLeaf(YType.uint32, 'number-nlri-xconnect')),
                    ('bgp_stateon_active_rp', YLeaf(YType.boolean, 'bgp-stateon-active-rp')),
                    ('bgp_stateon_standby_rp', YLeaf(YType.boolean, 'bgp-stateon-standby-rp')),
                    ('vpls_registered', YLeaf(YType.boolean, 'vpls-registered')),
                    ('vpws_registered', YLeaf(YType.boolean, 'vpws-registered')),
                    ('bgp_ipc_transport_mode', YLeaf(YType.enumeration, 'bgp-ipc-transport-mode')),
                    ('bgp_current_node_id', YLeaf(YType.str, 'bgp-current-node-id')),
                ])
                self.number_bridge_domainvpns = None
                self.number_mp2m_pxconnect_vpns = None
                self.number_local_edges_bridge_domain = None
                self.number_remote_edges_bridge_domain = None
                self.number_nlri_bridge_domain = None
                self.number_local_edges_xconnect = None
                self.number_remote_edges_xconnect = None
                self.number_nlri_xconnect = None
                self.bgp_stateon_active_rp = None
                self.bgp_stateon_standby_rp = None
                self.vpls_registered = None
                self.vpws_registered = None
                self.bgp_ipc_transport_mode = None
                self.bgp_current_node_id = None
                self._segment_path = lambda: "discovery-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.DiscoverySummary, ['number_bridge_domainvpns', 'number_mp2m_pxconnect_vpns', 'number_local_edges_bridge_domain', 'number_remote_edges_bridge_domain', 'number_nlri_bridge_domain', 'number_local_edges_xconnect', 'number_remote_edges_xconnect', 'number_nlri_xconnect', 'bgp_stateon_active_rp', 'bgp_stateon_standby_rp', 'vpls_registered', 'vpws_registered', 'bgp_ipc_transport_mode', 'bgp_current_node_id'], name, value)


        class G8032(Entity):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:  :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.G8032, self).__init__()

                self.yang_name = "g8032"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("g8032-rings", ("g8032_rings", L2vpnv2.Standby.G8032.G8032Rings))])
                self._leafs = OrderedDict()

                self.g8032_rings = L2vpnv2.Standby.G8032.G8032Rings()
                self.g8032_rings.parent = self
                self._children_name_map["g8032_rings"] = "g8032-rings"
                self._segment_path = lambda: "g8032"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.G8032, [], name, value)


            class G8032Rings(Entity):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of  		 :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.G8032.G8032Rings, self).__init__()

                    self.yang_name = "g8032-rings"
                    self.yang_parent_name = "g8032"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("g8032-ring", ("g8032_ring", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring))])
                    self._leafs = OrderedDict()

                    self.g8032_ring = YList(self)
                    self._segment_path = lambda: "g8032-rings"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/g8032/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings, [], name, value)


                class G8032Ring(Entity):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  (key)
                    
                    	Ring Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:  :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:  :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:  :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:  :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring, self).__init__()

                        self.yang_name = "g8032-ring"
                        self.yang_parent_name = "g8032-rings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ring_name']
                        self._child_classes = OrderedDict([("g8032-ring-detail", ("g8032_ring_detail", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail)), ("g8032-ring-instance-summaries", ("g8032_ring_instance_summaries", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries)), ("g8032-ring-summary", ("g8032_ring_summary", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary)), ("g8032-ring-instance-details", ("g8032_ring_instance_details", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails))])
                        self._leafs = OrderedDict([
                            ('ring_name', YLeaf(YType.str, 'ring-name')),
                        ])
                        self.ring_name = None

                        self.g8032_ring_detail = L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"

                        self.g8032_ring_instance_summaries = L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"

                        self.g8032_ring_summary = L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self
                        self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"

                        self.g8032_ring_instance_details = L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                        self._segment_path = lambda: "g8032-ring" + "[ring-name='" + str(self.ring_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/g8032/g8032-rings/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring, ['ring_name'], name, value)


                    class G8032RingDetail(Entity):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\: str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\: str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\: str
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\: str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\: str
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\: bool
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\: bool
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\: bool
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\: list of  		 :py:class:`ExcludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                            self.yang_name = "g8032-ring-detail"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("excluded-vlan-id", ("excluded_vlan_id", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId))])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                                ('port0', YLeaf(YType.str, 'port0')),
                                ('port1', YLeaf(YType.str, 'port1')),
                                ('monitor0', YLeaf(YType.str, 'monitor0')),
                                ('monitor1', YLeaf(YType.str, 'monitor1')),
                                ('is_provider_bridge', YLeaf(YType.boolean, 'is-provider-bridge')),
                                ('is_open_ring', YLeaf(YType.boolean, 'is-open-ring')),
                                ('tcn_propagation', YLeaf(YType.boolean, 'tcn-propagation')),
                            ])
                            self.ring_name = None
                            self.port0 = None
                            self.port1 = None
                            self.monitor0 = None
                            self.monitor1 = None
                            self.is_provider_bridge = None
                            self.is_open_ring = None
                            self.tcn_propagation = None

                            self.excluded_vlan_id = YList(self)
                            self._segment_path = lambda: "g8032-ring-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail, ['ring_name', 'port0', 'port1', 'monitor0', 'monitor1', 'is_provider_bridge', 'is_open_ring', 'tcn_propagation'], name, value)


                        class ExcludedVlanId(Entity):
                            """
                            Exclusion Vlan ids list 
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, self).__init__()

                                self.yang_name = "excluded-vlan-id"
                                self.yang_parent_name = "g8032-ring-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "excluded-vlan-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, ['entry'], name, value)


                    class G8032RingInstanceSummaries(Entity):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of  		 :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                            self.yang_name = "g8032-ring-instance-summaries"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("g8032-ring-instance-summary", ("g8032_ring_instance_summary", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary))])
                            self._leafs = OrderedDict()

                            self.g8032_ring_instance_summary = YList(self)
                            self._segment_path = lambda: "g8032-ring-instance-summaries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, [], name, value)


                        class G8032RingInstanceSummary(Entity):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\: bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                self.yang_name = "g8032-ring-instance-summary"
                                self.yang_parent_name = "g8032-ring-instance-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                    ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                    ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                    ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                    ('config_state', YLeaf(YType.boolean, 'config-state')),
                                ])
                                self.instance = None
                                self.ring_instance = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None

                                self.included_vlan_id = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-summary" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, ['instance', 'ring_instance', 'aps_port0', 'aps_port1', 'config_state'], name, value)


                            class IncludedVlanId(Entity):
                                """
                                Inclusion list Vlan Ids
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, self).__init__()

                                    self.yang_name = "included-vlan-id"
                                    self.yang_parent_name = "g8032-ring-instance-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "included-vlan-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, ['entry'], name, value)


                    class G8032RingSummary(Entity):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\: str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\: str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                            self.yang_name = "g8032-ring-summary"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                                ('port0', YLeaf(YType.str, 'port0')),
                                ('port1', YLeaf(YType.str, 'port1')),
                            ])
                            self.ring_name = None
                            self.port0 = None
                            self.port1 = None
                            self._segment_path = lambda: "g8032-ring-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingSummary, ['ring_name', 'port0', 'port1'], name, value)


                    class G8032RingInstanceDetails(Entity):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of  		 :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                            self.yang_name = "g8032-ring-instance-details"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("g8032-ring-instance-detail", ("g8032_ring_instance_detail", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail))])
                            self._leafs = OrderedDict()

                            self.g8032_ring_instance_detail = YList(self)
                            self._segment_path = lambda: "g8032-ring-instance-details"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, [], name, value)


                        class G8032RingInstanceDetail(Entity):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\: str
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\: str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:  :py:class:`L2vpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032Rpl>`
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\: bool
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:  :py:class:`L2vpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032UncfgReason>`
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                self.yang_name = "g8032-ring-instance-detail"
                                self.yang_parent_name = "g8032-ring-instance-details"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                    ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                    ('ring_description', YLeaf(YType.str, 'ring-description')),
                                    ('ring_profile', YLeaf(YType.str, 'ring-profile')),
                                    ('rpl', YLeaf(YType.enumeration, 'rpl')),
                                    ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                    ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                    ('config_state', YLeaf(YType.boolean, 'config-state')),
                                    ('unresolved_reason', YLeaf(YType.enumeration, 'unresolved-reason')),
                                    ('aps_channel_level', YLeaf(YType.uint32, 'aps-channel-level')),
                                ])
                                self.instance = None
                                self.ring_instance = None
                                self.ring_description = None
                                self.ring_profile = None
                                self.rpl = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.unresolved_reason = None
                                self.aps_channel_level = None

                                self.included_vlan_id = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-detail" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, ['instance', 'ring_instance', 'ring_description', 'ring_profile', 'rpl', 'aps_port0', 'aps_port1', 'config_state', 'unresolved_reason', 'aps_channel_level'], name, value)


                            class IncludedVlanId(Entity):
                                """
                                Inclusion list Vlan Ids
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, self).__init__()

                                    self.yang_name = "included-vlan-id"
                                    self.yang_parent_name = "g8032-ring-instance-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "included-vlan-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, ['entry'], name, value)


        class PseudowireClasses(Entity):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of  		 :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.PseudowireClasses, self).__init__()

                self.yang_name = "pseudowire-classes"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pseudowire-class", ("pseudowire_class", L2vpnv2.Standby.PseudowireClasses.PseudowireClass))])
                self._leafs = OrderedDict()

                self.pseudowire_class = YList(self)
                self._segment_path = lambda: "pseudowire-classes"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.PseudowireClasses, [], name, value)


            class PseudowireClass(Entity):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  (key)
                
                	Pseudowire Class Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:  :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:  :py:class:`L2vpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwClassControlWord>`
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:  :py:class:`L2vpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTransportMode>`
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\: bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\: bool
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\: bool
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\: bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\: bool
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass, self).__init__()

                    self.yang_name = "pseudowire-class"
                    self.yang_parent_name = "pseudowire-classes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pseudowire_class_name']
                    self._child_classes = OrderedDict([("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath)), ("local-source-address", ("local_source_address", L2vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress))])
                    self._leafs = OrderedDict([
                        ('pseudowire_class_name', YLeaf(YType.str, 'pseudowire-class-name')),
                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                        ('control_word', YLeaf(YType.enumeration, 'control-word')),
                        ('transport_mode', YLeaf(YType.enumeration, 'transport-mode')),
                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                        ('backup_mac_withdraw', YLeaf(YType.boolean, 'backup-mac-withdraw')),
                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                    ])
                    self.pseudowire_class_name = None
                    self.pw_class_name = None
                    self.control_word = None
                    self.transport_mode = None
                    self.sequencing_type = None
                    self.resync_enabled = None
                    self.resync_threshold = None
                    self.protocol = None
                    self.disable_never = None
                    self.disable_delay = None
                    self.backup_mac_withdraw = None
                    self.tag_rewrite = None
                    self.preferred_path_disable_fallback = None
                    self.load_balance = None
                    self.pw_flow_label_type_cfg = None
                    self.pw_flow_label_code17_disabled = None
                    self.is_flow_label_static = None

                    self.encapsulation_info = L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                    self.preferred_path = L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self._children_name_map["preferred_path"] = "preferred-path"

                    self.local_source_address = L2vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self._children_name_map["local_source_address"] = "local-source-address"
                    self._segment_path = lambda: "pseudowire-class" + "[pseudowire-class-name='" + str(self.pseudowire_class_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/pseudowire-classes/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass, ['pseudowire_class_name', 'pw_class_name', 'control_word', 'transport_mode', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'protocol', 'disable_never', 'disable_delay', 'backup_mac_withdraw', 'tag_rewrite', 'preferred_path_disable_fallback', 'load_balance', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static'], name, value)


                class EncapsulationInfo(Entity):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3>`
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                        self.yang_name = "encapsulation-info"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2tpv3", ("l2tpv3", L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3))])
                        self._leafs = OrderedDict([
                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                        ])
                        self.encapsulation = None

                        self.l2tpv3 = L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3()
                        self.l2tpv3.parent = self
                        self._children_name_map["l2tpv3"] = "l2tpv3"
                        self._segment_path = lambda: "encapsulation-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo, ['encapsulation'], name, value)


                    class L2tpv3(Entity):
                        """
                        l2tpv3
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\: bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\: bool
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, self).__init__()

                            self.yang_name = "l2tpv3"
                            self.yang_parent_name = "encapsulation-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                ('tos', YLeaf(YType.uint8, 'tos')),
                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                            ])
                            self.l2tp_class_name = None
                            self.ipv4_source_address = None
                            self.path_mtu_enabled = None
                            self.path_mtu_max_value = None
                            self.dont_fragment_bit = None
                            self.tos_mode = None
                            self.tos = None
                            self.ttl = None
                            self.cookie_size = None
                            self._segment_path = lambda: "l2tpv3"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'cookie_size'], name, value)


                class PreferredPath(Entity):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: srte_policy
                    
                    	srte policy
                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy>`
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                        self.yang_name = "preferred-path"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy))])
                        self._leafs = OrderedDict([
                            ('option', YLeaf(YType.enumeration, 'option')),
                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                        ])
                        self.option = None
                        self.next_hop_ip = None
                        self.te_tunnel_interface_number = None
                        self.ip_tunnel_interface_number = None
                        self.tp_tunnel_interface_number = None

                        self.srte_policy = L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy()
                        self.srte_policy.parent = self
                        self._children_name_map["srte_policy"] = "srte-policy"
                        self._segment_path = lambda: "preferred-path"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                    class SrtePolicy(Entity):
                        """
                        srte policy
                        
                        .. attribute:: policy_name
                        
                        	SR TE Policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, self).__init__()

                            self.yang_name = "srte-policy"
                            self.yang_parent_name = "preferred-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                            ])
                            self.policy_name = None
                            self._segment_path = lambda: "srte-policy"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                class LocalSourceAddress(Entity):
                    """
                    Local source address
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:  :py:class:`L2vpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSrcAddressSet>`
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                        self.yang_name = "local-source-address"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('configuration', YLeaf(YType.enumeration, 'configuration')),
                            ('address', YLeaf(YType.str, 'address')),
                        ])
                        self.configuration = None
                        self.address = None
                        self._segment_path = lambda: "local-source-address"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.PseudowireClasses.PseudowireClass.LocalSourceAddress, ['configuration', 'address'], name, value)


        class L2vpnCollaborators(Entity):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:  :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.L2vpnCollaborators, self).__init__()

                self.yang_name = "l2vpn-collaborators"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("collaborator-statistics", ("collaborator_statistics", L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics))])
                self._leafs = OrderedDict()

                self.collaborator_statistics = L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self
                self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                self._segment_path = lambda: "l2vpn-collaborators"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.L2vpnCollaborators, [], name, value)


            class CollaboratorStatistics(Entity):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of  		 :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics, self).__init__()

                    self.yang_name = "collaborator-statistics"
                    self.yang_parent_name = "l2vpn-collaborators"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("count", ("count", L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics.Count))])
                    self._leafs = OrderedDict()

                    self.count = YList(self)
                    self._segment_path = lambda: "collaborator-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/l2vpn-collaborators/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics, [], name, value)


                class Count(Entity):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\: str
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                        self.yang_name = "count"
                        self.yang_parent_name = "collaborator-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('collaborator_name', YLeaf(YType.str, 'collaborator-name')),
                            ('up', YLeaf(YType.uint32, 'up')),
                            ('down', YLeaf(YType.uint32, 'down')),
                            ('is_up', YLeaf(YType.boolean, 'is-up')),
                        ])
                        self.collaborator_name = None
                        self.up = None
                        self.down = None
                        self.is_up = None
                        self._segment_path = lambda: "count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/l2vpn-collaborators/collaborator-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.L2vpnCollaborators.CollaboratorStatistics.Count, ['collaborator_name', 'up', 'down', 'is_up'], name, value)


        class Mvrp(Entity):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:  :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.Mvrp, self).__init__()

                self.yang_name = "mvrp"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mvrp-main-ports", ("mvrp_main_ports", L2vpnv2.Standby.Mvrp.MvrpMainPorts))])
                self._leafs = OrderedDict()

                self.mvrp_main_ports = L2vpnv2.Standby.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self
                self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                self._segment_path = lambda: "mvrp"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.Mvrp, [], name, value)


            class MvrpMainPorts(Entity):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of  		 :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.Mvrp.MvrpMainPorts, self).__init__()

                    self.yang_name = "mvrp-main-ports"
                    self.yang_parent_name = "mvrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mvrp-main-port", ("mvrp_main_port", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort))])
                    self._leafs = OrderedDict()

                    self.mvrp_main_port = YList(self)
                    self._segment_path = lambda: "mvrp-main-ports"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mvrp/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts, [], name, value)


                class MvrpMainPort(Entity):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  (key)
                    
                    	Main Port interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:  :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:  :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                        self.yang_name = "mvrp-main-port"
                        self.yang_parent_name = "mvrp-main-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['main_port_interface_name']
                        self._child_classes = OrderedDict([("mvrp-main-port-info", ("mvrp_main_port_info", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo)), ("mvrp-bridge-ports", ("mvrp_bridge_ports", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts))])
                        self._leafs = OrderedDict([
                            ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                        ])
                        self.main_port_interface_name = None

                        self.mvrp_main_port_info = L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self
                        self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"

                        self.mvrp_bridge_ports = L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                        self._segment_path = lambda: "mvrp-main-port" + "[main-port-interface-name='" + str(self.main_port_interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mvrp/mvrp-main-ports/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort, ['main_port_interface_name'], name, value)


                    class MvrpMainPortInfo(Entity):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:  :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\: str
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\: bool
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\: bool
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                            self.yang_name = "mvrp-main-port-info"
                            self.yang_parent_name = "mvrp-main-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default-bridge-port", ("default_bridge_port", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort))])
                            self._leafs = OrderedDict([
                                ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                                ('is_trunk', YLeaf(YType.boolean, 'is-trunk')),
                                ('is_default_encap', YLeaf(YType.boolean, 'is-default-encap')),
                                ('number_of_bridge_ports', YLeaf(YType.uint32, 'number-of-bridge-ports')),
                            ])
                            self.main_port_interface_name = None
                            self.is_trunk = None
                            self.is_default_encap = None
                            self.number_of_bridge_ports = None

                            self.default_bridge_port = L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self._children_name_map["default_bridge_port"] = "default-bridge-port"
                            self._segment_path = lambda: "mvrp-main-port-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, ['main_port_interface_name', 'is_trunk', 'is_default_encap', 'number_of_bridge_ports'], name, value)


                        class DefaultBridgePort(Entity):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\: str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                self.yang_name = "default-bridge-port"
                                self.yang_parent_name = "mvrp-main-port-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange))])
                                self._leafs = OrderedDict([
                                    ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                    ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                ])
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None

                                self.vlan_range = YList(self)
                                self._segment_path = lambda: "default-bridge-port"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, ['bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "default-bridge-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                    ])
                                    self.lower = None
                                    self.upper = None
                                    self._segment_path = lambda: "vlan-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, ['lower', 'upper'], name, value)


                    class MvrpBridgePorts(Entity):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of  		 :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                            self.yang_name = "mvrp-bridge-ports"
                            self.yang_parent_name = "mvrp-main-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mvrp-bridge-port", ("mvrp_bridge_port", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort))])
                            self._leafs = OrderedDict()

                            self.mvrp_bridge_port = YList(self)
                            self._segment_path = lambda: "mvrp-bridge-ports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, [], name, value)


                        class MvrpBridgePort(Entity):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  (key)
                            
                            	Bridge Port Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\: str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                self.yang_name = "mvrp-bridge-port"
                                self.yang_parent_name = "mvrp-bridge-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                    ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                ])
                                self.interface_name = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None

                                self.vlan_range = YList(self)
                                self._segment_path = lambda: "mvrp-bridge-port" + "[interface-name='" + str(self.interface_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, ['interface_name', 'bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "mvrp-bridge-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                    ])
                                    self.lower = None
                                    self.upper = None
                                    self._segment_path = lambda: "vlan-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, ['lower', 'upper'], name, value)


        class GenericInterfaceLists(Entity):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface_list
            
            	Generic Interface List information
            	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.GenericInterfaceLists, self).__init__()

                self.yang_name = "generic-interface-lists"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList))])
                self._leafs = OrderedDict()

                self.generic_interface_list = YList(self)
                self._segment_path = lambda: "generic-interface-lists"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.GenericInterfaceLists, [], name, value)


            class GenericInterfaceList(Entity):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: items
                
                	Number of items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                    self.yang_name = "generic-interface-list"
                    self.yang_parent_name = "generic-interface-lists"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_list_name']
                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface))])
                    self._leafs = OrderedDict([
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                        ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                        ('items', YLeaf(YType.uint32, 'items')),
                    ])
                    self.interface_list_name = None
                    self.interface_list_name_xr = None
                    self.interface_list_id = None
                    self.number_of_interfaces = None
                    self.items = None

                    self.interface = YList(self)
                    self._segment_path = lambda: "generic-interface-list" + "[interface-list-name='" + str(self.interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/generic-interface-lists/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList, ['interface_list_name', 'interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


        class MstpVlans(Entity):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of  		 :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.MstpVlans, self).__init__()

                self.yang_name = "mstp-vlans"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mstp-vlan", ("mstp_vlan", L2vpnv2.Standby.MstpVlans.MstpVlan))])
                self._leafs = OrderedDict()

                self.mstp_vlan = YList(self)
                self._segment_path = lambda: "mstp-vlans"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.MstpVlans, [], name, value)


            class MstpVlan(Entity):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  (key)
                
                	vlan id
                	**type**\: int
                
                	**range:** 0..4098
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of  		 :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.MstpVlans.MstpVlan.SubInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.MstpVlans.MstpVlan, self).__init__()

                    self.yang_name = "mstp-vlan"
                    self.yang_parent_name = "mstp-vlans"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vlan_id']
                    self._child_classes = OrderedDict([("sub-interface", ("sub_interface", L2vpnv2.Standby.MstpVlans.MstpVlan.SubInterface))])
                    self._leafs = OrderedDict([
                        ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                        ('vlan_id_xr', YLeaf(YType.uint32, 'vlan-id-xr')),
                        ('msti_id', YLeaf(YType.uint32, 'msti-id')),
                        ('port_count', YLeaf(YType.uint32, 'port-count')),
                    ])
                    self.vlan_id = None
                    self.vlan_id_xr = None
                    self.msti_id = None
                    self.port_count = None

                    self.sub_interface = YList(self)
                    self._segment_path = lambda: "mstp-vlan" + "[vlan-id='" + str(self.vlan_id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/mstp-vlans/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.MstpVlans.MstpVlan, ['vlan_id', 'vlan_id_xr', 'msti_id', 'port_count'], name, value)


                class SubInterface(Entity):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.MstpVlans.MstpVlan.SubInterface, self).__init__()

                        self.yang_name = "sub-interface"
                        self.yang_parent_name = "mstp-vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "sub-interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.MstpVlans.MstpVlan.SubInterface, ['interface_name'], name, value)


        class L2vpnPbbBsa(Entity):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\: bool
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\: bool
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.L2vpnPbbBsa, self).__init__()

                self.yang_name = "l2vpn-pbb-bsa"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('provisioned', YLeaf(YType.boolean, 'provisioned')),
                    ('chassis_is_provisioned', YLeaf(YType.boolean, 'chassis-is-provisioned')),
                    ('bmac_sa', YLeaf(YType.str, 'bmac-sa')),
                    ('chassis_mac', YLeaf(YType.str, 'chassis-mac')),
                ])
                self.provisioned = None
                self.chassis_is_provisioned = None
                self.bmac_sa = None
                self.chassis_mac = None
                self._segment_path = lambda: "l2vpn-pbb-bsa"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.L2vpnPbbBsa, ['provisioned', 'chassis_is_provisioned', 'bmac_sa', 'chassis_mac'], name, value)


        class FlexibleXconnectServices(Entity):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of  		 :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.FlexibleXconnectServices, self).__init__()

                self.yang_name = "flexible-xconnect-services"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("flexible-xconnect-service", ("flexible_xconnect_service", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService))])
                self._leafs = OrderedDict()

                self.flexible_xconnect_service = YList(self)
                self._segment_path = lambda: "flexible-xconnect-services"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices, [], name, value)


            class FlexibleXconnectService(Entity):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  (key)
                
                	Flexible XConnect Service Name
                	**type**\: str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:  :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:  :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                    self.yang_name = "flexible-xconnect-service"
                    self.yang_parent_name = "flexible-xconnect-services"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("flexible-xconnect-service-acs", ("flexible_xconnect_service_acs", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs)), ("flexible-xconnect-service-info", ("flexible_xconnect_service_info", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo))])
                    self._leafs = OrderedDict([
                        ('name', YLeaf(YType.str, 'name')),
                    ])
                    self.name = None

                    self.flexible_xconnect_service_acs = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"

                    self.flexible_xconnect_service_info = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self
                    self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                    self._segment_path = lambda: "flexible-xconnect-service" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/flexible-xconnect-services/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService, ['name'], name, value)


                class FlexibleXconnectServiceAcs(Entity):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of  		 :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                        self.yang_name = "flexible-xconnect-service-acs"
                        self.yang_parent_name = "flexible-xconnect-service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flexible-xconnect-service-ac", ("flexible_xconnect_service_ac", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc))])
                        self._leafs = OrderedDict()

                        self.flexible_xconnect_service_ac = YList(self)
                        self._segment_path = lambda: "flexible-xconnect-service-acs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, [], name, value)


                    class FlexibleXconnectServiceAc(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                            self.yang_name = "flexible-xconnect-service-ac"
                            self.yang_parent_name = "flexible-xconnect-service-acs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit))])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ])
                            self.interface_name = None

                            self.attachment_circuit = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._segment_path = lambda: "flexible-xconnect-service-ac" + "[interface-name='" + str(self.interface_name) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, ['interface_name'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "flexible-xconnect-service-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                class FlexibleXconnectServiceInfo(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: fxc_id
                    
                    	Flexible XConnect ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\: str
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of  		 :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                        self.yang_name = "flexible-xconnect-service-info"
                        self.yang_parent_name = "flexible-xconnect-service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire))])
                        self._leafs = OrderedDict([
                            ('fxc_id', YLeaf(YType.uint32, 'fxc-id')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('state', YLeaf(YType.enumeration, 'state')),
                            ('num_p_ws', YLeaf(YType.uint8, 'num-p-ws')),
                        ])
                        self.fxc_id = None
                        self.name = None
                        self.state = None
                        self.num_p_ws = None

                        self.pseudowire = YList(self)
                        self._segment_path = lambda: "flexible-xconnect-service-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, ['fxc_id', 'name', 'state', 'num_p_ws'], name, value)


                    class Pseudowire(Entity):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                            self.yang_name = "pseudowire"
                            self.yang_parent_name = "flexible-xconnect-service-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudowire"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


        class XconnectBrief(Entity):
            """
            XConnect brief information
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:  :py:class:`L2vpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMemoryState>`
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of  		 :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of  		 :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationTotal>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Standby.XconnectBrief, self).__init__()

                self.yang_name = "xconnect-brief"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("encapsulation-report-matrix", ("encapsulation_report_matrix", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix)), ("encapsulation-total", ("encapsulation_total", L2vpnv2.Standby.XconnectBrief.EncapsulationTotal))])
                self._leafs = OrderedDict([
                    ('main_total_up', YLeaf(YType.uint32, 'main-total-up')),
                    ('main_total_down', YLeaf(YType.uint32, 'main-total-down')),
                    ('main_total_unresolved', YLeaf(YType.uint32, 'main-total-unresolved')),
                    ('undefined_xc', YLeaf(YType.uint32, 'undefined-xc')),
                    ('memory_state', YLeaf(YType.enumeration, 'memory-state')),
                ])
                self.main_total_up = None
                self.main_total_down = None
                self.main_total_unresolved = None
                self.undefined_xc = None
                self.memory_state = None

                self.encapsulation_report_matrix = YList(self)
                self.encapsulation_total = YList(self)
                self._segment_path = lambda: "xconnect-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Standby.XconnectBrief, ['main_total_up', 'main_total_down', 'main_total_unresolved', 'undefined_xc', 'memory_state'], name, value)


            class EncapsulationReportMatrix(Entity):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of  		 :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                    self.yang_name = "encapsulation-report-matrix"
                    self.yang_parent_name = "xconnect-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ac1", ("ac1", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1))])
                    self._leafs = OrderedDict()

                    self.ac1 = YList(self)
                    self._segment_path = lambda: "encapsulation-report-matrix"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix, [], name, value)


                class Ac1(Entity):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of  		 :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                        self.yang_name = "ac1"
                        self.yang_parent_name = "encapsulation-report-matrix"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ac2", ("ac2", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2))])
                        self._leafs = OrderedDict()

                        self.ac2 = YList(self)
                        self._segment_path = lambda: "ac1"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1, [], name, value)


                    class Ac2(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: psn_type
                        
                        	PSN Type
                        	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount>`
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                            self.yang_name = "ac2"
                            self.yang_parent_name = "ac1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount)), ("down-count", ("down_count", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount))])
                            self._leafs = OrderedDict([
                                ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                                ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                                ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                            ])
                            self.psn_type = None
                            self.ac1_encapsulation = None
                            self.ac2_encapsulation = None

                            self.up_count = YList(self)
                            self.down_count = YList(self)
                            self.unresolved_count = YList(self)
                            self._segment_path = lambda: "ac2"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/ac1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                        class UpCount(Entity):
                            """
                            Number of active cross\-connections array \- 
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, self).__init__()

                                self.yang_name = "up-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "up-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, ['entry'], name, value)


                        class DownCount(Entity):
                            """
                            Number of non\-active cross\-connections array \-
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, self).__init__()

                                self.yang_name = "down-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "down-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, ['entry'], name, value)


                        class UnresolvedCount(Entity):
                            """
                            Number of unresolved cross\-connections array \-
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, self).__init__()

                                self.yang_name = "unresolved-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "unresolved-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, ['entry'], name, value)


            class EncapsulationTotal(Entity):
                """
                Total summary
                
                .. attribute:: psn_type
                
                	PSN Type
                	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UpCount>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.DownCount>`
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UnresolvedCount>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal, self).__init__()

                    self.yang_name = "encapsulation-total"
                    self.yang_parent_name = "xconnect-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UpCount)), ("down-count", ("down_count", L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UnresolvedCount))])
                    self._leafs = OrderedDict([
                        ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                        ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                        ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                    ])
                    self.psn_type = None
                    self.ac1_encapsulation = None
                    self.ac2_encapsulation = None

                    self.up_count = YList(self)
                    self.down_count = YList(self)
                    self.unresolved_count = YList(self)
                    self._segment_path = lambda: "encapsulation-total"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                class UpCount(Entity):
                    """
                    Number of active cross\-connections array \- 
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UpCount, self).__init__()

                        self.yang_name = "up-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "up-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UpCount, ['entry'], name, value)


                class DownCount(Entity):
                    """
                    Number of non\-active cross\-connections array \-
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.DownCount, self).__init__()

                        self.yang_name = "down-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "down-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.DownCount, ['entry'], name, value)


                class UnresolvedCount(Entity):
                    """
                    Number of unresolved cross\-connections array \-
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UnresolvedCount, self).__init__()

                        self.yang_name = "unresolved-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "unresolved-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/standby/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Standby.XconnectBrief.EncapsulationTotal.UnresolvedCount, ['entry'], name, value)


    class Active(Entity):
        """
        Active L2VPN operational data
        
        .. attribute:: discoveries
        
        	Discovery Table
        	**type**\:  :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries>`
        
        .. attribute:: flexible_xconnect_service_summary
        
        	Flexible XConnect Service summary information
        	**type**\:  :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServiceSummary>`
        
        .. attribute:: main_interfaces
        
        	Main Interface
        	**type**\:  :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces>`
        
        .. attribute:: iccp_sm
        
        	ICCP\-based Service Multi\-homing operational data
        	**type**\:  :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm>`
        
        .. attribute:: bridge_summary
        
        	Bridge Domain summary information
        	**type**\:  :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeSummary>`
        
        .. attribute:: nsr
        
        	L2VPN NSR information
        	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr>`
        
        .. attribute:: preferred_paths
        
        	Preferred path Table
        	**type**\:  :py:class:`PreferredPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PreferredPaths>`
        
        .. attribute:: global_settings
        
        	L2VPN global settings
        	**type**\:  :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GlobalSettings>`
        
        .. attribute:: pwr
        
        	Pseudowire Routing Table
        	**type**\:  :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr>`
        
        .. attribute:: xconnect_mp2mp_ce2ces
        
        	XConnect MP2MP CE2CE Table
        	**type**\:  :py:class:`XconnectMp2mpCe2ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mpCe2ces>`
        
        .. attribute:: xconnects
        
        	XConnect Table
        	**type**\:  :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects>`
        
        .. attribute:: xconnect_groups
        
        	XConnect group Table
        	**type**\:  :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectGroups>`
        
        .. attribute:: xconnect_mp2mps
        
        	XConnect MP2MP Table
        	**type**\:  :py:class:`XconnectMp2mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps>`
        
        .. attribute:: indexes
        
        	ID Manager Index Table
        	**type**\:  :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Indexes>`
        
        .. attribute:: xconnect_summary
        
        	XConnect summary information
        	**type**\:  :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectSummary>`
        
        .. attribute:: proc_fsm
        
        	L2VPN Process FSM information
        	**type**\:  :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm>`
        
        .. attribute:: mstp_ports
        
        	L2VPN MSTP Port Table
        	**type**\:  :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpPorts>`
        
        .. attribute:: generic_interface_list_details
        
        	L2VPN generic interface list Detail Table
        	**type**\:  :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails>`
        
        .. attribute:: l2vpn_resource_state
        
        	L2VPN resource state information
        	**type**\:  :py:class:`L2vpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.L2vpnResourceState>`
        
        .. attribute:: bridge_domains
        
        	Bridge Domain Information
        	**type**\:  :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains>`
        
        .. attribute:: discovery_summary
        
        	Discovery summary information
        	**type**\:  :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.DiscoverySummary>`
        
        .. attribute:: g8032
        
        	G8032 information
        	**type**\:  :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032>`
        
        .. attribute:: pseudowire_classes
        
        	List of pseudowire classes
        	**type**\:  :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses>`
        
        .. attribute:: l2vpn_collaborators
        
        	L2VPN collaborator information
        	**type**\:  :py:class:`L2vpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.L2vpnCollaborators>`
        
        .. attribute:: mvrp
        
        	MVRP
        	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp>`
        
        .. attribute:: generic_interface_lists
        
        	L2VPN generic interface list Table
        	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceLists>`
        
        .. attribute:: mstp_vlans
        
        	L2VPN MSTP VLAN Table
        	**type**\:  :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpVlans>`
        
        .. attribute:: l2vpn_pbb_bsa
        
        	L2VPN PBB Backbone Source MAC information
        	**type**\:  :py:class:`L2vpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.L2vpnPbbBsa>`
        
        .. attribute:: flexible_xconnect_services
        
        	Flexible XConnect Service Table
        	**type**\:  :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices>`
        
        .. attribute:: xconnect_brief
        
        	XConnect brief information
        	**type**\:  :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(L2vpnv2.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "l2vpnv2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("discoveries", ("discoveries", L2vpnv2.Active.Discoveries)), ("flexible-xconnect-service-summary", ("flexible_xconnect_service_summary", L2vpnv2.Active.FlexibleXconnectServiceSummary)), ("main-interfaces", ("main_interfaces", L2vpnv2.Active.MainInterfaces)), ("iccp-sm", ("iccp_sm", L2vpnv2.Active.IccpSm)), ("bridge-summary", ("bridge_summary", L2vpnv2.Active.BridgeSummary)), ("nsr", ("nsr", L2vpnv2.Active.Nsr)), ("preferred-paths", ("preferred_paths", L2vpnv2.Active.PreferredPaths)), ("global-settings", ("global_settings", L2vpnv2.Active.GlobalSettings)), ("pwr", ("pwr", L2vpnv2.Active.Pwr)), ("xconnect-mp2mp-ce2ces", ("xconnect_mp2mp_ce2ces", L2vpnv2.Active.XconnectMp2mpCe2ces)), ("xconnects", ("xconnects", L2vpnv2.Active.Xconnects)), ("xconnect-groups", ("xconnect_groups", L2vpnv2.Active.XconnectGroups)), ("xconnect-mp2mps", ("xconnect_mp2mps", L2vpnv2.Active.XconnectMp2mps)), ("indexes", ("indexes", L2vpnv2.Active.Indexes)), ("xconnect-summary", ("xconnect_summary", L2vpnv2.Active.XconnectSummary)), ("proc-fsm", ("proc_fsm", L2vpnv2.Active.ProcFsm)), ("mstp-ports", ("mstp_ports", L2vpnv2.Active.MstpPorts)), ("generic-interface-list-details", ("generic_interface_list_details", L2vpnv2.Active.GenericInterfaceListDetails)), ("l2vpn-resource-state", ("l2vpn_resource_state", L2vpnv2.Active.L2vpnResourceState)), ("bridge-domains", ("bridge_domains", L2vpnv2.Active.BridgeDomains)), ("discovery-summary", ("discovery_summary", L2vpnv2.Active.DiscoverySummary)), ("g8032", ("g8032", L2vpnv2.Active.G8032)), ("pseudowire-classes", ("pseudowire_classes", L2vpnv2.Active.PseudowireClasses)), ("l2vpn-collaborators", ("l2vpn_collaborators", L2vpnv2.Active.L2vpnCollaborators)), ("mvrp", ("mvrp", L2vpnv2.Active.Mvrp)), ("generic-interface-lists", ("generic_interface_lists", L2vpnv2.Active.GenericInterfaceLists)), ("mstp-vlans", ("mstp_vlans", L2vpnv2.Active.MstpVlans)), ("l2vpn-pbb-bsa", ("l2vpn_pbb_bsa", L2vpnv2.Active.L2vpnPbbBsa)), ("flexible-xconnect-services", ("flexible_xconnect_services", L2vpnv2.Active.FlexibleXconnectServices)), ("xconnect-brief", ("xconnect_brief", L2vpnv2.Active.XconnectBrief))])
            self._leafs = OrderedDict()

            self.discoveries = L2vpnv2.Active.Discoveries()
            self.discoveries.parent = self
            self._children_name_map["discoveries"] = "discoveries"

            self.flexible_xconnect_service_summary = L2vpnv2.Active.FlexibleXconnectServiceSummary()
            self.flexible_xconnect_service_summary.parent = self
            self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"

            self.main_interfaces = L2vpnv2.Active.MainInterfaces()
            self.main_interfaces.parent = self
            self._children_name_map["main_interfaces"] = "main-interfaces"

            self.iccp_sm = L2vpnv2.Active.IccpSm()
            self.iccp_sm.parent = self
            self._children_name_map["iccp_sm"] = "iccp-sm"

            self.bridge_summary = L2vpnv2.Active.BridgeSummary()
            self.bridge_summary.parent = self
            self._children_name_map["bridge_summary"] = "bridge-summary"

            self.nsr = L2vpnv2.Active.Nsr()
            self.nsr.parent = self
            self._children_name_map["nsr"] = "nsr"

            self.preferred_paths = L2vpnv2.Active.PreferredPaths()
            self.preferred_paths.parent = self
            self._children_name_map["preferred_paths"] = "preferred-paths"

            self.global_settings = L2vpnv2.Active.GlobalSettings()
            self.global_settings.parent = self
            self._children_name_map["global_settings"] = "global-settings"

            self.pwr = L2vpnv2.Active.Pwr()
            self.pwr.parent = self
            self._children_name_map["pwr"] = "pwr"

            self.xconnect_mp2mp_ce2ces = L2vpnv2.Active.XconnectMp2mpCe2ces()
            self.xconnect_mp2mp_ce2ces.parent = self
            self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"

            self.xconnects = L2vpnv2.Active.Xconnects()
            self.xconnects.parent = self
            self._children_name_map["xconnects"] = "xconnects"

            self.xconnect_groups = L2vpnv2.Active.XconnectGroups()
            self.xconnect_groups.parent = self
            self._children_name_map["xconnect_groups"] = "xconnect-groups"

            self.xconnect_mp2mps = L2vpnv2.Active.XconnectMp2mps()
            self.xconnect_mp2mps.parent = self
            self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"

            self.indexes = L2vpnv2.Active.Indexes()
            self.indexes.parent = self
            self._children_name_map["indexes"] = "indexes"

            self.xconnect_summary = L2vpnv2.Active.XconnectSummary()
            self.xconnect_summary.parent = self
            self._children_name_map["xconnect_summary"] = "xconnect-summary"

            self.proc_fsm = L2vpnv2.Active.ProcFsm()
            self.proc_fsm.parent = self
            self._children_name_map["proc_fsm"] = "proc-fsm"

            self.mstp_ports = L2vpnv2.Active.MstpPorts()
            self.mstp_ports.parent = self
            self._children_name_map["mstp_ports"] = "mstp-ports"

            self.generic_interface_list_details = L2vpnv2.Active.GenericInterfaceListDetails()
            self.generic_interface_list_details.parent = self
            self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"

            self.l2vpn_resource_state = L2vpnv2.Active.L2vpnResourceState()
            self.l2vpn_resource_state.parent = self
            self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"

            self.bridge_domains = L2vpnv2.Active.BridgeDomains()
            self.bridge_domains.parent = self
            self._children_name_map["bridge_domains"] = "bridge-domains"

            self.discovery_summary = L2vpnv2.Active.DiscoverySummary()
            self.discovery_summary.parent = self
            self._children_name_map["discovery_summary"] = "discovery-summary"

            self.g8032 = L2vpnv2.Active.G8032()
            self.g8032.parent = self
            self._children_name_map["g8032"] = "g8032"

            self.pseudowire_classes = L2vpnv2.Active.PseudowireClasses()
            self.pseudowire_classes.parent = self
            self._children_name_map["pseudowire_classes"] = "pseudowire-classes"

            self.l2vpn_collaborators = L2vpnv2.Active.L2vpnCollaborators()
            self.l2vpn_collaborators.parent = self
            self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"

            self.mvrp = L2vpnv2.Active.Mvrp()
            self.mvrp.parent = self
            self._children_name_map["mvrp"] = "mvrp"

            self.generic_interface_lists = L2vpnv2.Active.GenericInterfaceLists()
            self.generic_interface_lists.parent = self
            self._children_name_map["generic_interface_lists"] = "generic-interface-lists"

            self.mstp_vlans = L2vpnv2.Active.MstpVlans()
            self.mstp_vlans.parent = self
            self._children_name_map["mstp_vlans"] = "mstp-vlans"

            self.l2vpn_pbb_bsa = L2vpnv2.Active.L2vpnPbbBsa()
            self.l2vpn_pbb_bsa.parent = self
            self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"

            self.flexible_xconnect_services = L2vpnv2.Active.FlexibleXconnectServices()
            self.flexible_xconnect_services.parent = self
            self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"

            self.xconnect_brief = L2vpnv2.Active.XconnectBrief()
            self.xconnect_brief.parent = self
            self._children_name_map["xconnect_brief"] = "xconnect-brief"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(L2vpnv2.Active, [], name, value)


        class Discoveries(Entity):
            """
            Discovery Table
            
            .. attribute:: discovery
            
            	VPLS Discovery information
            	**type**\: list of  		 :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Discoveries, self).__init__()

                self.yang_name = "discoveries"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Active.Discoveries.Discovery))])
                self._leafs = OrderedDict()

                self.discovery = YList(self)
                self._segment_path = lambda: "discoveries"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Discoveries, [], name, value)


            class Discovery(Entity):
                """
                VPLS Discovery information
                
                .. attribute:: service_name
                
                	Service type
                	**type**\:  :py:class:`L2vpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnService>`
                
                .. attribute:: group_name
                
                	Group Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: vpn_name
                
                	VPN Name
                	**type**\: str
                
                	**length:** 1..27
                
                .. attribute:: signalling_info
                
                	Info about signalling protocol
                	**type**\:  :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo>`
                
                .. attribute:: mtu_mismatch_ignore
                
                	Ignore MTU Mismatch
                	**type**\: bool
                
                .. attribute:: number_vpn
                
                	Number of vpns
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	VPN id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: service_name_xr
                
                	Service Type
                	**type**\: str
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: vpn_name_xr
                
                	VPN instance name
                	**type**\: str
                
                .. attribute:: is_service_connected
                
                	Is the service connected
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Discoveries.Discovery, self).__init__()

                    self.yang_name = "discovery"
                    self.yang_parent_name = "discoveries"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("signalling-info", ("signalling_info", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo))])
                    self._leafs = OrderedDict([
                        ('service_name', YLeaf(YType.enumeration, 'service-name')),
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('vpn_name', YLeaf(YType.str, 'vpn-name')),
                        ('mtu_mismatch_ignore', YLeaf(YType.boolean, 'mtu-mismatch-ignore')),
                        ('number_vpn', YLeaf(YType.uint32, 'number-vpn')),
                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                        ('service_name_xr', YLeaf(YType.str, 'service-name-xr')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('vpn_name_xr', YLeaf(YType.str, 'vpn-name-xr')),
                        ('is_service_connected', YLeaf(YType.boolean, 'is-service-connected')),
                    ])
                    self.service_name = None
                    self.group_name = None
                    self.vpn_name = None
                    self.mtu_mismatch_ignore = None
                    self.number_vpn = None
                    self.vpn_id = None
                    self.service_name_xr = None
                    self.group_name_xr = None
                    self.vpn_name_xr = None
                    self.is_service_connected = None

                    self.signalling_info = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo()
                    self.signalling_info.parent = self
                    self._children_name_map["signalling_info"] = "signalling-info"
                    self._segment_path = lambda: "discovery"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery, ['service_name', 'group_name', 'vpn_name', 'mtu_mismatch_ignore', 'number_vpn', 'vpn_id', 'service_name_xr', 'group_name_xr', 'vpn_name_xr', 'is_service_connected'], name, value)


                class SignallingInfo(Entity):
                    """
                    Info about signalling protocol
                    
                    .. attribute:: bgp_sig_info
                    
                    	bgp sig info
                    	**type**\:  :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                    
                    .. attribute:: ldp_sig_info
                    
                    	ldp sig info
                    	**type**\:  :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                    
                    .. attribute:: ad_signalling_method
                    
                    	ADSignallingMethod
                    	**type**\:  :py:class:`L2vpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdSigMethod>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo, self).__init__()

                        self.yang_name = "signalling-info"
                        self.yang_parent_name = "discovery"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bgp-sig-info", ("bgp_sig_info", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo)), ("ldp-sig-info", ("ldp_sig_info", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo))])
                        self._leafs = OrderedDict([
                            ('ad_signalling_method', YLeaf(YType.enumeration, 'ad-signalling-method')),
                        ])
                        self.ad_signalling_method = None

                        self.bgp_sig_info = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                        self.bgp_sig_info.parent = self
                        self._children_name_map["bgp_sig_info"] = "bgp-sig-info"

                        self.ldp_sig_info = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                        self.ldp_sig_info.parent = self
                        self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                        self._segment_path = lambda: "signalling-info"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo, ['ad_signalling_method'], name, value)


                    class BgpSigInfo(Entity):
                        """
                        bgp sig info
                        
                        .. attribute:: number_edges
                        
                        	Number of Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: edge
                        
                        	List of edge ids
                        	**type**\: list of  		 :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                        
                        .. attribute:: redge
                        
                        	List of edge ids
                        	**type**\: list of  		 :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                            self.yang_name = "bgp-sig-info"
                            self.yang_parent_name = "signalling-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("edge", ("edge", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge)), ("redge", ("redge", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge))])
                            self._leafs = OrderedDict([
                                ('number_edges', YLeaf(YType.uint32, 'number-edges')),
                                ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                            ])
                            self.number_edges = None
                            self.number_remote_edges = None

                            self.edge = YList(self)
                            self.redge = YList(self)
                            self._segment_path = lambda: "bgp-sig-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo, ['number_edges', 'number_remote_edges'], name, value)


                        class Edge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                self.yang_name = "edge"
                                self.yang_parent_name = "bgp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock))])
                                self._leafs = OrderedDict([
                                    ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                    ('label_count', YLeaf(YType.uint32, 'label-count')),
                                ])
                                self.edge_id = None
                                self.label_count = None

                                self.label_block = YList(self)
                                self._segment_path = lambda: "edge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, ['edge_id', 'label_count'], name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "edge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector))])
                                    self._leafs = OrderedDict([
                                        ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                        ('label_base', YLeaf(YType.uint32, 'label-base')),
                                        ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                        ('block_size', YLeaf(YType.uint32, 'block-size')),
                                        ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                    ])
                                    self.label_time_created = None
                                    self.label_base = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.label_error = None

                                    self.status_vector = YList(self)
                                    self._segment_path = lambda: "label-block"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/edge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                class StatusVector(Entity):
                                    """
                                    Status Vector
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, self).__init__()

                                        self.yang_name = "status-vector"
                                        self.yang_parent_name = "label-block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint8, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "status-vector"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/edge/label-block/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, ['entry'], name, value)


                        class Redge(Entity):
                            """
                            List of edge ids
                            
                            .. attribute:: edge_id
                            
                            	Edge ids
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_count
                            
                            	Number of label blocks
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: label_block
                            
                            	List of label blocks
                            	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                self.yang_name = "redge"
                                self.yang_parent_name = "bgp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock))])
                                self._leafs = OrderedDict([
                                    ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                    ('label_count', YLeaf(YType.uint32, 'label-count')),
                                ])
                                self.edge_id = None
                                self.label_count = None

                                self.label_block = YList(self)
                                self._segment_path = lambda: "redge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, ['edge_id', 'label_count'], name, value)


                            class LabelBlock(Entity):
                                """
                                List of label blocks
                                
                                .. attribute:: label_time_created
                                
                                	Creation time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_base
                                
                                	Label Base
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_offset
                                
                                	Block offset
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: block_size
                                
                                	Block size
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_edge_id
                                
                                	Local edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: next_hop
                                
                                	 Peer id
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: label_error
                                
                                	Label Error
                                	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                
                                .. attribute:: status_vector
                                
                                	Status Vector
                                	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                    self.yang_name = "label-block"
                                    self.yang_parent_name = "redge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector))])
                                    self._leafs = OrderedDict([
                                        ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                        ('label_base', YLeaf(YType.uint32, 'label-base')),
                                        ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                        ('block_size', YLeaf(YType.uint32, 'block-size')),
                                        ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                        ('next_hop', YLeaf(YType.str, 'next-hop')),
                                        ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                    ])
                                    self.label_time_created = None
                                    self.label_base = None
                                    self.block_offset = None
                                    self.block_size = None
                                    self.local_edge_id = None
                                    self.next_hop = None
                                    self.label_error = None

                                    self.status_vector = YList(self)
                                    self._segment_path = lambda: "label-block"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/redge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                class StatusVector(Entity):
                                    """
                                    Status Vector
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, self).__init__()

                                        self.yang_name = "status-vector"
                                        self.yang_parent_name = "label-block"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint8, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "status-vector"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/bgp-sig-info/redge/label-block/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, ['entry'], name, value)


                    class LdpSigInfo(Entity):
                        """
                        ldp sig info
                        
                        .. attribute:: local_vpls_id
                        
                        	Local VPLS\-ID
                        	**type**\:  :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                        
                        .. attribute:: local_l2_router_id
                        
                        	Local L2VPN Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: number_remote_edges
                        
                        	Number of remote Edges
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: remote_nlri
                        
                        	List of NLRIs
                        	**type**\: list of  		 :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                            self.yang_name = "ldp-sig-info"
                            self.yang_parent_name = "signalling-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("local-vpls-id", ("local_vpls_id", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId)), ("remote-nlri", ("remote_nlri", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri))])
                            self._leafs = OrderedDict([
                                ('local_l2_router_id', YLeaf(YType.str, 'local-l2-router-id')),
                                ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                            ])
                            self.local_l2_router_id = None
                            self.number_remote_edges = None

                            self.local_vpls_id = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                            self.local_vpls_id.parent = self
                            self._children_name_map["local_vpls_id"] = "local-vpls-id"

                            self.remote_nlri = YList(self)
                            self._segment_path = lambda: "ldp-sig-info"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo, ['local_l2_router_id', 'number_remote_edges'], name, value)


                        class LocalVplsId(Entity):
                            """
                            Local VPLS\-ID
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                            
                            .. attribute:: vpls_id_type
                            
                            	VPLS ID TYPE
                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                self.yang_name = "local-vpls-id"
                                self.yang_parent_name = "ldp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr))])
                                self._leafs = OrderedDict([
                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                ])
                                self.vpls_id_type = None

                                self.auto = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"

                                self.two_byte_as = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.v4_addr = L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._segment_path = lambda: "local-vpls-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, ['vpls_id_type'], name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: asn
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vpn_id
                                
                                	VPN ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ])
                                    self.asn = None
                                    self.vpn_id = None
                                    self._segment_path = lambda: "auto"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, ['asn', 'vpn_id'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "local-vpls-id"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/local-vpls-id/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class RemoteNlri(Entity):
                            """
                            List of NLRIs
                            
                            .. attribute:: nlri_time_created
                            
                            	NLRI creation time
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_address
                            
                            	Local BGP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_address
                            
                            	Remote BGP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_l2_router_id
                            
                            	Remote L2VPN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                self.yang_name = "remote-nlri"
                                self.yang_parent_name = "ldp-sig-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('nlri_time_created', YLeaf(YType.uint32, 'nlri-time-created')),
                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                    ('remote_l2_router_id', YLeaf(YType.str, 'remote-l2-router-id')),
                                ])
                                self.nlri_time_created = None
                                self.local_address = None
                                self.remote_address = None
                                self.remote_l2_router_id = None
                                self._segment_path = lambda: "remote-nlri"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/discoveries/discovery/signalling-info/ldp-sig-info/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, ['nlri_time_created', 'local_address', 'remote_address', 'remote_l2_router_id'], name, value)


        class FlexibleXconnectServiceSummary(Entity):
            """
            Flexible XConnect Service summary information
            
            .. attribute:: number_fxc
            
            	Number of flexible xconnect services
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_up
            
            	Number of flexible xconnect services whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_fxc_down
            
            	Number of flexible xconnect services whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.FlexibleXconnectServiceSummary, self).__init__()

                self.yang_name = "flexible-xconnect-service-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_fxc', YLeaf(YType.uint32, 'number-fxc')),
                    ('number_fxc_up', YLeaf(YType.uint32, 'number-fxc-up')),
                    ('number_fxc_down', YLeaf(YType.uint32, 'number-fxc-down')),
                ])
                self.number_fxc = None
                self.number_fxc_up = None
                self.number_fxc_down = None
                self._segment_path = lambda: "flexible-xconnect-service-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServiceSummary, ['number_fxc', 'number_fxc_up', 'number_fxc_down'], name, value)


        class MainInterfaces(Entity):
            """
            Main Interface
            
            .. attribute:: main_interface
            
            	Main Interface Table
            	**type**\: list of  		 :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.MainInterfaces, self).__init__()

                self.yang_name = "main-interfaces"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("main-interface", ("main_interface", L2vpnv2.Active.MainInterfaces.MainInterface))])
                self._leafs = OrderedDict()

                self.main_interface = YList(self)
                self._segment_path = lambda: "main-interfaces"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.MainInterfaces, [], name, value)


            class MainInterface(Entity):
                """
                Main Interface Table
                
                .. attribute:: interface_name  (key)
                
                	Main interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: main_interface_instances
                
                	Main Interface Instance table
                	**type**\:  :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances>`
                
                .. attribute:: main_interface_info
                
                	Main Interface info
                	**type**\:  :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.MainInterfaces.MainInterface, self).__init__()

                    self.yang_name = "main-interface"
                    self.yang_parent_name = "main-interfaces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_name']
                    self._child_classes = OrderedDict([("main-interface-instances", ("main_interface_instances", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances)), ("main-interface-info", ("main_interface_info", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo))])
                    self._leafs = OrderedDict([
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                    ])
                    self.interface_name = None

                    self.main_interface_instances = L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances()
                    self.main_interface_instances.parent = self
                    self._children_name_map["main_interface_instances"] = "main-interface-instances"

                    self.main_interface_info = L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo()
                    self.main_interface_info.parent = self
                    self._children_name_map["main_interface_info"] = "main-interface-info"
                    self._segment_path = lambda: "main-interface" + "[interface-name='" + str(self.interface_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/main-interfaces/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface, ['interface_name'], name, value)


                class MainInterfaceInstances(Entity):
                    """
                    Main Interface Instance table
                    
                    .. attribute:: main_interface_instance
                    
                    	Main Interface Instance
                    	**type**\: list of  		 :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                        self.yang_name = "main-interface-instances"
                        self.yang_parent_name = "main-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("main-interface-instance", ("main_interface_instance", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance))])
                        self._leafs = OrderedDict()

                        self.main_interface_instance = YList(self)
                        self._segment_path = lambda: "main-interface-instances"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances, [], name, value)


                    class MainInterfaceInstance(Entity):
                        """
                        Main Interface Instance
                        
                        .. attribute:: instance  (key)
                        
                        	Instance
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: main_interface_instance_info
                        
                        	Main Interface Instance info
                        	**type**\:  :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                        
                        .. attribute:: main_interface_instance_bridge_ports
                        
                        	Main Interface Instance Bridge Port table
                        	**type**\:  :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                            self.yang_name = "main-interface-instance"
                            self.yang_parent_name = "main-interface-instances"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['instance']
                            self._child_classes = OrderedDict([("main-interface-instance-info", ("main_interface_instance_info", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo)), ("main-interface-instance-bridge-ports", ("main_interface_instance_bridge_ports", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts))])
                            self._leafs = OrderedDict([
                                ('instance', YLeaf(YType.uint32, 'instance')),
                            ])
                            self.instance = None

                            self.main_interface_instance_info = L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                            self.main_interface_instance_info.parent = self
                            self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"

                            self.main_interface_instance_bridge_ports = L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                            self.main_interface_instance_bridge_ports.parent = self
                            self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                            self._segment_path = lambda: "main-interface-instance" + "[instance='" + str(self.instance) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, ['instance'], name, value)


                        class MainInterfaceInstanceInfo(Entity):
                            """
                            Main Interface Instance info
                            
                            .. attribute:: configured_instance
                            
                            	Configured Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: flush_count
                            
                            	Flush count 
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: interface_count
                            
                            	Interface count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_flags
                            
                            	Instance Flags
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_id
                            
                            	Instance ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: instance_state
                            
                            	Instance State
                            	**type**\:  :py:class:`L2vpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfInstanceState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                self.yang_name = "main-interface-instance-info"
                                self.yang_parent_name = "main-interface-instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('configured_instance', YLeaf(YType.uint32, 'configured-instance')),
                                    ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                                    ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                                    ('instance_flags', YLeaf(YType.uint32, 'instance-flags')),
                                    ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                    ('instance_state', YLeaf(YType.enumeration, 'instance-state')),
                                ])
                                self.configured_instance = None
                                self.flush_count = None
                                self.interface_count = None
                                self.instance_flags = None
                                self.instance_id = None
                                self.instance_state = None
                                self._segment_path = lambda: "main-interface-instance-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, ['configured_instance', 'flush_count', 'interface_count', 'instance_flags', 'instance_id', 'instance_state'], name, value)


                        class MainInterfaceInstanceBridgePorts(Entity):
                            """
                            Main Interface Instance Bridge Port table
                            
                            .. attribute:: main_interface_instance_bridge_port
                            
                            	Main Interface Bridge Port info
                            	**type**\: list of  		 :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                self.yang_name = "main-interface-instance-bridge-ports"
                                self.yang_parent_name = "main-interface-instance"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("main-interface-instance-bridge-port", ("main_interface_instance_bridge_port", L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort))])
                                self._leafs = OrderedDict()

                                self.main_interface_instance_bridge_port = YList(self)
                                self._segment_path = lambda: "main-interface-instance-bridge-ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, [], name, value)


                            class MainInterfaceInstanceBridgePort(Entity):
                                """
                                Main Interface Bridge Port info
                                
                                .. attribute:: bridge_port  (key)
                                
                                	Bridge Port
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: bridge_port_xr
                                
                                	Bridge port ifhandle
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-port"
                                    self.yang_parent_name = "main-interface-instance-bridge-ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['bridge_port']
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bridge_port', YLeaf(YType.str, 'bridge-port')),
                                        ('bridge_port_xr', YLeaf(YType.str, 'bridge-port-xr')),
                                        ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                    ])
                                    self.bridge_port = None
                                    self.bridge_port_xr = None
                                    self.instance_id = None
                                    self._segment_path = lambda: "main-interface-instance-bridge-port" + "[bridge-port='" + str(self.bridge_port) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, ['bridge_port', 'bridge_port_xr', 'instance_id'], name, value)


                class MainInterfaceInfo(Entity):
                    """
                    Main Interface info
                    
                    .. attribute:: main_interface_handle
                    
                    	Main Interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\:  :py:class:`L2vpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfProtectected>`
                    
                    .. attribute:: interface_count
                    
                    	Sub Interface Count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                        self.yang_name = "main-interface-info"
                        self.yang_parent_name = "main-interface"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('main_interface_handle', YLeaf(YType.str, 'main-interface-handle')),
                            ('protected', YLeaf(YType.enumeration, 'protected')),
                            ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                        ])
                        self.main_interface_handle = None
                        self.protected = None
                        self.interface_count = None
                        self._segment_path = lambda: "main-interface-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.MainInterfaces.MainInterface.MainInterfaceInfo, ['main_interface_handle', 'protected', 'interface_count'], name, value)


        class IccpSm(Entity):
            """
            ICCP\-based Service Multi\-homing operational data
            
            .. attribute:: iccp_sm_summary
            
            	ICCP\-based Service Multi\-homing database summary
            	**type**\:  :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpSmSummary>`
            
            .. attribute:: iccp_groups
            
            	ICCP Group Table
            	**type**\:  :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.IccpSm, self).__init__()

                self.yang_name = "iccp-sm"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("iccp-sm-summary", ("iccp_sm_summary", L2vpnv2.Active.IccpSm.IccpSmSummary)), ("iccp-groups", ("iccp_groups", L2vpnv2.Active.IccpSm.IccpGroups))])
                self._leafs = OrderedDict()

                self.iccp_sm_summary = L2vpnv2.Active.IccpSm.IccpSmSummary()
                self.iccp_sm_summary.parent = self
                self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"

                self.iccp_groups = L2vpnv2.Active.IccpSm.IccpGroups()
                self.iccp_groups.parent = self
                self._children_name_map["iccp_groups"] = "iccp-groups"
                self._segment_path = lambda: "iccp-sm"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.IccpSm, [], name, value)


            class IccpSmSummary(Entity):
                """
                ICCP\-based Service Multi\-homing database
                summary
                
                .. attribute:: groups
                
                	Total Number of Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_groups
                
                	Number of Unresolved Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: provisioned_groups
                
                	Number of Provisioned Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: connecting_groups
                
                	Number of Connecting Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: connected_groups
                
                	Number of Connected Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronizing_groups
                
                	Number of Synchronizing Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: synchronized_groups
                
                	Number of Synchronized Groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: ports
                
                	Total Number of Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: operational_ports
                
                	Number of Operational Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: failed_ports
                
                	Number of Failed Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unknown_ports
                
                	Number of Unknown Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unconfigured_ports
                
                	Number of Unconfigured Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unsynchronized_ports
                
                	Number of Unsynchronized Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: reverting_ports
                
                	Number of Reverting Ports
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.IccpSm.IccpSmSummary, self).__init__()

                    self.yang_name = "iccp-sm-summary"
                    self.yang_parent_name = "iccp-sm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('groups', YLeaf(YType.uint32, 'groups')),
                        ('unresolved_groups', YLeaf(YType.uint32, 'unresolved-groups')),
                        ('provisioned_groups', YLeaf(YType.uint32, 'provisioned-groups')),
                        ('connecting_groups', YLeaf(YType.uint32, 'connecting-groups')),
                        ('connected_groups', YLeaf(YType.uint32, 'connected-groups')),
                        ('synchronizing_groups', YLeaf(YType.uint32, 'synchronizing-groups')),
                        ('synchronized_groups', YLeaf(YType.uint32, 'synchronized-groups')),
                        ('ports', YLeaf(YType.uint32, 'ports')),
                        ('operational_ports', YLeaf(YType.uint32, 'operational-ports')),
                        ('failed_ports', YLeaf(YType.uint32, 'failed-ports')),
                        ('unknown_ports', YLeaf(YType.uint32, 'unknown-ports')),
                        ('unconfigured_ports', YLeaf(YType.uint32, 'unconfigured-ports')),
                        ('unsynchronized_ports', YLeaf(YType.uint32, 'unsynchronized-ports')),
                        ('reverting_ports', YLeaf(YType.uint32, 'reverting-ports')),
                    ])
                    self.groups = None
                    self.unresolved_groups = None
                    self.provisioned_groups = None
                    self.connecting_groups = None
                    self.connected_groups = None
                    self.synchronizing_groups = None
                    self.synchronized_groups = None
                    self.ports = None
                    self.operational_ports = None
                    self.failed_ports = None
                    self.unknown_ports = None
                    self.unconfigured_ports = None
                    self.unsynchronized_ports = None
                    self.reverting_ports = None
                    self._segment_path = lambda: "iccp-sm-summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpSmSummary, ['groups', 'unresolved_groups', 'provisioned_groups', 'connecting_groups', 'connected_groups', 'synchronizing_groups', 'synchronized_groups', 'ports', 'operational_ports', 'failed_ports', 'unknown_ports', 'unconfigured_ports', 'unsynchronized_ports', 'reverting_ports'], name, value)


            class IccpGroups(Entity):
                """
                ICCP Group Table
                
                .. attribute:: iccp_group
                
                	ICCP Group
                	**type**\: list of  		 :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.IccpSm.IccpGroups, self).__init__()

                    self.yang_name = "iccp-groups"
                    self.yang_parent_name = "iccp-sm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iccp-group", ("iccp_group", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup))])
                    self._leafs = OrderedDict()

                    self.iccp_group = YList(self)
                    self._segment_path = lambda: "iccp-groups"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups, [], name, value)


                class IccpGroup(Entity):
                    """
                    ICCP Group
                    
                    .. attribute:: group_id  (key)
                    
                    	Group ID
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: iccp_group_info
                    
                    	ICCP Group Information
                    	**type**\:  :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                    
                    .. attribute:: iccp_ports
                    
                    	ICCP Port Table
                    	**type**\:  :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup, self).__init__()

                        self.yang_name = "iccp-group"
                        self.yang_parent_name = "iccp-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['group_id']
                        self._child_classes = OrderedDict([("iccp-group-info", ("iccp_group_info", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo)), ("iccp-ports", ("iccp_ports", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts))])
                        self._leafs = OrderedDict([
                            ('group_id', YLeaf(YType.uint32, 'group-id')),
                        ])
                        self.group_id = None

                        self.iccp_group_info = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                        self.iccp_group_info.parent = self
                        self._children_name_map["iccp_group_info"] = "iccp-group-info"

                        self.iccp_ports = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                        self.iccp_ports.parent = self
                        self._children_name_map["iccp_ports"] = "iccp-ports"
                        self._segment_path = lambda: "iccp-group" + "[group-id='" + str(self.group_id) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/iccp-sm/iccp-groups/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup, ['group_id'], name, value)


                    class IccpGroupInfo(Entity):
                        """
                        ICCP Group Information
                        
                        .. attribute:: group_id
                        
                        	Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_node_id
                        
                        	Local Node ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: remote_node_id
                        
                        	Remote Node ID
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                        
                        .. attribute:: iccp_transport_up
                        
                        	ICCP Transport Up
                        	**type**\: bool
                        
                        .. attribute:: iccp_member_up
                        
                        	ICCP Member Up
                        	**type**\: bool
                        
                        .. attribute:: ports
                        
                        	List of ports in the group
                        	**type**\: list of  		 :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                            self.yang_name = "iccp-group-info"
                            self.yang_parent_name = "iccp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ports", ("ports", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports))])
                            self._leafs = OrderedDict([
                                ('group_id', YLeaf(YType.uint32, 'group-id')),
                                ('local_node_id', YLeaf(YType.uint8, 'local-node-id')),
                                ('remote_node_id', YLeaf(YType.uint8, 'remote-node-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('iccp_transport_up', YLeaf(YType.boolean, 'iccp-transport-up')),
                                ('iccp_member_up', YLeaf(YType.boolean, 'iccp-member-up')),
                            ])
                            self.group_id = None
                            self.local_node_id = None
                            self.remote_node_id = None
                            self.state = None
                            self.iccp_transport_up = None
                            self.iccp_member_up = None

                            self.ports = YList(self)
                            self._segment_path = lambda: "iccp-group-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, ['group_id', 'local_node_id', 'remote_node_id', 'state', 'iccp_transport_up', 'iccp_member_up'], name, value)


                        class Ports(Entity):
                            """
                            List of ports in the group
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                self.yang_name = "ports"
                                self.yang_parent_name = "iccp-group-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                ])
                                self.interface_name = None
                                self.mac_flush_tcn = None

                                self.local_port = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"

                                self.remote_port = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._segment_path = lambda: "ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, ['interface_name', 'mac_flush_tcn'], name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "local-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "remote-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                    class IccpPorts(Entity):
                        """
                        ICCP Port Table
                        
                        .. attribute:: iccp_port
                        
                        	ICCP Port
                        	**type**\: list of  		 :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                            self.yang_name = "iccp-ports"
                            self.yang_parent_name = "iccp-group"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("iccp-port", ("iccp_port", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort))])
                            self._leafs = OrderedDict()

                            self.iccp_port = YList(self)
                            self._segment_path = lambda: "iccp-ports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts, [], name, value)


                        class IccpPort(Entity):
                            """
                            ICCP Port
                            
                            .. attribute:: interface  (key)
                            
                            	Interface
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: local_port
                            
                            	Local port info
                            	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                            
                            .. attribute:: remote_port
                            
                            	Remote port info
                            	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: mac_flush_tcn
                            
                            	Is MAC flush through STP\-TCN?
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                self.yang_name = "iccp-port"
                                self.yang_parent_name = "iccp-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface']
                                self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort))])
                                self._leafs = OrderedDict([
                                    ('interface', YLeaf(YType.str, 'interface')),
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                ])
                                self.interface = None
                                self.interface_name = None
                                self.mac_flush_tcn = None

                                self.local_port = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                self.local_port.parent = self
                                self._children_name_map["local_port"] = "local-port"

                                self.remote_port = L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                self.remote_port.parent = self
                                self._children_name_map["remote_port"] = "remote-port"
                                self._segment_path = lambda: "iccp-port" + "[interface='" + str(self.interface) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, ['interface', 'interface_name', 'mac_flush_tcn'], name, value)


                            class LocalPort(Entity):
                                """
                                Local port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                    self.yang_name = "local-port"
                                    self.yang_parent_name = "iccp-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "local-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                            class RemotePort(Entity):
                                """
                                Remote port info
                                
                                .. attribute:: port_state
                                
                                	Port state
                                	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                
                                .. attribute:: port_fail_code
                                
                                	Port fail code
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: fsm_state
                                
                                	FSM state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_state
                                
                                	VLAN state
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: vlan_vector
                                
                                	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                	**type**\: str
                                
                                	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                
                                .. attribute:: reversion_time
                                
                                	Reversion Time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: reversion_time_remaining
                                
                                	Reversion Time Remaining
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                    self.yang_name = "remote-port"
                                    self.yang_parent_name = "iccp-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                        ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                        ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                        ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                        ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                        ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                        ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                    ])
                                    self.port_state = None
                                    self.port_fail_code = None
                                    self.fsm_state = None
                                    self.vlan_state = None
                                    self.vlan_vector = None
                                    self.reversion_time = None
                                    self.reversion_time_remaining = None
                                    self._segment_path = lambda: "remote-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


        class BridgeSummary(Entity):
            """
            Bridge Domain summary information
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains
            
            	Number of bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_up
            
            	Number of bridge\-domains up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_bridge_domains_shut
            
            	Number of bridge\-domains admin disabled
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_default_bridge_doamins
            
            	Number of default bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_edge
            
            	Number of PBB Edge
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pbb_core
            
            	Number of PBB Core
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp
            
            	Number of P2MPs
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_up
            
            	Number of P2MPs whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p2mp_down
            
            	Number of P2MPs whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs
            
            	Number of attachment circuits
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_up
            
            	Number of attachment circuits whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_a_cs_down
            
            	Number of attachment circuits whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_pseudowires
            
            	Number of pseudowires
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_up
            
            	Number of pseudowires whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_p_ws_down
            
            	Number of pseudowires whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_pseudowires
            
            	Number of pseudowires whose state is standby
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is
            
            	Number of VNIs
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_up
            
            	Number of VNIs up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_down
            
            	Number of VNIs down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: num_vn_is_unresolved
            
            	Number of VNIs unresolved
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_bridges
            
            	Number of partially programmed bridge\-domains
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_pseudowires
            
            	Number of partially programmed pseudowires
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_a_cs
            
            	Number of partially programmed attachment circuits
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.BridgeSummary, self).__init__()

                self.yang_name = "bridge-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                    ('number_bridge_domains', YLeaf(YType.uint32, 'number-bridge-domains')),
                    ('number_bridge_domains_up', YLeaf(YType.uint32, 'number-bridge-domains-up')),
                    ('number_bridge_domains_shut', YLeaf(YType.uint32, 'number-bridge-domains-shut')),
                    ('number_default_bridge_doamins', YLeaf(YType.uint32, 'number-default-bridge-doamins')),
                    ('number_pbb_edge', YLeaf(YType.uint32, 'number-pbb-edge')),
                    ('number_pbb_core', YLeaf(YType.uint32, 'number-pbb-core')),
                    ('number_p2mp', YLeaf(YType.uint32, 'number-p2mp')),
                    ('number_p2mp_up', YLeaf(YType.uint32, 'number-p2mp-up')),
                    ('number_p2mp_down', YLeaf(YType.uint32, 'number-p2mp-down')),
                    ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                    ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                    ('number_a_cs_down', YLeaf(YType.uint32, 'number-a-cs-down')),
                    ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                    ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                    ('number_p_ws_down', YLeaf(YType.uint32, 'number-p-ws-down')),
                    ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                    ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                    ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                    ('num_vn_is_down', YLeaf(YType.uint32, 'num-vn-is-down')),
                    ('num_vn_is_unresolved', YLeaf(YType.uint32, 'num-vn-is-unresolved')),
                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                    ('partially_programmed_bridges', YLeaf(YType.uint32, 'partially-programmed-bridges')),
                    ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                    ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                ])
                self.number_groups = None
                self.number_bridge_domains = None
                self.number_bridge_domains_up = None
                self.number_bridge_domains_shut = None
                self.number_default_bridge_doamins = None
                self.number_pbb_edge = None
                self.number_pbb_core = None
                self.number_p2mp = None
                self.number_p2mp_up = None
                self.number_p2mp_down = None
                self.number_a_cs = None
                self.number_a_cs_up = None
                self.number_a_cs_down = None
                self.number_pseudowires = None
                self.number_p_ws_up = None
                self.number_p_ws_down = None
                self.standby_pseudowires = None
                self.num_vn_is = None
                self.num_vn_is_up = None
                self.num_vn_is_down = None
                self.num_vn_is_unresolved = None
                self.out_of_memory_state = None
                self.partially_programmed_bridges = None
                self.partially_programmed_pseudowires = None
                self.partially_programmed_a_cs = None
                self._segment_path = lambda: "bridge-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.BridgeSummary, ['number_groups', 'number_bridge_domains', 'number_bridge_domains_up', 'number_bridge_domains_shut', 'number_default_bridge_doamins', 'number_pbb_edge', 'number_pbb_core', 'number_p2mp', 'number_p2mp_up', 'number_p2mp_down', 'number_a_cs', 'number_a_cs_up', 'number_a_cs_down', 'number_pseudowires', 'number_p_ws_up', 'number_p_ws_down', 'standby_pseudowires', 'num_vn_is', 'num_vn_is_up', 'num_vn_is_down', 'num_vn_is_unresolved', 'out_of_memory_state', 'partially_programmed_bridges', 'partially_programmed_pseudowires', 'partially_programmed_a_cs'], name, value)


        class Nsr(Entity):
            """
            L2VPN NSR information
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.FailoverStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.NsrStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.IssuStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\: bool
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.StateTransitionTime>`
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.XidInfo>`
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.ReportCard>`
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.EventHistory>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Nsr, self).__init__()

                self.yang_name = "nsr"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Active.Nsr.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Active.Nsr.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Active.Nsr.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Active.Nsr.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Active.Nsr.XidInfo)), ("report-card", ("report_card", L2vpnv2.Active.Nsr.ReportCard)), ("event-history", ("event_history", L2vpnv2.Active.Nsr.EventHistory))])
                self._leafs = OrderedDict([
                    ('process_role', YLeaf(YType.uint8, 'process-role')),
                    ('process_state', YLeaf(YType.uint8, 'process-state')),
                    ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                    ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                ])
                self.process_role = None
                self.process_state = None
                self.sync_flags = None
                self.sw_install_in_progress = None

                self.failover_status = L2vpnv2.Active.Nsr.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"

                self.nsr_status = L2vpnv2.Active.Nsr.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"

                self.issu_status = L2vpnv2.Active.Nsr.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"

                self.state_transition_time = YList(self)
                self.xid_info = YList(self)
                self.report_card = YList(self)
                self.event_history = YList(self)
                self._segment_path = lambda: "nsr"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Nsr, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: master_time
                
                	Master time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                        ('start_time', YLeaf(YType.uint32, 'start-time')),
                        ('master_time', YLeaf(YType.uint32, 'master-time')),
                    ])
                    self.triggered_time = None
                    self.start_time = None
                    self.master_time = None
                    self._segment_path = lambda: "failover-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Active.Nsr.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Active.Nsr.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "nsr-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.NsrStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Nsr.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Nsr.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Nsr.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Active.Nsr.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Active.Nsr.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "issu-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.IssuStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Nsr.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Nsr.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Nsr.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class StateTransitionTime(Entity):
                """
                Transition time for all states
                
                .. attribute:: entry
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.StateTransitionTime, self).__init__()

                    self.yang_name = "state-transition-time"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('entry', YLeaf(YType.uint32, 'entry')),
                    ])
                    self.entry = None
                    self._segment_path = lambda: "state-transition-time"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.StateTransitionTime, ['entry'], name, value)


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('app_type', YLeaf(YType.enumeration, 'app-type')),
                        ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                    ])
                    self.app_type = None
                    self.sent_ids = None
                    self._segment_path = lambda: "xid-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.XidInfo, ['app_type', 'sent_ids'], name, value)


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\: bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\: bool
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                        ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                        ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                        ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                        ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                    ])
                    self.collaborator_is_connected = None
                    self.connection_change_time = None
                    self.collaborator_idt_done = None
                    self.idt_time = None
                    self.collaborator_skipped = None
                    self._segment_path = lambda: "report-card"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: new_state
                
                	New state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_event
                
                	Process event
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Nsr.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "nsr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                        ('new_state', YLeaf(YType.uint8, 'new-state')),
                        ('process_event', YLeaf(YType.uint16, 'process-event')),
                        ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                        ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                    ])
                    self.previous_state = None
                    self.new_state = None
                    self.process_event = None
                    self.process_collaborator = None
                    self.event_timestamp = None
                    self._segment_path = lambda: "event-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/nsr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Nsr.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


        class PreferredPaths(Entity):
            """
            Preferred path Table
            
            .. attribute:: preferred_path
            
            	Preferred path information
            	**type**\: list of  		 :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PreferredPaths.PreferredPath>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.PreferredPaths, self).__init__()

                self.yang_name = "preferred-paths"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("preferred-path", ("preferred_path", L2vpnv2.Active.PreferredPaths.PreferredPath))])
                self._leafs = OrderedDict()

                self.preferred_path = YList(self)
                self._segment_path = lambda: "preferred-paths"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.PreferredPaths, [], name, value)


            class PreferredPath(Entity):
                """
                Preferred path information
                
                .. attribute:: preferred_type
                
                	Preferred type
                	**type**\:  :py:class:`PreferredPathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PreferredPathOption>`
                
                .. attribute:: interface_name
                
                	Main interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: type
                
                	Preferred type
                	**type**\:  :py:class:`L2vpnPreferred <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPreferred>`
                
                .. attribute:: interface_name_xr
                
                	Interface name
                	**type**\: str
                
                	**length:** 0..65
                
                .. attribute:: total_bandwidth
                
                	TotalBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: available_bandwidth
                
                	AvailableBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: reserved_bandwidth
                
                	ReservedBandwidth
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: virtual_circuit
                
                	virtual circuit
                	**type**\: list of  		 :py:class:`VirtualCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PreferredPaths.PreferredPath.VirtualCircuit>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.PreferredPaths.PreferredPath, self).__init__()

                    self.yang_name = "preferred-path"
                    self.yang_parent_name = "preferred-paths"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("virtual-circuit", ("virtual_circuit", L2vpnv2.Active.PreferredPaths.PreferredPath.VirtualCircuit))])
                    self._leafs = OrderedDict([
                        ('preferred_type', YLeaf(YType.enumeration, 'preferred-type')),
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ('type', YLeaf(YType.enumeration, 'type')),
                        ('interface_name_xr', YLeaf(YType.str, 'interface-name-xr')),
                        ('total_bandwidth', YLeaf(YType.uint32, 'total-bandwidth')),
                        ('available_bandwidth', YLeaf(YType.uint32, 'available-bandwidth')),
                        ('reserved_bandwidth', YLeaf(YType.uint32, 'reserved-bandwidth')),
                    ])
                    self.preferred_type = None
                    self.interface_name = None
                    self.type = None
                    self.interface_name_xr = None
                    self.total_bandwidth = None
                    self.available_bandwidth = None
                    self.reserved_bandwidth = None

                    self.virtual_circuit = YList(self)
                    self._segment_path = lambda: "preferred-path"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/preferred-paths/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.PreferredPaths.PreferredPath, ['preferred_type', 'interface_name', 'type', 'interface_name_xr', 'total_bandwidth', 'available_bandwidth', 'reserved_bandwidth'], name, value)


                class VirtualCircuit(Entity):
                    """
                    virtual circuit
                    
                    .. attribute:: peer_id
                    
                    	PeerID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: source_address
                    
                    	SourceAddress
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: pwid_type
                    
                    	pwid type
                    	**type**\:  :py:class:`L2vpnPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwId>`
                    
                    .. attribute:: pwid
                    
                    	PWID
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: fe_ctype
                    
                    	FECType
                    	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.PreferredPaths.PreferredPath.VirtualCircuit, self).__init__()

                        self.yang_name = "virtual-circuit"
                        self.yang_parent_name = "preferred-path"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('peer_id', YLeaf(YType.str, 'peer-id')),
                            ('source_address', YLeaf(YType.str, 'source-address')),
                            ('pwid_type', YLeaf(YType.enumeration, 'pwid-type')),
                            ('pwid', YLeaf(YType.uint64, 'pwid')),
                            ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                        ])
                        self.peer_id = None
                        self.source_address = None
                        self.pwid_type = None
                        self.pwid = None
                        self.fe_ctype = None
                        self._segment_path = lambda: "virtual-circuit"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/preferred-paths/preferred-path/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.PreferredPaths.PreferredPath.VirtualCircuit, ['peer_id', 'source_address', 'pwid_type', 'pwid', 'fe_ctype'], name, value)


        class GlobalSettings(Entity):
            """
            L2VPN global settings
            
            .. attribute:: pw_grouping_enabled
            
            	PW Grouping enabled
            	**type**\: bool
            
            .. attribute:: pw_status_enabled
            
            	PW Status enabled
            	**type**\: bool
            
            .. attribute:: logging_pw_enabled
            
            	Logging PW enabled
            	**type**\: bool
            
            .. attribute:: logging_bd_enabled
            
            	Logging BD state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_vfi_enabled
            
            	Logging VFI state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_nsr_enabled
            
            	Logging NSR state changes enabled
            	**type**\: bool
            
            .. attribute:: logging_df_election_enabled
            
            	Logging EVPN Designated Forwarder changes enabled
            	**type**\: bool
            
            .. attribute:: tcn_propagation_enabled
            
            	TCN propagation enabled
            	**type**\: bool
            
            .. attribute:: pw_oam_refresh_transmit_time
            
            	PW OAM refresh transmit (seconds)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            	**units**\: second
            
            .. attribute:: ha_role
            
            	Node redundancy role
            	**type**\: str
            
            .. attribute:: issu_role
            
            	Node ISSU role
            	**type**\: str
            
            .. attribute:: process_fsm
            
            	Current L2VPN FSM role
            	**type**\: str
            
            .. attribute:: going_active
            
            	transitioning to Active functional role
            	**type**\: bool
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.GlobalSettings, self).__init__()

                self.yang_name = "global-settings"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('pw_grouping_enabled', YLeaf(YType.boolean, 'pw-grouping-enabled')),
                    ('pw_status_enabled', YLeaf(YType.boolean, 'pw-status-enabled')),
                    ('logging_pw_enabled', YLeaf(YType.boolean, 'logging-pw-enabled')),
                    ('logging_bd_enabled', YLeaf(YType.boolean, 'logging-bd-enabled')),
                    ('logging_vfi_enabled', YLeaf(YType.boolean, 'logging-vfi-enabled')),
                    ('logging_nsr_enabled', YLeaf(YType.boolean, 'logging-nsr-enabled')),
                    ('logging_df_election_enabled', YLeaf(YType.boolean, 'logging-df-election-enabled')),
                    ('tcn_propagation_enabled', YLeaf(YType.boolean, 'tcn-propagation-enabled')),
                    ('pw_oam_refresh_transmit_time', YLeaf(YType.uint32, 'pw-oam-refresh-transmit-time')),
                    ('ha_role', YLeaf(YType.str, 'ha-role')),
                    ('issu_role', YLeaf(YType.str, 'issu-role')),
                    ('process_fsm', YLeaf(YType.str, 'process-fsm')),
                    ('going_active', YLeaf(YType.boolean, 'going-active')),
                ])
                self.pw_grouping_enabled = None
                self.pw_status_enabled = None
                self.logging_pw_enabled = None
                self.logging_bd_enabled = None
                self.logging_vfi_enabled = None
                self.logging_nsr_enabled = None
                self.logging_df_election_enabled = None
                self.tcn_propagation_enabled = None
                self.pw_oam_refresh_transmit_time = None
                self.ha_role = None
                self.issu_role = None
                self.process_fsm = None
                self.going_active = None
                self._segment_path = lambda: "global-settings"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.GlobalSettings, ['pw_grouping_enabled', 'pw_status_enabled', 'logging_pw_enabled', 'logging_bd_enabled', 'logging_vfi_enabled', 'logging_nsr_enabled', 'logging_df_election_enabled', 'tcn_propagation_enabled', 'pw_oam_refresh_transmit_time', 'ha_role', 'issu_role', 'process_fsm', 'going_active'], name, value)


        class Pwr(Entity):
            """
            Pseudowire Routing Table
            
            .. attribute:: summary
            
            	L2VPN Pseudowire Routing Summary
            	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Pwr, self).__init__()

                self.yang_name = "pwr"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Active.Pwr.Summary))])
                self._leafs = OrderedDict()

                self.summary = L2vpnv2.Active.Pwr.Summary()
                self.summary.parent = self
                self._children_name_map["summary"] = "summary"
                self._segment_path = lambda: "pwr"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Pwr, [], name, value)


            class Summary(Entity):
                """
                L2VPN Pseudowire Routing Summary
                
                .. attribute:: rd_auto
                
                	Automatic Route Distingtuisher
                	**type**\:  :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdAuto>`
                
                .. attribute:: rd_configured
                
                	Configured Route Distinguisher
                	**type**\:  :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdConfigured>`
                
                .. attribute:: bgp_router_id
                
                	BGP Router ID
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: cfg_router_id
                
                	Configured Router ID
                	**type**\: str
                
                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                
                .. attribute:: bgp_as
                
                	BGP AS number
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: cfg_global_id
                
                	Configured Global ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: l2vpn_has_bgp_eod
                
                	L2VPN got BGP EOD
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Pwr.Summary, self).__init__()

                    self.yang_name = "summary"
                    self.yang_parent_name = "pwr"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("rd-auto", ("rd_auto", L2vpnv2.Active.Pwr.Summary.RdAuto)), ("rd-configured", ("rd_configured", L2vpnv2.Active.Pwr.Summary.RdConfigured))])
                    self._leafs = OrderedDict([
                        ('bgp_router_id', YLeaf(YType.str, 'bgp-router-id')),
                        ('cfg_router_id', YLeaf(YType.str, 'cfg-router-id')),
                        ('bgp_as', YLeaf(YType.uint32, 'bgp-as')),
                        ('cfg_global_id', YLeaf(YType.uint32, 'cfg-global-id')),
                        ('l2vpn_has_bgp_eod', YLeaf(YType.boolean, 'l2vpn-has-bgp-eod')),
                    ])
                    self.bgp_router_id = None
                    self.cfg_router_id = None
                    self.bgp_as = None
                    self.cfg_global_id = None
                    self.l2vpn_has_bgp_eod = None

                    self.rd_auto = L2vpnv2.Active.Pwr.Summary.RdAuto()
                    self.rd_auto.parent = self
                    self._children_name_map["rd_auto"] = "rd-auto"

                    self.rd_configured = L2vpnv2.Active.Pwr.Summary.RdConfigured()
                    self.rd_configured.parent = self
                    self._children_name_map["rd_configured"] = "rd-configured"
                    self._segment_path = lambda: "summary"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Pwr.Summary, ['bgp_router_id', 'cfg_router_id', 'bgp_as', 'cfg_global_id', 'l2vpn_has_bgp_eod'], name, value)


                class RdAuto(Entity):
                    """
                    Automatic Route Distingtuisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdAuto.Auto>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdAuto.V4Addr>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Pwr.Summary.RdAuto, self).__init__()

                        self.yang_name = "rd-auto"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Pwr.Summary.RdAuto.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Pwr.Summary.RdAuto.V4Addr))])
                        self._leafs = OrderedDict([
                            ('rd', YLeaf(YType.enumeration, 'rd')),
                        ])
                        self.rd = None

                        self.auto = L2vpnv2.Active.Pwr.Summary.RdAuto.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"

                        self.two_byte_as = L2vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"

                        self.four_byte_as = L2vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"

                        self.v4_addr = L2vpnv2.Active.Pwr.Summary.RdAuto.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._segment_path = lambda: "rd-auto"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdAuto, ['rd'], name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdAuto.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('router_id', YLeaf(YType.str, 'router-id')),
                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                            ])
                            self.router_id = None
                            self.auto_index = None
                            self._segment_path = lambda: "auto"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdAuto.Auto, ['router_id', 'auto_index'], name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                            ])
                            self.two_byte_as = None
                            self.four_byte_index = None
                            self._segment_path = lambda: "two-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdAuto.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.four_byte_as = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "four-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdAuto.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-auto"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.ipv4_address = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "v4-addr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-auto/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdAuto.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                class RdConfigured(Entity):
                    """
                    Configured Route Distinguisher
                    
                    .. attribute:: auto
                    
                    	auto
                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdConfigured.Auto>`
                    
                    .. attribute:: two_byte_as
                    
                    	two byte as
                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs>`
                    
                    .. attribute:: four_byte_as
                    
                    	four byte as
                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs>`
                    
                    .. attribute:: v4_addr
                    
                    	v4 addr
                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr>`
                    
                    .. attribute:: rd
                    
                    	RD
                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Pwr.Summary.RdConfigured, self).__init__()

                        self.yang_name = "rd-configured"
                        self.yang_parent_name = "summary"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Pwr.Summary.RdConfigured.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr))])
                        self._leafs = OrderedDict([
                            ('rd', YLeaf(YType.enumeration, 'rd')),
                        ])
                        self.rd = None

                        self.auto = L2vpnv2.Active.Pwr.Summary.RdConfigured.Auto()
                        self.auto.parent = self
                        self._children_name_map["auto"] = "auto"

                        self.two_byte_as = L2vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs()
                        self.two_byte_as.parent = self
                        self._children_name_map["two_byte_as"] = "two-byte-as"

                        self.four_byte_as = L2vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs()
                        self.four_byte_as.parent = self
                        self._children_name_map["four_byte_as"] = "four-byte-as"

                        self.v4_addr = L2vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr()
                        self.v4_addr.parent = self
                        self._children_name_map["v4_addr"] = "v4-addr"
                        self._segment_path = lambda: "rd-configured"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdConfigured, ['rd'], name, value)


                    class Auto(Entity):
                        """
                        auto
                        
                        .. attribute:: router_id
                        
                        	BGP Router ID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: auto_index
                        
                        	Auto\-generated Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdConfigured.Auto, self).__init__()

                            self.yang_name = "auto"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('router_id', YLeaf(YType.str, 'router-id')),
                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                            ])
                            self.router_id = None
                            self.auto_index = None
                            self._segment_path = lambda: "auto"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdConfigured.Auto, ['router_id', 'auto_index'], name, value)


                    class TwoByteAs(Entity):
                        """
                        two byte as
                        
                        .. attribute:: two_byte_as
                        
                        	2 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: four_byte_index
                        
                        	4 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                            self.yang_name = "two-byte-as"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                            ])
                            self.two_byte_as = None
                            self.four_byte_index = None
                            self._segment_path = lambda: "two-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdConfigured.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                    class FourByteAs(Entity):
                        """
                        four byte as
                        
                        .. attribute:: four_byte_as
                        
                        	4 Byte AS Number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                            self.yang_name = "four-byte-as"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.four_byte_as = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "four-byte-as"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdConfigured.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                    class V4Addr(Entity):
                        """
                        v4 addr
                        
                        .. attribute:: ipv4_address
                        
                        	IPv4 Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: two_byte_index
                        
                        	2 Byte Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                            self.yang_name = "v4-addr"
                            self.yang_parent_name = "rd-configured"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                            ])
                            self.ipv4_address = None
                            self.two_byte_index = None
                            self._segment_path = lambda: "v4-addr"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pwr/summary/rd-configured/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Pwr.Summary.RdConfigured.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


        class XconnectMp2mpCe2ces(Entity):
            """
            XConnect MP2MP CE2CE Table
            
            .. attribute:: xconnect_mp2mp_ce2ce
            
            	XConnect MP2MP CE2CE information
            	**type**\: list of  		 :py:class:`XconnectMp2mpCe2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.XconnectMp2mpCe2ces, self).__init__()

                self.yang_name = "xconnect-mp2mp-ce2ces"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-mp2mp-ce2ce", ("xconnect_mp2mp_ce2ce", L2vpnv2.Active.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce))])
                self._leafs = OrderedDict()

                self.xconnect_mp2mp_ce2ce = YList(self)
                self._segment_path = lambda: "xconnect-mp2mp-ce2ces"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.XconnectMp2mpCe2ces, [], name, value)


            class XconnectMp2mpCe2ce(Entity):
                """
                XConnect MP2MP CE2CE information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\: str
                
                	**length:** 1..26
                
                .. attribute:: local_ceid
                
                	Local CE ID
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: remote_ceid
                
                	Remote CE ID
                	**type**\: int
                
                	**range:** 1..4294967295
                
                .. attribute:: local_customer_edge_id
                
                	Local CE ID
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: remote_customer_edge_id
                
                	Remote CE ID
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: ce_added
                
                	CE2CE Advertised
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ce"
                    self.yang_parent_name = "xconnect-mp2mp-ce2ces"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                        ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                        ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                        ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                    ])
                    self.group_name = None
                    self.mp2_mp_name = None
                    self.local_ceid = None
                    self.remote_ceid = None
                    self.local_customer_edge_id = None
                    self.remote_customer_edge_id = None
                    self.ce_added = None
                    self._segment_path = lambda: "xconnect-mp2mp-ce2ce"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mp-ce2ces/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, ['group_name', 'mp2_mp_name', 'local_ceid', 'remote_ceid', 'local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


        class Xconnects(Entity):
            """
            XConnect Table
            
            .. attribute:: xconnect
            
            	XConnect information
            	**type**\: list of  		 :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Xconnects, self).__init__()

                self.yang_name = "xconnects"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect", ("xconnect", L2vpnv2.Active.Xconnects.Xconnect))])
                self._leafs = OrderedDict()

                self.xconnect = YList(self)
                self._segment_path = lambda: "xconnects"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Xconnects, [], name, value)


            class Xconnect(Entity):
                """
                XConnect information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: xconnect_name
                
                	XConnect Name
                	**type**\: str
                
                	**length:** 1..38
                
                .. attribute:: backup
                
                	LCR backup
                	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup>`
                
                .. attribute:: segment1
                
                	Segment 1
                	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1>`
                
                .. attribute:: segment2
                
                	Segment 2
                	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2>`
                
                .. attribute:: ce2ce
                
                	CE2CE
                	**type**\:  :py:class:`Ce2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Ce2ce>`
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: xconnect_name_xr
                
                	XConnect name
                	**type**\: str
                
                .. attribute:: number_of_backup_p_ws
                
                	Number of backups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: state
                
                	State of the xconnect
                	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                
                .. attribute:: interworking
                
                	Interworking type
                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                
                .. attribute:: diag_mask
                
                	Mask indicating what if anything is missing before the XC can be provisioned
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: description
                
                	P2P Description
                	**type**\: str
                
                .. attribute:: is_mp2mp
                
                	xconnect is mp2mp
                	**type**\: bool
                
                .. attribute:: backup_segment
                
                	Backup Segment
                	**type**\: list of  		 :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Xconnects.Xconnect, self).__init__()

                    self.yang_name = "xconnect"
                    self.yang_parent_name = "xconnects"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("backup", ("backup", L2vpnv2.Active.Xconnects.Xconnect.Backup)), ("segment1", ("segment1", L2vpnv2.Active.Xconnects.Xconnect.Segment1)), ("segment2", ("segment2", L2vpnv2.Active.Xconnects.Xconnect.Segment2)), ("ce2ce", ("ce2ce", L2vpnv2.Active.Xconnects.Xconnect.Ce2ce)), ("backup-segment", ("backup_segment", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment))])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('xconnect_name', YLeaf(YType.str, 'xconnect-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('xconnect_name_xr', YLeaf(YType.str, 'xconnect-name-xr')),
                        ('number_of_backup_p_ws', YLeaf(YType.uint32, 'number-of-backup-p-ws')),
                        ('state', YLeaf(YType.enumeration, 'state')),
                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                        ('diag_mask', YLeaf(YType.uint32, 'diag-mask')),
                        ('description', YLeaf(YType.str, 'description')),
                        ('is_mp2mp', YLeaf(YType.boolean, 'is-mp2mp')),
                    ])
                    self.group_name = None
                    self.xconnect_name = None
                    self.group_name_xr = None
                    self.xconnect_name_xr = None
                    self.number_of_backup_p_ws = None
                    self.state = None
                    self.interworking = None
                    self.diag_mask = None
                    self.description = None
                    self.is_mp2mp = None

                    self.backup = L2vpnv2.Active.Xconnects.Xconnect.Backup()
                    self.backup.parent = self
                    self._children_name_map["backup"] = "backup"

                    self.segment1 = L2vpnv2.Active.Xconnects.Xconnect.Segment1()
                    self.segment1.parent = self
                    self._children_name_map["segment1"] = "segment1"

                    self.segment2 = L2vpnv2.Active.Xconnects.Xconnect.Segment2()
                    self.segment2.parent = self
                    self._children_name_map["segment2"] = "segment2"

                    self.ce2ce = L2vpnv2.Active.Xconnects.Xconnect.Ce2ce()
                    self.ce2ce.parent = self
                    self._children_name_map["ce2ce"] = "ce2ce"

                    self.backup_segment = YList(self)
                    self._segment_path = lambda: "xconnect"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect, ['group_name', 'xconnect_name', 'group_name_xr', 'xconnect_name_xr', 'number_of_backup_p_ws', 'state', 'interworking', 'diag_mask', 'description', 'is_mp2mp'], name, value)


                class Backup(Entity):
                    """
                    LCR backup
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup, self).__init__()

                        self.yang_name = "backup"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "backup"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Segment1(Entity):
                    """
                    Segment 1
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1, self).__init__()

                        self.yang_name = "segment1"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "segment1"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment1/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Segment2(Entity):
                    """
                    Segment 2
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2, self).__init__()

                        self.yang_name = "segment2"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "segment2"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "segment2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "segment2"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/segment2/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                class Ce2ce(Entity):
                    """
                    CE2CE
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Xconnects.Xconnect.Ce2ce, self).__init__()

                        self.yang_name = "ce2ce"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                            ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                            ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                        ])
                        self.local_customer_edge_id = None
                        self.remote_customer_edge_id = None
                        self.ce_added = None
                        self._segment_path = lambda: "ce2ce"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.Ce2ce, ['local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


                class BackupSegment(Entity):
                    """
                    Backup Segment
                    
                    .. attribute:: attachment_circuit
                    
                    	Attachment Circuit
                    	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                    
                    .. attribute:: pseudo_wire
                    
                    	Pseudowire
                    	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                    
                    .. attribute:: segment_type
                    
                    	SegmentType
                    	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment, self).__init__()

                        self.yang_name = "backup-segment"
                        self.yang_parent_name = "xconnect"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire))])
                        self._leafs = OrderedDict([
                            ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                        ])
                        self.segment_type = None

                        self.attachment_circuit = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                        self.attachment_circuit.parent = self
                        self._children_name_map["attachment_circuit"] = "attachment-circuit"

                        self.pseudo_wire = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire()
                        self.pseudo_wire.parent = self
                        self._children_name_map["pseudo_wire"] = "pseudo-wire"
                        self._segment_path = lambda: "backup-segment"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment, ['segment_type'], name, value)


                    class AttachmentCircuit(Entity):
                        """
                        Attachment Circuit
                        
                        .. attribute:: interface
                        
                        	Interface
                        	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                        
                        .. attribute:: l2vpn_protection
                        
                        	Protection object used for this segment
                        	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection>`
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: msti
                        
                        	MSTi
                        	**type**\: str
                        
                        .. attribute:: internal_ms_ti
                        
                        	Internal MSTi
                        	**type**\: str
                        
                        .. attribute:: interface_handle
                        
                        	Interface Handler
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: node_id
                        
                        	Node ID
                        	**type**\: str
                        
                        	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ms_ti_mismatch
                        
                        	MSTi mismatch
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: tdm_media_mismatched
                        
                        	TDM media parms mismatched
                        	**type**\: bool
                        
                        .. attribute:: bvi_mac_conflict
                        
                        	BVI Mac Conflict
                        	**type**\: bool
                        
                        .. attribute:: bvi_no_port_up
                        
                        	BVI no BP Up
                        	**type**\: bool
                        
                        .. attribute:: control_word_mismatched
                        
                        	Control word mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_mismatched
                        
                        	Encapsulation mismatched
                        	**type**\: bool
                        
                        .. attribute:: encapsulation_error
                        
                        	Encapsulation Error
                        	**type**\: str
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_mismatch_down
                        
                        	Oper down due to MSTI mismatch
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: redundancy_group_id
                        
                        	Redundancy Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: redundancy_group_state
                        
                        	Redundancy Group State
                        	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                        
                        .. attribute:: redundancy_object_id
                        
                        	Redundancy Object ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_ac_partially_programmed
                        
                        	Is attachment\-circuit partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evpn_internal_label
                        
                        	EVPN Internal Label
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                            self.yang_name = "attachment-circuit"
                            self.yang_parent_name = "backup-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection))])
                            self._leafs = OrderedDict([
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('msti', YLeaf(YType.str, 'msti')),
                                ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                ('node_id', YLeaf(YType.str, 'node-id')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                            ])
                            self.state = None
                            self.msti = None
                            self.internal_ms_ti = None
                            self.interface_handle = None
                            self.node_id = None
                            self.xconnect_id = None
                            self.ms_ti_mismatch = None
                            self.mtu_mismatched = None
                            self.tdm_media_mismatched = None
                            self.bvi_mac_conflict = None
                            self.bvi_no_port_up = None
                            self.control_word_mismatched = None
                            self.encapsulation_mismatched = None
                            self.encapsulation_error = None
                            self.interworking = None
                            self.out_of_memory_state = None
                            self.msti_mismatch_down = None
                            self.mac_limit_oper_down = None
                            self.redundancy_group_id = None
                            self.redundancy_group_state = None
                            self.redundancy_object_id = None
                            self.is_ac_partially_programmed = None
                            self.evpn_internal_label = None

                            self.interface = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                            self.interface.parent = self
                            self._children_name_map["interface"] = "interface"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.l2vpn_protection = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection()
                            self.l2vpn_protection.parent = self
                            self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                            self._segment_path = lambda: "attachment-circuit"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                        class Interface(Entity):
                            """
                            Interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface_(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class L2vpnProtection(Entity):
                            """
                            Protection object used for this segment
                            
                            .. attribute:: protection_type
                            
                            	Type of the protection
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                            
                            .. attribute:: protection_configured
                            
                            	Protection configured
                            	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                            
                            .. attribute:: protection_name
                            
                            	Name of the segment acting as backup
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: protected_name
                            
                            	Name of the protected segment
                            	**type**\: str
                            
                            	**length:** 0..65
                            
                            .. attribute:: active
                            
                            	Active
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, self).__init__()

                                self.yang_name = "l2vpn-protection"
                                self.yang_parent_name = "attachment-circuit"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                    ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                    ('protection_name', YLeaf(YType.str, 'protection-name')),
                                    ('protected_name', YLeaf(YType.str, 'protected-name')),
                                    ('active', YLeaf(YType.boolean, 'active')),
                                ])
                                self.protection_type = None
                                self.protection_configured = None
                                self.protection_name = None
                                self.protected_name = None
                                self.active = None
                                self._segment_path = lambda: "l2vpn-protection"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/attachment-circuit/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class PseudoWire(Entity):
                        """
                        Pseudowire
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                            self.yang_name = "pseudo-wire"
                            self.yang_parent_name = "backup-segment"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudo-wire"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/atom/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/encapsulation-info/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/preferred-path/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/local-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/remote-signalling/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudo-wire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnects/xconnect/backup-segment/pseudo-wire/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


        class XconnectGroups(Entity):
            """
            XConnect group Table
            
            .. attribute:: xconnect_group
            
            	XConnect group information
            	**type**\: list of  		 :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectGroups.XconnectGroup>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.XconnectGroups, self).__init__()

                self.yang_name = "xconnect-groups"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-group", ("xconnect_group", L2vpnv2.Active.XconnectGroups.XconnectGroup))])
                self._leafs = OrderedDict()

                self.xconnect_group = YList(self)
                self._segment_path = lambda: "xconnect-groups"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.XconnectGroups, [], name, value)


            class XconnectGroup(Entity):
                """
                XConnect group information
                
                .. attribute:: group_name  (key)
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.XconnectGroups.XconnectGroup, self).__init__()

                    self.yang_name = "xconnect-group"
                    self.yang_parent_name = "xconnect-groups"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['group_name']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                    ])
                    self.group_name = None
                    self.group_name_xr = None
                    self.number_xconnects = None
                    self._segment_path = lambda: "xconnect-group" + "[group-name='" + str(self.group_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-groups/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.XconnectGroups.XconnectGroup, ['group_name', 'group_name_xr', 'number_xconnects'], name, value)


        class XconnectMp2mps(Entity):
            """
            XConnect MP2MP Table
            
            .. attribute:: xconnect_mp2mp
            
            	XConnect MP2MP information
            	**type**\: list of  		 :py:class:`XconnectMp2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.XconnectMp2mps, self).__init__()

                self.yang_name = "xconnect-mp2mps"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("xconnect-mp2mp", ("xconnect_mp2mp", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp))])
                self._leafs = OrderedDict()

                self.xconnect_mp2mp = YList(self)
                self._segment_path = lambda: "xconnect-mp2mps"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps, [], name, value)


            class XconnectMp2mp(Entity):
                """
                XConnect MP2MP information
                
                .. attribute:: group_name
                
                	XConnect Group
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: mp2_mp_name
                
                	Mp2Mp Name
                	**type**\: str
                
                	**length:** 1..26
                
                .. attribute:: discovery
                
                	l2vpn xc auto discovery info
                	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery>`
                
                .. attribute:: group_name_xr
                
                	Group name
                	**type**\: str
                
                .. attribute:: mp2mp_name
                
                	MP2MP name
                	**type**\: str
                
                .. attribute:: mp2mpid
                
                	Identification Number
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_id
                
                	Vpn ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: vpn_mtu
                
                	VPN MTU
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: l2_encapsulation
                
                	L2 Encapsulation
                	**type**\:  :py:class:`L2vpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagAdEncap>`
                
                .. attribute:: xconnect_shutdown
                
                	Administratively disabled
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp, self).__init__()

                    self.yang_name = "xconnect-mp2mp"
                    self.yang_parent_name = "xconnect-mp2mps"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery))])
                    self._leafs = OrderedDict([
                        ('group_name', YLeaf(YType.str, 'group-name')),
                        ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                        ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                        ('mp2mp_name', YLeaf(YType.str, 'mp2mp-name')),
                        ('mp2mpid', YLeaf(YType.uint32, 'mp2mpid')),
                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                        ('vpn_mtu', YLeaf(YType.uint32, 'vpn-mtu')),
                        ('l2_encapsulation', YLeaf(YType.enumeration, 'l2-encapsulation')),
                        ('xconnect_shutdown', YLeaf(YType.boolean, 'xconnect-shutdown')),
                    ])
                    self.group_name = None
                    self.mp2_mp_name = None
                    self.group_name_xr = None
                    self.mp2mp_name = None
                    self.mp2mpid = None
                    self.vpn_id = None
                    self.vpn_mtu = None
                    self.l2_encapsulation = None
                    self.xconnect_shutdown = None

                    self.discovery = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery()
                    self.discovery.parent = self
                    self._children_name_map["discovery"] = "discovery"
                    self._segment_path = lambda: "xconnect-mp2mp"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp, ['group_name', 'mp2_mp_name', 'group_name_xr', 'mp2mp_name', 'mp2mpid', 'vpn_id', 'vpn_mtu', 'l2_encapsulation', 'xconnect_shutdown'], name, value)


                class Discovery(Entity):
                    """
                    l2vpn xc auto discovery info
                    
                    .. attribute:: rd_value
                    
                    	Route Distinguisher
                    	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue>`
                    
                    .. attribute:: ad_method
                    
                    	Autodiscovery Method
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_added
                    
                    	VPN Added
                    	**type**\: bool
                    
                    .. attribute:: ad_service_connected
                    
                    	Service Connected
                    	**type**\: bool
                    
                    .. attribute:: ad_signalling_method
                    
                    	Signaling Protocol
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ce_range
                    
                    	CE Range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: export_route_policy
                    
                    	Export Route Policy
                    	**type**\: str
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2ce_advertised
                    
                    	Number of ce2ce Advertised
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_ce2c_es
                    
                    	Number of ce2ce
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: import_rt
                    
                    	Import Route Targets
                    	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt>`
                    
                    .. attribute:: export_rt
                    
                    	Export Route Targets
                    	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "xconnect-mp2mp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue)), ("import-rt", ("import_rt", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt))])
                        self._leafs = OrderedDict([
                            ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                            ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                            ('ad_service_connected', YLeaf(YType.boolean, 'ad-service-connected')),
                            ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                            ('ce_range', YLeaf(YType.uint16, 'ce-range')),
                            ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                            ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                            ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                            ('number_ce2ce_advertised', YLeaf(YType.uint32, 'number-ce2ce-advertised')),
                            ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                            ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ('number_ce2c_es', YLeaf(YType.uint32, 'number-ce2c-es')),
                        ])
                        self.ad_method = None
                        self.vpn_added = None
                        self.ad_service_connected = None
                        self.ad_signalling_method = None
                        self.ce_range = None
                        self.export_route_policy = None
                        self.number_a_cs_up = None
                        self.number_p_ws_up = None
                        self.number_ce2ce_advertised = None
                        self.number_a_cs = None
                        self.number_pseudowires = None
                        self.number_ce2c_es = None

                        self.rd_value = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue()
                        self.rd_value.parent = self
                        self._children_name_map["rd_value"] = "rd-value"

                        self.import_rt = YList(self)
                        self.export_rt = YList(self)
                        self._segment_path = lambda: "discovery"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery, ['ad_method', 'vpn_added', 'ad_service_connected', 'ad_signalling_method', 'ce_range', 'export_route_policy', 'number_a_cs_up', 'number_p_ws_up', 'number_ce2ce_advertised', 'number_a_cs', 'number_pseudowires', 'number_ce2c_es'], name, value)


                    class RdValue(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, self).__init__()

                            self.yang_name = "rd-value"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd-value"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-value"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/rd-value/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                    class ImportRt(Entity):
                        """
                        Import Route Targets
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr>`
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, self).__init__()

                            self.yang_name = "import-rt"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport))])
                            self._leafs = OrderedDict([
                                ('rt', YLeaf(YType.enumeration, 'rt')),
                            ])
                            self.rt = None

                            self.two_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"

                            self.es_import = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._segment_path = lambda: "import-rt"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, ['rt'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "import-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                    ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                ])
                                self.high_bytes = None
                                self.low_bytes = None
                                self._segment_path = lambda: "es-import"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/import-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                    class ExportRt(Entity):
                        """
                        Export Route Targets
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr>`
                        
                        .. attribute:: es_import
                        
                        	es import
                        	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport>`
                        
                        .. attribute:: rt
                        
                        	RT
                        	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, self).__init__()

                            self.yang_name = "export-rt"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport))])
                            self._leafs = OrderedDict([
                                ('rt', YLeaf(YType.enumeration, 'rt')),
                            ])
                            self.rt = None

                            self.two_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"

                            self.es_import = L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport()
                            self.es_import.parent = self
                            self._children_name_map["es_import"] = "es-import"
                            self._segment_path = lambda: "export-rt"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, ['rt'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class EsImport(Entity):
                            """
                            es import
                            
                            .. attribute:: high_bytes
                            
                            	Top 4 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: low_bytes
                            
                            	Low 2 bytes of ES Import
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, self).__init__()

                                self.yang_name = "es-import"
                                self.yang_parent_name = "export-rt"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                    ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                ])
                                self.high_bytes = None
                                self.low_bytes = None
                                self._segment_path = lambda: "es-import"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-mp2mps/xconnect-mp2mp/discovery/export-rt/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


        class Indexes(Entity):
            """
            ID Manager Index Table
            
            .. attribute:: index
            
            	ID Manager Index Pool
            	**type**\: list of  		 :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Indexes.Index>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Indexes, self).__init__()

                self.yang_name = "indexes"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("index", ("index", L2vpnv2.Active.Indexes.Index))])
                self._leafs = OrderedDict()

                self.index = YList(self)
                self._segment_path = lambda: "indexes"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Indexes, [], name, value)


            class Index(Entity):
                """
                ID Manager Index Pool
                
                .. attribute:: pool_id  (key)
                
                	Pool ID
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{1,8}
                
                .. attribute:: pool_id_xr
                
                	Pool Id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: application_type
                
                	Application Type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: allocated_ids
                
                	Number of IDs allocated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: zombied_ids
                
                	Number of IDs allocated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pool_size
                
                	Pool size
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: max_num_id_mgr
                
                	Maximum number of pool extensions
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_id_mgr_in_use
                
                	ID mgr instances in use
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Indexes.Index, self).__init__()

                    self.yang_name = "index"
                    self.yang_parent_name = "indexes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pool_id']
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pool_id', YLeaf(YType.str, 'pool-id')),
                        ('pool_id_xr', YLeaf(YType.uint32, 'pool-id-xr')),
                        ('application_type', YLeaf(YType.enumeration, 'application-type')),
                        ('allocated_ids', YLeaf(YType.uint32, 'allocated-ids')),
                        ('zombied_ids', YLeaf(YType.uint32, 'zombied-ids')),
                        ('pool_size', YLeaf(YType.uint32, 'pool-size')),
                        ('max_num_id_mgr', YLeaf(YType.uint32, 'max-num-id-mgr')),
                        ('num_id_mgr_in_use', YLeaf(YType.uint32, 'num-id-mgr-in-use')),
                    ])
                    self.pool_id = None
                    self.pool_id_xr = None
                    self.application_type = None
                    self.allocated_ids = None
                    self.zombied_ids = None
                    self.pool_size = None
                    self.max_num_id_mgr = None
                    self.num_id_mgr_in_use = None
                    self._segment_path = lambda: "index" + "[pool-id='" + str(self.pool_id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/indexes/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Indexes.Index, ['pool_id', 'pool_id_xr', 'application_type', 'allocated_ids', 'zombied_ids', 'pool_size', 'max_num_id_mgr', 'num_id_mgr_in_use'], name, value)


        class XconnectSummary(Entity):
            """
            XConnect summary information
            
            .. attribute:: number_groups
            
            	Number of groups
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects
            
            	Number of xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_up
            
            	Numxber of xconnects whose state is up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_down
            
            	Number of xconnects whose state is down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_unresolved
            
            	Number of xconnects whose state is unresolved
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_administratively_down
            
            	Number of xconnects with segments in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
            
            	Number of xconnects of type attachment circuit to pseudowire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
            
            	Number of xconnects of type monitor session to pseudowire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_locally_switched
            
            	Number of locally switched xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_pw
            
            	Number of XCs configured with backup PW
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup
            
            	Number of XCs currently using backup PW (UP state)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_xconnects
            
            	Number of XCs with backup PW in down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_xconnects
            
            	Number of XCs with backup PW in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_xconnects
            
            	Number of XCs with backup PW in unresolved state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_xconnects
            
            	Number of XCs with backup PW in standby state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_ready_backup_xconnects
            
            	Number of XCs with backup PW in standby ready state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
            
            	Number of xconnects of type PseudoWire To PseudoWire
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects
            
            	Number of mp2mp xconnects
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_up
            
            	Number of Mp2mp XCs that have been admined up
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_down
            
            	Number of Mp2mp XCs that have ben admined down
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnects_advertised
            
            	Number of Mp2mp XCs that have been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2mp_xconnectss_not_advertised
            
            	Number of Mp2mp XCs that have not been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2_ceconnections
            
            	Number of Ce2Ce connections
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_advertized
            
            	Number of CE2CE connections that have been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_ce2ce_not_advertized
            
            	Number of CE2CE connections that have not been advertized
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: partially_programmed_xconnects
            
            	Number of cross\-connects partially programmed
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_with_backup_interface
            
            	Number of XCs configured with backup interface
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_xconnects_currently_using_backup_interface
            
            	Number of XCs currently using backup interface (UP state)
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: down_backup_interface_xconnects
            
            	Number of XCs with backup interface in down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: admin_down_backup_interface_xconnects
            
            	Number of XCs with backup interface in admin down state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: unresolved_backup_interface_xconnects
            
            	Number of XCs with backup interface in unresolved state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: standby_backup_interface_xconnects
            
            	Number of XCs with backup interface in standby state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.XconnectSummary, self).__init__()

                self.yang_name = "xconnect-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                    ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                    ('number_xconnects_up', YLeaf(YType.uint32, 'number-xconnects-up')),
                    ('number_xconnects_down', YLeaf(YType.uint32, 'number-xconnects-down')),
                    ('number_xconnects_unresolved', YLeaf(YType.uint32, 'number-xconnects-unresolved')),
                    ('number_xconnects_administratively_down', YLeaf(YType.uint32, 'number-xconnects-administratively-down')),
                    ('number_xconnects_type_attachment_circuit_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-attachment-circuit-to-pseudo-wire')),
                    ('number_xconnects_type_monitor_session_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-monitor-session-to-pseudo-wire')),
                    ('number_xconnects_locally_switched', YLeaf(YType.uint32, 'number-xconnects-locally-switched')),
                    ('number_xconnects_with_backup_pw', YLeaf(YType.uint32, 'number-xconnects-with-backup-pw')),
                    ('number_xconnects_currently_using_backup', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup')),
                    ('down_backup_xconnects', YLeaf(YType.uint32, 'down-backup-xconnects')),
                    ('admin_down_backup_xconnects', YLeaf(YType.uint32, 'admin-down-backup-xconnects')),
                    ('unresolved_backup_xconnects', YLeaf(YType.uint32, 'unresolved-backup-xconnects')),
                    ('standby_backup_xconnects', YLeaf(YType.uint32, 'standby-backup-xconnects')),
                    ('standby_ready_backup_xconnects', YLeaf(YType.uint32, 'standby-ready-backup-xconnects')),
                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                    ('number_xconnects_type_pseudo_wire_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-pseudo-wire-to-pseudo-wire')),
                    ('number_mp2mp_xconnects', YLeaf(YType.uint32, 'number-mp2mp-xconnects')),
                    ('number_mp2mp_xconnects_up', YLeaf(YType.uint32, 'number-mp2mp-xconnects-up')),
                    ('number_mp2mp_xconnects_down', YLeaf(YType.uint32, 'number-mp2mp-xconnects-down')),
                    ('number_mp2mp_xconnects_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnects-advertised')),
                    ('number_mp2mp_xconnectss_not_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnectss-not-advertised')),
                    ('number_ce2_ceconnections', YLeaf(YType.uint32, 'number-ce2-ceconnections')),
                    ('number_ce2ce_advertized', YLeaf(YType.uint32, 'number-ce2ce-advertized')),
                    ('number_ce2ce_not_advertized', YLeaf(YType.uint32, 'number-ce2ce-not-advertized')),
                    ('partially_programmed_xconnects', YLeaf(YType.uint32, 'partially-programmed-xconnects')),
                    ('number_xconnects_with_backup_interface', YLeaf(YType.uint32, 'number-xconnects-with-backup-interface')),
                    ('number_xconnects_currently_using_backup_interface', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup-interface')),
                    ('down_backup_interface_xconnects', YLeaf(YType.uint32, 'down-backup-interface-xconnects')),
                    ('admin_down_backup_interface_xconnects', YLeaf(YType.uint32, 'admin-down-backup-interface-xconnects')),
                    ('unresolved_backup_interface_xconnects', YLeaf(YType.uint32, 'unresolved-backup-interface-xconnects')),
                    ('standby_backup_interface_xconnects', YLeaf(YType.uint32, 'standby-backup-interface-xconnects')),
                ])
                self.number_groups = None
                self.number_xconnects = None
                self.number_xconnects_up = None
                self.number_xconnects_down = None
                self.number_xconnects_unresolved = None
                self.number_xconnects_administratively_down = None
                self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                self.number_xconnects_locally_switched = None
                self.number_xconnects_with_backup_pw = None
                self.number_xconnects_currently_using_backup = None
                self.down_backup_xconnects = None
                self.admin_down_backup_xconnects = None
                self.unresolved_backup_xconnects = None
                self.standby_backup_xconnects = None
                self.standby_ready_backup_xconnects = None
                self.out_of_memory_state = None
                self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                self.number_mp2mp_xconnects = None
                self.number_mp2mp_xconnects_up = None
                self.number_mp2mp_xconnects_down = None
                self.number_mp2mp_xconnects_advertised = None
                self.number_mp2mp_xconnectss_not_advertised = None
                self.number_ce2_ceconnections = None
                self.number_ce2ce_advertized = None
                self.number_ce2ce_not_advertized = None
                self.partially_programmed_xconnects = None
                self.number_xconnects_with_backup_interface = None
                self.number_xconnects_currently_using_backup_interface = None
                self.down_backup_interface_xconnects = None
                self.admin_down_backup_interface_xconnects = None
                self.unresolved_backup_interface_xconnects = None
                self.standby_backup_interface_xconnects = None
                self._segment_path = lambda: "xconnect-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.XconnectSummary, ['number_groups', 'number_xconnects', 'number_xconnects_up', 'number_xconnects_down', 'number_xconnects_unresolved', 'number_xconnects_administratively_down', 'number_xconnects_type_attachment_circuit_to_pseudo_wire', 'number_xconnects_type_monitor_session_to_pseudo_wire', 'number_xconnects_locally_switched', 'number_xconnects_with_backup_pw', 'number_xconnects_currently_using_backup', 'down_backup_xconnects', 'admin_down_backup_xconnects', 'unresolved_backup_xconnects', 'standby_backup_xconnects', 'standby_ready_backup_xconnects', 'out_of_memory_state', 'number_xconnects_type_pseudo_wire_to_pseudo_wire', 'number_mp2mp_xconnects', 'number_mp2mp_xconnects_up', 'number_mp2mp_xconnects_down', 'number_mp2mp_xconnects_advertised', 'number_mp2mp_xconnectss_not_advertised', 'number_ce2_ceconnections', 'number_ce2ce_advertized', 'number_ce2ce_not_advertized', 'partially_programmed_xconnects', 'number_xconnects_with_backup_interface', 'number_xconnects_currently_using_backup_interface', 'down_backup_interface_xconnects', 'admin_down_backup_interface_xconnects', 'unresolved_backup_interface_xconnects', 'standby_backup_interface_xconnects'], name, value)


        class ProcFsm(Entity):
            """
            L2VPN Process FSM information
            
            .. attribute:: failover_status
            
            	L2VPN failover status
            	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.FailoverStatus>`
            
            .. attribute:: nsr_status
            
            	L2VPN NSR status and timestamp
            	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.NsrStatus>`
            
            .. attribute:: issu_status
            
            	L2VPN ISSU Status and timestamp
            	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.IssuStatus>`
            
            .. attribute:: process_role
            
            	Current Process Role
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: process_state
            
            	Current Process State
            	**type**\: int
            
            	**range:** 0..255
            
            .. attribute:: sync_flags
            
            	Sync complete flags
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: sw_install_in_progress
            
            	Is s/w install currently in progress?
            	**type**\: bool
            
            .. attribute:: state_transition_time
            
            	Transition time for all states
            	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.StateTransitionTime>`
            
            .. attribute:: xid_info
            
            	XID information
            	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.XidInfo>`
            
            .. attribute:: report_card
            
            	L2VPN Collaborator report card
            	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.ReportCard>`
            
            .. attribute:: event_history
            
            	L2VPN Process event history
            	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.EventHistory>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.ProcFsm, self).__init__()

                self.yang_name = "proc-fsm"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Active.ProcFsm.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Active.ProcFsm.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Active.ProcFsm.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Active.ProcFsm.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Active.ProcFsm.XidInfo)), ("report-card", ("report_card", L2vpnv2.Active.ProcFsm.ReportCard)), ("event-history", ("event_history", L2vpnv2.Active.ProcFsm.EventHistory))])
                self._leafs = OrderedDict([
                    ('process_role', YLeaf(YType.uint8, 'process-role')),
                    ('process_state', YLeaf(YType.uint8, 'process-state')),
                    ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                    ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                ])
                self.process_role = None
                self.process_state = None
                self.sync_flags = None
                self.sw_install_in_progress = None

                self.failover_status = L2vpnv2.Active.ProcFsm.FailoverStatus()
                self.failover_status.parent = self
                self._children_name_map["failover_status"] = "failover-status"

                self.nsr_status = L2vpnv2.Active.ProcFsm.NsrStatus()
                self.nsr_status.parent = self
                self._children_name_map["nsr_status"] = "nsr-status"

                self.issu_status = L2vpnv2.Active.ProcFsm.IssuStatus()
                self.issu_status.parent = self
                self._children_name_map["issu_status"] = "issu-status"

                self.state_transition_time = YList(self)
                self.xid_info = YList(self)
                self.report_card = YList(self)
                self.event_history = YList(self)
                self._segment_path = lambda: "proc-fsm"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.ProcFsm, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


            class FailoverStatus(Entity):
                """
                L2VPN failover status
                
                .. attribute:: triggered_time
                
                	Triggered time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: start_time
                
                	Start time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: master_time
                
                	Master time
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.FailoverStatus, self).__init__()

                    self.yang_name = "failover-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                        ('start_time', YLeaf(YType.uint32, 'start-time')),
                        ('master_time', YLeaf(YType.uint32, 'master-time')),
                    ])
                    self.triggered_time = None
                    self.start_time = None
                    self.master_time = None
                    self._segment_path = lambda: "failover-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


            class NsrStatus(Entity):
                """
                L2VPN NSR status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.NsrStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.NsrStatus, self).__init__()

                    self.yang_name = "nsr-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Active.ProcFsm.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Active.ProcFsm.NsrStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "nsr-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.NsrStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.ProcFsm.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "nsr-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/nsr-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.ProcFsm.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class IssuStatus(Entity):
                """
                L2VPN ISSU Status and timestamp
                
                .. attribute:: idt_status
                
                	IDT status
                	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.IssuStatus.IdtStatus>`
                
                .. attribute:: previ_ous_idt_status
                
                	Previous IDT status
                	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                
                .. attribute:: role
                
                	Process role
                	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.IssuStatus, self).__init__()

                    self.yang_name = "issu-status"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Active.ProcFsm.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus))])
                    self._leafs = OrderedDict([
                        ('role', YLeaf(YType.enumeration, 'role')),
                    ])
                    self.role = None

                    self.idt_status = L2vpnv2.Active.ProcFsm.IssuStatus.IdtStatus()
                    self.idt_status.parent = self
                    self._children_name_map["idt_status"] = "idt-status"

                    self.previ_ous_idt_status = L2vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus()
                    self.previ_ous_idt_status.parent = self
                    self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                    self._segment_path = lambda: "issu-status"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.IssuStatus, ['role'], name, value)


                class IdtStatus(Entity):
                    """
                    IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                        self.yang_name = "idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.ProcFsm.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class PreviOusIdtStatus(Entity):
                    """
                    Previous IDT status
                    
                    .. attribute:: sync_status
                    
                    	Sync status
                    	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                    
                    .. attribute:: not_ready_reason
                    
                    	Not ready reason
                    	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                    
                    .. attribute:: idt_start_time
                    
                    	IDT start timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: idt_end_time
                    
                    	IDT end timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: declare_time
                    
                    	Declare ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    .. attribute:: withdraw_time
                    
                    	Withdraw ready timestamp in seconds
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    	**units**\: second
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                        self.yang_name = "previ-ous-idt-status"
                        self.yang_parent_name = "issu-status"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                            ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                            ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                            ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                            ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                            ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                        ])
                        self.sync_status = None
                        self.not_ready_reason = None
                        self.idt_start_time = None
                        self.idt_end_time = None
                        self.declare_time = None
                        self.withdraw_time = None
                        self._segment_path = lambda: "previ-ous-idt-status"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/issu-status/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.ProcFsm.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


            class StateTransitionTime(Entity):
                """
                Transition time for all states
                
                .. attribute:: entry
                
                	
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.StateTransitionTime, self).__init__()

                    self.yang_name = "state-transition-time"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('entry', YLeaf(YType.uint32, 'entry')),
                    ])
                    self.entry = None
                    self._segment_path = lambda: "state-transition-time"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.StateTransitionTime, ['entry'], name, value)


            class XidInfo(Entity):
                """
                XID information
                
                .. attribute:: app_type
                
                	App type
                	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                
                .. attribute:: sent_ids
                
                	Number of XIDs transferred
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.XidInfo, self).__init__()

                    self.yang_name = "xid-info"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('app_type', YLeaf(YType.enumeration, 'app-type')),
                        ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                    ])
                    self.app_type = None
                    self.sent_ids = None
                    self._segment_path = lambda: "xid-info"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.XidInfo, ['app_type', 'sent_ids'], name, value)


            class ReportCard(Entity):
                """
                L2VPN Collaborator report card
                
                .. attribute:: collaborator_is_connected
                
                	Is the collaborator connected
                	**type**\: bool
                
                .. attribute:: connection_change_time
                
                	Time when connection state (UP/DOWN) changed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_idt_done
                
                	Is IDT done for this collaborator
                	**type**\: bool
                
                .. attribute:: idt_time
                
                	Time when IDT was done
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: collaborator_skipped
                
                	Was this collaborator skipped for not connecting in time
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.ReportCard, self).__init__()

                    self.yang_name = "report-card"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                        ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                        ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                        ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                        ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                    ])
                    self.collaborator_is_connected = None
                    self.connection_change_time = None
                    self.collaborator_idt_done = None
                    self.idt_time = None
                    self.collaborator_skipped = None
                    self._segment_path = lambda: "report-card"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


            class EventHistory(Entity):
                """
                L2VPN Process event history
                
                .. attribute:: previous_state
                
                	Previous state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: new_state
                
                	New state
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_event
                
                	Process event
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: process_collaborator
                
                	Process collaborator
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: event_timestamp
                
                	Event timestamp
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.ProcFsm.EventHistory, self).__init__()

                    self.yang_name = "event-history"
                    self.yang_parent_name = "proc-fsm"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                        ('new_state', YLeaf(YType.uint8, 'new-state')),
                        ('process_event', YLeaf(YType.uint16, 'process-event')),
                        ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                        ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                    ])
                    self.previous_state = None
                    self.new_state = None
                    self.process_event = None
                    self.process_collaborator = None
                    self.event_timestamp = None
                    self._segment_path = lambda: "event-history"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/proc-fsm/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.ProcFsm.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


        class MstpPorts(Entity):
            """
            L2VPN MSTP Port Table
            
            .. attribute:: mstp_port
            
            	MSTP Port information
            	**type**\: list of  		 :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpPorts.MstpPort>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.MstpPorts, self).__init__()

                self.yang_name = "mstp-ports"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mstp-port", ("mstp_port", L2vpnv2.Active.MstpPorts.MstpPort))])
                self._leafs = OrderedDict()

                self.mstp_port = YList(self)
                self._segment_path = lambda: "mstp-ports"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.MstpPorts, [], name, value)


            class MstpPort(Entity):
                """
                MSTP Port information
                
                .. attribute:: interface  (key)
                
                	Interface
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: mstp_interface_handle
                
                	Interface handle
                	**type**\: str
                
                	**pattern:** [a\-zA\-Z0\-9./\-]+
                
                .. attribute:: interface_name
                
                	Interface name
                	**type**\: str
                
                .. attribute:: protected
                
                	Protected
                	**type**\: bool
                
                .. attribute:: reference_count
                
                	Reference Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_entry
                
                	MSTI
                	**type**\: list of  		 :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.MstpPorts.MstpPort, self).__init__()

                    self.yang_name = "mstp-port"
                    self.yang_parent_name = "mstp-ports"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface']
                    self._child_classes = OrderedDict([("msti-entry", ("msti_entry", L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry))])
                    self._leafs = OrderedDict([
                        ('interface', YLeaf(YType.str, 'interface')),
                        ('mstp_interface_handle', YLeaf(YType.str, 'mstp-interface-handle')),
                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ('protected', YLeaf(YType.boolean, 'protected')),
                        ('reference_count', YLeaf(YType.uint32, 'reference-count')),
                    ])
                    self.interface = None
                    self.mstp_interface_handle = None
                    self.interface_name = None
                    self.protected = None
                    self.reference_count = None

                    self.msti_entry = YList(self)
                    self._segment_path = lambda: "mstp-port" + "[interface='" + str(self.interface) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mstp-ports/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.MstpPorts.MstpPort, ['interface', 'mstp_interface_handle', 'interface_name', 'protected', 'reference_count'], name, value)


                class MstiEntry(Entity):
                    """
                    MSTI
                    
                    .. attribute:: cfg_ms_ti
                    
                    	 Configured MSTi
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: rcv_count
                    
                    	Receive count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ack_count
                    
                    	Ack count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nack_count
                    
                    	Nack count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: flush_count
                    
                    	Flush count 
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface_count
                    
                    	Interface count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bd_count
                    
                    	BD count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_flags
                    
                    	Msti Flags
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_state
                    
                    	Msti State
                    	**type**\:  :py:class:`L2vpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMstiState>`
                    
                    .. attribute:: bd_entry
                    
                    	BD entries
                    	**type**\: list of  		 :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry, self).__init__()

                        self.yang_name = "msti-entry"
                        self.yang_parent_name = "mstp-port"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bd-entry", ("bd_entry", L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry))])
                        self._leafs = OrderedDict([
                            ('cfg_ms_ti', YLeaf(YType.uint32, 'cfg-ms-ti')),
                            ('rcv_count', YLeaf(YType.uint32, 'rcv-count')),
                            ('ack_count', YLeaf(YType.uint32, 'ack-count')),
                            ('nack_count', YLeaf(YType.uint32, 'nack-count')),
                            ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                            ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                            ('bd_count', YLeaf(YType.uint32, 'bd-count')),
                            ('msti_flags', YLeaf(YType.uint32, 'msti-flags')),
                            ('msti_state', YLeaf(YType.enumeration, 'msti-state')),
                        ])
                        self.cfg_ms_ti = None
                        self.rcv_count = None
                        self.ack_count = None
                        self.nack_count = None
                        self.flush_count = None
                        self.interface_count = None
                        self.bd_count = None
                        self.msti_flags = None
                        self.msti_state = None

                        self.bd_entry = YList(self)
                        self._segment_path = lambda: "msti-entry"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry, ['cfg_ms_ti', 'rcv_count', 'ack_count', 'nack_count', 'flush_count', 'interface_count', 'bd_count', 'msti_flags', 'msti_state'], name, value)


                    class BdEntry(Entity):
                        """
                        BD entries
                        
                        .. attribute:: bdid
                        
                        	BD ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bdif_count
                        
                        	BD Intf Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                            self.yang_name = "bd-entry"
                            self.yang_parent_name = "msti-entry"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('bdid', YLeaf(YType.uint32, 'bdid')),
                                ('bdif_count', YLeaf(YType.uint32, 'bdif-count')),
                            ])
                            self.bdid = None
                            self.bdif_count = None
                            self._segment_path = lambda: "bd-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.MstpPorts.MstpPort.MstiEntry.BdEntry, ['bdid', 'bdif_count'], name, value)


        class GenericInterfaceListDetails(Entity):
            """
            L2VPN generic interface list Detail Table
            
            .. attribute:: generic_interface_list_detail
            
            	Generic Interface List detail information
            	**type**\: list of  		 :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.GenericInterfaceListDetails, self).__init__()

                self.yang_name = "generic-interface-list-details"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list-detail", ("generic_interface_list_detail", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail))])
                self._leafs = OrderedDict()

                self.generic_interface_list_detail = YList(self)
                self._segment_path = lambda: "generic-interface-list-details"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails, [], name, value)


            class GenericInterfaceListDetail(Entity):
                """
                Generic Interface List detail information
                
                .. attribute:: interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: summary
                
                	Summary information
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                
                .. attribute:: items
                
                	Number of items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\: bool
                
                .. attribute:: psedowire_ether_items
                
                	Number PW Ether Items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: pseudowire_iw_items
                
                	Number PW IW Items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                
                .. attribute:: pseudowire_ether_range
                
                	PW\-Ether ranges
                	**type**\: list of  		 :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                
                .. attribute:: pseudowire_iw_range
                
                	PW\-IW ranges
                	**type**\: list of  		 :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                    self.yang_name = "generic-interface-list-detail"
                    self.yang_parent_name = "generic-interface-list-details"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_list_name']
                    self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary)), ("interface", ("interface", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface)), ("pseudowire-ether-range", ("pseudowire_ether_range", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange)), ("pseudowire-iw-range", ("pseudowire_iw_range", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange))])
                    self._leafs = OrderedDict([
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('items', YLeaf(YType.uint32, 'items')),
                        ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                        ('psedowire_ether_items', YLeaf(YType.uint32, 'psedowire-ether-items')),
                        ('pseudowire_iw_items', YLeaf(YType.uint32, 'pseudowire-iw-items')),
                    ])
                    self.interface_list_name = None
                    self.items = None
                    self.is_provisioned = None
                    self.psedowire_ether_items = None
                    self.pseudowire_iw_items = None

                    self.summary = L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"

                    self.interface = YList(self)
                    self.pseudowire_ether_range = YList(self)
                    self.pseudowire_iw_range = YList(self)
                    self._segment_path = lambda: "generic-interface-list-detail" + "[interface-list-name='" + str(self.interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/generic-interface-list-details/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail, ['interface_list_name', 'items', 'is_provisioned', 'psedowire_ether_items', 'pseudowire_iw_items'], name, value)


                class Summary(Entity):
                    """
                    Summary information
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface))])
                        self._leafs = OrderedDict([
                            ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                            ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                            ('items', YLeaf(YType.uint32, 'items')),
                        ])
                        self.interface_list_name_xr = None
                        self.interface_list_id = None
                        self.number_of_interfaces = None
                        self.items = None

                        self.interface = YList(self)
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, ['interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                            ])
                            self.interface_name = None
                            self.pending_replications = None
                            self.not_supported_replications = None
                            self.is_fib_downloaded = None
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                class PseudowireEtherRange(Entity):
                    """
                    PW\-Ether ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                        self.yang_name = "pseudowire-ether-range"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lower', YLeaf(YType.uint16, 'lower')),
                            ('upper', YLeaf(YType.uint16, 'upper')),
                        ])
                        self.lower = None
                        self.upper = None
                        self._segment_path = lambda: "pseudowire-ether-range"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, ['lower', 'upper'], name, value)


                class PseudowireIwRange(Entity):
                    """
                    PW\-IW ranges
                    
                    .. attribute:: lower
                    
                    	lower range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: upper
                    
                    	upper range
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                        self.yang_name = "pseudowire-iw-range"
                        self.yang_parent_name = "generic-interface-list-detail"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('lower', YLeaf(YType.uint16, 'lower')),
                            ('upper', YLeaf(YType.uint16, 'upper')),
                        ])
                        self.lower = None
                        self.upper = None
                        self._segment_path = lambda: "pseudowire-iw-range"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, ['lower', 'upper'], name, value)


        class L2vpnResourceState(Entity):
            """
            L2VPN resource state information
            
            .. attribute:: resource_out_of_memory_state
            
            	L2VPN Out of memory state
            	**type**\: int
            
            	**range:** 0..4294967295
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.L2vpnResourceState, self).__init__()

                self.yang_name = "l2vpn-resource-state"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('resource_out_of_memory_state', YLeaf(YType.uint32, 'resource-out-of-memory-state')),
                ])
                self.resource_out_of_memory_state = None
                self._segment_path = lambda: "l2vpn-resource-state"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.L2vpnResourceState, ['resource_out_of_memory_state'], name, value)


        class BridgeDomains(Entity):
            """
            Bridge Domain Information
            
            .. attribute:: bridge_domain
            
            	Bridge Domain Information
            	**type**\: list of  		 :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.BridgeDomains, self).__init__()

                self.yang_name = "bridge-domains"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("bridge-domain", ("bridge_domain", L2vpnv2.Active.BridgeDomains.BridgeDomain))])
                self._leafs = OrderedDict()

                self.bridge_domain = YList(self)
                self._segment_path = lambda: "bridge-domains"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.BridgeDomains, [], name, value)


            class BridgeDomain(Entity):
                """
                Bridge Domain Information
                
                .. attribute:: bridge_access_vfi_table
                
                	Bridge Domain Access VFI Table
                	**type**\:  :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                
                .. attribute:: bridge_core_vfi_table
                
                	Bridge Domain Core VFI Table
                	**type**\:  :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                
                .. attribute:: bridge_acs
                
                	Bridge Domain Attachment Circuit Table
                	**type**\:  :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs>`
                
                .. attribute:: bridge_access_pws
                
                	Bridge Domain Access Pseudowire Table
                	**type**\:  :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                
                .. attribute:: bridge_domain_info
                
                	Bridge Domain Information
                	**type**\:  :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                
                .. attribute:: bridge_domain_group_name
                
                	Bridge Domain Group Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: bridge_domain_name
                
                	Bridge Domain Name
                	**type**\: str
                
                	**length:** 1..27
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain, self).__init__()

                    self.yang_name = "bridge-domain"
                    self.yang_parent_name = "bridge-domains"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bridge-access-vfi-table", ("bridge_access_vfi_table", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable)), ("bridge-core-vfi-table", ("bridge_core_vfi_table", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable)), ("bridge-acs", ("bridge_acs", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs)), ("bridge-access-pws", ("bridge_access_pws", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws)), ("bridge-domain-info", ("bridge_domain_info", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo))])
                    self._leafs = OrderedDict([
                        ('bridge_domain_group_name', YLeaf(YType.str, 'bridge-domain-group-name')),
                        ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                    ])
                    self.bridge_domain_group_name = None
                    self.bridge_domain_name = None

                    self.bridge_access_vfi_table = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                    self.bridge_access_vfi_table.parent = self
                    self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"

                    self.bridge_core_vfi_table = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                    self.bridge_core_vfi_table.parent = self
                    self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"

                    self.bridge_acs = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs()
                    self.bridge_acs.parent = self
                    self._children_name_map["bridge_acs"] = "bridge-acs"

                    self.bridge_access_pws = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws()
                    self.bridge_access_pws.parent = self
                    self._children_name_map["bridge_access_pws"] = "bridge-access-pws"

                    self.bridge_domain_info = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                    self.bridge_domain_info.parent = self
                    self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                    self._segment_path = lambda: "bridge-domain"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain, ['bridge_domain_group_name', 'bridge_domain_name'], name, value)


                class BridgeAccessVfiTable(Entity):
                    """
                    Bridge Domain Access VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                        self.yang_name = "bridge-access-vfi-table"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws))])
                        self._leafs = OrderedDict()

                        self.bridge_pws = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._segment_path = lambda: "bridge-access-vfi-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, [], name, value)


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	Bridge Domain Pseudowire
                        	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-access-vfi-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw))])
                            self._leafs = OrderedDict()

                            self.bridge_pw = YList(self)
                            self._segment_path = lambda: "bridge-pws"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, [], name, value)


                        class BridgePw(Entity):
                            """
                            Bridge Domain Pseudowire
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\: bool
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                    ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                    ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                    ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                    ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                    ('is_access', YLeaf(YType.boolean, 'is-access')),
                                ])
                                self.neighbor = None
                                self.pw_type = None
                                self.pseudowire_id = None
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None
                                self.is_access = None

                                self.pseudowire = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"

                                self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "bridge-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\: bool
                                
                                .. attribute:: is_evpn_vpws_type
                                
                                	is EVPN VPWS
                                	**type**\: bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\: bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\: bool
                                
                                .. attribute:: data_path_down
                                
                                	True if LSP down
                                	**type**\: bool
                                
                                .. attribute:: use_tunnel_path
                                
                                	True if using TE tunnel
                                	**type**\: bool
                                
                                .. attribute:: odn_configured
                                
                                	True if ODN is configured
                                	**type**\: bool
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\: bool
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\: bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\: bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\: bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\: bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\: bool
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\: bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\: bool
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\: bool
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\: bool
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\: bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\: bool
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\: bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\: bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\: bool
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\: bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\: bool
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\: bool
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\: bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\: bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\: bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\: bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\: bool
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                    self._leafs = OrderedDict([
                                        ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                        ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                        ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                        ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                        ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                        ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                        ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                        ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                        ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                        ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                        ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                        ('time_created', YLeaf(YType.str, 'time-created')),
                                        ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                        ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                        ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                        ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                        ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                        ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                        ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                        ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                        ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                        ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                        ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                        ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                        ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                        ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                        ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                        ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                        ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                        ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                        ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                        ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                        ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                        ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                        ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                        ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                        ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                        ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                        ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                        ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                        ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                        ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                        ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                        ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                        ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                        ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                        ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                        ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                        ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                        ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                        ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                        ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                        ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                        ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                        ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                        ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                    ])
                                    self.local_source_address = None
                                    self.ipv6_local_source_address = None
                                    self.pseudo_wire_id = None
                                    self.is_pwr_type = None
                                    self.is_evpn_vpws_type = None
                                    self.xconnect_id = None
                                    self.state = None
                                    self.pseudo_wire_state = None
                                    self.protocol = None
                                    self.pw_class_name = None
                                    self.tag_rewrite = None
                                    self.interworking = None
                                    self.fe_ctype = None
                                    self.evpn_src_acid = None
                                    self.sequencing_type = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.local_control_word = None
                                    self.remote_control_word = None
                                    self.local_pseudo_wire_type = None
                                    self.remote_pseudo_wire_type = None
                                    self.imposed_vlan_id = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.last_time_status_changed = None
                                    self.time_elapsed_status_changed = None
                                    self.last_time_status_down = None
                                    self.time_elapsed_status_down = None
                                    self.shutdown = None
                                    self.data_path_down = None
                                    self.use_tunnel_path = None
                                    self.odn_configured = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.payload_bytes_mismatched = None
                                    self.bitrate_mismatched = None
                                    self.rtp_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.sig_pkts_mismatched = None
                                    self.cas_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.freq_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.mtu_mismatched = None
                                    self.illegal_control_word = None
                                    self.ad_remote_down = None
                                    self.not_supported_qinq = None
                                    self.local_label_failed = None
                                    self.remote_label_failed = None
                                    self.preferred_path_disable_fallback = None
                                    self.backup_pw = None
                                    self.primary_pw = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.disable_never = None
                                    self.disable_delay = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.out_of_memory_state = None
                                    self.transport_lsp_down = None
                                    self.mac_limit_oper_down = None
                                    self.pw_status_use = None
                                    self.auto_discovery = None
                                    self.ad_method = None
                                    self.pwlsd_rewrite_failed = None
                                    self.ldp_label_advertise_failed = None
                                    self.is_vfi = None
                                    self.is_multi_segment_pseudowire = None
                                    self.pw_redundancy_one_way = None
                                    self.load_balance = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.is_flow_label_static = None
                                    self.is_partially_programmed = None
                                    self.pw_redundancy_initial_delay = None
                                    self.bridge_pw_type_mismatch = None
                                    self.required_bw = None
                                    self.admited_bw = None
                                    self.forward_class = None
                                    self.table_policy_name = None

                                    self.peer_id = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"

                                    self.encapsulation_info = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                    self.local_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"

                                    self.remote_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"

                                    self.preferred_path = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"

                                    self.local_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"

                                    self.remote_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"

                                    self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.p2mp_pw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._segment_path = lambda: "pseudowire"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                            ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                            ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.type = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.internal_label = None
                                        self._segment_path = lambda: "peer-id"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                        self._leafs = OrderedDict([
                                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                        ])
                                        self.encapsulation = None

                                        self.atom = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"

                                        self.l2tpv3 = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._segment_path = lambda: "encapsulation-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                            self._leafs = OrderedDict([
                                                ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                ('saii', YLeaf(YType.str, 'saii')),
                                                ('taii', YLeaf(YType.str, 'taii')),
                                                ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                            ])
                                            self.is_pseudowire_headend = None
                                            self.local_label = None
                                            self.remote_label = None
                                            self.local_group_id = None
                                            self.remote_group_id = None
                                            self.local_cv_type = None
                                            self.local_c_ctype = None
                                            self.remote_cv_type = None
                                            self.remote_c_ctype = None
                                            self.local_veid = None
                                            self.remote_veid = None
                                            self.local_ceid = None
                                            self.remote_ceid = None
                                            self.source_address = None
                                            self.remote_source_address = None
                                            self.local_ldp_id = None
                                            self.remote_ldp_id = None
                                            self.saii = None
                                            self.taii = None
                                            self.is_sai_itype2 = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.is_tai_itype2 = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.rem_saii = None
                                            self.rem_taii = None
                                            self.lsd_rewrite_failed = None
                                            self.ldp_label_advertisment_failed = None

                                            self.local_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"

                                            self.remote_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"

                                            self.multi_segment_pseudowire_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._segment_path = lambda: "atom"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "local-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "remote-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                    ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                ])
                                                self.received_packets = None
                                                self.received_bytes = None
                                                self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                    class L2tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\: str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\: bool
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\: bool
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                            ])
                                            self.l2tp_class_name = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.dont_fragment_bit = None
                                            self.tos_mode = None
                                            self.tos = None
                                            self.ttl = None
                                            self.local_session_id = None
                                            self.remote_session_id = None
                                            self.local_cookie_size = None
                                            self.remote_cookie_size = None
                                            self.local_cookie_low_value = None
                                            self.remote_cookie_low_value = None
                                            self.local_cookie_high_value = None
                                            self.remote_cookie_high_value = None
                                            self.remote_circuit_status_up = None
                                            self.tunnel_state = None
                                            self.local_secondary_cookie_size = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_high_value = None
                                            self._segment_path = lambda: "l2tpv3"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "local-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "remote-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: srte_policy
                                    
                                    	srte policy
                                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                        self._leafs = OrderedDict([
                                            ('option', YLeaf(YType.enumeration, 'option')),
                                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                        ])
                                        self.option = None
                                        self.next_hop_ip = None
                                        self.te_tunnel_interface_number = None
                                        self.ip_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                        self.srte_policy = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                        self.srte_policy.parent = self
                                        self._children_name_map["srte_policy"] = "srte-policy"
                                        self._segment_path = lambda: "preferred-path"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                    class SrtePolicy(Entity):
                                        """
                                        srte policy
                                        
                                        .. attribute:: policy_name
                                        
                                        	SR TE Policy Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                            self.yang_name = "srte-policy"
                                            self.yang_parent_name = "preferred-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                                            ])
                                            self.policy_name = None
                                            self._segment_path = lambda: "srte-policy"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "local-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "remote-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class P2mpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_available', YLeaf(YType.boolean, 'local-available')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                            ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                            ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                            ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                            ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                            ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                            ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                            ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                            ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                            ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                        ])
                                        self.local_available = None
                                        self.local_label = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.local_extended_tunnel_id = None
                                        self.local_p2mp_id = None
                                        self.local_flags = None
                                        self.remote_available = None
                                        self.remote_label = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_p2mp_id = None
                                        self.remote_flags = None
                                        self._segment_path = lambda: "p2mp-pw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeCoreVfiTable(Entity):
                    """
                    Bridge Domain Core VFI Table
                    
                    .. attribute:: bridge_pws
                    
                    	Bridge Domain Access/Core Pseudowire Table
                    	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                        self.yang_name = "bridge-core-vfi-table"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws))])
                        self._leafs = OrderedDict()

                        self.bridge_pws = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                        self.bridge_pws.parent = self
                        self._children_name_map["bridge_pws"] = "bridge-pws"
                        self._segment_path = lambda: "bridge-core-vfi-table"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, [], name, value)


                    class BridgePws(Entity):
                        """
                        Bridge Domain Access/Core Pseudowire Table
                        
                        .. attribute:: bridge_pw
                        
                        	Bridge Domain Pseudowire
                        	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                            self.yang_name = "bridge-pws"
                            self.yang_parent_name = "bridge-core-vfi-table"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw))])
                            self._leafs = OrderedDict()

                            self.bridge_pw = YList(self)
                            self._segment_path = lambda: "bridge-pws"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, [], name, value)


                        class BridgePw(Entity):
                            """
                            Bridge Domain Pseudowire
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\: bool
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                self.yang_name = "bridge-pw"
                                self.yang_parent_name = "bridge-pws"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                    ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                    ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                    ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                    ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                    ('is_access', YLeaf(YType.boolean, 'is-access')),
                                ])
                                self.neighbor = None
                                self.pw_type = None
                                self.pseudowire_id = None
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None
                                self.is_access = None

                                self.pseudowire = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"

                                self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "bridge-pw"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\: bool
                                
                                .. attribute:: is_evpn_vpws_type
                                
                                	is EVPN VPWS
                                	**type**\: bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\: bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\: bool
                                
                                .. attribute:: data_path_down
                                
                                	True if LSP down
                                	**type**\: bool
                                
                                .. attribute:: use_tunnel_path
                                
                                	True if using TE tunnel
                                	**type**\: bool
                                
                                .. attribute:: odn_configured
                                
                                	True if ODN is configured
                                	**type**\: bool
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\: bool
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\: bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\: bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\: bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\: bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\: bool
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\: bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\: bool
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\: bool
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\: bool
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\: bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\: bool
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\: bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\: bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\: bool
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\: bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\: bool
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\: bool
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\: bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\: bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\: bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\: bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\: bool
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                    self._leafs = OrderedDict([
                                        ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                        ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                        ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                        ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                        ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                        ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                        ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                        ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                        ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                        ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                        ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                        ('time_created', YLeaf(YType.str, 'time-created')),
                                        ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                        ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                        ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                        ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                        ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                        ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                        ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                        ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                        ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                        ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                        ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                        ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                        ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                        ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                        ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                        ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                        ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                        ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                        ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                        ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                        ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                        ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                        ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                        ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                        ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                        ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                        ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                        ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                        ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                        ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                        ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                        ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                        ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                        ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                        ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                        ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                        ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                        ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                        ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                        ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                        ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                        ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                        ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                        ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                    ])
                                    self.local_source_address = None
                                    self.ipv6_local_source_address = None
                                    self.pseudo_wire_id = None
                                    self.is_pwr_type = None
                                    self.is_evpn_vpws_type = None
                                    self.xconnect_id = None
                                    self.state = None
                                    self.pseudo_wire_state = None
                                    self.protocol = None
                                    self.pw_class_name = None
                                    self.tag_rewrite = None
                                    self.interworking = None
                                    self.fe_ctype = None
                                    self.evpn_src_acid = None
                                    self.sequencing_type = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.local_control_word = None
                                    self.remote_control_word = None
                                    self.local_pseudo_wire_type = None
                                    self.remote_pseudo_wire_type = None
                                    self.imposed_vlan_id = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.last_time_status_changed = None
                                    self.time_elapsed_status_changed = None
                                    self.last_time_status_down = None
                                    self.time_elapsed_status_down = None
                                    self.shutdown = None
                                    self.data_path_down = None
                                    self.use_tunnel_path = None
                                    self.odn_configured = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.payload_bytes_mismatched = None
                                    self.bitrate_mismatched = None
                                    self.rtp_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.sig_pkts_mismatched = None
                                    self.cas_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.freq_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.mtu_mismatched = None
                                    self.illegal_control_word = None
                                    self.ad_remote_down = None
                                    self.not_supported_qinq = None
                                    self.local_label_failed = None
                                    self.remote_label_failed = None
                                    self.preferred_path_disable_fallback = None
                                    self.backup_pw = None
                                    self.primary_pw = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.disable_never = None
                                    self.disable_delay = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.out_of_memory_state = None
                                    self.transport_lsp_down = None
                                    self.mac_limit_oper_down = None
                                    self.pw_status_use = None
                                    self.auto_discovery = None
                                    self.ad_method = None
                                    self.pwlsd_rewrite_failed = None
                                    self.ldp_label_advertise_failed = None
                                    self.is_vfi = None
                                    self.is_multi_segment_pseudowire = None
                                    self.pw_redundancy_one_way = None
                                    self.load_balance = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.is_flow_label_static = None
                                    self.is_partially_programmed = None
                                    self.pw_redundancy_initial_delay = None
                                    self.bridge_pw_type_mismatch = None
                                    self.required_bw = None
                                    self.admited_bw = None
                                    self.forward_class = None
                                    self.table_policy_name = None

                                    self.peer_id = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"

                                    self.encapsulation_info = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                    self.local_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"

                                    self.remote_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"

                                    self.preferred_path = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"

                                    self.local_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"

                                    self.remote_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"

                                    self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.p2mp_pw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._segment_path = lambda: "pseudowire"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                            ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                            ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.type = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.internal_label = None
                                        self._segment_path = lambda: "peer-id"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                        self._leafs = OrderedDict([
                                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                        ])
                                        self.encapsulation = None

                                        self.atom = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"

                                        self.l2tpv3 = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._segment_path = lambda: "encapsulation-info"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                            self._leafs = OrderedDict([
                                                ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                ('saii', YLeaf(YType.str, 'saii')),
                                                ('taii', YLeaf(YType.str, 'taii')),
                                                ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                            ])
                                            self.is_pseudowire_headend = None
                                            self.local_label = None
                                            self.remote_label = None
                                            self.local_group_id = None
                                            self.remote_group_id = None
                                            self.local_cv_type = None
                                            self.local_c_ctype = None
                                            self.remote_cv_type = None
                                            self.remote_c_ctype = None
                                            self.local_veid = None
                                            self.remote_veid = None
                                            self.local_ceid = None
                                            self.remote_ceid = None
                                            self.source_address = None
                                            self.remote_source_address = None
                                            self.local_ldp_id = None
                                            self.remote_ldp_id = None
                                            self.saii = None
                                            self.taii = None
                                            self.is_sai_itype2 = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.is_tai_itype2 = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.rem_saii = None
                                            self.rem_taii = None
                                            self.lsd_rewrite_failed = None
                                            self.ldp_label_advertisment_failed = None

                                            self.local_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"

                                            self.remote_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"

                                            self.multi_segment_pseudowire_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._segment_path = lambda: "atom"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "local-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "remote-agi"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                    ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                ])
                                                self.received_packets = None
                                                self.received_bytes = None
                                                self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                    class L2tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\: str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\: bool
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\: bool
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                            ])
                                            self.l2tp_class_name = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.dont_fragment_bit = None
                                            self.tos_mode = None
                                            self.tos = None
                                            self.ttl = None
                                            self.local_session_id = None
                                            self.remote_session_id = None
                                            self.local_cookie_size = None
                                            self.remote_cookie_size = None
                                            self.local_cookie_low_value = None
                                            self.remote_cookie_low_value = None
                                            self.local_cookie_high_value = None
                                            self.remote_cookie_high_value = None
                                            self.remote_circuit_status_up = None
                                            self.tunnel_state = None
                                            self.local_secondary_cookie_size = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_high_value = None
                                            self._segment_path = lambda: "l2tpv3"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "local-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "remote-interface"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = False
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"
                                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: srte_policy
                                    
                                    	srte policy
                                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                        self._leafs = OrderedDict([
                                            ('option', YLeaf(YType.enumeration, 'option')),
                                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                        ])
                                        self.option = None
                                        self.next_hop_ip = None
                                        self.te_tunnel_interface_number = None
                                        self.ip_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                        self.srte_policy = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                        self.srte_policy.parent = self
                                        self._children_name_map["srte_policy"] = "srte-policy"
                                        self._segment_path = lambda: "preferred-path"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                    class SrtePolicy(Entity):
                                        """
                                        srte policy
                                        
                                        .. attribute:: policy_name
                                        
                                        	SR TE Policy Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                            self.yang_name = "srte-policy"
                                            self.yang_parent_name = "preferred-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                                            ])
                                            self.policy_name = None
                                            self._segment_path = lambda: "srte-policy"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "local-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "remote-signalling"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class P2mpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_available', YLeaf(YType.boolean, 'local-available')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                            ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                            ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                            ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                            ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                            ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                            ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                            ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                            ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                            ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                        ])
                                        self.local_available = None
                                        self.local_label = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.local_extended_tunnel_id = None
                                        self.local_p2mp_id = None
                                        self.local_flags = None
                                        self.remote_available = None
                                        self.remote_label = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_p2mp_id = None
                                        self.remote_flags = None
                                        self._segment_path = lambda: "p2mp-pw"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/pseudowire/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-core-vfi-table/bridge-pws/bridge-pw/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeAcs(Entity):
                    """
                    Bridge Domain Attachment Circuit Table
                    
                    .. attribute:: bridge_ac
                    
                    	Bridge Domain Attachment Circuit
                    	**type**\: list of  		 :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                        self.yang_name = "bridge-acs"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-ac", ("bridge_ac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc))])
                        self._leafs = OrderedDict()

                        self.bridge_ac = YList(self)
                        self._segment_path = lambda: "bridge-acs"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs, [], name, value)


                    class BridgeAc(Entity):
                        """
                        Bridge Domain Attachment Circuit
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                        
                        .. attribute:: bvi_mac_index
                        
                        	MyMac Index
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                        
                        .. attribute:: bvimac
                        
                        	BVI MAC addresses
                        	**type**\: list of  		 :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                            self.yang_name = "bridge-ac"
                            self.yang_parent_name = "bridge-acs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit)), ("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac)), ("bvimac", ("bvimac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac))])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('bvi_mac_index', YLeaf(YType.uint16, 'bvi-mac-index')),
                            ])
                            self.interface_name = None
                            self.bvi_mac_index = None

                            self.attachment_circuit = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.static_mac = YList(self)
                            self.bvimac = YList(self)
                            self._segment_path = lambda: "bridge-ac" + "[interface-name='" + str(self.interface_name) + "']"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-acs/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, ['interface_name', 'bvi_mac_index'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class Bvimac(Entity):
                            """
                            BVI MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                self.yang_name = "bvimac"
                                self.yang_parent_name = "bridge-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "bvimac"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeAccessPws(Entity):
                    """
                    Bridge Domain Access Pseudowire Table
                    
                    .. attribute:: bridge_access_pw
                    
                    	Bridge Domain Access Pseudowire
                    	**type**\: list of  		 :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                        self.yang_name = "bridge-access-pws"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-access-pw", ("bridge_access_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw))])
                        self._leafs = OrderedDict()

                        self.bridge_access_pw = YList(self)
                        self._segment_path = lambda: "bridge-access-pws"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws, [], name, value)


                    class BridgeAccessPw(Entity):
                        """
                        Bridge Domain Access Pseudowire
                        
                        .. attribute:: neighbor
                        
                        	Neighbor IPv4 address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pw_type
                        
                        	PW Type
                        	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                        
                        .. attribute:: pseudowire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: ve_id_vpls_id_0_3
                        
                        	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpls_id_4_7
                        
                        	Zero or Last 4 bytes of VPLS\-ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pseudowire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                        
                        .. attribute:: is_access
                        
                        	Is Access PW
                        	**type**\: bool
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                            self.yang_name = "bridge-access-pw"
                            self.yang_parent_name = "bridge-access-pws"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac))])
                            self._leafs = OrderedDict([
                                ('neighbor', YLeaf(YType.str, 'neighbor')),
                                ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                ('is_access', YLeaf(YType.boolean, 'is-access')),
                            ])
                            self.neighbor = None
                            self.pw_type = None
                            self.pseudowire_id = None
                            self.ve_id_vpls_id_0_3 = None
                            self.vpls_id_4_7 = None
                            self.is_access = None

                            self.pseudowire = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                            self.pseudowire.parent = self
                            self._children_name_map["pseudowire"] = "pseudowire"

                            self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.static_mac = YList(self)
                            self._segment_path = lambda: "bridge-access-pw"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                        class Pseudowire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudowire"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/local-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/remote-agi/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/atom/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/encapsulation-info/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/tdm/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/vlan/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/tdm/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-ether/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = False
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"
                                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-interface/parameters/pseudowire-iw/interface-list/%s" % self._segment_path()

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/preferred-path/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/local-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/remote-signalling/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/pseudowire/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/base/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "bridge-access-pw"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-access-pws/bridge-access-pw/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                class BridgeDomainInfo(Entity):
                    """
                    Bridge Domain Information
                    
                    .. attribute:: security_parameters
                    
                    	Security parameters
                    	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                    
                    .. attribute:: pbb_parameters
                    
                    	PBB parameters
                    	**type**\:  :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                    
                    .. attribute:: evpn_parameters
                    
                    	EVPN parameters
                    	**type**\:  :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                    
                    .. attribute:: vni_parameters
                    
                    	VNI parameters
                    	**type**\:  :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                    
                    .. attribute:: rd
                    
                    	Route Distinguisher
                    	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                    
                    .. attribute:: group_name
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: bridge_name
                    
                    	Bridge\-domain name
                    	**type**\: str
                    
                    .. attribute:: bridge_domain_id
                    
                    	Identification number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_description
                    
                    	Human\-readable bridge\-domain description
                    	**type**\: str
                    
                    .. attribute:: bridge_state
                    
                    	Bridge\-domain state
                    	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                    
                    .. attribute:: bridge_coupled_state
                    
                    	Bridge\-domain coupled state
                    	**type**\:  :py:class:`L2vpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeCoupledState>`
                    
                    .. attribute:: bridge_shg_id
                    
                    	Bridge\-domain shgid
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_msti
                    
                    	Bridge\-domain msti
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: acpwup
                    
                    	Number of bridge ports (AC,PW) which are up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_internal_msti
                    
                    	Bridge\-domain internal msti
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: configured
                    
                    	Bridge\-domain is configured
                    	**type**\: bool
                    
                    .. attribute:: number_vf_is
                    
                    	Number of virtual forwarding interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_access_vf_is
                    
                    	Number of Access VFIs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs
                    
                    	Number of attachment circuits
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_a_cs_up
                    
                    	Number of attachment circuits up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pseudowires
                    
                    	Number of pseudowires
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_p_ws_up
                    
                    	Number of pseudowires up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: standby_pseudowires
                    
                    	Number of pseudowires standby
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_pb_bs
                    
                    	Number of pbbs
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: number_pb_bs_up
                    
                    	Number of pbbs up
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: num_vn_is
                    
                    	Number of VNIs
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_vn_is_up
                    
                    	Number of VNIs up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_pseudowires
                    
                    	Number of pseudowires partially programmed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: partially_programmed_a_cs
                    
                    	Number of attachment circuits partially programmed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: bridge_mtu
                    
                    	Maximum transmission unit
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: shutdown
                    
                    	Administratively disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_limit_down
                    
                    	Oper down because MAC limit reached
                    	**type**\: bool
                    
                    .. attribute:: flodd_group_id_down
                    
                    	Oper down because no FGID
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw
                    
                    	MAC withdraw enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_access
                    
                    	MAC Access PW withdraw enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_relay
                    
                    	MAC Access PW withdraw relaying from access to access enabled
                    	**type**\: bool
                    
                    .. attribute:: mac_withdraw_option
                    
                    	Event on which MAC withdraw is sent
                    	**type**\:  :py:class:`L2vpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacWithdrawOption>`
                    
                    .. attribute:: p2mp_enabled
                    
                    	P2MP Enabled on this Bridge Domain
                    	**type**\: bool
                    
                    .. attribute:: bridge_type
                    
                    	Bridge\-domain type
                    	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                    
                    .. attribute:: vine_fsm_state
                    
                    	VNI, IRB, Native\-Evpn state
                    	**type**\: str
                    
                    .. attribute:: time_created
                    
                    	Time when the bridge domain was created
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_creation
                    
                    	Time elapsed since creation
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: last_time_status_changed
                    
                    	Last time the bridge domain status changed
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: time_elapsed_status_changed
                    
                    	Time elapsed since status changed
                    	**type**\: str
                    
                    	**length:** 0..50
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                    
                    .. attribute:: is_bridge_partially_programmed
                    
                    	Bridge is partially programmed
                    	**type**\: bool
                    
                    .. attribute:: evi
                    
                    	E\-VPN id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_rd_configured
                    
                    	Config or Auto
                    	**type**\: bool
                    
                    .. attribute:: imposition_pkt_count
                    
                    	EVPN Imposition Packet Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: imposition_byte_count
                    
                    	EVPN Imposition Byte Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_pkt_count
                    
                    	EVPN Disposition Packet Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: disposition_bytecount
                    
                    	EVPN Disposition Byte Count
                    	**type**\: int
                    
                    	**range:** 0..18446744073709551615
                    
                    .. attribute:: as_
                    
                    	BGP AS number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                    
                    	nV Satellite Offload IPv4 Multicast Disabled
                    	**type**\: bool
                    
                    .. attribute:: mac_filter
                    
                    	MAC addresses for filtering
                    	**type**\: list of  		 :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                    
                    .. attribute:: bridge_vfi
                    
                    	Virtual Forwarding Interfaces
                    	**type**\: list of  		 :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                    
                    .. attribute:: bridge_access_vfi
                    
                    	Access Virtual Forwarding Interfaces
                    	**type**\: list of  		 :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                        self.yang_name = "bridge-domain-info"
                        self.yang_parent_name = "bridge-domain"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters)), ("pbb-parameters", ("pbb_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters)), ("evpn-parameters", ("evpn_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters)), ("vni-parameters", ("vni_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters)), ("rd", ("rd", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd)), ("mac-filter", ("mac_filter", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter)), ("bridge-vfi", ("bridge_vfi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi)), ("bridge-access-vfi", ("bridge_access_vfi", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi))])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('bridge_name', YLeaf(YType.str, 'bridge-name')),
                            ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                            ('bridge_description', YLeaf(YType.str, 'bridge-description')),
                            ('bridge_state', YLeaf(YType.enumeration, 'bridge-state')),
                            ('bridge_coupled_state', YLeaf(YType.enumeration, 'bridge-coupled-state')),
                            ('bridge_shg_id', YLeaf(YType.uint32, 'bridge-shg-id')),
                            ('bridge_msti', YLeaf(YType.uint32, 'bridge-msti')),
                            ('acpwup', YLeaf(YType.uint32, 'acpwup')),
                            ('bridge_internal_msti', YLeaf(YType.uint32, 'bridge-internal-msti')),
                            ('configured', YLeaf(YType.boolean, 'configured')),
                            ('number_vf_is', YLeaf(YType.uint32, 'number-vf-is')),
                            ('number_access_vf_is', YLeaf(YType.uint32, 'number-access-vf-is')),
                            ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                            ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                            ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                            ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                            ('number_pb_bs', YLeaf(YType.uint8, 'number-pb-bs')),
                            ('number_pb_bs_up', YLeaf(YType.uint8, 'number-pb-bs-up')),
                            ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                            ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                            ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                            ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                            ('bridge_mtu', YLeaf(YType.uint32, 'bridge-mtu')),
                            ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                            ('mac_limit_down', YLeaf(YType.boolean, 'mac-limit-down')),
                            ('flodd_group_id_down', YLeaf(YType.boolean, 'flodd-group-id-down')),
                            ('mac_withdraw', YLeaf(YType.boolean, 'mac-withdraw')),
                            ('mac_withdraw_access', YLeaf(YType.boolean, 'mac-withdraw-access')),
                            ('mac_withdraw_relay', YLeaf(YType.boolean, 'mac-withdraw-relay')),
                            ('mac_withdraw_option', YLeaf(YType.enumeration, 'mac-withdraw-option')),
                            ('p2mp_enabled', YLeaf(YType.boolean, 'p2mp-enabled')),
                            ('bridge_type', YLeaf(YType.enumeration, 'bridge-type')),
                            ('vine_fsm_state', YLeaf(YType.str, 'vine-fsm-state')),
                            ('time_created', YLeaf(YType.str, 'time-created')),
                            ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                            ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                            ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                            ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                            ('is_bridge_partially_programmed', YLeaf(YType.boolean, 'is-bridge-partially-programmed')),
                            ('evi', YLeaf(YType.uint32, 'evi')),
                            ('is_rd_configured', YLeaf(YType.boolean, 'is-rd-configured')),
                            ('imposition_pkt_count', YLeaf(YType.uint64, 'imposition-pkt-count')),
                            ('imposition_byte_count', YLeaf(YType.uint64, 'imposition-byte-count')),
                            ('disposition_pkt_count', YLeaf(YType.uint64, 'disposition-pkt-count')),
                            ('disposition_bytecount', YLeaf(YType.uint64, 'disposition-bytecount')),
                            ('as_', YLeaf(YType.uint32, 'as')),
                            ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                        ])
                        self.group_name = None
                        self.bridge_name = None
                        self.bridge_domain_id = None
                        self.bridge_description = None
                        self.bridge_state = None
                        self.bridge_coupled_state = None
                        self.bridge_shg_id = None
                        self.bridge_msti = None
                        self.acpwup = None
                        self.bridge_internal_msti = None
                        self.configured = None
                        self.number_vf_is = None
                        self.number_access_vf_is = None
                        self.number_a_cs = None
                        self.number_a_cs_up = None
                        self.number_pseudowires = None
                        self.number_p_ws_up = None
                        self.standby_pseudowires = None
                        self.number_pb_bs = None
                        self.number_pb_bs_up = None
                        self.num_vn_is = None
                        self.num_vn_is_up = None
                        self.partially_programmed_pseudowires = None
                        self.partially_programmed_a_cs = None
                        self.bridge_mtu = None
                        self.shutdown = None
                        self.mac_limit_down = None
                        self.flodd_group_id_down = None
                        self.mac_withdraw = None
                        self.mac_withdraw_access = None
                        self.mac_withdraw_relay = None
                        self.mac_withdraw_option = None
                        self.p2mp_enabled = None
                        self.bridge_type = None
                        self.vine_fsm_state = None
                        self.time_created = None
                        self.time_elapsed_creation = None
                        self.last_time_status_changed = None
                        self.time_elapsed_status_changed = None
                        self.load_balance = None
                        self.is_bridge_partially_programmed = None
                        self.evi = None
                        self.is_rd_configured = None
                        self.imposition_pkt_count = None
                        self.imposition_byte_count = None
                        self.disposition_pkt_count = None
                        self.disposition_bytecount = None
                        self.as_ = None
                        self.nv_satellite_offload_ipv4_multicast_disabled = None

                        self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                        self.security_parameters.parent = self
                        self._children_name_map["security_parameters"] = "security-parameters"

                        self.pbb_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                        self.pbb_parameters.parent = self
                        self._children_name_map["pbb_parameters"] = "pbb-parameters"

                        self.evpn_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                        self.evpn_parameters.parent = self
                        self._children_name_map["evpn_parameters"] = "evpn-parameters"

                        self.vni_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                        self.vni_parameters.parent = self
                        self._children_name_map["vni_parameters"] = "vni-parameters"

                        self.rd = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                        self.rd.parent = self
                        self._children_name_map["rd"] = "rd"

                        self.mac_filter = YList(self)
                        self.bridge_vfi = YList(self)
                        self.bridge_access_vfi = YList(self)
                        self._segment_path = lambda: "bridge-domain-info"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo, ['group_name', 'bridge_name', 'bridge_domain_id', 'bridge_description', 'bridge_state', 'bridge_coupled_state', 'bridge_shg_id', 'bridge_msti', 'acpwup', 'bridge_internal_msti', 'configured', 'number_vf_is', 'number_access_vf_is', 'number_a_cs', 'number_a_cs_up', 'number_pseudowires', 'number_p_ws_up', 'standby_pseudowires', 'number_pb_bs', 'number_pb_bs_up', 'num_vn_is', 'num_vn_is_up', 'partially_programmed_pseudowires', 'partially_programmed_a_cs', 'bridge_mtu', 'shutdown', 'mac_limit_down', 'flodd_group_id_down', 'mac_withdraw', 'mac_withdraw_access', 'mac_withdraw_relay', 'mac_withdraw_option', 'p2mp_enabled', 'bridge_type', 'vine_fsm_state', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'load_balance', 'is_bridge_partially_programmed', 'evi', 'is_rd_configured', 'imposition_pkt_count', 'imposition_byte_count', 'disposition_pkt_count', 'disposition_bytecount', 'as_', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                    class SecurityParameters(Entity):
                        """
                        Security parameters
                        
                        .. attribute:: storm_control
                        
                        	Storm Control Configuration
                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                        
                        .. attribute:: mac_limit
                        
                        	MAC address limit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: mac_limit_action
                        
                        	MAC limit action
                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                        
                        .. attribute:: mac_limit_notification
                        
                        	MAC limit notification
                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                        
                        .. attribute:: mac_aging_time
                        
                        	MAC aging time in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: mac_aging_mode
                        
                        	MAC Aging Mode
                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                        
                        .. attribute:: mac_flooding
                        
                        	MAC flooding enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_learning
                        
                        	MAC learning enabled
                        	**type**\: bool
                        
                        .. attribute:: learn_disabled_mac_limit_action
                        
                        	Learning disabled due to MAC limit action
                        	**type**\: bool
                        
                        .. attribute:: flood_uu_disabled_mac_limit_action
                        
                        	Flooding of unknown\-unicast disabled due to MAC limit action
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_reached
                        
                        	MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_threshold
                        
                        	MAC Limit Threshold Percentage
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: percentage
                        
                        .. attribute:: flood_unknown_unicast_enabled
                        
                        	Flooding unknown unicast enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_port_down_flush_enabled
                        
                        	MAC Flush when port goes down
                        	**type**\: bool
                        
                        .. attribute:: split_horizon_group_id
                        
                        	Split Horizon Group ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_ip_source_guard_enabled
                        
                        	Is IP Source Guard Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_ipsg_logging_enabled
                        
                        	Is IP Source Guard Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_enabled
                        
                        	Is Dynamic ARP Inspection Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_logging_enabled
                        
                        	Is DAI Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                        
                        	Is DAI Source MAC Address Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                        
                        	Is DAI Dstination MAC Address Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                        
                        	Is DAI IPv4 Addr Validation Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_enabled
                        
                        	Is MAC Secure Enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_secure_action
                        
                        	MAC Secure Action
                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                        
                        .. attribute:: is_mac_secure_logging_enabled
                        
                        	Is MAC Secure Logging Enabled
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                        
                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                        	**type**\: bool
                        
                        .. attribute:: is_mac_secure_threshold_enabled
                        
                        	Is MAC Secure Threshold Enabled
                        	**type**\: bool
                        
                        .. attribute:: dai_address_validation_mask
                        
                        	DAI Address Validation mask
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: dhcpv4_snoop
                        
                        	DHCPv4 Snoop Status
                        	**type**\: bool
                        
                        .. attribute:: dhcpv4_profile_name
                        
                        	DHCPv4 Profile Name
                        	**type**\: str
                        
                        .. attribute:: igm_pv4_disabled
                        
                        	IGMPv4 Disabled
                        	**type**\: bool
                        
                        .. attribute:: igm_pv4_profile_name
                        
                        	IGMPv4 Profile Name
                        	**type**\: str
                        
                        .. attribute:: mld_profile_name
                        
                        	MLD Profile Name
                        	**type**\: str
                        
                        .. attribute:: mmrp_flood_optimization
                        
                        	MMRP Flood Optimization Status
                        	**type**\: bool
                        
                        .. attribute:: unicast_storm_control_rate_unit
                        
                        	Unicast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: unicast_storm_control_pps
                        
                        	Unicast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: unicast_storm_control_kb_ps
                        
                        	Unicast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: multicast_storm_control_rate_unit
                        
                        	Multicast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: multicast_storm_control_pps
                        
                        	Multicast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: multicast_storm_control_kb_ps
                        
                        	Multicast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        .. attribute:: broadcast_storm_control_rate_unit
                        
                        	Broadcast Storm Control Rate Unit
                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                        
                        .. attribute:: broadcast_storm_control_pps
                        
                        	Broadcast Storm Control PPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: broadcast_storm_control_kb_ps
                        
                        	Broadcast Storm Control KbPS
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        	**units**\: kbit/s
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                            self.yang_name = "security-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl))])
                            self._leafs = OrderedDict([
                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                            ])
                            self.mac_limit = None
                            self.mac_limit_action = None
                            self.mac_limit_notification = None
                            self.mac_aging_time = None
                            self.mac_aging_mode = None
                            self.mac_flooding = None
                            self.mac_learning = None
                            self.learn_disabled_mac_limit_action = None
                            self.flood_uu_disabled_mac_limit_action = None
                            self.mac_limit_reached = None
                            self.mac_limit_threshold = None
                            self.flood_unknown_unicast_enabled = None
                            self.mac_port_down_flush_enabled = None
                            self.split_horizon_group_id = None
                            self.is_ip_source_guard_enabled = None
                            self.is_ipsg_logging_enabled = None
                            self.is_dai_enabled = None
                            self.is_dai_logging_enabled = None
                            self.is_dai_addr_validate_source_mac_enabled = None
                            self.is_dai_addr_validate_destination_mac_enabled = None
                            self.is_dai_addr_validate_ipv4_enabled = None
                            self.is_mac_secure_enabled = None
                            self.mac_secure_action = None
                            self.is_mac_secure_logging_enabled = None
                            self.is_mac_secure_accept_shutdown_enabled = None
                            self.is_mac_secure_threshold_enabled = None
                            self.dai_address_validation_mask = None
                            self.dhcpv4_snoop = None
                            self.dhcpv4_profile_name = None
                            self.igm_pv4_disabled = None
                            self.igm_pv4_profile_name = None
                            self.mld_profile_name = None
                            self.mmrp_flood_optimization = None
                            self.unicast_storm_control_rate_unit = None
                            self.unicast_storm_control_pps = None
                            self.unicast_storm_control_kb_ps = None
                            self.multicast_storm_control_rate_unit = None
                            self.multicast_storm_control_pps = None
                            self.multicast_storm_control_kb_ps = None
                            self.broadcast_storm_control_rate_unit = None
                            self.broadcast_storm_control_pps = None
                            self.broadcast_storm_control_kb_ps = None

                            self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                            self.storm_control.parent = self
                            self._children_name_map["storm_control"] = "storm-control"
                            self._segment_path = lambda: "security-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                        class StormControl(Entity):
                            """
                            Storm Control Configuration
                            
                            .. attribute:: bd_policer
                            
                            	Bridge Domain Policer
                            	**type**\: bool
                            
                            .. attribute:: unicast
                            
                            	Unknown\-unicast Storm Control
                            	**type**\: bool
                            
                            .. attribute:: multicast
                            
                            	Multicast Storm Control
                            	**type**\: bool
                            
                            .. attribute:: broadcast
                            
                            	Broadcast Storm Control
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                self.yang_name = "storm-control"
                                self.yang_parent_name = "security-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                ])
                                self.bd_policer = None
                                self.unicast = None
                                self.multicast = None
                                self.broadcast = None
                                self._segment_path = lambda: "storm-control"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/security-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                    class PbbParameters(Entity):
                        """
                        PBB parameters
                        
                        .. attribute:: pbb_edge
                        
                        	PBB Edge
                        	**type**\:  :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                        
                        .. attribute:: pbb_core
                        
                        	PBB Core
                        	**type**\:  :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                        
                        .. attribute:: type
                        
                        	Type
                        	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                            self.yang_name = "pbb-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pbb-edge", ("pbb_edge", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge)), ("pbb-core", ("pbb_core", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore))])
                            self._leafs = OrderedDict([
                                ('type', YLeaf(YType.enumeration, 'type')),
                            ])
                            self.type = None

                            self.pbb_edge = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                            self.pbb_edge.parent = self
                            self._children_name_map["pbb_edge"] = "pbb-edge"

                            self.pbb_core = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                            self.pbb_core.parent = self
                            self._children_name_map["pbb_core"] = "pbb-core"
                            self._segment_path = lambda: "pbb-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, ['type'], name, value)


                        class PbbEdge(Entity):
                            """
                            PBB Edge
                            
                            .. attribute:: edge_port
                            
                            	PBB Edge Port
                            	**type**\:  :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                            
                            .. attribute:: i_sid
                            
                            	SID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: core_bridge_name
                            
                            	Core Bridge Domain Name
                            	**type**\: str
                            
                            .. attribute:: core_bridge_state
                            
                            	Core Bridge State
                            	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                            
                            .. attribute:: mirp_lite_status
                            
                            	MIRP\-lite Status
                            	**type**\:  :py:class:`L2vpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteStatus>`
                            
                            .. attribute:: mirp_lite_protocol
                            
                            	MIRP\-lite protocol info
                            	**type**\:  :py:class:`L2vpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteProtocolInfo>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                self.yang_name = "pbb-edge"
                                self.yang_parent_name = "pbb-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("edge-port", ("edge_port", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort))])
                                self._leafs = OrderedDict([
                                    ('i_sid', YLeaf(YType.uint32, 'i-sid')),
                                    ('core_bridge_name', YLeaf(YType.str, 'core-bridge-name')),
                                    ('core_bridge_state', YLeaf(YType.enumeration, 'core-bridge-state')),
                                    ('mirp_lite_status', YLeaf(YType.enumeration, 'mirp-lite-status')),
                                    ('mirp_lite_protocol', YLeaf(YType.enumeration, 'mirp-lite-protocol')),
                                ])
                                self.i_sid = None
                                self.core_bridge_name = None
                                self.core_bridge_state = None
                                self.mirp_lite_status = None
                                self.mirp_lite_protocol = None

                                self.edge_port = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                self.edge_port.parent = self
                                self._children_name_map["edge_port"] = "edge-port"
                                self._segment_path = lambda: "pbb-edge"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, ['i_sid', 'core_bridge_name', 'core_bridge_state', 'mirp_lite_status', 'mirp_lite_protocol'], name, value)


                            class EdgePort(Entity):
                                """
                                PBB Edge Port
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: unknown_unicast_mac_set
                                
                                	Unknown Unicast MAC Configured
                                	**type**\: bool
                                
                                .. attribute:: unknown_unicast_mac
                                
                                	Unknown Unicast MAC
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: edge_port_state
                                
                                	PBB Edge Port State
                                	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                
                                .. attribute:: bmac_mapping
                                
                                	CMAC to BMAC Mapping
                                	**type**\: list of  		 :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                    self.yang_name = "edge-port"
                                    self.yang_parent_name = "pbb-edge"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics)), ("bmac-mapping", ("bmac_mapping", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping))])
                                    self._leafs = OrderedDict([
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('unknown_unicast_mac_set', YLeaf(YType.boolean, 'unknown-unicast-mac-set')),
                                        ('unknown_unicast_mac', YLeaf(YType.str, 'unknown-unicast-mac')),
                                        ('edge_port_state', YLeaf(YType.enumeration, 'edge-port-state')),
                                    ])
                                    self.xconnect_id = None
                                    self.unknown_unicast_mac_set = None
                                    self.unknown_unicast_mac = None
                                    self.edge_port_state = None

                                    self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"

                                    self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.bmac_mapping = YList(self)
                                    self._segment_path = lambda: "edge-port"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, ['xconnect_id', 'unknown_unicast_mac_set', 'unknown_unicast_mac', 'edge_port_state'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/base/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/impostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/dispostion-stats/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/statistics/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class BmacMapping(Entity):
                                    """
                                    CMAC to BMAC Mapping
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                        self.yang_name = "bmac-mapping"
                                        self.yang_parent_name = "edge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', YLeaf(YType.str, 'address')),
                                            ('bmac', YLeaf(YType.str, 'bmac')),
                                            ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                        ])
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None
                                        self._segment_path = lambda: "bmac-mapping"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-edge/edge-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class PbbCore(Entity):
                            """
                            PBB Core
                            
                            .. attribute:: core_port
                            
                            	PBB Core Port
                            	**type**\:  :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                            
                            .. attribute:: num_ass_edge
                            
                            	Number of Associated PBB Edges
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                self.yang_name = "pbb-core"
                                self.yang_parent_name = "pbb-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("core-port", ("core_port", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort))])
                                self._leafs = OrderedDict([
                                    ('num_ass_edge', YLeaf(YType.uint32, 'num-ass-edge')),
                                ])
                                self.num_ass_edge = None

                                self.core_port = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                self.core_port.parent = self
                                self._children_name_map["core_port"] = "core-port"
                                self._segment_path = lambda: "pbb-core"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, ['num_ass_edge'], name, value)


                            class CorePort(Entity):
                                """
                                PBB Core Port
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vlan_id
                                
                                	Vlan ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: core_port_state
                                
                                	PBB Core Port State
                                	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                    self.yang_name = "core-port"
                                    self.yang_parent_name = "pbb-core"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters))])
                                    self._leafs = OrderedDict([
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                        ('core_port_state', YLeaf(YType.enumeration, 'core-port-state')),
                                    ])
                                    self.xconnect_id = None
                                    self.vlan_id = None
                                    self.core_port_state = None

                                    self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"
                                    self._segment_path = lambda: "core-port"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, ['xconnect_id', 'vlan_id', 'core_port_state'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "core-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = False
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"
                                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/base/%s" % self._segment_path()

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/pbb-parameters/pbb-core/core-port/security-parameters/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                    class EvpnParameters(Entity):
                        """
                        EVPN parameters
                        
                        .. attribute:: evpn_port
                        
                        	EVPN Port
                        	**type**\:  :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                            self.yang_name = "evpn-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("evpn-port", ("evpn_port", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort))])
                            self._leafs = OrderedDict([
                                ('evi', YLeaf(YType.uint32, 'evi')),
                            ])
                            self.evi = None

                            self.evpn_port = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                            self.evpn_port.parent = self
                            self._children_name_map["evpn_port"] = "evpn-port"
                            self._segment_path = lambda: "evpn-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, ['evi'], name, value)


                        class EvpnPort(Entity):
                            """
                            EVPN Port
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: evpn_port_state
                            
                            	EVPN Port State
                            	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                self.yang_name = "evpn-port"
                                self.yang_parent_name = "evpn-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics))])
                                self._leafs = OrderedDict([
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('evpn_port_state', YLeaf(YType.enumeration, 'evpn-port-state')),
                                ])
                                self.xconnect_id = None
                                self.evpn_port_state = None

                                self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"
                                self._segment_path = lambda: "evpn-port"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, ['xconnect_id', 'evpn_port_state'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "evpn-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/base/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/security-parameters/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "evpn-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/impostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = False
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"
                                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/dispostion-stats/%s" % self._segment_path()

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/evpn-parameters/evpn-port/statistics/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                    class VniParameters(Entity):
                        """
                        VNI parameters
                        
                        .. attribute:: security_parameters
                        
                        	Security Parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                        
                        .. attribute:: vni
                        
                        	VNI
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: overlay
                        
                        	NVE Overlay
                        	**type**\: str
                        
                        .. attribute:: source_ip_addr
                        
                        	Source IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: multicast_group_addr
                        
                        	Multicast Group Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_vtep_ip_addr
                        
                        	Anycast VTEP IP Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: anycast_mcast_group_addr
                        
                        	Anycast Multicast Group Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: udp_port
                        
                        	UDP Port
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vni_encap_type
                        
                        	VNI Encapsulation Type
                        	**type**\:  :py:class:`L2vpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniEncaps>`
                        
                        .. attribute:: vni_port_state
                        
                        	VNI Port State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: vni_mode
                        
                        	VNI Mode
                        	**type**\:  :py:class:`L2vpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniMode>`
                        
                        .. attribute:: ingress_replication
                        
                        	VNI Ingress Replication is enabled
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	Xconnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: static_mac
                        
                        	Static MAC addresses
                        	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                            self.yang_name = "vni-parameters"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics)), ("static-mac", ("static_mac", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac))])
                            self._leafs = OrderedDict([
                                ('vni', YLeaf(YType.uint32, 'vni')),
                                ('overlay', YLeaf(YType.str, 'overlay')),
                                ('source_ip_addr', YLeaf(YType.str, 'source-ip-addr')),
                                ('multicast_group_addr', YLeaf(YType.str, 'multicast-group-addr')),
                                ('anycast_vtep_ip_addr', YLeaf(YType.str, 'anycast-vtep-ip-addr')),
                                ('anycast_mcast_group_addr', YLeaf(YType.str, 'anycast-mcast-group-addr')),
                                ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                ('vni_encap_type', YLeaf(YType.enumeration, 'vni-encap-type')),
                                ('vni_port_state', YLeaf(YType.enumeration, 'vni-port-state')),
                                ('vni_mode', YLeaf(YType.enumeration, 'vni-mode')),
                                ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                            ])
                            self.vni = None
                            self.overlay = None
                            self.source_ip_addr = None
                            self.multicast_group_addr = None
                            self.anycast_vtep_ip_addr = None
                            self.anycast_mcast_group_addr = None
                            self.udp_port = None
                            self.vni_encap_type = None
                            self.vni_port_state = None
                            self.vni_mode = None
                            self.ingress_replication = None
                            self.xconnect_id = None

                            self.security_parameters = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.statistics = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.static_mac = YList(self)
                            self._segment_path = lambda: "vni-parameters"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, ['vni', 'overlay', 'source_ip_addr', 'multicast_group_addr', 'anycast_vtep_ip_addr', 'anycast_mcast_group_addr', 'udp_port', 'vni_encap_type', 'vni_port_state', 'vni_mode', 'ingress_replication', 'xconnect_id'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security Parameters
                            
                            .. attribute:: base
                            
                            	Basic Security Parameters
                            	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: dhcpv4_trust
                            
                            	DHCPv4 Trust Status
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                ])
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None
                                self.dhcpv4_trust = None

                                self.base = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                self.base.parent = self
                                self._children_name_map["base"] = "base"

                                self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                            class Base(Entity):
                                """
                                Basic Security Parameters
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                
                                .. attribute:: mac_limit
                                
                                	MAC address limit
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mac_limit_action
                                
                                	MAC limit action
                                	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                
                                .. attribute:: mac_limit_notification
                                
                                	MAC limit notification
                                	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                
                                .. attribute:: mac_aging_time
                                
                                	MAC aging time in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: mac_aging_mode
                                
                                	MAC Aging Mode
                                	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                
                                .. attribute:: mac_flooding
                                
                                	MAC flooding enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_learning
                                
                                	MAC learning enabled
                                	**type**\: bool
                                
                                .. attribute:: learn_disabled_mac_limit_action
                                
                                	Learning disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: flood_uu_disabled_mac_limit_action
                                
                                	Flooding of unknown\-unicast disabled due to MAC limit action
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_reached
                                
                                	MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_threshold
                                
                                	MAC Limit Threshold Percentage
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: percentage
                                
                                .. attribute:: flood_unknown_unicast_enabled
                                
                                	Flooding unknown unicast enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_port_down_flush_enabled
                                
                                	MAC Flush when port goes down
                                	**type**\: bool
                                
                                .. attribute:: split_horizon_group_id
                                
                                	Split Horizon Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_ip_source_guard_enabled
                                
                                	Is IP Source Guard Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_ipsg_logging_enabled
                                
                                	Is IP Source Guard Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_enabled
                                
                                	Is Dynamic ARP Inspection Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_logging_enabled
                                
                                	Is DAI Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_source_mac_enabled
                                
                                	Is DAI Source MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                
                                	Is DAI Dstination MAC Address Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_dai_addr_validate_ipv4_enabled
                                
                                	Is DAI IPv4 Addr Validation Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_enabled
                                
                                	Is MAC Secure Enabled
                                	**type**\: bool
                                
                                .. attribute:: mac_secure_action
                                
                                	MAC Secure Action
                                	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                
                                .. attribute:: is_mac_secure_logging_enabled
                                
                                	Is MAC Secure Logging Enabled
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_accept_shutdown_enabled
                                
                                	Is MAC Secure Accept Shutdown Enabled (BP only)
                                	**type**\: bool
                                
                                .. attribute:: is_mac_secure_threshold_enabled
                                
                                	Is MAC Secure Threshold Enabled
                                	**type**\: bool
                                
                                .. attribute:: dai_address_validation_mask
                                
                                	DAI Address Validation mask
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: dhcpv4_snoop
                                
                                	DHCPv4 Snoop Status
                                	**type**\: bool
                                
                                .. attribute:: dhcpv4_profile_name
                                
                                	DHCPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: igm_pv4_disabled
                                
                                	IGMPv4 Disabled
                                	**type**\: bool
                                
                                .. attribute:: igm_pv4_profile_name
                                
                                	IGMPv4 Profile Name
                                	**type**\: str
                                
                                .. attribute:: mld_profile_name
                                
                                	MLD Profile Name
                                	**type**\: str
                                
                                .. attribute:: mmrp_flood_optimization
                                
                                	MMRP Flood Optimization Status
                                	**type**\: bool
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                    self.yang_name = "base"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                        ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                        ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                        ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                        ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                        ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                        ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                        ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                        ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                        ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                        ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                        ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                        ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                        ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                        ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                        ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                        ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                        ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                        ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                        ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                        ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                        ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                        ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                        ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                        ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                        ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                        ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                        ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                        ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                        ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                        ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                        ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                        ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                    ])
                                    self.mac_limit = None
                                    self.mac_limit_action = None
                                    self.mac_limit_notification = None
                                    self.mac_aging_time = None
                                    self.mac_aging_mode = None
                                    self.mac_flooding = None
                                    self.mac_learning = None
                                    self.learn_disabled_mac_limit_action = None
                                    self.flood_uu_disabled_mac_limit_action = None
                                    self.mac_limit_reached = None
                                    self.mac_limit_threshold = None
                                    self.flood_unknown_unicast_enabled = None
                                    self.mac_port_down_flush_enabled = None
                                    self.split_horizon_group_id = None
                                    self.is_ip_source_guard_enabled = None
                                    self.is_ipsg_logging_enabled = None
                                    self.is_dai_enabled = None
                                    self.is_dai_logging_enabled = None
                                    self.is_dai_addr_validate_source_mac_enabled = None
                                    self.is_dai_addr_validate_destination_mac_enabled = None
                                    self.is_dai_addr_validate_ipv4_enabled = None
                                    self.is_mac_secure_enabled = None
                                    self.mac_secure_action = None
                                    self.is_mac_secure_logging_enabled = None
                                    self.is_mac_secure_accept_shutdown_enabled = None
                                    self.is_mac_secure_threshold_enabled = None
                                    self.dai_address_validation_mask = None
                                    self.dhcpv4_snoop = None
                                    self.dhcpv4_profile_name = None
                                    self.igm_pv4_disabled = None
                                    self.igm_pv4_profile_name = None
                                    self.mld_profile_name = None
                                    self.mmrp_flood_optimization = None
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None

                                    self.storm_control = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "base"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "base"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/base/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/security-parameters/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/impostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/dispostion-stats/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/statistics/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class StaticMac(Entity):
                            """
                            Static MAC addresses
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                self.yang_name = "static-mac"
                                self.yang_parent_name = "vni-parameters"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "static-mac"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/vni-parameters/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class Rd(Entity):
                        """
                        Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                            self.yang_name = "rd"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/rd/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                    class MacFilter(Entity):
                        """
                        MAC addresses for filtering
                        
                        .. attribute:: address
                        
                        	MAC address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: bmac
                        
                        	Backbone MAC address
                        	**type**\: str
                        
                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                        
                        .. attribute:: next_hop_ip
                        
                        	Next Hop IP
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                            self.yang_name = "mac-filter"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('address', YLeaf(YType.str, 'address')),
                                ('bmac', YLeaf(YType.str, 'bmac')),
                                ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                            ])
                            self.address = None
                            self.bmac = None
                            self.next_hop_ip = None
                            self._segment_path = lambda: "mac-filter"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeVfi(Entity):
                        """
                        Virtual Forwarding Interfaces
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\: bool
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                            self.yang_name = "bridge-vfi"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation))])
                            self._leafs = OrderedDict([
                                ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('access', YLeaf(YType.boolean, 'access')),
                                ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ])
                            self.vfi_name = None
                            self.shutdown = None
                            self.access = None
                            self.vfi_state = None
                            self.number_pseudowires = None

                            self.discovery_information = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"

                            self.p2mp_information = YList(self)
                            self._segment_path = lambda: "bridge-vfi"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\: bool
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\: bool
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\: bool
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\: str
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt))])
                                self._leafs = OrderedDict([
                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('ve_id', YLeaf(YType.uint32, 've-id')),
                                    ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                    ('ve_range', YLeaf(YType.uint16, 've-range')),
                                    ('as_number', YLeaf(YType.uint32, 'as-number')),
                                    ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                    ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                    ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                    ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                    ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                ])
                                self.vpn_id = None
                                self.ad_signalling_method = None
                                self.ad_method = None
                                self.ve_id = None
                                self.provisioned_ve_id = None
                                self.ve_range = None
                                self.as_number = None
                                self.l2vpn_router_id = None
                                self.vpn_added = None
                                self.service_connected = None
                                self.vpls_id_conflict = None
                                self.export_route_policy = None

                                self.rd_value = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"

                                self.vpls_id = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"

                                self.import_rt = YList(self)
                                self.export_rt = YList(self)
                                self._segment_path = lambda: "discovery-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('rd', YLeaf(YType.enumeration, 'rd')),
                                    ])
                                    self.rd = None

                                    self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "rd-value"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('router_id', YLeaf(YType.str, 'router-id')),
                                            ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                        ])
                                        self.router_id = None
                                        self.auto_index = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                    ])
                                    self.vpls_id_type = None

                                    self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "vpls-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ])
                                        self.asn = None
                                        self.vpn_id = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "import-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "export-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                        class P2mpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\: str
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('transport', YLeaf(YType.enumeration, 'transport')),
                                    ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                    ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                    ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                    ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                ])
                                self.transport = None
                                self.signaling = None
                                self.ptree_id = None
                                self.attribute_set_name = None
                                self.transport_status = None
                                self.local_label = None
                                self.tunnel_interface = None
                                self._segment_path = lambda: "p2mp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


                    class BridgeAccessVfi(Entity):
                        """
                        Access Virtual Forwarding Interfaces
                        
                        .. attribute:: discovery_information
                        
                        	Auto Discovery information
                        	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                        
                        .. attribute:: vfi_name
                        
                        	Virtual forwarding instance name
                        	**type**\: str
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: access
                        
                        	VFI is an Access VFI
                        	**type**\: bool
                        
                        .. attribute:: vfi_state
                        
                        	VFI state
                        	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of Pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: p2mp_information
                        
                        	Multicast P2MP information
                        	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                            self.yang_name = "bridge-access-vfi"
                            self.yang_parent_name = "bridge-domain-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation))])
                            self._leafs = OrderedDict([
                                ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('access', YLeaf(YType.boolean, 'access')),
                                ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                            ])
                            self.vfi_name = None
                            self.shutdown = None
                            self.access = None
                            self.vfi_state = None
                            self.number_pseudowires = None

                            self.discovery_information = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                            self.discovery_information.parent = self
                            self._children_name_map["discovery_information"] = "discovery-information"

                            self.p2mp_information = YList(self)
                            self._segment_path = lambda: "bridge-access-vfi"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                        class DiscoveryInformation(Entity):
                            """
                            Auto Discovery information
                            
                            .. attribute:: rd_value
                            
                            	Route Distinguisher
                            	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                            
                            .. attribute:: vpls_id
                            
                            	VPLS ID
                            	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                            
                            .. attribute:: vpn_id
                            
                            	Vpn ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_signalling_method
                            
                            	Signaling protocol
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_id
                            
                            	VPLS Edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: provisioned_ve_id
                            
                            	Provisioned VPLS edge ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ve_range
                            
                            	VE range
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: as_number
                            
                            	Autonomous System Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: l2vpn_router_id
                            
                            	L2PVN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: vpn_added
                            
                            	Is VPN id configured
                            	**type**\: bool
                            
                            .. attribute:: service_connected
                            
                            	Is the BGP service connected?
                            	**type**\: bool
                            
                            .. attribute:: vpls_id_conflict
                            
                            	VPLS\-ID Conflict
                            	**type**\: bool
                            
                            .. attribute:: export_route_policy
                            
                            	Export Route Policy
                            	**type**\: str
                            
                            .. attribute:: import_rt
                            
                            	List of import route targets
                            	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                            
                            .. attribute:: export_rt
                            
                            	List of export route targets
                            	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                self.yang_name = "discovery-information"
                                self.yang_parent_name = "bridge-access-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt))])
                                self._leafs = OrderedDict([
                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                    ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('ve_id', YLeaf(YType.uint32, 've-id')),
                                    ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                    ('ve_range', YLeaf(YType.uint16, 've-range')),
                                    ('as_number', YLeaf(YType.uint32, 'as-number')),
                                    ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                    ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                    ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                    ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                    ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                ])
                                self.vpn_id = None
                                self.ad_signalling_method = None
                                self.ad_method = None
                                self.ve_id = None
                                self.provisioned_ve_id = None
                                self.ve_range = None
                                self.as_number = None
                                self.l2vpn_router_id = None
                                self.vpn_added = None
                                self.service_connected = None
                                self.vpls_id_conflict = None
                                self.export_route_policy = None

                                self.rd_value = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                self.rd_value.parent = self
                                self._children_name_map["rd_value"] = "rd-value"

                                self.vpls_id = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                self.vpls_id.parent = self
                                self._children_name_map["vpls_id"] = "vpls-id"

                                self.import_rt = YList(self)
                                self.export_rt = YList(self)
                                self._segment_path = lambda: "discovery-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                            class RdValue(Entity):
                                """
                                Route Distinguisher
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                
                                .. attribute:: rd
                                
                                	RD
                                	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                    self.yang_name = "rd-value"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('rd', YLeaf(YType.enumeration, 'rd')),
                                    ])
                                    self.rd = None

                                    self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "rd-value"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: router_id
                                    
                                    	BGP Router ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: auto_index
                                    
                                    	Auto\-generated Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('router_id', YLeaf(YType.str, 'router-id')),
                                            ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                        ])
                                        self.router_id = None
                                        self.auto_index = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "rd-value"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/rd-value/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class VplsId(Entity):
                                """
                                VPLS ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                    self.yang_name = "vpls-id"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                    ])
                                    self.vpls_id_type = None

                                    self.auto = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "vpls-id"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ])
                                        self.asn = None
                                        self.vpn_id = None
                                        self._segment_path = lambda: "auto"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/vpls-id/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class ImportRt(Entity):
                                """
                                List of import route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                    self.yang_name = "import-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "import-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "import-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/import-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class ExportRt(Entity):
                                """
                                List of export route targets
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                
                                .. attribute:: four_byte_as
                                
                                	four byte as
                                	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                
                                .. attribute:: es_import
                                
                                	es import
                                	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                
                                .. attribute:: rt
                                
                                	RT
                                	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                    self.yang_name = "export-rt"
                                    self.yang_parent_name = "discovery-information"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = False
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport))])
                                    self._leafs = OrderedDict([
                                        ('rt', YLeaf(YType.enumeration, 'rt')),
                                    ])
                                    self.rt = None

                                    self.two_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.four_byte_as = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                    self.four_byte_as.parent = self
                                    self._children_name_map["four_byte_as"] = "four-byte-as"

                                    self.v4_addr = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"

                                    self.es_import = L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                    self.es_import.parent = self
                                    self._children_name_map["es_import"] = "es-import"
                                    self._segment_path = lambda: "export-rt"
                                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/%s" % self._segment_path()

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class FourByteAs(Entity):
                                    """
                                    four byte as
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	4 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                        self.yang_name = "four-byte-as"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.four_byte_as = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "four-byte-as"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class EsImport(Entity):
                                    """
                                    es import
                                    
                                    .. attribute:: high_bytes
                                    
                                    	Top 4 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: low_bytes
                                    
                                    	Low 2 bytes of ES Import
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                        self.yang_name = "es-import"
                                        self.yang_parent_name = "export-rt"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = False
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                            ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                        ])
                                        self.high_bytes = None
                                        self.low_bytes = None
                                        self._segment_path = lambda: "es-import"
                                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/discovery-information/export-rt/%s" % self._segment_path()

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                        class P2mpInformation(Entity):
                            """
                            Multicast P2MP information
                            
                            .. attribute:: transport
                            
                            	P2MP transport
                            	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                            
                            .. attribute:: signaling
                            
                            	P2MP signaling
                            	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                            
                            .. attribute:: ptree_id
                            
                            	PTree ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: attribute_set_name
                            
                            	TE Attribute Set Name
                            	**type**\: str
                            
                            .. attribute:: transport_status
                            
                            	Transport Status
                            	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                            
                            .. attribute:: local_label
                            
                            	P2MP Tunnel Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tunnel_interface
                            
                            	P2MP Tunnel Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, self).__init__()

                                self.yang_name = "p2mp-information"
                                self.yang_parent_name = "bridge-access-vfi"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('transport', YLeaf(YType.enumeration, 'transport')),
                                    ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                    ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                    ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                    ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                ])
                                self.transport = None
                                self.signaling = None
                                self.ptree_id = None
                                self.attribute_set_name = None
                                self.transport_status = None
                                self.local_label = None
                                self.tunnel_interface = None
                                self._segment_path = lambda: "p2mp-information"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/bridge-domains/bridge-domain/bridge-domain-info/bridge-access-vfi/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


        class DiscoverySummary(Entity):
            """
            Discovery summary information
            
            .. attribute:: number_bridge_domainvpns
            
            	Number of BDs registered
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_mp2m_pxconnect_vpns
            
            	Number of XCs registered
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_bridge_domain
            
            	Number of local Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_bridge_domain
            
            	Number of Remote Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_bridge_domain
            
            	Number of NLRI
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_local_edges_xconnect
            
            	Number of local Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_remote_edges_xconnect
            
            	Number of Remote Edges
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: number_nlri_xconnect
            
            	Number of NLRI
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: bgp_stateon_active_rp
            
            	BGP state on the active RP
            	**type**\: bool
            
            .. attribute:: bgp_stateon_standby_rp
            
            	BGP state on standby RP
            	**type**\: bool
            
            .. attribute:: vpls_registered
            
            	Is the VPLS service registered
            	**type**\: bool
            
            .. attribute:: vpws_registered
            
            	Is the VPWS service registered
            	**type**\: bool
            
            .. attribute:: bgp_ipc_transport_mode
            
            	IPC Transport mode with BGP
            	**type**\:  :py:class:`L2vpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIpcTransportMode>`
            
            .. attribute:: bgp_current_node_id
            
            	BGP current node id
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.DiscoverySummary, self).__init__()

                self.yang_name = "discovery-summary"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('number_bridge_domainvpns', YLeaf(YType.uint32, 'number-bridge-domainvpns')),
                    ('number_mp2m_pxconnect_vpns', YLeaf(YType.uint32, 'number-mp2m-pxconnect-vpns')),
                    ('number_local_edges_bridge_domain', YLeaf(YType.uint32, 'number-local-edges-bridge-domain')),
                    ('number_remote_edges_bridge_domain', YLeaf(YType.uint32, 'number-remote-edges-bridge-domain')),
                    ('number_nlri_bridge_domain', YLeaf(YType.uint32, 'number-nlri-bridge-domain')),
                    ('number_local_edges_xconnect', YLeaf(YType.uint32, 'number-local-edges-xconnect')),
                    ('number_remote_edges_xconnect', YLeaf(YType.uint32, 'number-remote-edges-xconnect')),
                    ('number_nlri_xconnect', YLeaf(YType.uint32, 'number-nlri-xconnect')),
                    ('bgp_stateon_active_rp', YLeaf(YType.boolean, 'bgp-stateon-active-rp')),
                    ('bgp_stateon_standby_rp', YLeaf(YType.boolean, 'bgp-stateon-standby-rp')),
                    ('vpls_registered', YLeaf(YType.boolean, 'vpls-registered')),
                    ('vpws_registered', YLeaf(YType.boolean, 'vpws-registered')),
                    ('bgp_ipc_transport_mode', YLeaf(YType.enumeration, 'bgp-ipc-transport-mode')),
                    ('bgp_current_node_id', YLeaf(YType.str, 'bgp-current-node-id')),
                ])
                self.number_bridge_domainvpns = None
                self.number_mp2m_pxconnect_vpns = None
                self.number_local_edges_bridge_domain = None
                self.number_remote_edges_bridge_domain = None
                self.number_nlri_bridge_domain = None
                self.number_local_edges_xconnect = None
                self.number_remote_edges_xconnect = None
                self.number_nlri_xconnect = None
                self.bgp_stateon_active_rp = None
                self.bgp_stateon_standby_rp = None
                self.vpls_registered = None
                self.vpws_registered = None
                self.bgp_ipc_transport_mode = None
                self.bgp_current_node_id = None
                self._segment_path = lambda: "discovery-summary"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.DiscoverySummary, ['number_bridge_domainvpns', 'number_mp2m_pxconnect_vpns', 'number_local_edges_bridge_domain', 'number_remote_edges_bridge_domain', 'number_nlri_bridge_domain', 'number_local_edges_xconnect', 'number_remote_edges_xconnect', 'number_nlri_xconnect', 'bgp_stateon_active_rp', 'bgp_stateon_standby_rp', 'vpls_registered', 'vpws_registered', 'bgp_ipc_transport_mode', 'bgp_current_node_id'], name, value)


        class G8032(Entity):
            """
            G8032 information
            
            .. attribute:: g8032_rings
            
            	G8032 Ring table
            	**type**\:  :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.G8032, self).__init__()

                self.yang_name = "g8032"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("g8032-rings", ("g8032_rings", L2vpnv2.Active.G8032.G8032Rings))])
                self._leafs = OrderedDict()

                self.g8032_rings = L2vpnv2.Active.G8032.G8032Rings()
                self.g8032_rings.parent = self
                self._children_name_map["g8032_rings"] = "g8032-rings"
                self._segment_path = lambda: "g8032"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.G8032, [], name, value)


            class G8032Rings(Entity):
                """
                G8032 Ring table
                
                .. attribute:: g8032_ring
                
                	G8032 Ring
                	**type**\: list of  		 :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.G8032.G8032Rings, self).__init__()

                    self.yang_name = "g8032-rings"
                    self.yang_parent_name = "g8032"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("g8032-ring", ("g8032_ring", L2vpnv2.Active.G8032.G8032Rings.G8032Ring))])
                    self._leafs = OrderedDict()

                    self.g8032_ring = YList(self)
                    self._segment_path = lambda: "g8032-rings"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/g8032/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings, [], name, value)


                class G8032Ring(Entity):
                    """
                    G8032 Ring
                    
                    .. attribute:: ring_name  (key)
                    
                    	Ring Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: g8032_ring_detail
                    
                    	G8032 Ring detailed information
                    	**type**\:  :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                    
                    .. attribute:: g8032_ring_instance_summaries
                    
                    	G8032 Ring Instance summary table
                    	**type**\:  :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                    
                    .. attribute:: g8032_ring_summary
                    
                    	G8032 Ring summary information
                    	**type**\:  :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                    
                    .. attribute:: g8032_ring_instance_details
                    
                    	G8032 Ring Instance detail table
                    	**type**\:  :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring, self).__init__()

                        self.yang_name = "g8032-ring"
                        self.yang_parent_name = "g8032-rings"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['ring_name']
                        self._child_classes = OrderedDict([("g8032-ring-detail", ("g8032_ring_detail", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail)), ("g8032-ring-instance-summaries", ("g8032_ring_instance_summaries", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries)), ("g8032-ring-summary", ("g8032_ring_summary", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary)), ("g8032-ring-instance-details", ("g8032_ring_instance_details", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails))])
                        self._leafs = OrderedDict([
                            ('ring_name', YLeaf(YType.str, 'ring-name')),
                        ])
                        self.ring_name = None

                        self.g8032_ring_detail = L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                        self.g8032_ring_detail.parent = self
                        self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"

                        self.g8032_ring_instance_summaries = L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                        self.g8032_ring_instance_summaries.parent = self
                        self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"

                        self.g8032_ring_summary = L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                        self.g8032_ring_summary.parent = self
                        self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"

                        self.g8032_ring_instance_details = L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                        self.g8032_ring_instance_details.parent = self
                        self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                        self._segment_path = lambda: "g8032-ring" + "[ring-name='" + str(self.ring_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/g8032/g8032-rings/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring, ['ring_name'], name, value)


                    class G8032RingDetail(Entity):
                        """
                        G8032 Ring detailed information
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\: str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\: str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\: str
                        
                        .. attribute:: monitor0
                        
                        	Monitor port 0
                        	**type**\: str
                        
                        .. attribute:: monitor1
                        
                        	Monitor port 1
                        	**type**\: str
                        
                        .. attribute:: is_provider_bridge
                        
                        	Operating mode Customer/Provider 
                        	**type**\: bool
                        
                        .. attribute:: is_open_ring
                        
                        	Flag open ring
                        	**type**\: bool
                        
                        .. attribute:: tcn_propagation
                        
                        	Global TCN propagation
                        	**type**\: bool
                        
                        .. attribute:: excluded_vlan_id
                        
                        	Exclusion Vlan ids list 
                        	**type**\: list of  		 :py:class:`ExcludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                            self.yang_name = "g8032-ring-detail"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("excluded-vlan-id", ("excluded_vlan_id", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId))])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                                ('port0', YLeaf(YType.str, 'port0')),
                                ('port1', YLeaf(YType.str, 'port1')),
                                ('monitor0', YLeaf(YType.str, 'monitor0')),
                                ('monitor1', YLeaf(YType.str, 'monitor1')),
                                ('is_provider_bridge', YLeaf(YType.boolean, 'is-provider-bridge')),
                                ('is_open_ring', YLeaf(YType.boolean, 'is-open-ring')),
                                ('tcn_propagation', YLeaf(YType.boolean, 'tcn-propagation')),
                            ])
                            self.ring_name = None
                            self.port0 = None
                            self.port1 = None
                            self.monitor0 = None
                            self.monitor1 = None
                            self.is_provider_bridge = None
                            self.is_open_ring = None
                            self.tcn_propagation = None

                            self.excluded_vlan_id = YList(self)
                            self._segment_path = lambda: "g8032-ring-detail"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail, ['ring_name', 'port0', 'port1', 'monitor0', 'monitor1', 'is_provider_bridge', 'is_open_ring', 'tcn_propagation'], name, value)


                        class ExcludedVlanId(Entity):
                            """
                            Exclusion Vlan ids list 
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, self).__init__()

                                self.yang_name = "excluded-vlan-id"
                                self.yang_parent_name = "g8032-ring-detail"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "excluded-vlan-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, ['entry'], name, value)


                    class G8032RingInstanceSummaries(Entity):
                        """
                        G8032 Ring Instance summary table
                        
                        .. attribute:: g8032_ring_instance_summary
                        
                        	G8032 Ring Instance summary information
                        	**type**\: list of  		 :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                            self.yang_name = "g8032-ring-instance-summaries"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("g8032-ring-instance-summary", ("g8032_ring_instance_summary", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary))])
                            self._leafs = OrderedDict()

                            self.g8032_ring_instance_summary = YList(self)
                            self._segment_path = lambda: "g8032-ring-instance-summaries"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, [], name, value)


                        class G8032RingInstanceSummary(Entity):
                            """
                            G8032 Ring Instance summary information
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\: bool
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                self.yang_name = "g8032-ring-instance-summary"
                                self.yang_parent_name = "g8032-ring-instance-summaries"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                    ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                    ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                    ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                    ('config_state', YLeaf(YType.boolean, 'config-state')),
                                ])
                                self.instance = None
                                self.ring_instance = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None

                                self.included_vlan_id = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-summary" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, ['instance', 'ring_instance', 'aps_port0', 'aps_port1', 'config_state'], name, value)


                            class IncludedVlanId(Entity):
                                """
                                Inclusion list Vlan Ids
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, self).__init__()

                                    self.yang_name = "included-vlan-id"
                                    self.yang_parent_name = "g8032-ring-instance-summary"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "included-vlan-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, ['entry'], name, value)


                    class G8032RingSummary(Entity):
                        """
                        G8032 Ring summary information
                        
                        .. attribute:: ring_name
                        
                        	Name of the ring
                        	**type**\: str
                        
                        .. attribute:: port0
                        
                        	Port 0
                        	**type**\: str
                        
                        .. attribute:: port1
                        
                        	Port 1
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                            self.yang_name = "g8032-ring-summary"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                                ('port0', YLeaf(YType.str, 'port0')),
                                ('port1', YLeaf(YType.str, 'port1')),
                            ])
                            self.ring_name = None
                            self.port0 = None
                            self.port1 = None
                            self._segment_path = lambda: "g8032-ring-summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingSummary, ['ring_name', 'port0', 'port1'], name, value)


                    class G8032RingInstanceDetails(Entity):
                        """
                        G8032 Ring Instance detail table
                        
                        .. attribute:: g8032_ring_instance_detail
                        
                        	G8032 Ring Instance detailed information
                        	**type**\: list of  		 :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                            self.yang_name = "g8032-ring-instance-details"
                            self.yang_parent_name = "g8032-ring"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("g8032-ring-instance-detail", ("g8032_ring_instance_detail", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail))])
                            self._leafs = OrderedDict()

                            self.g8032_ring_instance_detail = YList(self)
                            self._segment_path = lambda: "g8032-ring-instance-details"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, [], name, value)


                        class G8032RingInstanceDetail(Entity):
                            """
                            G8032 Ring Instance detailed information
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_instance
                            
                            	Ring instance number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ring_description
                            
                            	Ring description
                            	**type**\: str
                            
                            .. attribute:: ring_profile
                            
                            	Ring Profile
                            	**type**\: str
                            
                            .. attribute:: rpl
                            
                            	RPL
                            	**type**\:  :py:class:`L2vpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032Rpl>`
                            
                            .. attribute:: aps_port0
                            
                            	Port 0 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: aps_port1
                            
                            	Port 1 of aps\-channel
                            	**type**\: str
                            
                            .. attribute:: config_state
                            
                            	State of the instance
                            	**type**\: bool
                            
                            .. attribute:: unresolved_reason
                            
                            	Reason of unresolved state state
                            	**type**\:  :py:class:`L2vpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032UncfgReason>`
                            
                            .. attribute:: aps_channel_level
                            
                            	APS channel level
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: included_vlan_id
                            
                            	Inclusion list Vlan Ids
                            	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                self.yang_name = "g8032-ring-instance-detail"
                                self.yang_parent_name = "g8032-ring-instance-details"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                    ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                    ('ring_description', YLeaf(YType.str, 'ring-description')),
                                    ('ring_profile', YLeaf(YType.str, 'ring-profile')),
                                    ('rpl', YLeaf(YType.enumeration, 'rpl')),
                                    ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                    ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                    ('config_state', YLeaf(YType.boolean, 'config-state')),
                                    ('unresolved_reason', YLeaf(YType.enumeration, 'unresolved-reason')),
                                    ('aps_channel_level', YLeaf(YType.uint32, 'aps-channel-level')),
                                ])
                                self.instance = None
                                self.ring_instance = None
                                self.ring_description = None
                                self.ring_profile = None
                                self.rpl = None
                                self.aps_port0 = None
                                self.aps_port1 = None
                                self.config_state = None
                                self.unresolved_reason = None
                                self.aps_channel_level = None

                                self.included_vlan_id = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-detail" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, ['instance', 'ring_instance', 'ring_description', 'ring_profile', 'rpl', 'aps_port0', 'aps_port1', 'config_state', 'unresolved_reason', 'aps_channel_level'], name, value)


                            class IncludedVlanId(Entity):
                                """
                                Inclusion list Vlan Ids
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, self).__init__()

                                    self.yang_name = "included-vlan-id"
                                    self.yang_parent_name = "g8032-ring-instance-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "included-vlan-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, ['entry'], name, value)


        class PseudowireClasses(Entity):
            """
            List of pseudowire classes
            
            .. attribute:: pseudowire_class
            
            	Pseudowire class information
            	**type**\: list of  		 :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.PseudowireClasses, self).__init__()

                self.yang_name = "pseudowire-classes"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("pseudowire-class", ("pseudowire_class", L2vpnv2.Active.PseudowireClasses.PseudowireClass))])
                self._leafs = OrderedDict()

                self.pseudowire_class = YList(self)
                self._segment_path = lambda: "pseudowire-classes"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.PseudowireClasses, [], name, value)


            class PseudowireClass(Entity):
                """
                Pseudowire class information
                
                .. attribute:: pseudowire_class_name  (key)
                
                	Pseudowire Class Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: encapsulation_info
                
                	Encapsulation specific pseudowire information
                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                
                .. attribute:: preferred_path
                
                	MPLS Preferred Path
                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath>`
                
                .. attribute:: local_source_address
                
                	Local source address
                	**type**\:  :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                
                .. attribute:: pw_class_name
                
                	Pseudowire class name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: control_word
                
                	Control word
                	**type**\:  :py:class:`L2vpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwClassControlWord>`
                
                .. attribute:: transport_mode
                
                	Transport mode
                	**type**\:  :py:class:`L2vpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTransportMode>`
                
                .. attribute:: sequencing_type
                
                	Sequencing Type
                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                
                .. attribute:: resync_enabled
                
                	Resync if packets out of sequence
                	**type**\: bool
                
                .. attribute:: resync_threshold
                
                	Number of Packets Out of Seqence to trigger resync
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: protocol
                
                	Protocol
                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                
                .. attribute:: disable_never
                
                	TRUE if backup is not automatically disabled
                	**type**\: bool
                
                .. attribute:: disable_delay
                
                	Disable Deley
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: backup_mac_withdraw
                
                	TRUE if MAC withdraw message is sent
                	**type**\: bool
                
                .. attribute:: tag_rewrite
                
                	Static tag rewrite
                	**type**\: int
                
                	**range:** 0..65535
                
                .. attribute:: preferred_path_disable_fallback
                
                	PreferredPathDisableFallback
                	**type**\: bool
                
                .. attribute:: load_balance
                
                	Load Balance Type
                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                
                .. attribute:: pw_flow_label_type_cfg
                
                	Configured pseudowire flow label type
                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                
                .. attribute:: pw_flow_label_code17_disabled
                
                	Disable sending Code 17 TLV
                	**type**\: bool
                
                .. attribute:: is_flow_label_static
                
                	is flow label static
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.PseudowireClasses.PseudowireClass, self).__init__()

                    self.yang_name = "pseudowire-class"
                    self.yang_parent_name = "pseudowire-classes"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['pseudowire_class_name']
                    self._child_classes = OrderedDict([("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo)), ("preferred-path", ("preferred_path", L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath)), ("local-source-address", ("local_source_address", L2vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress))])
                    self._leafs = OrderedDict([
                        ('pseudowire_class_name', YLeaf(YType.str, 'pseudowire-class-name')),
                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                        ('control_word', YLeaf(YType.enumeration, 'control-word')),
                        ('transport_mode', YLeaf(YType.enumeration, 'transport-mode')),
                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                        ('backup_mac_withdraw', YLeaf(YType.boolean, 'backup-mac-withdraw')),
                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                    ])
                    self.pseudowire_class_name = None
                    self.pw_class_name = None
                    self.control_word = None
                    self.transport_mode = None
                    self.sequencing_type = None
                    self.resync_enabled = None
                    self.resync_threshold = None
                    self.protocol = None
                    self.disable_never = None
                    self.disable_delay = None
                    self.backup_mac_withdraw = None
                    self.tag_rewrite = None
                    self.preferred_path_disable_fallback = None
                    self.load_balance = None
                    self.pw_flow_label_type_cfg = None
                    self.pw_flow_label_code17_disabled = None
                    self.is_flow_label_static = None

                    self.encapsulation_info = L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                    self.encapsulation_info.parent = self
                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                    self.preferred_path = L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath()
                    self.preferred_path.parent = self
                    self._children_name_map["preferred_path"] = "preferred-path"

                    self.local_source_address = L2vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                    self.local_source_address.parent = self
                    self._children_name_map["local_source_address"] = "local-source-address"
                    self._segment_path = lambda: "pseudowire-class" + "[pseudowire-class-name='" + str(self.pseudowire_class_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/pseudowire-classes/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass, ['pseudowire_class_name', 'pw_class_name', 'control_word', 'transport_mode', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'protocol', 'disable_never', 'disable_delay', 'backup_mac_withdraw', 'tag_rewrite', 'preferred_path_disable_fallback', 'load_balance', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static'], name, value)


                class EncapsulationInfo(Entity):
                    """
                    Encapsulation specific pseudowire information
                    
                    .. attribute:: l2tpv3
                    
                    	l2tpv3
                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3>`
                    
                    .. attribute:: encapsulation
                    
                    	Encapsulation
                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                        self.yang_name = "encapsulation-info"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("l2tpv3", ("l2tpv3", L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3))])
                        self._leafs = OrderedDict([
                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                        ])
                        self.encapsulation = None

                        self.l2tpv3 = L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3()
                        self.l2tpv3.parent = self
                        self._children_name_map["l2tpv3"] = "l2tpv3"
                        self._segment_path = lambda: "encapsulation-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo, ['encapsulation'], name, value)


                    class L2tpv3(Entity):
                        """
                        l2tpv3
                        
                        .. attribute:: l2tp_class_name
                        
                        	L2TPClassName
                        	**type**\: str
                        
                        	**length:** 0..32
                        
                        .. attribute:: ipv4_source_address
                        
                        	IPv4 source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: path_mtu_enabled
                        
                        	Path MTU enabled
                        	**type**\: bool
                        
                        .. attribute:: path_mtu_max_value
                        
                        	Path MTU Maximum allowable session MTU
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: dont_fragment_bit
                        
                        	Don't Fragment Bit
                        	**type**\: bool
                        
                        .. attribute:: tos_mode
                        
                        	Type Of Service Mode
                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                        
                        .. attribute:: tos
                        
                        	Type Of Service Value
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: ttl
                        
                        	Time To Live value
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: cookie_size
                        
                        	Cookie size\: 0, 4, or 8 bytes
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, self).__init__()

                            self.yang_name = "l2tpv3"
                            self.yang_parent_name = "encapsulation-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                ('tos', YLeaf(YType.uint8, 'tos')),
                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                            ])
                            self.l2tp_class_name = None
                            self.ipv4_source_address = None
                            self.path_mtu_enabled = None
                            self.path_mtu_max_value = None
                            self.dont_fragment_bit = None
                            self.tos_mode = None
                            self.tos = None
                            self.ttl = None
                            self.cookie_size = None
                            self._segment_path = lambda: "l2tpv3"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'cookie_size'], name, value)


                class PreferredPath(Entity):
                    """
                    MPLS Preferred Path
                    
                    .. attribute:: srte_policy
                    
                    	srte policy
                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy>`
                    
                    .. attribute:: option
                    
                    	Option
                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                    
                    .. attribute:: next_hop_ip
                    
                    	NextHopIP
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: te_tunnel_interface_number
                    
                    	TETunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ip_tunnel_interface_number
                    
                    	IPTunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: tp_tunnel_interface_number
                    
                    	TPTunnelInterfaceNumber
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                        self.yang_name = "preferred-path"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy))])
                        self._leafs = OrderedDict([
                            ('option', YLeaf(YType.enumeration, 'option')),
                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                        ])
                        self.option = None
                        self.next_hop_ip = None
                        self.te_tunnel_interface_number = None
                        self.ip_tunnel_interface_number = None
                        self.tp_tunnel_interface_number = None

                        self.srte_policy = L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy()
                        self.srte_policy.parent = self
                        self._children_name_map["srte_policy"] = "srte-policy"
                        self._segment_path = lambda: "preferred-path"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                    class SrtePolicy(Entity):
                        """
                        srte policy
                        
                        .. attribute:: policy_name
                        
                        	SR TE Policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, self).__init__()

                            self.yang_name = "srte-policy"
                            self.yang_parent_name = "preferred-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                            ])
                            self.policy_name = None
                            self._segment_path = lambda: "srte-policy"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                class LocalSourceAddress(Entity):
                    """
                    Local source address
                    
                    .. attribute:: configuration
                    
                    	Configuration
                    	**type**\:  :py:class:`L2vpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSrcAddressSet>`
                    
                    .. attribute:: address
                    
                    	Local source address
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                        self.yang_name = "local-source-address"
                        self.yang_parent_name = "pseudowire-class"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('configuration', YLeaf(YType.enumeration, 'configuration')),
                            ('address', YLeaf(YType.str, 'address')),
                        ])
                        self.configuration = None
                        self.address = None
                        self._segment_path = lambda: "local-source-address"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.PseudowireClasses.PseudowireClass.LocalSourceAddress, ['configuration', 'address'], name, value)


        class L2vpnCollaborators(Entity):
            """
            L2VPN collaborator information
            
            .. attribute:: collaborator_statistics
            
            	Collaborator Statistics
            	**type**\:  :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.L2vpnCollaborators, self).__init__()

                self.yang_name = "l2vpn-collaborators"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("collaborator-statistics", ("collaborator_statistics", L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics))])
                self._leafs = OrderedDict()

                self.collaborator_statistics = L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics()
                self.collaborator_statistics.parent = self
                self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                self._segment_path = lambda: "l2vpn-collaborators"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.L2vpnCollaborators, [], name, value)


            class CollaboratorStatistics(Entity):
                """
                Collaborator Statistics
                
                .. attribute:: count
                
                	count
                	**type**\: list of  		 :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics.Count>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics, self).__init__()

                    self.yang_name = "collaborator-statistics"
                    self.yang_parent_name = "l2vpn-collaborators"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("count", ("count", L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics.Count))])
                    self._leafs = OrderedDict()

                    self.count = YList(self)
                    self._segment_path = lambda: "collaborator-statistics"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/l2vpn-collaborators/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics, [], name, value)


                class Count(Entity):
                    """
                    count
                    
                    .. attribute:: collaborator_name
                    
                    	Collaborator Name
                    	**type**\: str
                    
                    .. attribute:: up
                    
                    	Up
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: down
                    
                    	Down
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_up
                    
                    	Is up
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                        self.yang_name = "count"
                        self.yang_parent_name = "collaborator-statistics"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('collaborator_name', YLeaf(YType.str, 'collaborator-name')),
                            ('up', YLeaf(YType.uint32, 'up')),
                            ('down', YLeaf(YType.uint32, 'down')),
                            ('is_up', YLeaf(YType.boolean, 'is-up')),
                        ])
                        self.collaborator_name = None
                        self.up = None
                        self.down = None
                        self.is_up = None
                        self._segment_path = lambda: "count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/l2vpn-collaborators/collaborator-statistics/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.L2vpnCollaborators.CollaboratorStatistics.Count, ['collaborator_name', 'up', 'down', 'is_up'], name, value)


        class Mvrp(Entity):
            """
            MVRP
            
            .. attribute:: mvrp_main_ports
            
            	MVRP Main Port Table
            	**type**\:  :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.Mvrp, self).__init__()

                self.yang_name = "mvrp"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mvrp-main-ports", ("mvrp_main_ports", L2vpnv2.Active.Mvrp.MvrpMainPorts))])
                self._leafs = OrderedDict()

                self.mvrp_main_ports = L2vpnv2.Active.Mvrp.MvrpMainPorts()
                self.mvrp_main_ports.parent = self
                self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                self._segment_path = lambda: "mvrp"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.Mvrp, [], name, value)


            class MvrpMainPorts(Entity):
                """
                MVRP Main Port Table
                
                .. attribute:: mvrp_main_port
                
                	MVRP Main Port
                	**type**\: list of  		 :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.Mvrp.MvrpMainPorts, self).__init__()

                    self.yang_name = "mvrp-main-ports"
                    self.yang_parent_name = "mvrp"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mvrp-main-port", ("mvrp_main_port", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort))])
                    self._leafs = OrderedDict()

                    self.mvrp_main_port = YList(self)
                    self._segment_path = lambda: "mvrp-main-ports"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mvrp/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts, [], name, value)


                class MvrpMainPort(Entity):
                    """
                    MVRP Main Port
                    
                    .. attribute:: main_port_interface_name  (key)
                    
                    	Main Port interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mvrp_main_port_info
                    
                    	MVRP Main Port Information
                    	**type**\:  :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                    
                    .. attribute:: mvrp_bridge_ports
                    
                    	MVRP Bridge Port Table
                    	**type**\:  :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                        self.yang_name = "mvrp-main-port"
                        self.yang_parent_name = "mvrp-main-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = ['main_port_interface_name']
                        self._child_classes = OrderedDict([("mvrp-main-port-info", ("mvrp_main_port_info", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo)), ("mvrp-bridge-ports", ("mvrp_bridge_ports", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts))])
                        self._leafs = OrderedDict([
                            ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                        ])
                        self.main_port_interface_name = None

                        self.mvrp_main_port_info = L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                        self.mvrp_main_port_info.parent = self
                        self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"

                        self.mvrp_bridge_ports = L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                        self.mvrp_bridge_ports.parent = self
                        self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                        self._segment_path = lambda: "mvrp-main-port" + "[main-port-interface-name='" + str(self.main_port_interface_name) + "']"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mvrp/mvrp-main-ports/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort, ['main_port_interface_name'], name, value)


                    class MvrpMainPortInfo(Entity):
                        """
                        MVRP Main Port Information
                        
                        .. attribute:: default_bridge_port
                        
                        	Trunk or default Bridge Port
                        	**type**\:  :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                        
                        .. attribute:: main_port_interface_name
                        
                        	Main Port Interface name
                        	**type**\: str
                        
                        .. attribute:: is_trunk
                        
                        	Is main port a trunk
                        	**type**\: bool
                        
                        .. attribute:: is_default_encap
                        
                        	Is default encap set
                        	**type**\: bool
                        
                        .. attribute:: number_of_bridge_ports
                        
                        	Number of Bridge Ports
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                            self.yang_name = "mvrp-main-port-info"
                            self.yang_parent_name = "mvrp-main-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("default-bridge-port", ("default_bridge_port", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort))])
                            self._leafs = OrderedDict([
                                ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                                ('is_trunk', YLeaf(YType.boolean, 'is-trunk')),
                                ('is_default_encap', YLeaf(YType.boolean, 'is-default-encap')),
                                ('number_of_bridge_ports', YLeaf(YType.uint32, 'number-of-bridge-ports')),
                            ])
                            self.main_port_interface_name = None
                            self.is_trunk = None
                            self.is_default_encap = None
                            self.number_of_bridge_ports = None

                            self.default_bridge_port = L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                            self.default_bridge_port.parent = self
                            self._children_name_map["default_bridge_port"] = "default-bridge-port"
                            self._segment_path = lambda: "mvrp-main-port-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, ['main_port_interface_name', 'is_trunk', 'is_default_encap', 'number_of_bridge_ports'], name, value)


                        class DefaultBridgePort(Entity):
                            """
                            Trunk or default Bridge Port
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\: str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                self.yang_name = "default-bridge-port"
                                self.yang_parent_name = "mvrp-main-port-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange))])
                                self._leafs = OrderedDict([
                                    ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                    ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                ])
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None

                                self.vlan_range = YList(self)
                                self._segment_path = lambda: "default-bridge-port"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, ['bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "default-bridge-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                    ])
                                    self.lower = None
                                    self.upper = None
                                    self._segment_path = lambda: "vlan-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, ['lower', 'upper'], name, value)


                    class MvrpBridgePorts(Entity):
                        """
                        MVRP Bridge Port Table
                        
                        .. attribute:: mvrp_bridge_port
                        
                        	MVRP Bridge Port Information
                        	**type**\: list of  		 :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                            self.yang_name = "mvrp-bridge-ports"
                            self.yang_parent_name = "mvrp-main-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("mvrp-bridge-port", ("mvrp_bridge_port", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort))])
                            self._leafs = OrderedDict()

                            self.mvrp_bridge_port = YList(self)
                            self._segment_path = lambda: "mvrp-bridge-ports"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, [], name, value)


                        class MvrpBridgePort(Entity):
                            """
                            MVRP Bridge Port Information
                            
                            .. attribute:: interface_name  (key)
                            
                            	Bridge Port Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: bridge_port_interface_name
                            
                            	Bridge port Interface name
                            	**type**\: str
                            
                            .. attribute:: bridge_port_xconnect_id
                            
                            	Bridge port XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mvrp_sequence_number
                            
                            	MVRP Sequence Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: vlan_range
                            
                            	VLAN IDs
                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                self.yang_name = "mvrp-bridge-port"
                                self.yang_parent_name = "mvrp-bridge-ports"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                    ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                    ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                ])
                                self.interface_name = None
                                self.bridge_port_interface_name = None
                                self.bridge_port_xconnect_id = None
                                self.mvrp_sequence_number = None

                                self.vlan_range = YList(self)
                                self._segment_path = lambda: "mvrp-bridge-port" + "[interface-name='" + str(self.interface_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, ['interface_name', 'bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                            class VlanRange(Entity):
                                """
                                VLAN IDs
                                
                                .. attribute:: lower
                                
                                	Lower
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: upper
                                
                                	Upper
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                    self.yang_name = "vlan-range"
                                    self.yang_parent_name = "mvrp-bridge-port"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                    ])
                                    self.lower = None
                                    self.upper = None
                                    self._segment_path = lambda: "vlan-range"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, ['lower', 'upper'], name, value)


        class GenericInterfaceLists(Entity):
            """
            L2VPN generic interface list Table
            
            .. attribute:: generic_interface_list
            
            	Generic Interface List information
            	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.GenericInterfaceLists, self).__init__()

                self.yang_name = "generic-interface-lists"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList))])
                self._leafs = OrderedDict()

                self.generic_interface_list = YList(self)
                self._segment_path = lambda: "generic-interface-lists"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.GenericInterfaceLists, [], name, value)


            class GenericInterfaceList(Entity):
                """
                Generic Interface List information
                
                .. attribute:: interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: interface_list_name_xr
                
                	Interface\-list name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_of_interfaces
                
                	Number of interfaces
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: items
                
                	Number of items
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList.Interface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                    self.yang_name = "generic-interface-list"
                    self.yang_parent_name = "generic-interface-lists"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['interface_list_name']
                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList.Interface))])
                    self._leafs = OrderedDict([
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                        ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                        ('items', YLeaf(YType.uint32, 'items')),
                    ])
                    self.interface_list_name = None
                    self.interface_list_name_xr = None
                    self.interface_list_id = None
                    self.number_of_interfaces = None
                    self.items = None

                    self.interface = YList(self)
                    self._segment_path = lambda: "generic-interface-list" + "[interface-list-name='" + str(self.interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/generic-interface-lists/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList, ['interface_list_name', 'interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


        class MstpVlans(Entity):
            """
            L2VPN MSTP VLAN Table
            
            .. attribute:: mstp_vlan
            
            	L2VPN MSTP VLAN information
            	**type**\: list of  		 :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpVlans.MstpVlan>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.MstpVlans, self).__init__()

                self.yang_name = "mstp-vlans"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("mstp-vlan", ("mstp_vlan", L2vpnv2.Active.MstpVlans.MstpVlan))])
                self._leafs = OrderedDict()

                self.mstp_vlan = YList(self)
                self._segment_path = lambda: "mstp-vlans"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.MstpVlans, [], name, value)


            class MstpVlan(Entity):
                """
                L2VPN MSTP VLAN information
                
                .. attribute:: vlan_id  (key)
                
                	vlan id
                	**type**\: int
                
                	**range:** 0..4098
                
                .. attribute:: vlan_id_xr
                
                	Vlan id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: msti_id
                
                	MSTI id
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: port_count
                
                	Port Count
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sub_interface
                
                	Sub interfaces
                	**type**\: list of  		 :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.MstpVlans.MstpVlan.SubInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.MstpVlans.MstpVlan, self).__init__()

                    self.yang_name = "mstp-vlan"
                    self.yang_parent_name = "mstp-vlans"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['vlan_id']
                    self._child_classes = OrderedDict([("sub-interface", ("sub_interface", L2vpnv2.Active.MstpVlans.MstpVlan.SubInterface))])
                    self._leafs = OrderedDict([
                        ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                        ('vlan_id_xr', YLeaf(YType.uint32, 'vlan-id-xr')),
                        ('msti_id', YLeaf(YType.uint32, 'msti-id')),
                        ('port_count', YLeaf(YType.uint32, 'port-count')),
                    ])
                    self.vlan_id = None
                    self.vlan_id_xr = None
                    self.msti_id = None
                    self.port_count = None

                    self.sub_interface = YList(self)
                    self._segment_path = lambda: "mstp-vlan" + "[vlan-id='" + str(self.vlan_id) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/mstp-vlans/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.MstpVlans.MstpVlan, ['vlan_id', 'vlan_id_xr', 'msti_id', 'port_count'], name, value)


                class SubInterface(Entity):
                    """
                    Sub interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.MstpVlans.MstpVlan.SubInterface, self).__init__()

                        self.yang_name = "sub-interface"
                        self.yang_parent_name = "mstp-vlan"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ])
                        self.interface_name = None
                        self._segment_path = lambda: "sub-interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.MstpVlans.MstpVlan.SubInterface, ['interface_name'], name, value)


        class L2vpnPbbBsa(Entity):
            """
            L2VPN PBB Backbone Source MAC information
            
            .. attribute:: provisioned
            
            	BMAC SA configured
            	**type**\: bool
            
            .. attribute:: chassis_is_provisioned
            
            	Chassis MAC is configured
            	**type**\: bool
            
            .. attribute:: bmac_sa
            
            	BMAC SA
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            .. attribute:: chassis_mac
            
            	Chassis MAC
            	**type**\: str
            
            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.L2vpnPbbBsa, self).__init__()

                self.yang_name = "l2vpn-pbb-bsa"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([])
                self._leafs = OrderedDict([
                    ('provisioned', YLeaf(YType.boolean, 'provisioned')),
                    ('chassis_is_provisioned', YLeaf(YType.boolean, 'chassis-is-provisioned')),
                    ('bmac_sa', YLeaf(YType.str, 'bmac-sa')),
                    ('chassis_mac', YLeaf(YType.str, 'chassis-mac')),
                ])
                self.provisioned = None
                self.chassis_is_provisioned = None
                self.bmac_sa = None
                self.chassis_mac = None
                self._segment_path = lambda: "l2vpn-pbb-bsa"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.L2vpnPbbBsa, ['provisioned', 'chassis_is_provisioned', 'bmac_sa', 'chassis_mac'], name, value)


        class FlexibleXconnectServices(Entity):
            """
            Flexible XConnect Service Table
            
            .. attribute:: flexible_xconnect_service
            
            	Flexible XConnect Service Information
            	**type**\: list of  		 :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.FlexibleXconnectServices, self).__init__()

                self.yang_name = "flexible-xconnect-services"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("flexible-xconnect-service", ("flexible_xconnect_service", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService))])
                self._leafs = OrderedDict()

                self.flexible_xconnect_service = YList(self)
                self._segment_path = lambda: "flexible-xconnect-services"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices, [], name, value)


            class FlexibleXconnectService(Entity):
                """
                Flexible XConnect Service Information
                
                .. attribute:: name  (key)
                
                	Flexible XConnect Service Name
                	**type**\: str
                
                	**length:** 1..23
                
                .. attribute:: flexible_xconnect_service_acs
                
                	Flexible XConnect Service Attachment Circuit Table
                	**type**\:  :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                
                .. attribute:: flexible_xconnect_service_info
                
                	Flexible XConnect Service Information
                	**type**\:  :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                    self.yang_name = "flexible-xconnect-service"
                    self.yang_parent_name = "flexible-xconnect-services"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['name']
                    self._child_classes = OrderedDict([("flexible-xconnect-service-acs", ("flexible_xconnect_service_acs", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs)), ("flexible-xconnect-service-info", ("flexible_xconnect_service_info", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo))])
                    self._leafs = OrderedDict([
                        ('name', YLeaf(YType.str, 'name')),
                    ])
                    self.name = None

                    self.flexible_xconnect_service_acs = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                    self.flexible_xconnect_service_acs.parent = self
                    self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"

                    self.flexible_xconnect_service_info = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                    self.flexible_xconnect_service_info.parent = self
                    self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                    self._segment_path = lambda: "flexible-xconnect-service" + "[name='" + str(self.name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/flexible-xconnect-services/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService, ['name'], name, value)


                class FlexibleXconnectServiceAcs(Entity):
                    """
                    Flexible XConnect Service Attachment Circuit
                    Table
                    
                    .. attribute:: flexible_xconnect_service_ac
                    
                    	Flexible XConnect Service Attachment Circuit
                    	**type**\: list of  		 :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                        self.yang_name = "flexible-xconnect-service-acs"
                        self.yang_parent_name = "flexible-xconnect-service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("flexible-xconnect-service-ac", ("flexible_xconnect_service_ac", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc))])
                        self._leafs = OrderedDict()

                        self.flexible_xconnect_service_ac = YList(self)
                        self._segment_path = lambda: "flexible-xconnect-service-acs"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, [], name, value)


                    class FlexibleXconnectServiceAc(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        
                        .. attribute:: interface_name  (key)
                        
                        	Interface Name
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: attachment_circuit
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                            self.yang_name = "flexible-xconnect-service-ac"
                            self.yang_parent_name = "flexible-xconnect-service-acs"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['interface_name']
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit))])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ])
                            self.interface_name = None

                            self.attachment_circuit = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"
                            self._segment_path = lambda: "flexible-xconnect-service-ac" + "[interface-name='" + str(self.interface_name) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, ['interface_name'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "flexible-xconnect-service-ac"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                class FlexibleXconnectServiceInfo(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: fxc_id
                    
                    	Flexible XConnect ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: name
                    
                    	Flexible XConnect Service Name
                    	**type**\: str
                    
                    .. attribute:: state
                    
                    	State of the Flexible XConnect Service
                    	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                    
                    .. attribute:: num_p_ws
                    
                    	Number of Pseudowires in Pseudowire List
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: pseudowire
                    
                    	Flexible XConnect Service Pseudowire List
                    	**type**\: list of  		 :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                        self.yang_name = "flexible-xconnect-service-info"
                        self.yang_parent_name = "flexible-xconnect-service"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire))])
                        self._leafs = OrderedDict([
                            ('fxc_id', YLeaf(YType.uint32, 'fxc-id')),
                            ('name', YLeaf(YType.str, 'name')),
                            ('state', YLeaf(YType.enumeration, 'state')),
                            ('num_p_ws', YLeaf(YType.uint8, 'num-p-ws')),
                        ])
                        self.fxc_id = None
                        self.name = None
                        self.state = None
                        self.num_p_ws = None

                        self.pseudowire = YList(self)
                        self._segment_path = lambda: "flexible-xconnect-service-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, ['fxc_id', 'name', 'state', 'num_p_ws'], name, value)


                    class Pseudowire(Entity):
                        """
                        Flexible XConnect Service Pseudowire List
                        
                        .. attribute:: peer_id
                        
                        	Peer
                        	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                        
                        .. attribute:: encapsulation_info
                        
                        	Encapsulation specific pseudowire information
                        	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                        
                        .. attribute:: local_interface
                        
                        	Local interface
                        	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                        
                        .. attribute:: remote_interface
                        
                        	Remote interface
                        	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                        
                        .. attribute:: preferred_path
                        
                        	MPLS Preferred Path
                        	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                        
                        .. attribute:: local_signalling
                        
                        	Local signalling
                        	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                        
                        .. attribute:: remote_signalling
                        
                        	Remote signalling
                        	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                        
                        .. attribute:: statistics
                        
                        	Statistics
                        	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                        
                        .. attribute:: p2mp_pw
                        
                        	P2MP Pseudowire Information
                        	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw>`
                        
                        .. attribute:: local_source_address
                        
                        	Local Source Address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: ipv6_local_source_address
                        
                        	Local IPv6 Source Address
                        	**type**\: str
                        
                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pseudo_wire_id
                        
                        	Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: is_pwr_type
                        
                        	is Pseudowire\-routed
                        	**type**\: bool
                        
                        .. attribute:: is_evpn_vpws_type
                        
                        	is EVPN VPWS
                        	**type**\: bool
                        
                        .. attribute:: xconnect_id
                        
                        	XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: state
                        
                        	State
                        	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                        
                        .. attribute:: pseudo_wire_state
                        
                        	Pseudowire state
                        	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                        
                        .. attribute:: protocol
                        
                        	Protocol
                        	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                        
                        .. attribute:: pw_class_name
                        
                        	Pseudowire class name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: tag_rewrite
                        
                        	StaticTagRewrite
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: interworking
                        
                        	Interworking type
                        	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                        
                        .. attribute:: fe_ctype
                        
                        	Pseudowire FEC type
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        .. attribute:: evpn_src_acid
                        
                        	EVPN VPWS Source AC ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: sequencing_type
                        
                        	Sequencing Type
                        	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                        
                        .. attribute:: resync_enabled
                        
                        	Resync if packets out of sequence
                        	**type**\: bool
                        
                        .. attribute:: resync_threshold
                        
                        	Number of Packets Out of Seqence to trigger resync
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: local_control_word
                        
                        	Local control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: remote_control_word
                        
                        	Remote control word
                        	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                        
                        .. attribute:: local_pseudo_wire_type
                        
                        	Local pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: remote_pseudo_wire_type
                        
                        	Remote pseudowire type
                        	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                        
                        .. attribute:: imposed_vlan_id
                        
                        	Imposed vlan id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: time_created
                        
                        	Time when the pseudowire was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the pseudowire status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_down
                        
                        	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_down
                        
                        	Time elapsed since last status down in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: shutdown
                        
                        	Shutdown
                        	**type**\: bool
                        
                        .. attribute:: data_path_down
                        
                        	True if LSP down
                        	**type**\: bool
                        
                        .. attribute:: use_tunnel_path
                        
                        	True if using TE tunnel
                        	**type**\: bool
                        
                        .. attribute:: odn_configured
                        
                        	True if ODN is configured
                        	**type**\: bool
                        
                        .. attribute:: pseudo_wire_type_mismatched
                        
                        	Pseudowire type mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_bytes_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: bitrate_mismatched
                        
                        	Bitrate mismatched
                        	**type**\: bool
                        
                        .. attribute:: rtp_mismatched
                        
                        	RTP mismatched
                        	**type**\: bool
                        
                        .. attribute:: diff_ts_mismatched
                        
                        	Differential timestamp mismatched
                        	**type**\: bool
                        
                        .. attribute:: sig_pkts_mismatched
                        
                        	Signalling packets mismatched
                        	**type**\: bool
                        
                        .. attribute:: cas_mismatched
                        
                        	CAS mismatched
                        	**type**\: bool
                        
                        .. attribute:: payload_type_mismatched
                        
                        	Payload bytes mismatched
                        	**type**\: bool
                        
                        .. attribute:: freq_mismatched
                        
                        	Frequency mismatched
                        	**type**\: bool
                        
                        .. attribute:: ssrc_mismatched
                        
                        	SSRC mismatched
                        	**type**\: bool
                        
                        .. attribute:: mtu_mismatched
                        
                        	MTU mismatched
                        	**type**\: bool
                        
                        .. attribute:: illegal_control_word
                        
                        	Illegal control word
                        	**type**\: bool
                        
                        .. attribute:: ad_remote_down
                        
                        	Auto\-Discovered PW remote state down
                        	**type**\: bool
                        
                        .. attribute:: not_supported_qinq
                        
                        	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                        	**type**\: bool
                        
                        .. attribute:: local_label_failed
                        
                        	Failed to set BGP advertised local label
                        	**type**\: bool
                        
                        .. attribute:: remote_label_failed
                        
                        	Failed to set BGP advertised remote label
                        	**type**\: bool
                        
                        .. attribute:: preferred_path_disable_fallback
                        
                        	Prefpath fallback enable/disable
                        	**type**\: bool
                        
                        .. attribute:: backup_pw
                        
                        	TRUE if PW is a backup PW
                        	**type**\: bool
                        
                        .. attribute:: primary_pw
                        
                        	TRUE if PW is a primary PW
                        	**type**\: bool
                        
                        .. attribute:: backup_active
                        
                        	TRUE if backup is active
                        	**type**\: bool
                        
                        .. attribute:: backup_force_active
                        
                        	TRUE if backup is active due to switchover
                        	**type**\: bool
                        
                        .. attribute:: disable_never
                        
                        	TRUE if backup is not automatically disabled
                        	**type**\: bool
                        
                        .. attribute:: disable_delay
                        
                        	Backup disable delay
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: primary_peer_id
                        
                        	Primary Peer IP address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: primary_pseudo_wire_id
                        
                        	Primary Pseudowire ID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: number_ma_cwithdraw_message_sent
                        
                        	Num MW messages sent over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_ma_cwithdraw_msg_received
                        
                        	Num MW messages received over PW
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: out_of_memory_state
                        
                        	L2VPN Out of memory state
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: transport_lsp_down
                        
                        	Oper down due to Transport LSP down
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_oper_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: pw_status_use
                        
                        	PW status in use
                        	**type**\: bool
                        
                        .. attribute:: auto_discovery
                        
                        	Is autodiscovery
                        	**type**\: bool
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: pwlsd_rewrite_failed
                        
                        	LSD rewrite failed
                        	**type**\: bool
                        
                        .. attribute:: ldp_label_advertise_failed
                        
                        	LDP label advertisment failed
                        	**type**\: bool
                        
                        .. attribute:: is_vfi
                        
                        	Is VFI interface
                        	**type**\: bool
                        
                        .. attribute:: is_multi_segment_pseudowire
                        
                        	Is Multi\-Segment Pseudowire
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_one_way
                        
                        	Force one\-way PW redundancy behaviour in Redundancy Group
                        	**type**\: bool
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: pw_flow_label_type
                        
                        	Negotiated pseudowire flow label type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_type_cfg
                        
                        	Configured pseudowire flow label Type
                        	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                        
                        .. attribute:: pw_flow_label_code17_disabled
                        
                        	Disable sending Code 17 TLV
                        	**type**\: bool
                        
                        .. attribute:: is_flow_label_static
                        
                        	is flow label static
                        	**type**\: bool
                        
                        .. attribute:: is_partially_programmed
                        
                        	Is Pseudowire partially programmed
                        	**type**\: bool
                        
                        .. attribute:: pw_redundancy_initial_delay
                        
                        	Initial delay for redundant PW in seconds
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        	**units**\: second
                        
                        .. attribute:: bridge_pw_type_mismatch
                        
                        	Oper down because Bridge has mismatched PW Types
                        	**type**\: bool
                        
                        .. attribute:: required_bw
                        
                        	Required Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: admited_bw
                        
                        	Admited Bandwidth
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: forward_class
                        
                        	Forward Class attribute
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: table_policy_name
                        
                        	Table\-policy Name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                            self.yang_name = "pseudowire"
                            self.yang_parent_name = "flexible-xconnect-service-info"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw))])
                            self._leafs = OrderedDict([
                                ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                            ])
                            self.local_source_address = None
                            self.ipv6_local_source_address = None
                            self.pseudo_wire_id = None
                            self.is_pwr_type = None
                            self.is_evpn_vpws_type = None
                            self.xconnect_id = None
                            self.state = None
                            self.pseudo_wire_state = None
                            self.protocol = None
                            self.pw_class_name = None
                            self.tag_rewrite = None
                            self.interworking = None
                            self.fe_ctype = None
                            self.evpn_src_acid = None
                            self.sequencing_type = None
                            self.resync_enabled = None
                            self.resync_threshold = None
                            self.local_control_word = None
                            self.remote_control_word = None
                            self.local_pseudo_wire_type = None
                            self.remote_pseudo_wire_type = None
                            self.imposed_vlan_id = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.last_time_status_down = None
                            self.time_elapsed_status_down = None
                            self.shutdown = None
                            self.data_path_down = None
                            self.use_tunnel_path = None
                            self.odn_configured = None
                            self.pseudo_wire_type_mismatched = None
                            self.payload_bytes_mismatched = None
                            self.bitrate_mismatched = None
                            self.rtp_mismatched = None
                            self.diff_ts_mismatched = None
                            self.sig_pkts_mismatched = None
                            self.cas_mismatched = None
                            self.payload_type_mismatched = None
                            self.freq_mismatched = None
                            self.ssrc_mismatched = None
                            self.mtu_mismatched = None
                            self.illegal_control_word = None
                            self.ad_remote_down = None
                            self.not_supported_qinq = None
                            self.local_label_failed = None
                            self.remote_label_failed = None
                            self.preferred_path_disable_fallback = None
                            self.backup_pw = None
                            self.primary_pw = None
                            self.backup_active = None
                            self.backup_force_active = None
                            self.disable_never = None
                            self.disable_delay = None
                            self.primary_peer_id = None
                            self.primary_pseudo_wire_id = None
                            self.number_ma_cwithdraw_message_sent = None
                            self.num_ma_cwithdraw_msg_received = None
                            self.out_of_memory_state = None
                            self.transport_lsp_down = None
                            self.mac_limit_oper_down = None
                            self.pw_status_use = None
                            self.auto_discovery = None
                            self.ad_method = None
                            self.pwlsd_rewrite_failed = None
                            self.ldp_label_advertise_failed = None
                            self.is_vfi = None
                            self.is_multi_segment_pseudowire = None
                            self.pw_redundancy_one_way = None
                            self.load_balance = None
                            self.pw_flow_label_type = None
                            self.pw_flow_label_type_cfg = None
                            self.pw_flow_label_code17_disabled = None
                            self.is_flow_label_static = None
                            self.is_partially_programmed = None
                            self.pw_redundancy_initial_delay = None
                            self.bridge_pw_type_mismatch = None
                            self.required_bw = None
                            self.admited_bw = None
                            self.forward_class = None
                            self.table_policy_name = None

                            self.peer_id = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                            self.peer_id.parent = self
                            self._children_name_map["peer_id"] = "peer-id"

                            self.encapsulation_info = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                            self.encapsulation_info.parent = self
                            self._children_name_map["encapsulation_info"] = "encapsulation-info"

                            self.local_interface = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                            self.local_interface.parent = self
                            self._children_name_map["local_interface"] = "local-interface"

                            self.remote_interface = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                            self.remote_interface.parent = self
                            self._children_name_map["remote_interface"] = "remote-interface"

                            self.preferred_path = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                            self.preferred_path.parent = self
                            self._children_name_map["preferred_path"] = "preferred-path"

                            self.local_signalling = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                            self.local_signalling.parent = self
                            self._children_name_map["local_signalling"] = "local-signalling"

                            self.remote_signalling = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                            self.remote_signalling.parent = self
                            self._children_name_map["remote_signalling"] = "remote-signalling"

                            self.statistics = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                            self.statistics.parent = self
                            self._children_name_map["statistics"] = "statistics"

                            self.p2mp_pw = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw()
                            self.p2mp_pw.parent = self
                            self._children_name_map["p2mp_pw"] = "p2mp-pw"
                            self._segment_path = lambda: "pseudowire"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                        class PeerId(Entity):
                            """
                            Peer
                            
                            .. attribute:: type
                            
                            	type
                            	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                            
                            .. attribute:: ipv4_peer_id
                            
                            	Peer IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_peer_id
                            
                            	Peer IPv6 address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: internal_label
                            
                            	Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                self.yang_name = "peer-id"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                    ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                    ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                ])
                                self.type = None
                                self.ipv4_peer_id = None
                                self.ipv6_peer_id = None
                                self.internal_label = None
                                self._segment_path = lambda: "peer-id"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                        class EncapsulationInfo(Entity):
                            """
                            Encapsulation specific pseudowire information
                            
                            .. attribute:: atom
                            
                            	atom
                            	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                            
                            .. attribute:: l2tpv3
                            
                            	l2tpv3
                            	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3>`
                            
                            .. attribute:: encapsulation
                            
                            	Encapsulation
                            	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                self.yang_name = "encapsulation-info"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3))])
                                self._leafs = OrderedDict([
                                    ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                ])
                                self.encapsulation = None

                                self.atom = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                self.atom.parent = self
                                self._children_name_map["atom"] = "atom"

                                self.l2tpv3 = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3()
                                self.l2tpv3.parent = self
                                self._children_name_map["l2tpv3"] = "l2tpv3"
                                self._segment_path = lambda: "encapsulation-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                            class Atom(Entity):
                                """
                                atom
                                
                                .. attribute:: local_agi
                                
                                	Local Attachment Group Identifier
                                	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                
                                .. attribute:: remote_agi
                                
                                	Remote Attachment Group Identifier
                                	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                
                                .. attribute:: multi_segment_pseudowire_stats
                                
                                	Multisegment pseudowire statistics
                                	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                
                                .. attribute:: is_pseudowire_headend
                                
                                	Is this connected to a PW\-HE AC
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_label
                                
                                	Remote label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_group_id
                                
                                	Local group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_group_id
                                
                                	Remote group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cv_type
                                
                                	Local VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_c_ctype
                                
                                	Local VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cv_type
                                
                                	Remote VCCV CV type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_c_ctype
                                
                                	Remote VCCV CC type
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_veid
                                
                                	Local VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_veid
                                
                                	Remote VE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ceid
                                
                                	Local CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ceid
                                
                                	Remote CE ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: source_address
                                
                                	Local BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_source_address
                                
                                	Remote BGP source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_ldp_id
                                
                                	Local LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_ldp_id
                                
                                	Remote LDP ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: saii
                                
                                	Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: taii
                                
                                	Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: is_sai_itype2
                                
                                	Is SAII FEC129 Type 2
                                	**type**\: bool
                                
                                .. attribute:: local_saii_gbl_id
                                
                                	Local SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_saiiac_id
                                
                                	Local SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: is_tai_itype2
                                
                                	Is TAII type 2
                                	**type**\: bool
                                
                                .. attribute:: local_taii_gbl_id
                                
                                	Local TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_taiiac_id
                                
                                	Local TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii_gbl_id
                                
                                	Remote SAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saiiac_id
                                
                                	Remote SAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taii_gbl_id
                                
                                	Remote TAII Global ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_taiiac_id
                                
                                	Remote TAII AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: rem_saii
                                
                                	Remote Source Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: rem_taii
                                
                                	Remote Target Attachment Individual Identifer
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: lsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertisment_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                    self.yang_name = "atom"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                    self._leafs = OrderedDict([
                                        ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                        ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                        ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                        ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                        ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                        ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                        ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                        ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                        ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                        ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                        ('source_address', YLeaf(YType.str, 'source-address')),
                                        ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                        ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                        ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                        ('saii', YLeaf(YType.str, 'saii')),
                                        ('taii', YLeaf(YType.str, 'taii')),
                                        ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                        ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                        ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                        ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                        ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                        ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                        ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                        ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                        ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                        ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                        ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                        ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                        ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                        ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                    ])
                                    self.is_pseudowire_headend = None
                                    self.local_label = None
                                    self.remote_label = None
                                    self.local_group_id = None
                                    self.remote_group_id = None
                                    self.local_cv_type = None
                                    self.local_c_ctype = None
                                    self.remote_cv_type = None
                                    self.remote_c_ctype = None
                                    self.local_veid = None
                                    self.remote_veid = None
                                    self.local_ceid = None
                                    self.remote_ceid = None
                                    self.source_address = None
                                    self.remote_source_address = None
                                    self.local_ldp_id = None
                                    self.remote_ldp_id = None
                                    self.saii = None
                                    self.taii = None
                                    self.is_sai_itype2 = None
                                    self.local_saii_gbl_id = None
                                    self.local_saiiac_id = None
                                    self.is_tai_itype2 = None
                                    self.local_taii_gbl_id = None
                                    self.local_taiiac_id = None
                                    self.rem_saii_gbl_id = None
                                    self.rem_saiiac_id = None
                                    self.rem_taii_gbl_id = None
                                    self.rem_taiiac_id = None
                                    self.rem_saii = None
                                    self.rem_taii = None
                                    self.lsd_rewrite_failed = None
                                    self.ldp_label_advertisment_failed = None

                                    self.local_agi = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                    self.local_agi.parent = self
                                    self._children_name_map["local_agi"] = "local-agi"

                                    self.remote_agi = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                    self.remote_agi.parent = self
                                    self._children_name_map["remote_agi"] = "remote-agi"

                                    self.multi_segment_pseudowire_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                    self.multi_segment_pseudowire_stats.parent = self
                                    self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                    self._segment_path = lambda: "atom"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                class LocalAgi(Entity):
                                    """
                                    Local Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                        self.yang_name = "local-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "local-agi"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "local-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class RemoteAgi(Entity):
                                    """
                                    Remote Attachment Group Identifier
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                        self.yang_name = "remote-agi"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "remote-agi"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "remote-agi"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class MultiSegmentPseudowireStats(Entity):
                                    """
                                    Multisegment pseudowire statistics
                                    
                                    .. attribute:: received_packets
                                    
                                    	Packets received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: received_bytes
                                    
                                    	Bytes received
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                        self.yang_name = "multi-segment-pseudowire-stats"
                                        self.yang_parent_name = "atom"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                            ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                        ])
                                        self.received_packets = None
                                        self.received_bytes = None
                                        self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                            class L2tpv3(Entity):
                                """
                                l2tpv3
                                
                                .. attribute:: l2tp_class_name
                                
                                	L2TPClassName
                                	**type**\: str
                                
                                	**length:** 0..32
                                
                                .. attribute:: ipv4_source_address
                                
                                	IPv4 source address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_source_address
                                
                                	IPv6 source address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: path_mtu_enabled
                                
                                	Path MTU enabled
                                	**type**\: bool
                                
                                .. attribute:: path_mtu_max_value
                                
                                	Path MTU Maximum allowable session MTU
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: dont_fragment_bit
                                
                                	Don't Fragment Bit
                                	**type**\: bool
                                
                                .. attribute:: tos_mode
                                
                                	Type Of Service Mode
                                	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                
                                .. attribute:: tos
                                
                                	Type Of Service Value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: ttl
                                
                                	Time To Live value
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_session_id
                                
                                	Local session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_session_id
                                
                                	Remote session id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_size
                                
                                	Local cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_cookie_size
                                
                                	Remote cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_low_value
                                
                                	Lower 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_cookie_high_value
                                
                                	Upper 4 bytes of the value of the remote cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_circuit_status_up
                                
                                	RemoteCircuitStatusUp
                                	**type**\: bool
                                
                                .. attribute:: tunnel_state
                                
                                	L2TP tunnel state
                                	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                
                                .. attribute:: local_secondary_cookie_size
                                
                                	Local secondary cookie size\: 0, 4, or 8 bytes
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: local_secondary_cookie_low_value
                                
                                	Lower 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_secondary_cookie_high_value
                                
                                	Upper 4 bytes of the value of the local secondary cookie
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                    self.yang_name = "l2tpv3"
                                    self.yang_parent_name = "encapsulation-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                        ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                        ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                        ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                        ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                        ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                        ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                        ('tos', YLeaf(YType.uint8, 'tos')),
                                        ('ttl', YLeaf(YType.uint8, 'ttl')),
                                        ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                        ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                        ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                        ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                        ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                        ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                        ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                        ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                        ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                        ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                        ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                        ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                        ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                    ])
                                    self.l2tp_class_name = None
                                    self.ipv4_source_address = None
                                    self.ipv6_source_address = None
                                    self.path_mtu_enabled = None
                                    self.path_mtu_max_value = None
                                    self.dont_fragment_bit = None
                                    self.tos_mode = None
                                    self.tos = None
                                    self.ttl = None
                                    self.local_session_id = None
                                    self.remote_session_id = None
                                    self.local_cookie_size = None
                                    self.remote_cookie_size = None
                                    self.local_cookie_low_value = None
                                    self.remote_cookie_low_value = None
                                    self.local_cookie_high_value = None
                                    self.remote_cookie_high_value = None
                                    self.remote_circuit_status_up = None
                                    self.tunnel_state = None
                                    self.local_secondary_cookie_size = None
                                    self.local_secondary_cookie_low_value = None
                                    self.local_secondary_cookie_high_value = None
                                    self._segment_path = lambda: "l2tpv3"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                        class LocalInterface(Entity):
                            """
                            Local interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                self.yang_name = "local-interface"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "local-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "local-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class RemoteInterface(Entity):
                            """
                            Remote interface
                            
                            .. attribute:: parameters
                            
                            	Interface parameters
                            	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                            
                            .. attribute:: name
                            
                            	Interface name
                            	**type**\: str
                            
                            	**length:** 0..81
                            
                            .. attribute:: mtu
                            
                            	Interface MTU
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: payload_bytes
                            
                            	Payload bytes
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            	**units**\: byte
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                self.yang_name = "remote-interface"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters))])
                                self._leafs = OrderedDict([
                                    ('name', YLeaf(YType.str, 'name')),
                                    ('mtu', YLeaf(YType.uint32, 'mtu')),
                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                ])
                                self.name = None
                                self.mtu = None
                                self.payload_bytes = None

                                self.parameters = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                self.parameters.parent = self
                                self._children_name_map["parameters"] = "parameters"
                                self._segment_path = lambda: "remote-interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                            class Parameters(Entity):
                                """
                                Interface parameters
                                
                                .. attribute:: ethernet
                                
                                	Ethernet
                                	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                
                                .. attribute:: vlan
                                
                                	VLAN
                                	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                
                                .. attribute:: tdm
                                
                                	TDM
                                	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                
                                .. attribute:: atm
                                
                                	ATM
                                	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                
                                .. attribute:: fr
                                
                                	Frame Relay
                                	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                
                                .. attribute:: pseudowire_ether
                                
                                	PW Ether
                                	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                
                                .. attribute:: pseudowire_iw
                                
                                	PW IW
                                	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                
                                .. attribute:: type
                                
                                	Type
                                	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                    self.yang_name = "parameters"
                                    self.yang_parent_name = "remote-interface"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                    ])
                                    self.type = None

                                    self.ethernet = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                    self.ethernet.parent = self
                                    self._children_name_map["ethernet"] = "ethernet"

                                    self.vlan = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                    self.vlan.parent = self
                                    self._children_name_map["vlan"] = "vlan"

                                    self.tdm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                    self.tdm.parent = self
                                    self._children_name_map["tdm"] = "tdm"

                                    self.atm = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                    self.atm.parent = self
                                    self._children_name_map["atm"] = "atm"

                                    self.fr = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                    self.fr.parent = self
                                    self._children_name_map["fr"] = "fr"

                                    self.pseudowire_ether = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                    self.pseudowire_ether.parent = self
                                    self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                    self.pseudowire_iw = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                    self.pseudowire_iw.parent = self
                                    self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                    self._segment_path = lambda: "parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                class Ethernet(Entity):
                                    """
                                    Ethernet
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                        self.yang_name = "ethernet"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                        ])
                                        self.xconnect_tags = None
                                        self._segment_path = lambda: "ethernet"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                class Vlan(Entity):
                                    """
                                    VLAN
                                    
                                    .. attribute:: xconnect_tags
                                    
                                    	XConnect tags
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_rewrite_tag
                                    
                                    	VLAN rewrite tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: simple_efp
                                    
                                    	Simple EFP
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: encapsulation_type
                                    
                                    	Encapsulation Type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: outer_tag
                                    
                                    	Outer Tag
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: rewrite_tag
                                    
                                    	Rewrite Tags
                                    	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                    
                                    .. attribute:: vlan_range
                                    
                                    	vlan range
                                    	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                        self.yang_name = "vlan"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                            ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                            ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                            ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                        ])
                                        self.xconnect_tags = None
                                        self.vlan_rewrite_tag = None
                                        self.simple_efp = None
                                        self.encapsulation_type = None
                                        self.outer_tag = None

                                        self.rewrite_tag = YList(self)
                                        self.vlan_range = YList(self)
                                        self._segment_path = lambda: "vlan"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                    class RewriteTag(Entity):
                                        """
                                        Rewrite Tags
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                            self.yang_name = "rewrite-tag"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint16, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "rewrite-tag"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                    class VlanRange(Entity):
                                        """
                                        vlan range
                                        
                                        .. attribute:: lower
                                        
                                        	Lower
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: upper
                                        
                                        	Upper
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                            self.yang_name = "vlan-range"
                                            self.yang_parent_name = "vlan"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('lower', YLeaf(YType.uint16, 'lower')),
                                                ('upper', YLeaf(YType.uint16, 'upper')),
                                            ])
                                            self.lower = None
                                            self.upper = None
                                            self._segment_path = lambda: "vlan-range"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                class Tdm(Entity):
                                    """
                                    TDM
                                    
                                    .. attribute:: tdm_options
                                    
                                    	TDM options
                                    	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                    
                                    .. attribute:: timeslot_group
                                    
                                    	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                    	**type**\: str
                                    
                                    .. attribute:: timeslot_rate
                                    
                                    	Timeslot rate in units of Kbps
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: tdm_mode
                                    
                                    	TDM mode
                                    	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                        self.yang_name = "tdm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                        self._leafs = OrderedDict([
                                            ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                            ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                            ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                        ])
                                        self.timeslot_group = None
                                        self.timeslot_rate = None
                                        self.tdm_mode = None

                                        self.tdm_options = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                        self.tdm_options.parent = self
                                        self._children_name_map["tdm_options"] = "tdm-options"
                                        self._segment_path = lambda: "tdm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                    class TdmOptions(Entity):
                                        """
                                        TDM options
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	TDM payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        .. attribute:: bit_rate
                                        
                                        	TDM bit rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: rtp
                                        
                                        	RTP header
                                        	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                        
                                        .. attribute:: timestamp_mode
                                        
                                        	TDM Timestamping mode
                                        	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                        
                                        .. attribute:: signalling_packets
                                        
                                        	Signalling packets
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: cas
                                        
                                        	CAS
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: rtp_header_payload_type
                                        
                                        	RTP header payload type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: timestamp_clock_freq
                                        
                                        	Timestamping clock frequency in units of 8Khz
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: ssrc
                                        
                                        	Synchronization Source identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                            self.yang_name = "tdm-options"
                                            self.yang_parent_name = "tdm"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                ('cas', YLeaf(YType.uint8, 'cas')),
                                                ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                            ])
                                            self.payload_bytes = None
                                            self.bit_rate = None
                                            self.rtp = None
                                            self.timestamp_mode = None
                                            self.signalling_packets = None
                                            self.cas = None
                                            self.rtp_header_payload_type = None
                                            self.timestamp_clock_freq = None
                                            self.ssrc = None
                                            self._segment_path = lambda: "tdm-options"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                class Atm(Entity):
                                    """
                                    ATM
                                    
                                    .. attribute:: maximum_number_cells_packed
                                    
                                    	Max number of cells packed
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: maximum_number_cells_un_packed
                                    
                                    	Max number of cells unpacked
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: atm_mode
                                    
                                    	ATM mode
                                    	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                    
                                    .. attribute:: vpi
                                    
                                    	Virtual path identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vci
                                    
                                    	Virtual channel identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                        self.yang_name = "atm"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                            ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                            ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                            ('vpi', YLeaf(YType.uint16, 'vpi')),
                                            ('vci', YLeaf(YType.uint16, 'vci')),
                                        ])
                                        self.maximum_number_cells_packed = None
                                        self.maximum_number_cells_un_packed = None
                                        self.atm_mode = None
                                        self.vpi = None
                                        self.vci = None
                                        self._segment_path = lambda: "atm"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                class Fr(Entity):
                                    """
                                    Frame Relay
                                    
                                    .. attribute:: fr_mode
                                    
                                    	Frame Relay mode
                                    	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                    
                                    .. attribute:: dlci
                                    
                                    	Data\-link connection identifier
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                        self.yang_name = "fr"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                            ('dlci', YLeaf(YType.uint32, 'dlci')),
                                        ])
                                        self.fr_mode = None
                                        self.dlci = None
                                        self._segment_path = lambda: "fr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                class PseudowireEther(Entity):
                                    """
                                    PW Ether
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                        self.yang_name = "pseudowire-ether"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-ether"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-ether"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PseudowireIw(Entity):
                                    """
                                    PW IW
                                    
                                    .. attribute:: interface_list
                                    
                                    	Interface list data
                                    	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                    
                                    .. attribute:: is_valid
                                    
                                    	Is this Interface list valid
                                    	**type**\: bool
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                        self.yang_name = "pseudowire-iw"
                                        self.yang_parent_name = "parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                        self._leafs = OrderedDict([
                                            ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.is_valid = None
                                        self.internal_label = None

                                        self.interface_list = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                        self.interface_list.parent = self
                                        self._children_name_map["interface_list"] = "interface-list"
                                        self._segment_path = lambda: "pseudowire-iw"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                    class InterfaceList(Entity):
                                        """
                                        Interface list data
                                        
                                        .. attribute:: interface_list_name
                                        
                                        	Interface\-list name
                                        	**type**\: str
                                        
                                        	**length:** 0..33
                                        
                                        .. attribute:: interface_list_id
                                        
                                        	Interface internal ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: interface
                                        
                                        	Interfaces
                                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                            self.yang_name = "interface-list"
                                            self.yang_parent_name = "pseudowire-iw"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                            self._leafs = OrderedDict([
                                                ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                            ])
                                            self.interface_list_name = None
                                            self.interface_list_id = None

                                            self.interface = YList(self)
                                            self._segment_path = lambda: "interface-list"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                        class Interface(Entity):
                                            """
                                            Interfaces
                                            
                                            .. attribute:: interface_name
                                            
                                            	Interface name
                                            	**type**\: str
                                            
                                            .. attribute:: replicate_status
                                            
                                            	Replicate status
                                            	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                self.yang_name = "interface"
                                                self.yang_parent_name = "interface-list"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                    ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                ])
                                                self.interface_name = None
                                                self.replicate_status = None
                                                self._segment_path = lambda: "interface"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                        class PreferredPath(Entity):
                            """
                            MPLS Preferred Path
                            
                            .. attribute:: srte_policy
                            
                            	srte policy
                            	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy>`
                            
                            .. attribute:: option
                            
                            	Option
                            	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                            
                            .. attribute:: next_hop_ip
                            
                            	NextHopIP
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: te_tunnel_interface_number
                            
                            	TETunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ip_tunnel_interface_number
                            
                            	IPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tp_tunnel_interface_number
                            
                            	TPTunnelInterfaceNumber
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                self.yang_name = "preferred-path"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy))])
                                self._leafs = OrderedDict([
                                    ('option', YLeaf(YType.enumeration, 'option')),
                                    ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                    ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                    ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                    ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                ])
                                self.option = None
                                self.next_hop_ip = None
                                self.te_tunnel_interface_number = None
                                self.ip_tunnel_interface_number = None
                                self.tp_tunnel_interface_number = None

                                self.srte_policy = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy()
                                self.srte_policy.parent = self
                                self._children_name_map["srte_policy"] = "srte-policy"
                                self._segment_path = lambda: "preferred-path"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                            class SrtePolicy(Entity):
                                """
                                srte policy
                                
                                .. attribute:: policy_name
                                
                                	SR TE Policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                    self.yang_name = "srte-policy"
                                    self.yang_parent_name = "preferred-path"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('policy_name', YLeaf(YType.str, 'policy-name')),
                                    ])
                                    self.policy_name = None
                                    self._segment_path = lambda: "srte-policy"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                        class LocalSignalling(Entity):
                            """
                            Local signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                self.yang_name = "local-signalling"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "local-signalling"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "local-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class RemoteSignalling(Entity):
                            """
                            Remote signalling
                            
                            .. attribute:: status_tlv
                            
                            	PW Status Switching TLV
                            	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                            
                            .. attribute:: pw_status
                            
                            	PW Status
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: tlv
                            
                            	Switching TLV info
                            	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                self.yang_name = "remote-signalling"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv))])
                                self._leafs = OrderedDict([
                                    ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                ])
                                self.pw_status = None

                                self.status_tlv = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                self.status_tlv.parent = self
                                self._children_name_map["status_tlv"] = "status-tlv"

                                self.tlv = YList(self)
                                self._segment_path = lambda: "remote-signalling"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                            class StatusTlv(Entity):
                                """
                                PW Status Switching TLV
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                    self.yang_name = "status-tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "status-tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Tlv(Entity):
                                """
                                Switching TLV info
                                
                                .. attribute:: pw_id
                                
                                	PW ID of last PW segment traversed
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local IP Address of PW Switching Point
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote IP Address of Last PW Switching Point traversed
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: description
                                
                                	PW Switching Point description
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                    self.yang_name = "tlv"
                                    self.yang_parent_name = "remote-signalling"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('description', YLeaf(YType.str, 'description')),
                                    ])
                                    self.pw_id = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.description = None
                                    self._segment_path = lambda: "tlv"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                        class Statistics(Entity):
                            """
                            Statistics
                            
                            .. attribute:: impostion_stats
                            
                            	imposition stats
                            	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                            
                            .. attribute:: dispostion_stats
                            
                            	disposition stats
                            	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                            
                            .. attribute:: sequence_number
                            
                            	sequence numbers
                            	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                self.yang_name = "statistics"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber))])
                                self._leafs = OrderedDict()

                                self.impostion_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                self.impostion_stats.parent = self
                                self._children_name_map["impostion_stats"] = "impostion-stats"

                                self.dispostion_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                self.dispostion_stats.parent = self
                                self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                self.sequence_number = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                self.sequence_number.parent = self
                                self._children_name_map["sequence_number"] = "sequence-number"
                                self._segment_path = lambda: "statistics"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, [], name, value)


                            class ImpostionStats(Entity):
                                """
                                imposition stats
                                
                                .. attribute:: imposition_stat
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                
                                .. attribute:: imposition_mtu_drop
                                
                                	imposition mtu drop stats
                                	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                
                                .. attribute:: impostion_tail_drop
                                
                                	imposition tail drop stats
                                	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                
                                .. attribute:: l2fsbi_drop
                                
                                	rx discards
                                	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                
                                .. attribute:: multicast
                                
                                	Multicast
                                	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                
                                .. attribute:: broadcast
                                
                                	Broadcast
                                	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                
                                .. attribute:: unknown_unicast
                                
                                	Unknown Unicast
                                	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                    self.yang_name = "impostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                    self._leafs = OrderedDict()

                                    self.imposition_stat = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                    self.imposition_stat.parent = self
                                    self._children_name_map["imposition_stat"] = "imposition-stat"

                                    self.imposition_mtu_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                    self.imposition_mtu_drop.parent = self
                                    self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                    self.impostion_tail_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                    self.impostion_tail_drop.parent = self
                                    self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                    self.l2fsbi_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                    self.l2fsbi_drop.parent = self
                                    self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                    self.multicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                    self.multicast.parent = self
                                    self._children_name_map["multicast"] = "multicast"

                                    self.broadcast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                    self.broadcast.parent = self
                                    self._children_name_map["broadcast"] = "broadcast"

                                    self.known_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.unknown_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                    self.unknown_unicast.parent = self
                                    self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                    self._segment_path = lambda: "impostion-stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                class ImpositionStat(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                        self.yang_name = "imposition-stat"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class ImpositionMtuDrop(Entity):
                                    """
                                    imposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                        self.yang_name = "imposition-mtu-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "imposition-mtu-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ImpostionTailDrop(Entity):
                                    """
                                    imposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                        self.yang_name = "impostion-tail-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "impostion-tail-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class L2fsbiDrop(Entity):
                                    """
                                    rx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                        self.yang_name = "l2fsbi-drop"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "l2fsbi-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class Multicast(Entity):
                                    """
                                    Multicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                        self.yang_name = "multicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                class Broadcast(Entity):
                                    """
                                    Broadcast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                        self.yang_name = "broadcast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class UnknownUnicast(Entity):
                                    """
                                    Unknown Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                        self.yang_name = "unknown-unicast"
                                        self.yang_parent_name = "impostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unknown-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                            class DispostionStats(Entity):
                                """
                                disposition stats
                                
                                .. attribute:: disposition_stat
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                
                                .. attribute:: disposition_mtu_drop
                                
                                	disposition mtu drop stats
                                	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                
                                .. attribute:: disposition_tail_drop
                                
                                	disposition tail drop stats
                                	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                
                                .. attribute:: multicast_drop
                                
                                	disposition storm control multicast drop stats
                                	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                
                                .. attribute:: unicast_drop
                                
                                	disposition storm control unknown unicast drop stats
                                	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                
                                .. attribute:: broadcast_drop
                                
                                	disposition storm control broadcast drop stats
                                	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                
                                .. attribute:: received_drops
                                
                                	tx discards
                                	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                
                                .. attribute:: dai_drop
                                
                                	Disposition dynamic ARP inspection drop statistics
                                	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                
                                .. attribute:: ipsg_drop
                                
                                	disposition IP source guard drop statistics
                                	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                
                                .. attribute:: disposition_oo_o_drops
                                
                                	Disposition Out\-of\-Order Drops
                                	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                
                                .. attribute:: disposition_p2mp_stats
                                
                                	Disposition P2MP Stats
                                	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                
                                .. attribute:: known_unicast
                                
                                	Known Unicast
                                	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                
                                .. attribute:: mac_move
                                
                                	MAC Move
                                	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                    self.yang_name = "dispostion-stats"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove))])
                                    self._leafs = OrderedDict()

                                    self.disposition_stat = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                    self.disposition_stat.parent = self
                                    self._children_name_map["disposition_stat"] = "disposition-stat"

                                    self.disposition_mtu_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                    self.disposition_mtu_drop.parent = self
                                    self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                    self.disposition_tail_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                    self.disposition_tail_drop.parent = self
                                    self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                    self.multicast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                    self.multicast_drop.parent = self
                                    self._children_name_map["multicast_drop"] = "multicast-drop"

                                    self.unicast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                    self.unicast_drop.parent = self
                                    self._children_name_map["unicast_drop"] = "unicast-drop"

                                    self.broadcast_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                    self.broadcast_drop.parent = self
                                    self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                    self.received_drops = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                    self.received_drops.parent = self
                                    self._children_name_map["received_drops"] = "received-drops"

                                    self.dai_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                    self.dai_drop.parent = self
                                    self._children_name_map["dai_drop"] = "dai-drop"

                                    self.ipsg_drop = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                    self.ipsg_drop.parent = self
                                    self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                    self.disposition_oo_o_drops = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                    self.disposition_oo_o_drops.parent = self
                                    self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                    self.disposition_p2mp_stats = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                    self.disposition_p2mp_stats.parent = self
                                    self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                    self.known_unicast = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                    self.known_unicast.parent = self
                                    self._children_name_map["known_unicast"] = "known-unicast"

                                    self.mac_move = L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                    self.mac_move.parent = self
                                    self._children_name_map["mac_move"] = "mac-move"
                                    self._segment_path = lambda: "dispostion-stats"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, [], name, value)


                                class DispositionStat(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                        self.yang_name = "disposition-stat"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-stat"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionMtuDrop(Entity):
                                    """
                                    disposition mtu drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                        self.yang_name = "disposition-mtu-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-mtu-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionTailDrop(Entity):
                                    """
                                    disposition tail drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                        self.yang_name = "disposition-tail-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-tail-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                class MulticastDrop(Entity):
                                    """
                                    disposition storm control multicast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                        self.yang_name = "multicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "multicast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class UnicastDrop(Entity):
                                    """
                                    disposition storm control unknown unicast drop
                                    stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                        self.yang_name = "unicast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "unicast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class BroadcastDrop(Entity):
                                    """
                                    disposition storm control broadcast drop stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                        self.yang_name = "broadcast-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "broadcast-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                class ReceivedDrops(Entity):
                                    """
                                    tx discards
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                        self.yang_name = "received-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "received-drops"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                class DaiDrop(Entity):
                                    """
                                    Disposition dynamic ARP inspection drop
                                    statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                        self.yang_name = "dai-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "dai-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                class IpsgDrop(Entity):
                                    """
                                    disposition IP source guard drop statistics
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                        self.yang_name = "ipsg-drop"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "ipsg-drop"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionOoODrops(Entity):
                                    """
                                    Disposition Out\-of\-Order Drops
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                        self.yang_name = "disposition-oo-o-drops"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-oo-o-drops"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                class DispositionP2mpStats(Entity):
                                    """
                                    Disposition P2MP Stats
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                        self.yang_name = "disposition-p2mp-stats"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "disposition-p2mp-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                class KnownUnicast(Entity):
                                    """
                                    Known Unicast
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                        self.yang_name = "known-unicast"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "known-unicast"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class MacMove(Entity):
                                    """
                                    MAC Move
                                    
                                    .. attribute:: packet_counts
                                    
                                    	packets counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: byte_counts
                                    
                                    	bytes counters
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                        self.yang_name = "mac-move"
                                        self.yang_parent_name = "dispostion-stats"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                            ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                        ])
                                        self.packet_counts = None
                                        self.byte_counts = None
                                        self._segment_path = lambda: "mac-move"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                            class SequenceNumber(Entity):
                                """
                                sequence numbers
                                
                                .. attribute:: sequence_number_sent
                                
                                	sequence number sent
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequence_number_expected
                                
                                	sequence number expected
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: bypassed_inbound_sequence_packet
                                
                                	Bypassed inbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: bypassed_out_sequence_packet
                                
                                	Bypassed outbound sequence packets
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                    self.yang_name = "sequence-number"
                                    self.yang_parent_name = "statistics"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                        ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                        ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                        ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                    ])
                                    self.sequence_number_sent = None
                                    self.sequence_number_expected = None
                                    self.bypassed_inbound_sequence_packet = None
                                    self.bypassed_out_sequence_packet = None
                                    self._segment_path = lambda: "sequence-number"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class P2mpPw(Entity):
                            """
                            P2MP Pseudowire Information
                            
                            .. attribute:: local_available
                            
                            	Local LSM info available
                            	**type**\: bool
                            
                            .. attribute:: local_label
                            
                            	Local Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_ptree_type
                            
                            	Local P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: local_tunnel_id
                            
                            	Local Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_extended_tunnel_id
                            
                            	Local Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: local_p2mp_id
                            
                            	Local P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_flags
                            
                            	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_available
                            
                            	Remote LSM info available
                            	**type**\: bool
                            
                            .. attribute:: remote_label
                            
                            	Remote Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_ptree_type
                            
                            	Remote P\-Tree Type
                            	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                            
                            .. attribute:: remote_tunnel_id
                            
                            	Remote Tunnel ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_extended_tunnel_id
                            
                            	Remote Extended Tunnel ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: remote_p2mp_id
                            
                            	Remote P2MP ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_flags
                            
                            	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, self).__init__()

                                self.yang_name = "p2mp-pw"
                                self.yang_parent_name = "pseudowire"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('local_available', YLeaf(YType.boolean, 'local-available')),
                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                    ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                    ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                    ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                    ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                    ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                    ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                    ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                    ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                    ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                    ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                    ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                ])
                                self.local_available = None
                                self.local_label = None
                                self.local_ptree_type = None
                                self.local_tunnel_id = None
                                self.local_extended_tunnel_id = None
                                self.local_p2mp_id = None
                                self.local_flags = None
                                self.remote_available = None
                                self.remote_label = None
                                self.remote_ptree_type = None
                                self.remote_tunnel_id = None
                                self.remote_extended_tunnel_id = None
                                self.remote_p2mp_id = None
                                self.remote_flags = None
                                self._segment_path = lambda: "p2mp-pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


        class XconnectBrief(Entity):
            """
            XConnect brief information
            
            .. attribute:: main_total_up
            
            	Total Number of active Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_down
            
            	Total Number of non\-active Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: main_total_unresolved
            
            	Total Number of unresolved Cross\-Conections with valid encaps
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: undefined_xc
            
            	Undefined xc including PW\-PW
            	**type**\: int
            
            	**range:** 0..4294967295
            
            .. attribute:: memory_state
            
            	L2VPN memory state
            	**type**\:  :py:class:`L2vpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMemoryState>`
            
            .. attribute:: encapsulation_report_matrix
            
            	Encapsulation report counters matrix
            	**type**\: list of  		 :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix>`
            
            .. attribute:: encapsulation_total
            
            	Total summary
            	**type**\: list of  		 :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationTotal>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Active.XconnectBrief, self).__init__()

                self.yang_name = "xconnect-brief"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("encapsulation-report-matrix", ("encapsulation_report_matrix", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix)), ("encapsulation-total", ("encapsulation_total", L2vpnv2.Active.XconnectBrief.EncapsulationTotal))])
                self._leafs = OrderedDict([
                    ('main_total_up', YLeaf(YType.uint32, 'main-total-up')),
                    ('main_total_down', YLeaf(YType.uint32, 'main-total-down')),
                    ('main_total_unresolved', YLeaf(YType.uint32, 'main-total-unresolved')),
                    ('undefined_xc', YLeaf(YType.uint32, 'undefined-xc')),
                    ('memory_state', YLeaf(YType.enumeration, 'memory-state')),
                ])
                self.main_total_up = None
                self.main_total_down = None
                self.main_total_unresolved = None
                self.undefined_xc = None
                self.memory_state = None

                self.encapsulation_report_matrix = YList(self)
                self.encapsulation_total = YList(self)
                self._segment_path = lambda: "xconnect-brief"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Active.XconnectBrief, ['main_total_up', 'main_total_down', 'main_total_unresolved', 'undefined_xc', 'memory_state'], name, value)


            class EncapsulationReportMatrix(Entity):
                """
                Encapsulation report counters matrix
                
                .. attribute:: ac1
                
                	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                	**type**\: list of  		 :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                    self.yang_name = "encapsulation-report-matrix"
                    self.yang_parent_name = "xconnect-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("ac1", ("ac1", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1))])
                    self._leafs = OrderedDict()

                    self.ac1 = YList(self)
                    self._segment_path = lambda: "encapsulation-report-matrix"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix, [], name, value)


                class Ac1(Entity):
                    """
                    Array of l2vpn\_xc\_brief\_first layer indexed by
                    the AC1 encapsulation type
                    
                    .. attribute:: ac2
                    
                    	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                    	**type**\: list of  		 :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                        self.yang_name = "ac1"
                        self.yang_parent_name = "encapsulation-report-matrix"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ac2", ("ac2", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2))])
                        self._leafs = OrderedDict()

                        self.ac2 = YList(self)
                        self._segment_path = lambda: "ac1"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1, [], name, value)


                    class Ac2(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_line indexed by the AC2
                        encapsulation type plus one type for PW
                        
                        .. attribute:: psn_type
                        
                        	PSN Type
                        	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                        
                        .. attribute:: ac1_encapsulation
                        
                        	AC1 encapsulation
                        	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                        
                        .. attribute:: ac2_encapsulation
                        
                        	AC2 encapsulation
                        	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                        
                        .. attribute:: up_count
                        
                        	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount>`
                        
                        .. attribute:: down_count
                        
                        	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount>`
                        
                        .. attribute:: unresolved_count
                        
                        	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                        	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                            self.yang_name = "ac2"
                            self.yang_parent_name = "ac1"
                            self.is_top_level_class = False
                            self.has_list_ancestor = False
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount)), ("down-count", ("down_count", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount))])
                            self._leafs = OrderedDict([
                                ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                                ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                                ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                            ])
                            self.psn_type = None
                            self.ac1_encapsulation = None
                            self.ac2_encapsulation = None

                            self.up_count = YList(self)
                            self.down_count = YList(self)
                            self.unresolved_count = YList(self)
                            self._segment_path = lambda: "ac2"
                            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/ac1/%s" % self._segment_path()

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                        class UpCount(Entity):
                            """
                            Number of active cross\-connections array \- 
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, self).__init__()

                                self.yang_name = "up-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "up-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, ['entry'], name, value)


                        class DownCount(Entity):
                            """
                            Number of non\-active cross\-connections array \-
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, self).__init__()

                                self.yang_name = "down-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "down-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, ['entry'], name, value)


                        class UnresolvedCount(Entity):
                            """
                            Number of unresolved cross\-connections array \-
                            
                            Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                            
                            EthernetInterworking, 3 is Total
                            
                            .. attribute:: entry
                            
                            	
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, self).__init__()

                                self.yang_name = "unresolved-count"
                                self.yang_parent_name = "ac2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = False
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('entry', YLeaf(YType.uint32, 'entry')),
                                ])
                                self.entry = None
                                self._segment_path = lambda: "unresolved-count"
                                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-report-matrix/ac1/ac2/%s" % self._segment_path()

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, ['entry'], name, value)


            class EncapsulationTotal(Entity):
                """
                Total summary
                
                .. attribute:: psn_type
                
                	PSN Type
                	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                
                .. attribute:: ac1_encapsulation
                
                	AC1 encapsulation
                	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                
                .. attribute:: ac2_encapsulation
                
                	AC2 encapsulation
                	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                
                .. attribute:: up_count
                
                	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UpCount>`
                
                .. attribute:: down_count
                
                	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationTotal.DownCount>`
                
                .. attribute:: unresolved_count
                
                	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UnresolvedCount>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Active.XconnectBrief.EncapsulationTotal, self).__init__()

                    self.yang_name = "encapsulation-total"
                    self.yang_parent_name = "xconnect-brief"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UpCount)), ("down-count", ("down_count", L2vpnv2.Active.XconnectBrief.EncapsulationTotal.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UnresolvedCount))])
                    self._leafs = OrderedDict([
                        ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                        ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                        ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                    ])
                    self.psn_type = None
                    self.ac1_encapsulation = None
                    self.ac2_encapsulation = None

                    self.up_count = YList(self)
                    self.down_count = YList(self)
                    self.unresolved_count = YList(self)
                    self._segment_path = lambda: "encapsulation-total"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationTotal, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                class UpCount(Entity):
                    """
                    Number of active cross\-connections array \- 
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UpCount, self).__init__()

                        self.yang_name = "up-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "up-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UpCount, ['entry'], name, value)


                class DownCount(Entity):
                    """
                    Number of non\-active cross\-connections array \-
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.DownCount, self).__init__()

                        self.yang_name = "down-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "down-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.DownCount, ['entry'], name, value)


                class UnresolvedCount(Entity):
                    """
                    Number of unresolved cross\-connections array \-
                    
                    Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                    
                    EthernetInterworking, 3 is Total
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UnresolvedCount, self).__init__()

                        self.yang_name = "unresolved-count"
                        self.yang_parent_name = "encapsulation-total"
                        self.is_top_level_class = False
                        self.has_list_ancestor = False
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "unresolved-count"
                        self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/active/xconnect-brief/encapsulation-total/%s" % self._segment_path()

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Active.XconnectBrief.EncapsulationTotal.UnresolvedCount, ['entry'], name, value)


    class Nodes(Entity):
        """
        Table of L2VPN operational data for a particular
        node
        
        .. attribute:: node
        
        	L2VPN operational data for a particular node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(L2vpnv2.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "l2vpnv2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", L2vpnv2.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(L2vpnv2.Nodes, [], name, value)


        class Node(Entity):
            """
            L2VPN operational data for a particular node
            
            .. attribute:: node_id  (key)
            
            	Location
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: discoveries
            
            	Discovery Table
            	**type**\:  :py:class:`Discoveries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries>`
            
            .. attribute:: flexible_xconnect_service_summary
            
            	Flexible XConnect Service summary information
            	**type**\:  :py:class:`FlexibleXconnectServiceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServiceSummary>`
            
            .. attribute:: main_interfaces
            
            	Main Interface
            	**type**\:  :py:class:`MainInterfaces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces>`
            
            .. attribute:: iccp_sm
            
            	ICCP\-based Service Multi\-homing operational data
            	**type**\:  :py:class:`IccpSm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm>`
            
            .. attribute:: bridge_summary
            
            	Bridge Domain summary information
            	**type**\:  :py:class:`BridgeSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeSummary>`
            
            .. attribute:: nsr
            
            	L2VPN NSR information
            	**type**\:  :py:class:`Nsr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr>`
            
            .. attribute:: preferred_paths
            
            	Preferred path Table
            	**type**\:  :py:class:`PreferredPaths <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PreferredPaths>`
            
            .. attribute:: global_settings
            
            	L2VPN global settings
            	**type**\:  :py:class:`GlobalSettings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GlobalSettings>`
            
            .. attribute:: pwr
            
            	Pseudowire Routing Table
            	**type**\:  :py:class:`Pwr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr>`
            
            .. attribute:: xconnect_mp2mp_ce2ces
            
            	XConnect MP2MP CE2CE Table
            	**type**\:  :py:class:`XconnectMp2mpCe2ces <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces>`
            
            .. attribute:: xconnects
            
            	XConnect Table
            	**type**\:  :py:class:`Xconnects <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects>`
            
            .. attribute:: xconnect_groups
            
            	XConnect group Table
            	**type**\:  :py:class:`XconnectGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectGroups>`
            
            .. attribute:: xconnect_mp2mps
            
            	XConnect MP2MP Table
            	**type**\:  :py:class:`XconnectMp2mps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps>`
            
            .. attribute:: indexes
            
            	ID Manager Index Table
            	**type**\:  :py:class:`Indexes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Indexes>`
            
            .. attribute:: xconnect_summary
            
            	XConnect summary information
            	**type**\:  :py:class:`XconnectSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectSummary>`
            
            .. attribute:: proc_fsm
            
            	L2VPN Process FSM information
            	**type**\:  :py:class:`ProcFsm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm>`
            
            .. attribute:: mstp_ports
            
            	L2VPN MSTP Port Table
            	**type**\:  :py:class:`MstpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpPorts>`
            
            .. attribute:: generic_interface_list_details
            
            	L2VPN generic interface list Detail Table
            	**type**\:  :py:class:`GenericInterfaceListDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails>`
            
            .. attribute:: l2vpn_resource_state
            
            	L2VPN resource state information
            	**type**\:  :py:class:`L2vpnResourceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.L2vpnResourceState>`
            
            .. attribute:: bridge_domains
            
            	Bridge Domain Information
            	**type**\:  :py:class:`BridgeDomains <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains>`
            
            .. attribute:: discovery_summary
            
            	Discovery summary information
            	**type**\:  :py:class:`DiscoverySummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.DiscoverySummary>`
            
            .. attribute:: g8032
            
            	G8032 information
            	**type**\:  :py:class:`G8032 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032>`
            
            .. attribute:: pseudowire_classes
            
            	List of pseudowire classes
            	**type**\:  :py:class:`PseudowireClasses <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses>`
            
            .. attribute:: l2vpn_collaborators
            
            	L2VPN collaborator information
            	**type**\:  :py:class:`L2vpnCollaborators <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.L2vpnCollaborators>`
            
            .. attribute:: mvrp
            
            	MVRP
            	**type**\:  :py:class:`Mvrp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp>`
            
            .. attribute:: generic_interface_lists
            
            	L2VPN generic interface list Table
            	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceLists>`
            
            .. attribute:: mstp_vlans
            
            	L2VPN MSTP VLAN Table
            	**type**\:  :py:class:`MstpVlans <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpVlans>`
            
            .. attribute:: l2vpn_pbb_bsa
            
            	L2VPN PBB Backbone Source MAC information
            	**type**\:  :py:class:`L2vpnPbbBsa <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.L2vpnPbbBsa>`
            
            .. attribute:: flexible_xconnect_services
            
            	Flexible XConnect Service Table
            	**type**\:  :py:class:`FlexibleXconnectServices <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices>`
            
            .. attribute:: xconnect_brief
            
            	XConnect brief information
            	**type**\:  :py:class:`XconnectBrief <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(L2vpnv2.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_id']
                self._child_classes = OrderedDict([("discoveries", ("discoveries", L2vpnv2.Nodes.Node.Discoveries)), ("flexible-xconnect-service-summary", ("flexible_xconnect_service_summary", L2vpnv2.Nodes.Node.FlexibleXconnectServiceSummary)), ("main-interfaces", ("main_interfaces", L2vpnv2.Nodes.Node.MainInterfaces)), ("iccp-sm", ("iccp_sm", L2vpnv2.Nodes.Node.IccpSm)), ("bridge-summary", ("bridge_summary", L2vpnv2.Nodes.Node.BridgeSummary)), ("nsr", ("nsr", L2vpnv2.Nodes.Node.Nsr)), ("preferred-paths", ("preferred_paths", L2vpnv2.Nodes.Node.PreferredPaths)), ("global-settings", ("global_settings", L2vpnv2.Nodes.Node.GlobalSettings)), ("pwr", ("pwr", L2vpnv2.Nodes.Node.Pwr)), ("xconnect-mp2mp-ce2ces", ("xconnect_mp2mp_ce2ces", L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces)), ("xconnects", ("xconnects", L2vpnv2.Nodes.Node.Xconnects)), ("xconnect-groups", ("xconnect_groups", L2vpnv2.Nodes.Node.XconnectGroups)), ("xconnect-mp2mps", ("xconnect_mp2mps", L2vpnv2.Nodes.Node.XconnectMp2mps)), ("indexes", ("indexes", L2vpnv2.Nodes.Node.Indexes)), ("xconnect-summary", ("xconnect_summary", L2vpnv2.Nodes.Node.XconnectSummary)), ("proc-fsm", ("proc_fsm", L2vpnv2.Nodes.Node.ProcFsm)), ("mstp-ports", ("mstp_ports", L2vpnv2.Nodes.Node.MstpPorts)), ("generic-interface-list-details", ("generic_interface_list_details", L2vpnv2.Nodes.Node.GenericInterfaceListDetails)), ("l2vpn-resource-state", ("l2vpn_resource_state", L2vpnv2.Nodes.Node.L2vpnResourceState)), ("bridge-domains", ("bridge_domains", L2vpnv2.Nodes.Node.BridgeDomains)), ("discovery-summary", ("discovery_summary", L2vpnv2.Nodes.Node.DiscoverySummary)), ("g8032", ("g8032", L2vpnv2.Nodes.Node.G8032)), ("pseudowire-classes", ("pseudowire_classes", L2vpnv2.Nodes.Node.PseudowireClasses)), ("l2vpn-collaborators", ("l2vpn_collaborators", L2vpnv2.Nodes.Node.L2vpnCollaborators)), ("mvrp", ("mvrp", L2vpnv2.Nodes.Node.Mvrp)), ("generic-interface-lists", ("generic_interface_lists", L2vpnv2.Nodes.Node.GenericInterfaceLists)), ("mstp-vlans", ("mstp_vlans", L2vpnv2.Nodes.Node.MstpVlans)), ("l2vpn-pbb-bsa", ("l2vpn_pbb_bsa", L2vpnv2.Nodes.Node.L2vpnPbbBsa)), ("flexible-xconnect-services", ("flexible_xconnect_services", L2vpnv2.Nodes.Node.FlexibleXconnectServices)), ("xconnect-brief", ("xconnect_brief", L2vpnv2.Nodes.Node.XconnectBrief))])
                self._leafs = OrderedDict([
                    ('node_id', YLeaf(YType.str, 'node-id')),
                ])
                self.node_id = None

                self.discoveries = L2vpnv2.Nodes.Node.Discoveries()
                self.discoveries.parent = self
                self._children_name_map["discoveries"] = "discoveries"

                self.flexible_xconnect_service_summary = L2vpnv2.Nodes.Node.FlexibleXconnectServiceSummary()
                self.flexible_xconnect_service_summary.parent = self
                self._children_name_map["flexible_xconnect_service_summary"] = "flexible-xconnect-service-summary"

                self.main_interfaces = L2vpnv2.Nodes.Node.MainInterfaces()
                self.main_interfaces.parent = self
                self._children_name_map["main_interfaces"] = "main-interfaces"

                self.iccp_sm = L2vpnv2.Nodes.Node.IccpSm()
                self.iccp_sm.parent = self
                self._children_name_map["iccp_sm"] = "iccp-sm"

                self.bridge_summary = L2vpnv2.Nodes.Node.BridgeSummary()
                self.bridge_summary.parent = self
                self._children_name_map["bridge_summary"] = "bridge-summary"

                self.nsr = L2vpnv2.Nodes.Node.Nsr()
                self.nsr.parent = self
                self._children_name_map["nsr"] = "nsr"

                self.preferred_paths = L2vpnv2.Nodes.Node.PreferredPaths()
                self.preferred_paths.parent = self
                self._children_name_map["preferred_paths"] = "preferred-paths"

                self.global_settings = L2vpnv2.Nodes.Node.GlobalSettings()
                self.global_settings.parent = self
                self._children_name_map["global_settings"] = "global-settings"

                self.pwr = L2vpnv2.Nodes.Node.Pwr()
                self.pwr.parent = self
                self._children_name_map["pwr"] = "pwr"

                self.xconnect_mp2mp_ce2ces = L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces()
                self.xconnect_mp2mp_ce2ces.parent = self
                self._children_name_map["xconnect_mp2mp_ce2ces"] = "xconnect-mp2mp-ce2ces"

                self.xconnects = L2vpnv2.Nodes.Node.Xconnects()
                self.xconnects.parent = self
                self._children_name_map["xconnects"] = "xconnects"

                self.xconnect_groups = L2vpnv2.Nodes.Node.XconnectGroups()
                self.xconnect_groups.parent = self
                self._children_name_map["xconnect_groups"] = "xconnect-groups"

                self.xconnect_mp2mps = L2vpnv2.Nodes.Node.XconnectMp2mps()
                self.xconnect_mp2mps.parent = self
                self._children_name_map["xconnect_mp2mps"] = "xconnect-mp2mps"

                self.indexes = L2vpnv2.Nodes.Node.Indexes()
                self.indexes.parent = self
                self._children_name_map["indexes"] = "indexes"

                self.xconnect_summary = L2vpnv2.Nodes.Node.XconnectSummary()
                self.xconnect_summary.parent = self
                self._children_name_map["xconnect_summary"] = "xconnect-summary"

                self.proc_fsm = L2vpnv2.Nodes.Node.ProcFsm()
                self.proc_fsm.parent = self
                self._children_name_map["proc_fsm"] = "proc-fsm"

                self.mstp_ports = L2vpnv2.Nodes.Node.MstpPorts()
                self.mstp_ports.parent = self
                self._children_name_map["mstp_ports"] = "mstp-ports"

                self.generic_interface_list_details = L2vpnv2.Nodes.Node.GenericInterfaceListDetails()
                self.generic_interface_list_details.parent = self
                self._children_name_map["generic_interface_list_details"] = "generic-interface-list-details"

                self.l2vpn_resource_state = L2vpnv2.Nodes.Node.L2vpnResourceState()
                self.l2vpn_resource_state.parent = self
                self._children_name_map["l2vpn_resource_state"] = "l2vpn-resource-state"

                self.bridge_domains = L2vpnv2.Nodes.Node.BridgeDomains()
                self.bridge_domains.parent = self
                self._children_name_map["bridge_domains"] = "bridge-domains"

                self.discovery_summary = L2vpnv2.Nodes.Node.DiscoverySummary()
                self.discovery_summary.parent = self
                self._children_name_map["discovery_summary"] = "discovery-summary"

                self.g8032 = L2vpnv2.Nodes.Node.G8032()
                self.g8032.parent = self
                self._children_name_map["g8032"] = "g8032"

                self.pseudowire_classes = L2vpnv2.Nodes.Node.PseudowireClasses()
                self.pseudowire_classes.parent = self
                self._children_name_map["pseudowire_classes"] = "pseudowire-classes"

                self.l2vpn_collaborators = L2vpnv2.Nodes.Node.L2vpnCollaborators()
                self.l2vpn_collaborators.parent = self
                self._children_name_map["l2vpn_collaborators"] = "l2vpn-collaborators"

                self.mvrp = L2vpnv2.Nodes.Node.Mvrp()
                self.mvrp.parent = self
                self._children_name_map["mvrp"] = "mvrp"

                self.generic_interface_lists = L2vpnv2.Nodes.Node.GenericInterfaceLists()
                self.generic_interface_lists.parent = self
                self._children_name_map["generic_interface_lists"] = "generic-interface-lists"

                self.mstp_vlans = L2vpnv2.Nodes.Node.MstpVlans()
                self.mstp_vlans.parent = self
                self._children_name_map["mstp_vlans"] = "mstp-vlans"

                self.l2vpn_pbb_bsa = L2vpnv2.Nodes.Node.L2vpnPbbBsa()
                self.l2vpn_pbb_bsa.parent = self
                self._children_name_map["l2vpn_pbb_bsa"] = "l2vpn-pbb-bsa"

                self.flexible_xconnect_services = L2vpnv2.Nodes.Node.FlexibleXconnectServices()
                self.flexible_xconnect_services.parent = self
                self._children_name_map["flexible_xconnect_services"] = "flexible-xconnect-services"

                self.xconnect_brief = L2vpnv2.Nodes.Node.XconnectBrief()
                self.xconnect_brief.parent = self
                self._children_name_map["xconnect_brief"] = "xconnect-brief"
                self._segment_path = lambda: "node" + "[node-id='" + str(self.node_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:l2vpnv2/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(L2vpnv2.Nodes.Node, ['node_id'], name, value)


            class Discoveries(Entity):
                """
                Discovery Table
                
                .. attribute:: discovery
                
                	VPLS Discovery information
                	**type**\: list of  		 :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Discoveries, self).__init__()

                    self.yang_name = "discoveries"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Nodes.Node.Discoveries.Discovery))])
                    self._leafs = OrderedDict()

                    self.discovery = YList(self)
                    self._segment_path = lambda: "discoveries"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries, [], name, value)


                class Discovery(Entity):
                    """
                    VPLS Discovery information
                    
                    .. attribute:: service_name
                    
                    	Service type
                    	**type**\:  :py:class:`L2vpnService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnService>`
                    
                    .. attribute:: group_name
                    
                    	Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: vpn_name
                    
                    	VPN Name
                    	**type**\: str
                    
                    	**length:** 1..27
                    
                    .. attribute:: signalling_info
                    
                    	Info about signalling protocol
                    	**type**\:  :py:class:`SignallingInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo>`
                    
                    .. attribute:: mtu_mismatch_ignore
                    
                    	Ignore MTU Mismatch
                    	**type**\: bool
                    
                    .. attribute:: number_vpn
                    
                    	Number of vpns
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_id
                    
                    	VPN id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: service_name_xr
                    
                    	Service Type
                    	**type**\: str
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: vpn_name_xr
                    
                    	VPN instance name
                    	**type**\: str
                    
                    .. attribute:: is_service_connected
                    
                    	Is the service connected
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery, self).__init__()

                        self.yang_name = "discovery"
                        self.yang_parent_name = "discoveries"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("signalling-info", ("signalling_info", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo))])
                        self._leafs = OrderedDict([
                            ('service_name', YLeaf(YType.enumeration, 'service-name')),
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('vpn_name', YLeaf(YType.str, 'vpn-name')),
                            ('mtu_mismatch_ignore', YLeaf(YType.boolean, 'mtu-mismatch-ignore')),
                            ('number_vpn', YLeaf(YType.uint32, 'number-vpn')),
                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                            ('service_name_xr', YLeaf(YType.str, 'service-name-xr')),
                            ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                            ('vpn_name_xr', YLeaf(YType.str, 'vpn-name-xr')),
                            ('is_service_connected', YLeaf(YType.boolean, 'is-service-connected')),
                        ])
                        self.service_name = None
                        self.group_name = None
                        self.vpn_name = None
                        self.mtu_mismatch_ignore = None
                        self.number_vpn = None
                        self.vpn_id = None
                        self.service_name_xr = None
                        self.group_name_xr = None
                        self.vpn_name_xr = None
                        self.is_service_connected = None

                        self.signalling_info = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo()
                        self.signalling_info.parent = self
                        self._children_name_map["signalling_info"] = "signalling-info"
                        self._segment_path = lambda: "discovery"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery, ['service_name', 'group_name', 'vpn_name', 'mtu_mismatch_ignore', 'number_vpn', 'vpn_id', 'service_name_xr', 'group_name_xr', 'vpn_name_xr', 'is_service_connected'], name, value)


                    class SignallingInfo(Entity):
                        """
                        Info about signalling protocol
                        
                        .. attribute:: bgp_sig_info
                        
                        	bgp sig info
                        	**type**\:  :py:class:`BgpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo>`
                        
                        .. attribute:: ldp_sig_info
                        
                        	ldp sig info
                        	**type**\:  :py:class:`LdpSigInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo>`
                        
                        .. attribute:: ad_signalling_method
                        
                        	ADSignallingMethod
                        	**type**\:  :py:class:`L2vpnAdSigMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdSigMethod>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo, self).__init__()

                            self.yang_name = "signalling-info"
                            self.yang_parent_name = "discovery"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bgp-sig-info", ("bgp_sig_info", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo)), ("ldp-sig-info", ("ldp_sig_info", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo))])
                            self._leafs = OrderedDict([
                                ('ad_signalling_method', YLeaf(YType.enumeration, 'ad-signalling-method')),
                            ])
                            self.ad_signalling_method = None

                            self.bgp_sig_info = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo()
                            self.bgp_sig_info.parent = self
                            self._children_name_map["bgp_sig_info"] = "bgp-sig-info"

                            self.ldp_sig_info = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo()
                            self.ldp_sig_info.parent = self
                            self._children_name_map["ldp_sig_info"] = "ldp-sig-info"
                            self._segment_path = lambda: "signalling-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo, ['ad_signalling_method'], name, value)


                        class BgpSigInfo(Entity):
                            """
                            bgp sig info
                            
                            .. attribute:: number_edges
                            
                            	Number of Edges
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: edge
                            
                            	List of edge ids
                            	**type**\: list of  		 :py:class:`Edge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge>`
                            
                            .. attribute:: redge
                            
                            	List of edge ids
                            	**type**\: list of  		 :py:class:`Redge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo, self).__init__()

                                self.yang_name = "bgp-sig-info"
                                self.yang_parent_name = "signalling-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("edge", ("edge", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge)), ("redge", ("redge", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge))])
                                self._leafs = OrderedDict([
                                    ('number_edges', YLeaf(YType.uint32, 'number-edges')),
                                    ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                                ])
                                self.number_edges = None
                                self.number_remote_edges = None

                                self.edge = YList(self)
                                self.redge = YList(self)
                                self._segment_path = lambda: "bgp-sig-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo, ['number_edges', 'number_remote_edges'], name, value)


                            class Edge(Entity):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, self).__init__()

                                    self.yang_name = "edge"
                                    self.yang_parent_name = "bgp-sig-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock))])
                                    self._leafs = OrderedDict([
                                        ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                        ('label_count', YLeaf(YType.uint32, 'label-count')),
                                    ])
                                    self.edge_id = None
                                    self.label_count = None

                                    self.label_block = YList(self)
                                    self._segment_path = lambda: "edge"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge, ['edge_id', 'label_count'], name, value)


                                class LabelBlock(Entity):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, self).__init__()

                                        self.yang_name = "label-block"
                                        self.yang_parent_name = "edge"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector))])
                                        self._leafs = OrderedDict([
                                            ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                            ('label_base', YLeaf(YType.uint32, 'label-base')),
                                            ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                            ('block_size', YLeaf(YType.uint32, 'block-size')),
                                            ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                            ('next_hop', YLeaf(YType.str, 'next-hop')),
                                            ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                        ])
                                        self.label_time_created = None
                                        self.label_base = None
                                        self.block_offset = None
                                        self.block_size = None
                                        self.local_edge_id = None
                                        self.next_hop = None
                                        self.label_error = None

                                        self.status_vector = YList(self)
                                        self._segment_path = lambda: "label-block"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                    class StatusVector(Entity):
                                        """
                                        Status Vector
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, self).__init__()

                                            self.yang_name = "status-vector"
                                            self.yang_parent_name = "label-block"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint8, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "status-vector"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Edge.LabelBlock.StatusVector, ['entry'], name, value)


                            class Redge(Entity):
                                """
                                List of edge ids
                                
                                .. attribute:: edge_id
                                
                                	Edge ids
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_count
                                
                                	Number of label blocks
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: label_block
                                
                                	List of label blocks
                                	**type**\: list of  		 :py:class:`LabelBlock <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, self).__init__()

                                    self.yang_name = "redge"
                                    self.yang_parent_name = "bgp-sig-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("label-block", ("label_block", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock))])
                                    self._leafs = OrderedDict([
                                        ('edge_id', YLeaf(YType.uint32, 'edge-id')),
                                        ('label_count', YLeaf(YType.uint32, 'label-count')),
                                    ])
                                    self.edge_id = None
                                    self.label_count = None

                                    self.label_block = YList(self)
                                    self._segment_path = lambda: "redge"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge, ['edge_id', 'label_count'], name, value)


                                class LabelBlock(Entity):
                                    """
                                    List of label blocks
                                    
                                    .. attribute:: label_time_created
                                    
                                    	Creation time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: label_base
                                    
                                    	Label Base
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_offset
                                    
                                    	Block offset
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: block_size
                                    
                                    	Block size
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_edge_id
                                    
                                    	Local edge ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: next_hop
                                    
                                    	 Peer id
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: label_error
                                    
                                    	Label Error
                                    	**type**\:  :py:class:`L2vpnAdLsdErr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdLsdErr>`
                                    
                                    .. attribute:: status_vector
                                    
                                    	Status Vector
                                    	**type**\: list of  		 :py:class:`StatusVector <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, self).__init__()

                                        self.yang_name = "label-block"
                                        self.yang_parent_name = "redge"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-vector", ("status_vector", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector))])
                                        self._leafs = OrderedDict([
                                            ('label_time_created', YLeaf(YType.uint32, 'label-time-created')),
                                            ('label_base', YLeaf(YType.uint32, 'label-base')),
                                            ('block_offset', YLeaf(YType.uint32, 'block-offset')),
                                            ('block_size', YLeaf(YType.uint32, 'block-size')),
                                            ('local_edge_id', YLeaf(YType.uint32, 'local-edge-id')),
                                            ('next_hop', YLeaf(YType.str, 'next-hop')),
                                            ('label_error', YLeaf(YType.enumeration, 'label-error')),
                                        ])
                                        self.label_time_created = None
                                        self.label_base = None
                                        self.block_offset = None
                                        self.block_size = None
                                        self.local_edge_id = None
                                        self.next_hop = None
                                        self.label_error = None

                                        self.status_vector = YList(self)
                                        self._segment_path = lambda: "label-block"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock, ['label_time_created', 'label_base', 'block_offset', 'block_size', 'local_edge_id', 'next_hop', 'label_error'], name, value)


                                    class StatusVector(Entity):
                                        """
                                        Status Vector
                                        
                                        .. attribute:: entry
                                        
                                        	
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, self).__init__()

                                            self.yang_name = "status-vector"
                                            self.yang_parent_name = "label-block"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('entry', YLeaf(YType.uint8, 'entry')),
                                            ])
                                            self.entry = None
                                            self._segment_path = lambda: "status-vector"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.BgpSigInfo.Redge.LabelBlock.StatusVector, ['entry'], name, value)


                        class LdpSigInfo(Entity):
                            """
                            ldp sig info
                            
                            .. attribute:: local_vpls_id
                            
                            	Local VPLS\-ID
                            	**type**\:  :py:class:`LocalVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId>`
                            
                            .. attribute:: local_l2_router_id
                            
                            	Local L2VPN Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: number_remote_edges
                            
                            	Number of remote Edges
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: remote_nlri
                            
                            	List of NLRIs
                            	**type**\: list of  		 :py:class:`RemoteNlri <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo, self).__init__()

                                self.yang_name = "ldp-sig-info"
                                self.yang_parent_name = "signalling-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("local-vpls-id", ("local_vpls_id", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId)), ("remote-nlri", ("remote_nlri", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri))])
                                self._leafs = OrderedDict([
                                    ('local_l2_router_id', YLeaf(YType.str, 'local-l2-router-id')),
                                    ('number_remote_edges', YLeaf(YType.uint32, 'number-remote-edges')),
                                ])
                                self.local_l2_router_id = None
                                self.number_remote_edges = None

                                self.local_vpls_id = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId()
                                self.local_vpls_id.parent = self
                                self._children_name_map["local_vpls_id"] = "local-vpls-id"

                                self.remote_nlri = YList(self)
                                self._segment_path = lambda: "ldp-sig-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo, ['local_l2_router_id', 'number_remote_edges'], name, value)


                            class LocalVplsId(Entity):
                                """
                                Local VPLS\-ID
                                
                                .. attribute:: auto
                                
                                	auto
                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto>`
                                
                                .. attribute:: two_byte_as
                                
                                	two byte as
                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs>`
                                
                                .. attribute:: v4_addr
                                
                                	v4 addr
                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr>`
                                
                                .. attribute:: vpls_id_type
                                
                                	VPLS ID TYPE
                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, self).__init__()

                                    self.yang_name = "local-vpls-id"
                                    self.yang_parent_name = "ldp-sig-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr))])
                                    self._leafs = OrderedDict([
                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                    ])
                                    self.vpls_id_type = None

                                    self.auto = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto()
                                    self.auto.parent = self
                                    self._children_name_map["auto"] = "auto"

                                    self.two_byte_as = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs()
                                    self.two_byte_as.parent = self
                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                    self.v4_addr = L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr()
                                    self.v4_addr.parent = self
                                    self._children_name_map["v4_addr"] = "v4-addr"
                                    self._segment_path = lambda: "local-vpls-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId, ['vpls_id_type'], name, value)


                                class Auto(Entity):
                                    """
                                    auto
                                    
                                    .. attribute:: asn
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: vpn_id
                                    
                                    	VPN ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, self).__init__()

                                        self.yang_name = "auto"
                                        self.yang_parent_name = "local-vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ])
                                        self.asn = None
                                        self.vpn_id = None
                                        self._segment_path = lambda: "auto"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.Auto, ['asn', 'vpn_id'], name, value)


                                class TwoByteAs(Entity):
                                    """
                                    two byte as
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	2 Byte AS Number
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: four_byte_index
                                    
                                    	4 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, self).__init__()

                                        self.yang_name = "two-byte-as"
                                        self.yang_parent_name = "local-vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                        ])
                                        self.two_byte_as = None
                                        self.four_byte_index = None
                                        self._segment_path = lambda: "two-byte-as"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                class V4Addr(Entity):
                                    """
                                    v4 addr
                                    
                                    .. attribute:: ipv4_address
                                    
                                    	IPv4 Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: two_byte_index
                                    
                                    	2 Byte Index
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, self).__init__()

                                        self.yang_name = "v4-addr"
                                        self.yang_parent_name = "local-vpls-id"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                        ])
                                        self.ipv4_address = None
                                        self.two_byte_index = None
                                        self._segment_path = lambda: "v4-addr"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.LocalVplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class RemoteNlri(Entity):
                                """
                                List of NLRIs
                                
                                .. attribute:: nlri_time_created
                                
                                	NLRI creation time
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_address
                                
                                	Local BGP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_address
                                
                                	Remote BGP Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_l2_router_id
                                
                                	Remote L2VPN Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, self).__init__()

                                    self.yang_name = "remote-nlri"
                                    self.yang_parent_name = "ldp-sig-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('nlri_time_created', YLeaf(YType.uint32, 'nlri-time-created')),
                                        ('local_address', YLeaf(YType.str, 'local-address')),
                                        ('remote_address', YLeaf(YType.str, 'remote-address')),
                                        ('remote_l2_router_id', YLeaf(YType.str, 'remote-l2-router-id')),
                                    ])
                                    self.nlri_time_created = None
                                    self.local_address = None
                                    self.remote_address = None
                                    self.remote_l2_router_id = None
                                    self._segment_path = lambda: "remote-nlri"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Discoveries.Discovery.SignallingInfo.LdpSigInfo.RemoteNlri, ['nlri_time_created', 'local_address', 'remote_address', 'remote_l2_router_id'], name, value)


            class FlexibleXconnectServiceSummary(Entity):
                """
                Flexible XConnect Service summary information
                
                .. attribute:: number_fxc
                
                	Number of flexible xconnect services
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_up
                
                	Number of flexible xconnect services whose state is up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_fxc_down
                
                	Number of flexible xconnect services whose state is down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServiceSummary, self).__init__()

                    self.yang_name = "flexible-xconnect-service-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number_fxc', YLeaf(YType.uint32, 'number-fxc')),
                        ('number_fxc_up', YLeaf(YType.uint32, 'number-fxc-up')),
                        ('number_fxc_down', YLeaf(YType.uint32, 'number-fxc-down')),
                    ])
                    self.number_fxc = None
                    self.number_fxc_up = None
                    self.number_fxc_down = None
                    self._segment_path = lambda: "flexible-xconnect-service-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServiceSummary, ['number_fxc', 'number_fxc_up', 'number_fxc_down'], name, value)


            class MainInterfaces(Entity):
                """
                Main Interface
                
                .. attribute:: main_interface
                
                	Main Interface Table
                	**type**\: list of  		 :py:class:`MainInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.MainInterfaces, self).__init__()

                    self.yang_name = "main-interfaces"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("main-interface", ("main_interface", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface))])
                    self._leafs = OrderedDict()

                    self.main_interface = YList(self)
                    self._segment_path = lambda: "main-interfaces"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces, [], name, value)


                class MainInterface(Entity):
                    """
                    Main Interface Table
                    
                    .. attribute:: interface_name  (key)
                    
                    	Main interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: main_interface_instances
                    
                    	Main Interface Instance table
                    	**type**\:  :py:class:`MainInterfaceInstances <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances>`
                    
                    .. attribute:: main_interface_info
                    
                    	Main Interface info
                    	**type**\:  :py:class:`MainInterfaceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface, self).__init__()

                        self.yang_name = "main-interface"
                        self.yang_parent_name = "main-interfaces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_name']
                        self._child_classes = OrderedDict([("main-interface-instances", ("main_interface_instances", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances)), ("main-interface-info", ("main_interface_info", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo))])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                        ])
                        self.interface_name = None

                        self.main_interface_instances = L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances()
                        self.main_interface_instances.parent = self
                        self._children_name_map["main_interface_instances"] = "main-interface-instances"

                        self.main_interface_info = L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo()
                        self.main_interface_info.parent = self
                        self._children_name_map["main_interface_info"] = "main-interface-info"
                        self._segment_path = lambda: "main-interface" + "[interface-name='" + str(self.interface_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface, ['interface_name'], name, value)


                    class MainInterfaceInstances(Entity):
                        """
                        Main Interface Instance table
                        
                        .. attribute:: main_interface_instance
                        
                        	Main Interface Instance
                        	**type**\: list of  		 :py:class:`MainInterfaceInstance <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances, self).__init__()

                            self.yang_name = "main-interface-instances"
                            self.yang_parent_name = "main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("main-interface-instance", ("main_interface_instance", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance))])
                            self._leafs = OrderedDict()

                            self.main_interface_instance = YList(self)
                            self._segment_path = lambda: "main-interface-instances"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances, [], name, value)


                        class MainInterfaceInstance(Entity):
                            """
                            Main Interface Instance
                            
                            .. attribute:: instance  (key)
                            
                            	Instance
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: main_interface_instance_info
                            
                            	Main Interface Instance info
                            	**type**\:  :py:class:`MainInterfaceInstanceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo>`
                            
                            .. attribute:: main_interface_instance_bridge_ports
                            
                            	Main Interface Instance Bridge Port table
                            	**type**\:  :py:class:`MainInterfaceInstanceBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, self).__init__()

                                self.yang_name = "main-interface-instance"
                                self.yang_parent_name = "main-interface-instances"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['instance']
                                self._child_classes = OrderedDict([("main-interface-instance-info", ("main_interface_instance_info", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo)), ("main-interface-instance-bridge-ports", ("main_interface_instance_bridge_ports", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts))])
                                self._leafs = OrderedDict([
                                    ('instance', YLeaf(YType.uint32, 'instance')),
                                ])
                                self.instance = None

                                self.main_interface_instance_info = L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo()
                                self.main_interface_instance_info.parent = self
                                self._children_name_map["main_interface_instance_info"] = "main-interface-instance-info"

                                self.main_interface_instance_bridge_ports = L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts()
                                self.main_interface_instance_bridge_ports.parent = self
                                self._children_name_map["main_interface_instance_bridge_ports"] = "main-interface-instance-bridge-ports"
                                self._segment_path = lambda: "main-interface-instance" + "[instance='" + str(self.instance) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance, ['instance'], name, value)


                            class MainInterfaceInstanceInfo(Entity):
                                """
                                Main Interface Instance info
                                
                                .. attribute:: configured_instance
                                
                                	Configured Instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: flush_count
                                
                                	Flush count 
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: interface_count
                                
                                	Interface count
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_flags
                                
                                	Instance Flags
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_id
                                
                                	Instance ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: instance_state
                                
                                	Instance State
                                	**type**\:  :py:class:`L2vpnMainIfInstanceState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfInstanceState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, self).__init__()

                                    self.yang_name = "main-interface-instance-info"
                                    self.yang_parent_name = "main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('configured_instance', YLeaf(YType.uint32, 'configured-instance')),
                                        ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                                        ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                                        ('instance_flags', YLeaf(YType.uint32, 'instance-flags')),
                                        ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                        ('instance_state', YLeaf(YType.enumeration, 'instance-state')),
                                    ])
                                    self.configured_instance = None
                                    self.flush_count = None
                                    self.interface_count = None
                                    self.instance_flags = None
                                    self.instance_id = None
                                    self.instance_state = None
                                    self._segment_path = lambda: "main-interface-instance-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceInfo, ['configured_instance', 'flush_count', 'interface_count', 'instance_flags', 'instance_id', 'instance_state'], name, value)


                            class MainInterfaceInstanceBridgePorts(Entity):
                                """
                                Main Interface Instance Bridge Port table
                                
                                .. attribute:: main_interface_instance_bridge_port
                                
                                	Main Interface Bridge Port info
                                	**type**\: list of  		 :py:class:`MainInterfaceInstanceBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, self).__init__()

                                    self.yang_name = "main-interface-instance-bridge-ports"
                                    self.yang_parent_name = "main-interface-instance"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("main-interface-instance-bridge-port", ("main_interface_instance_bridge_port", L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort))])
                                    self._leafs = OrderedDict()

                                    self.main_interface_instance_bridge_port = YList(self)
                                    self._segment_path = lambda: "main-interface-instance-bridge-ports"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts, [], name, value)


                                class MainInterfaceInstanceBridgePort(Entity):
                                    """
                                    Main Interface Bridge Port info
                                    
                                    .. attribute:: bridge_port  (key)
                                    
                                    	Bridge Port
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: bridge_port_xr
                                    
                                    	Bridge port ifhandle
                                    	**type**\: str
                                    
                                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                                    
                                    .. attribute:: instance_id
                                    
                                    	Instance ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, self).__init__()

                                        self.yang_name = "main-interface-instance-bridge-port"
                                        self.yang_parent_name = "main-interface-instance-bridge-ports"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = ['bridge_port']
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bridge_port', YLeaf(YType.str, 'bridge-port')),
                                            ('bridge_port_xr', YLeaf(YType.str, 'bridge-port-xr')),
                                            ('instance_id', YLeaf(YType.uint32, 'instance-id')),
                                        ])
                                        self.bridge_port = None
                                        self.bridge_port_xr = None
                                        self.instance_id = None
                                        self._segment_path = lambda: "main-interface-instance-bridge-port" + "[bridge-port='" + str(self.bridge_port) + "']"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInstances.MainInterfaceInstance.MainInterfaceInstanceBridgePorts.MainInterfaceInstanceBridgePort, ['bridge_port', 'bridge_port_xr', 'instance_id'], name, value)


                    class MainInterfaceInfo(Entity):
                        """
                        Main Interface info
                        
                        .. attribute:: main_interface_handle
                        
                        	Main Interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: protected
                        
                        	Protected
                        	**type**\:  :py:class:`L2vpnMainIfProtectected <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMainIfProtectected>`
                        
                        .. attribute:: interface_count
                        
                        	Sub Interface Count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo, self).__init__()

                            self.yang_name = "main-interface-info"
                            self.yang_parent_name = "main-interface"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('main_interface_handle', YLeaf(YType.str, 'main-interface-handle')),
                                ('protected', YLeaf(YType.enumeration, 'protected')),
                                ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                            ])
                            self.main_interface_handle = None
                            self.protected = None
                            self.interface_count = None
                            self._segment_path = lambda: "main-interface-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.MainInterfaces.MainInterface.MainInterfaceInfo, ['main_interface_handle', 'protected', 'interface_count'], name, value)


            class IccpSm(Entity):
                """
                ICCP\-based Service Multi\-homing operational data
                
                .. attribute:: iccp_sm_summary
                
                	ICCP\-based Service Multi\-homing database summary
                	**type**\:  :py:class:`IccpSmSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpSmSummary>`
                
                .. attribute:: iccp_groups
                
                	ICCP Group Table
                	**type**\:  :py:class:`IccpGroups <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.IccpSm, self).__init__()

                    self.yang_name = "iccp-sm"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("iccp-sm-summary", ("iccp_sm_summary", L2vpnv2.Nodes.Node.IccpSm.IccpSmSummary)), ("iccp-groups", ("iccp_groups", L2vpnv2.Nodes.Node.IccpSm.IccpGroups))])
                    self._leafs = OrderedDict()

                    self.iccp_sm_summary = L2vpnv2.Nodes.Node.IccpSm.IccpSmSummary()
                    self.iccp_sm_summary.parent = self
                    self._children_name_map["iccp_sm_summary"] = "iccp-sm-summary"

                    self.iccp_groups = L2vpnv2.Nodes.Node.IccpSm.IccpGroups()
                    self.iccp_groups.parent = self
                    self._children_name_map["iccp_groups"] = "iccp-groups"
                    self._segment_path = lambda: "iccp-sm"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm, [], name, value)


                class IccpSmSummary(Entity):
                    """
                    ICCP\-based Service Multi\-homing database
                    summary
                    
                    .. attribute:: groups
                    
                    	Total Number of Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unresolved_groups
                    
                    	Number of Unresolved Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: provisioned_groups
                    
                    	Number of Provisioned Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: connecting_groups
                    
                    	Number of Connecting Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: connected_groups
                    
                    	Number of Connected Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronizing_groups
                    
                    	Number of Synchronizing Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: synchronized_groups
                    
                    	Number of Synchronized Groups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: ports
                    
                    	Total Number of Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: operational_ports
                    
                    	Number of Operational Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: failed_ports
                    
                    	Number of Failed Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unknown_ports
                    
                    	Number of Unknown Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unconfigured_ports
                    
                    	Number of Unconfigured Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: unsynchronized_ports
                    
                    	Number of Unsynchronized Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reverting_ports
                    
                    	Number of Reverting Ports
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.IccpSm.IccpSmSummary, self).__init__()

                        self.yang_name = "iccp-sm-summary"
                        self.yang_parent_name = "iccp-sm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('groups', YLeaf(YType.uint32, 'groups')),
                            ('unresolved_groups', YLeaf(YType.uint32, 'unresolved-groups')),
                            ('provisioned_groups', YLeaf(YType.uint32, 'provisioned-groups')),
                            ('connecting_groups', YLeaf(YType.uint32, 'connecting-groups')),
                            ('connected_groups', YLeaf(YType.uint32, 'connected-groups')),
                            ('synchronizing_groups', YLeaf(YType.uint32, 'synchronizing-groups')),
                            ('synchronized_groups', YLeaf(YType.uint32, 'synchronized-groups')),
                            ('ports', YLeaf(YType.uint32, 'ports')),
                            ('operational_ports', YLeaf(YType.uint32, 'operational-ports')),
                            ('failed_ports', YLeaf(YType.uint32, 'failed-ports')),
                            ('unknown_ports', YLeaf(YType.uint32, 'unknown-ports')),
                            ('unconfigured_ports', YLeaf(YType.uint32, 'unconfigured-ports')),
                            ('unsynchronized_ports', YLeaf(YType.uint32, 'unsynchronized-ports')),
                            ('reverting_ports', YLeaf(YType.uint32, 'reverting-ports')),
                        ])
                        self.groups = None
                        self.unresolved_groups = None
                        self.provisioned_groups = None
                        self.connecting_groups = None
                        self.connected_groups = None
                        self.synchronizing_groups = None
                        self.synchronized_groups = None
                        self.ports = None
                        self.operational_ports = None
                        self.failed_ports = None
                        self.unknown_ports = None
                        self.unconfigured_ports = None
                        self.unsynchronized_ports = None
                        self.reverting_ports = None
                        self._segment_path = lambda: "iccp-sm-summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpSmSummary, ['groups', 'unresolved_groups', 'provisioned_groups', 'connecting_groups', 'connected_groups', 'synchronizing_groups', 'synchronized_groups', 'ports', 'operational_ports', 'failed_ports', 'unknown_ports', 'unconfigured_ports', 'unsynchronized_ports', 'reverting_ports'], name, value)


                class IccpGroups(Entity):
                    """
                    ICCP Group Table
                    
                    .. attribute:: iccp_group
                    
                    	ICCP Group
                    	**type**\: list of  		 :py:class:`IccpGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups, self).__init__()

                        self.yang_name = "iccp-groups"
                        self.yang_parent_name = "iccp-sm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("iccp-group", ("iccp_group", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup))])
                        self._leafs = OrderedDict()

                        self.iccp_group = YList(self)
                        self._segment_path = lambda: "iccp-groups"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups, [], name, value)


                    class IccpGroup(Entity):
                        """
                        ICCP Group
                        
                        .. attribute:: group_id  (key)
                        
                        	Group ID
                        	**type**\: int
                        
                        	**range:** 1..4294967295
                        
                        .. attribute:: iccp_group_info
                        
                        	ICCP Group Information
                        	**type**\:  :py:class:`IccpGroupInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo>`
                        
                        .. attribute:: iccp_ports
                        
                        	ICCP Port Table
                        	**type**\:  :py:class:`IccpPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup, self).__init__()

                            self.yang_name = "iccp-group"
                            self.yang_parent_name = "iccp-groups"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['group_id']
                            self._child_classes = OrderedDict([("iccp-group-info", ("iccp_group_info", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo)), ("iccp-ports", ("iccp_ports", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts))])
                            self._leafs = OrderedDict([
                                ('group_id', YLeaf(YType.uint32, 'group-id')),
                            ])
                            self.group_id = None

                            self.iccp_group_info = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo()
                            self.iccp_group_info.parent = self
                            self._children_name_map["iccp_group_info"] = "iccp-group-info"

                            self.iccp_ports = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts()
                            self.iccp_ports.parent = self
                            self._children_name_map["iccp_ports"] = "iccp-ports"
                            self._segment_path = lambda: "iccp-group" + "[group-id='" + str(self.group_id) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup, ['group_id'], name, value)


                        class IccpGroupInfo(Entity):
                            """
                            ICCP Group Information
                            
                            .. attribute:: group_id
                            
                            	Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_node_id
                            
                            	Local Node ID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: remote_node_id
                            
                            	Remote Node ID
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`IccpSmState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmState>`
                            
                            .. attribute:: iccp_transport_up
                            
                            	ICCP Transport Up
                            	**type**\: bool
                            
                            .. attribute:: iccp_member_up
                            
                            	ICCP Member Up
                            	**type**\: bool
                            
                            .. attribute:: ports
                            
                            	List of ports in the group
                            	**type**\: list of  		 :py:class:`Ports <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, self).__init__()

                                self.yang_name = "iccp-group-info"
                                self.yang_parent_name = "iccp-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("ports", ("ports", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports))])
                                self._leafs = OrderedDict([
                                    ('group_id', YLeaf(YType.uint32, 'group-id')),
                                    ('local_node_id', YLeaf(YType.uint8, 'local-node-id')),
                                    ('remote_node_id', YLeaf(YType.uint8, 'remote-node-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('iccp_transport_up', YLeaf(YType.boolean, 'iccp-transport-up')),
                                    ('iccp_member_up', YLeaf(YType.boolean, 'iccp-member-up')),
                                ])
                                self.group_id = None
                                self.local_node_id = None
                                self.remote_node_id = None
                                self.state = None
                                self.iccp_transport_up = None
                                self.iccp_member_up = None

                                self.ports = YList(self)
                                self._segment_path = lambda: "iccp-group-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo, ['group_id', 'local_node_id', 'remote_node_id', 'state', 'iccp_transport_up', 'iccp_member_up'], name, value)


                            class Ports(Entity):
                                """
                                List of ports in the group
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort>`
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, self).__init__()

                                    self.yang_name = "ports"
                                    self.yang_parent_name = "iccp-group-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                        ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                    ])
                                    self.interface_name = None
                                    self.mac_flush_tcn = None

                                    self.local_port = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"

                                    self.remote_port = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                    self._segment_path = lambda: "ports"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports, ['interface_name', 'mac_flush_tcn'], name, value)


                                class LocalPort(Entity):
                                    """
                                    Local port info
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, self).__init__()

                                        self.yang_name = "local-port"
                                        self.yang_parent_name = "ports"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                            ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                            ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                            ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                            ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                            ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                            ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                        ])
                                        self.port_state = None
                                        self.port_fail_code = None
                                        self.fsm_state = None
                                        self.vlan_state = None
                                        self.vlan_vector = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self._segment_path = lambda: "local-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                                class RemotePort(Entity):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, self).__init__()

                                        self.yang_name = "remote-port"
                                        self.yang_parent_name = "ports"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                            ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                            ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                            ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                            ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                            ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                            ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                        ])
                                        self.port_state = None
                                        self.port_fail_code = None
                                        self.fsm_state = None
                                        self.vlan_state = None
                                        self.vlan_vector = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self._segment_path = lambda: "remote-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpGroupInfo.Ports.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                        class IccpPorts(Entity):
                            """
                            ICCP Port Table
                            
                            .. attribute:: iccp_port
                            
                            	ICCP Port
                            	**type**\: list of  		 :py:class:`IccpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts, self).__init__()

                                self.yang_name = "iccp-ports"
                                self.yang_parent_name = "iccp-group"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("iccp-port", ("iccp_port", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort))])
                                self._leafs = OrderedDict()

                                self.iccp_port = YList(self)
                                self._segment_path = lambda: "iccp-ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts, [], name, value)


                            class IccpPort(Entity):
                                """
                                ICCP Port
                                
                                .. attribute:: interface  (key)
                                
                                	Interface
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: local_port
                                
                                	Local port info
                                	**type**\:  :py:class:`LocalPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort>`
                                
                                .. attribute:: remote_port
                                
                                	Remote port info
                                	**type**\:  :py:class:`RemotePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort>`
                                
                                .. attribute:: interface_name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: mac_flush_tcn
                                
                                	Is MAC flush through STP\-TCN?
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, self).__init__()

                                    self.yang_name = "iccp-port"
                                    self.yang_parent_name = "iccp-ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface']
                                    self._child_classes = OrderedDict([("local-port", ("local_port", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort)), ("remote-port", ("remote_port", L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort))])
                                    self._leafs = OrderedDict([
                                        ('interface', YLeaf(YType.str, 'interface')),
                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                        ('mac_flush_tcn', YLeaf(YType.boolean, 'mac-flush-tcn')),
                                    ])
                                    self.interface = None
                                    self.interface_name = None
                                    self.mac_flush_tcn = None

                                    self.local_port = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort()
                                    self.local_port.parent = self
                                    self._children_name_map["local_port"] = "local-port"

                                    self.remote_port = L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort()
                                    self.remote_port.parent = self
                                    self._children_name_map["remote_port"] = "remote-port"
                                    self._segment_path = lambda: "iccp-port" + "[interface='" + str(self.interface) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort, ['interface', 'interface_name', 'mac_flush_tcn'], name, value)


                                class LocalPort(Entity):
                                    """
                                    Local port info
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, self).__init__()

                                        self.yang_name = "local-port"
                                        self.yang_parent_name = "iccp-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                            ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                            ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                            ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                            ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                            ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                            ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                        ])
                                        self.port_state = None
                                        self.port_fail_code = None
                                        self.fsm_state = None
                                        self.vlan_state = None
                                        self.vlan_vector = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self._segment_path = lambda: "local-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.LocalPort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


                                class RemotePort(Entity):
                                    """
                                    Remote port info
                                    
                                    .. attribute:: port_state
                                    
                                    	Port state
                                    	**type**\:  :py:class:`IccpSmPortState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IccpSmPortState>`
                                    
                                    .. attribute:: port_fail_code
                                    
                                    	Port fail code
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: fsm_state
                                    
                                    	FSM state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_state
                                    
                                    	VLAN state
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: vlan_vector
                                    
                                    	VLAN Vector. VLANList\:\:= FivePackedVLANRoleVectorByte { ,FivePackedVLANRoleVectorByte}. FivePackedVLANRoleVectorByte = (((3\*firstVLANRole + secondVLANRole)\*3 + thirdVLANRole)\*3 + fourthVLAN Role)\*3 + fifthVLANRole. Role\:\:= Primary \| Secondary \| NotConfigured. NotConfigured\:\:= 0. Primary\:\:= 1. Secondary\:\:= 2
                                    	**type**\: str
                                    
                                    	**pattern:** ([0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2})\*)?
                                    
                                    .. attribute:: reversion_time
                                    
                                    	Reversion Time
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: reversion_time_remaining
                                    
                                    	Reversion Time Remaining
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, self).__init__()

                                        self.yang_name = "remote-port"
                                        self.yang_parent_name = "iccp-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('port_state', YLeaf(YType.enumeration, 'port-state')),
                                            ('port_fail_code', YLeaf(YType.uint8, 'port-fail-code')),
                                            ('fsm_state', YLeaf(YType.uint8, 'fsm-state')),
                                            ('vlan_state', YLeaf(YType.uint8, 'vlan-state')),
                                            ('vlan_vector', YLeaf(YType.str, 'vlan-vector')),
                                            ('reversion_time', YLeaf(YType.uint32, 'reversion-time')),
                                            ('reversion_time_remaining', YLeaf(YType.uint32, 'reversion-time-remaining')),
                                        ])
                                        self.port_state = None
                                        self.port_fail_code = None
                                        self.fsm_state = None
                                        self.vlan_state = None
                                        self.vlan_vector = None
                                        self.reversion_time = None
                                        self.reversion_time_remaining = None
                                        self._segment_path = lambda: "remote-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.IccpSm.IccpGroups.IccpGroup.IccpPorts.IccpPort.RemotePort, ['port_state', 'port_fail_code', 'fsm_state', 'vlan_state', 'vlan_vector', 'reversion_time', 'reversion_time_remaining'], name, value)


            class BridgeSummary(Entity):
                """
                Bridge Domain summary information
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains
                
                	Number of bridge\-domains
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_up
                
                	Number of bridge\-domains up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_bridge_domains_shut
                
                	Number of bridge\-domains admin disabled
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_default_bridge_doamins
                
                	Number of default bridge\-domains
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_edge
                
                	Number of PBB Edge
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pbb_core
                
                	Number of PBB Core
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp
                
                	Number of P2MPs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_up
                
                	Number of P2MPs whose state is up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p2mp_down
                
                	Number of P2MPs whose state is down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs
                
                	Number of attachment circuits
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_up
                
                	Number of attachment circuits whose state is up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_a_cs_down
                
                	Number of attachment circuits whose state is down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_pseudowires
                
                	Number of pseudowires
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_up
                
                	Number of pseudowires whose state is up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_p_ws_down
                
                	Number of pseudowires whose state is down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_pseudowires
                
                	Number of pseudowires whose state is standby
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is
                
                	Number of VNIs
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_up
                
                	Number of VNIs up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_down
                
                	Number of VNIs down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: num_vn_is_unresolved
                
                	Number of VNIs unresolved
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_bridges
                
                	Number of partially programmed bridge\-domains
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_pseudowires
                
                	Number of partially programmed pseudowires
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_a_cs
                
                	Number of partially programmed attachment circuits
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.BridgeSummary, self).__init__()

                    self.yang_name = "bridge-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                        ('number_bridge_domains', YLeaf(YType.uint32, 'number-bridge-domains')),
                        ('number_bridge_domains_up', YLeaf(YType.uint32, 'number-bridge-domains-up')),
                        ('number_bridge_domains_shut', YLeaf(YType.uint32, 'number-bridge-domains-shut')),
                        ('number_default_bridge_doamins', YLeaf(YType.uint32, 'number-default-bridge-doamins')),
                        ('number_pbb_edge', YLeaf(YType.uint32, 'number-pbb-edge')),
                        ('number_pbb_core', YLeaf(YType.uint32, 'number-pbb-core')),
                        ('number_p2mp', YLeaf(YType.uint32, 'number-p2mp')),
                        ('number_p2mp_up', YLeaf(YType.uint32, 'number-p2mp-up')),
                        ('number_p2mp_down', YLeaf(YType.uint32, 'number-p2mp-down')),
                        ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                        ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                        ('number_a_cs_down', YLeaf(YType.uint32, 'number-a-cs-down')),
                        ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                        ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                        ('number_p_ws_down', YLeaf(YType.uint32, 'number-p-ws-down')),
                        ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                        ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                        ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                        ('num_vn_is_down', YLeaf(YType.uint32, 'num-vn-is-down')),
                        ('num_vn_is_unresolved', YLeaf(YType.uint32, 'num-vn-is-unresolved')),
                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                        ('partially_programmed_bridges', YLeaf(YType.uint32, 'partially-programmed-bridges')),
                        ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                        ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                    ])
                    self.number_groups = None
                    self.number_bridge_domains = None
                    self.number_bridge_domains_up = None
                    self.number_bridge_domains_shut = None
                    self.number_default_bridge_doamins = None
                    self.number_pbb_edge = None
                    self.number_pbb_core = None
                    self.number_p2mp = None
                    self.number_p2mp_up = None
                    self.number_p2mp_down = None
                    self.number_a_cs = None
                    self.number_a_cs_up = None
                    self.number_a_cs_down = None
                    self.number_pseudowires = None
                    self.number_p_ws_up = None
                    self.number_p_ws_down = None
                    self.standby_pseudowires = None
                    self.num_vn_is = None
                    self.num_vn_is_up = None
                    self.num_vn_is_down = None
                    self.num_vn_is_unresolved = None
                    self.out_of_memory_state = None
                    self.partially_programmed_bridges = None
                    self.partially_programmed_pseudowires = None
                    self.partially_programmed_a_cs = None
                    self._segment_path = lambda: "bridge-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeSummary, ['number_groups', 'number_bridge_domains', 'number_bridge_domains_up', 'number_bridge_domains_shut', 'number_default_bridge_doamins', 'number_pbb_edge', 'number_pbb_core', 'number_p2mp', 'number_p2mp_up', 'number_p2mp_down', 'number_a_cs', 'number_a_cs_up', 'number_a_cs_down', 'number_pseudowires', 'number_p_ws_up', 'number_p_ws_down', 'standby_pseudowires', 'num_vn_is', 'num_vn_is_up', 'num_vn_is_down', 'num_vn_is_unresolved', 'out_of_memory_state', 'partially_programmed_bridges', 'partially_programmed_pseudowires', 'partially_programmed_a_cs'], name, value)


            class Nsr(Entity):
                """
                L2VPN NSR information
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.FailoverStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.NsrStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.IssuStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\: bool
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.StateTransitionTime>`
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.XidInfo>`
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.ReportCard>`
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.EventHistory>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Nsr, self).__init__()

                    self.yang_name = "nsr"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Nodes.Node.Nsr.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Nodes.Node.Nsr.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Nodes.Node.Nsr.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Nodes.Node.Nsr.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Nodes.Node.Nsr.XidInfo)), ("report-card", ("report_card", L2vpnv2.Nodes.Node.Nsr.ReportCard)), ("event-history", ("event_history", L2vpnv2.Nodes.Node.Nsr.EventHistory))])
                    self._leafs = OrderedDict([
                        ('process_role', YLeaf(YType.uint8, 'process-role')),
                        ('process_state', YLeaf(YType.uint8, 'process-state')),
                        ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                        ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                    ])
                    self.process_role = None
                    self.process_state = None
                    self.sync_flags = None
                    self.sw_install_in_progress = None

                    self.failover_status = L2vpnv2.Nodes.Node.Nsr.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"

                    self.nsr_status = L2vpnv2.Nodes.Node.Nsr.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"

                    self.issu_status = L2vpnv2.Nodes.Node.Nsr.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"

                    self.state_transition_time = YList(self)
                    self.xid_info = YList(self)
                    self.report_card = YList(self)
                    self.event_history = YList(self)
                    self._segment_path = lambda: "nsr"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Nsr, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


                class FailoverStatus(Entity):
                    """
                    L2VPN failover status
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.FailoverStatus, self).__init__()

                        self.yang_name = "failover-status"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                            ('start_time', YLeaf(YType.uint32, 'start-time')),
                            ('master_time', YLeaf(YType.uint32, 'master-time')),
                        ])
                        self.triggered_time = None
                        self.start_time = None
                        self.master_time = None
                        self._segment_path = lambda: "failover-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


                class NsrStatus(Entity):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.NsrStatus, self).__init__()

                        self.yang_name = "nsr-status"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus))])
                        self._leafs = OrderedDict([
                            ('role', YLeaf(YType.enumeration, 'role')),
                        ])
                        self.role = None

                        self.idt_status = L2vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"

                        self.previ_ous_idt_status = L2vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._segment_path = lambda: "nsr-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.NsrStatus, ['role'], name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "nsr-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "nsr-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "previ-ous-idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class IssuStatus(Entity):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.IssuStatus, self).__init__()

                        self.yang_name = "issu-status"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus))])
                        self._leafs = OrderedDict([
                            ('role', YLeaf(YType.enumeration, 'role')),
                        ])
                        self.role = None

                        self.idt_status = L2vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"

                        self.previ_ous_idt_status = L2vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._segment_path = lambda: "issu-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.IssuStatus, ['role'], name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "issu-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "issu-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "previ-ous-idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class StateTransitionTime(Entity):
                    """
                    Transition time for all states
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.StateTransitionTime, self).__init__()

                        self.yang_name = "state-transition-time"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "state-transition-time"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.StateTransitionTime, ['entry'], name, value)


                class XidInfo(Entity):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.XidInfo, self).__init__()

                        self.yang_name = "xid-info"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('app_type', YLeaf(YType.enumeration, 'app-type')),
                            ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                        ])
                        self.app_type = None
                        self.sent_ids = None
                        self._segment_path = lambda: "xid-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.XidInfo, ['app_type', 'sent_ids'], name, value)


                class ReportCard(Entity):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\: bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\: bool
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.ReportCard, self).__init__()

                        self.yang_name = "report-card"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                            ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                            ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                            ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                            ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                        ])
                        self.collaborator_is_connected = None
                        self.connection_change_time = None
                        self.collaborator_idt_done = None
                        self.idt_time = None
                        self.collaborator_skipped = None
                        self._segment_path = lambda: "report-card"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


                class EventHistory(Entity):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Nsr.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "nsr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                            ('new_state', YLeaf(YType.uint8, 'new-state')),
                            ('process_event', YLeaf(YType.uint16, 'process-event')),
                            ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                            ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                        ])
                        self.previous_state = None
                        self.new_state = None
                        self.process_event = None
                        self.process_collaborator = None
                        self.event_timestamp = None
                        self._segment_path = lambda: "event-history"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Nsr.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


            class PreferredPaths(Entity):
                """
                Preferred path Table
                
                .. attribute:: preferred_path
                
                	Preferred path information
                	**type**\: list of  		 :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.PreferredPaths, self).__init__()

                    self.yang_name = "preferred-paths"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath))])
                    self._leafs = OrderedDict()

                    self.preferred_path = YList(self)
                    self._segment_path = lambda: "preferred-paths"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.PreferredPaths, [], name, value)


                class PreferredPath(Entity):
                    """
                    Preferred path information
                    
                    .. attribute:: preferred_type
                    
                    	Preferred type
                    	**type**\:  :py:class:`PreferredPathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.PreferredPathOption>`
                    
                    .. attribute:: interface_name
                    
                    	Main interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: type
                    
                    	Preferred type
                    	**type**\:  :py:class:`L2vpnPreferred <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPreferred>`
                    
                    .. attribute:: interface_name_xr
                    
                    	Interface name
                    	**type**\: str
                    
                    	**length:** 0..65
                    
                    .. attribute:: total_bandwidth
                    
                    	TotalBandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: available_bandwidth
                    
                    	AvailableBandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: reserved_bandwidth
                    
                    	ReservedBandwidth
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: virtual_circuit
                    
                    	virtual circuit
                    	**type**\: list of  		 :py:class:`VirtualCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath.VirtualCircuit>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath, self).__init__()

                        self.yang_name = "preferred-path"
                        self.yang_parent_name = "preferred-paths"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("virtual-circuit", ("virtual_circuit", L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath.VirtualCircuit))])
                        self._leafs = OrderedDict([
                            ('preferred_type', YLeaf(YType.enumeration, 'preferred-type')),
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('type', YLeaf(YType.enumeration, 'type')),
                            ('interface_name_xr', YLeaf(YType.str, 'interface-name-xr')),
                            ('total_bandwidth', YLeaf(YType.uint32, 'total-bandwidth')),
                            ('available_bandwidth', YLeaf(YType.uint32, 'available-bandwidth')),
                            ('reserved_bandwidth', YLeaf(YType.uint32, 'reserved-bandwidth')),
                        ])
                        self.preferred_type = None
                        self.interface_name = None
                        self.type = None
                        self.interface_name_xr = None
                        self.total_bandwidth = None
                        self.available_bandwidth = None
                        self.reserved_bandwidth = None

                        self.virtual_circuit = YList(self)
                        self._segment_path = lambda: "preferred-path"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath, ['preferred_type', 'interface_name', 'type', 'interface_name_xr', 'total_bandwidth', 'available_bandwidth', 'reserved_bandwidth'], name, value)


                    class VirtualCircuit(Entity):
                        """
                        virtual circuit
                        
                        .. attribute:: peer_id
                        
                        	PeerID
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: source_address
                        
                        	SourceAddress
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        .. attribute:: pwid_type
                        
                        	pwid type
                        	**type**\:  :py:class:`L2vpnPwId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwId>`
                        
                        .. attribute:: pwid
                        
                        	PWID
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: fe_ctype
                        
                        	FECType
                        	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath.VirtualCircuit, self).__init__()

                            self.yang_name = "virtual-circuit"
                            self.yang_parent_name = "preferred-path"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('peer_id', YLeaf(YType.str, 'peer-id')),
                                ('source_address', YLeaf(YType.str, 'source-address')),
                                ('pwid_type', YLeaf(YType.enumeration, 'pwid-type')),
                                ('pwid', YLeaf(YType.uint64, 'pwid')),
                                ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                            ])
                            self.peer_id = None
                            self.source_address = None
                            self.pwid_type = None
                            self.pwid = None
                            self.fe_ctype = None
                            self._segment_path = lambda: "virtual-circuit"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.PreferredPaths.PreferredPath.VirtualCircuit, ['peer_id', 'source_address', 'pwid_type', 'pwid', 'fe_ctype'], name, value)


            class GlobalSettings(Entity):
                """
                L2VPN global settings
                
                .. attribute:: pw_grouping_enabled
                
                	PW Grouping enabled
                	**type**\: bool
                
                .. attribute:: pw_status_enabled
                
                	PW Status enabled
                	**type**\: bool
                
                .. attribute:: logging_pw_enabled
                
                	Logging PW enabled
                	**type**\: bool
                
                .. attribute:: logging_bd_enabled
                
                	Logging BD state changes enabled
                	**type**\: bool
                
                .. attribute:: logging_vfi_enabled
                
                	Logging VFI state changes enabled
                	**type**\: bool
                
                .. attribute:: logging_nsr_enabled
                
                	Logging NSR state changes enabled
                	**type**\: bool
                
                .. attribute:: logging_df_election_enabled
                
                	Logging EVPN Designated Forwarder changes enabled
                	**type**\: bool
                
                .. attribute:: tcn_propagation_enabled
                
                	TCN propagation enabled
                	**type**\: bool
                
                .. attribute:: pw_oam_refresh_transmit_time
                
                	PW OAM refresh transmit (seconds)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                	**units**\: second
                
                .. attribute:: ha_role
                
                	Node redundancy role
                	**type**\: str
                
                .. attribute:: issu_role
                
                	Node ISSU role
                	**type**\: str
                
                .. attribute:: process_fsm
                
                	Current L2VPN FSM role
                	**type**\: str
                
                .. attribute:: going_active
                
                	transitioning to Active functional role
                	**type**\: bool
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.GlobalSettings, self).__init__()

                    self.yang_name = "global-settings"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('pw_grouping_enabled', YLeaf(YType.boolean, 'pw-grouping-enabled')),
                        ('pw_status_enabled', YLeaf(YType.boolean, 'pw-status-enabled')),
                        ('logging_pw_enabled', YLeaf(YType.boolean, 'logging-pw-enabled')),
                        ('logging_bd_enabled', YLeaf(YType.boolean, 'logging-bd-enabled')),
                        ('logging_vfi_enabled', YLeaf(YType.boolean, 'logging-vfi-enabled')),
                        ('logging_nsr_enabled', YLeaf(YType.boolean, 'logging-nsr-enabled')),
                        ('logging_df_election_enabled', YLeaf(YType.boolean, 'logging-df-election-enabled')),
                        ('tcn_propagation_enabled', YLeaf(YType.boolean, 'tcn-propagation-enabled')),
                        ('pw_oam_refresh_transmit_time', YLeaf(YType.uint32, 'pw-oam-refresh-transmit-time')),
                        ('ha_role', YLeaf(YType.str, 'ha-role')),
                        ('issu_role', YLeaf(YType.str, 'issu-role')),
                        ('process_fsm', YLeaf(YType.str, 'process-fsm')),
                        ('going_active', YLeaf(YType.boolean, 'going-active')),
                    ])
                    self.pw_grouping_enabled = None
                    self.pw_status_enabled = None
                    self.logging_pw_enabled = None
                    self.logging_bd_enabled = None
                    self.logging_vfi_enabled = None
                    self.logging_nsr_enabled = None
                    self.logging_df_election_enabled = None
                    self.tcn_propagation_enabled = None
                    self.pw_oam_refresh_transmit_time = None
                    self.ha_role = None
                    self.issu_role = None
                    self.process_fsm = None
                    self.going_active = None
                    self._segment_path = lambda: "global-settings"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.GlobalSettings, ['pw_grouping_enabled', 'pw_status_enabled', 'logging_pw_enabled', 'logging_bd_enabled', 'logging_vfi_enabled', 'logging_nsr_enabled', 'logging_df_election_enabled', 'tcn_propagation_enabled', 'pw_oam_refresh_transmit_time', 'ha_role', 'issu_role', 'process_fsm', 'going_active'], name, value)


            class Pwr(Entity):
                """
                Pseudowire Routing Table
                
                .. attribute:: summary
                
                	L2VPN Pseudowire Routing Summary
                	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Pwr, self).__init__()

                    self.yang_name = "pwr"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Nodes.Node.Pwr.Summary))])
                    self._leafs = OrderedDict()

                    self.summary = L2vpnv2.Nodes.Node.Pwr.Summary()
                    self.summary.parent = self
                    self._children_name_map["summary"] = "summary"
                    self._segment_path = lambda: "pwr"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Pwr, [], name, value)


                class Summary(Entity):
                    """
                    L2VPN Pseudowire Routing Summary
                    
                    .. attribute:: rd_auto
                    
                    	Automatic Route Distingtuisher
                    	**type**\:  :py:class:`RdAuto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto>`
                    
                    .. attribute:: rd_configured
                    
                    	Configured Route Distinguisher
                    	**type**\:  :py:class:`RdConfigured <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured>`
                    
                    .. attribute:: bgp_router_id
                    
                    	BGP Router ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: cfg_router_id
                    
                    	Configured Router ID
                    	**type**\: str
                    
                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                    
                    .. attribute:: bgp_as
                    
                    	BGP AS number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: cfg_global_id
                    
                    	Configured Global ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: l2vpn_has_bgp_eod
                    
                    	L2VPN got BGP EOD
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Pwr.Summary, self).__init__()

                        self.yang_name = "summary"
                        self.yang_parent_name = "pwr"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("rd-auto", ("rd_auto", L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto)), ("rd-configured", ("rd_configured", L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured))])
                        self._leafs = OrderedDict([
                            ('bgp_router_id', YLeaf(YType.str, 'bgp-router-id')),
                            ('cfg_router_id', YLeaf(YType.str, 'cfg-router-id')),
                            ('bgp_as', YLeaf(YType.uint32, 'bgp-as')),
                            ('cfg_global_id', YLeaf(YType.uint32, 'cfg-global-id')),
                            ('l2vpn_has_bgp_eod', YLeaf(YType.boolean, 'l2vpn-has-bgp-eod')),
                        ])
                        self.bgp_router_id = None
                        self.cfg_router_id = None
                        self.bgp_as = None
                        self.cfg_global_id = None
                        self.l2vpn_has_bgp_eod = None

                        self.rd_auto = L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto()
                        self.rd_auto.parent = self
                        self._children_name_map["rd_auto"] = "rd-auto"

                        self.rd_configured = L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured()
                        self.rd_configured.parent = self
                        self._children_name_map["rd_configured"] = "rd-configured"
                        self._segment_path = lambda: "summary"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary, ['bgp_router_id', 'cfg_router_id', 'bgp_as', 'cfg_global_id', 'l2vpn_has_bgp_eod'], name, value)


                    class RdAuto(Entity):
                        """
                        Automatic Route Distingtuisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto, self).__init__()

                            self.yang_name = "rd-auto"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd-auto"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-auto"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdAuto.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                    class RdConfigured(Entity):
                        """
                        Configured Route Distinguisher
                        
                        .. attribute:: auto
                        
                        	auto
                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto>`
                        
                        .. attribute:: two_byte_as
                        
                        	two byte as
                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs>`
                        
                        .. attribute:: four_byte_as
                        
                        	four byte as
                        	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs>`
                        
                        .. attribute:: v4_addr
                        
                        	v4 addr
                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr>`
                        
                        .. attribute:: rd
                        
                        	RD
                        	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured, self).__init__()

                            self.yang_name = "rd-configured"
                            self.yang_parent_name = "summary"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr))])
                            self._leafs = OrderedDict([
                                ('rd', YLeaf(YType.enumeration, 'rd')),
                            ])
                            self.rd = None

                            self.auto = L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto()
                            self.auto.parent = self
                            self._children_name_map["auto"] = "auto"

                            self.two_byte_as = L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs()
                            self.two_byte_as.parent = self
                            self._children_name_map["two_byte_as"] = "two-byte-as"

                            self.four_byte_as = L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs()
                            self.four_byte_as.parent = self
                            self._children_name_map["four_byte_as"] = "four-byte-as"

                            self.v4_addr = L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr()
                            self.v4_addr.parent = self
                            self._children_name_map["v4_addr"] = "v4-addr"
                            self._segment_path = lambda: "rd-configured"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured, ['rd'], name, value)


                        class Auto(Entity):
                            """
                            auto
                            
                            .. attribute:: router_id
                            
                            	BGP Router ID
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: auto_index
                            
                            	Auto\-generated Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto, self).__init__()

                                self.yang_name = "auto"
                                self.yang_parent_name = "rd-configured"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('router_id', YLeaf(YType.str, 'router-id')),
                                    ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                ])
                                self.router_id = None
                                self.auto_index = None
                                self._segment_path = lambda: "auto"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.Auto, ['router_id', 'auto_index'], name, value)


                        class TwoByteAs(Entity):
                            """
                            two byte as
                            
                            .. attribute:: two_byte_as
                            
                            	2 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: four_byte_index
                            
                            	4 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs, self).__init__()

                                self.yang_name = "two-byte-as"
                                self.yang_parent_name = "rd-configured"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                ])
                                self.two_byte_as = None
                                self.four_byte_index = None
                                self._segment_path = lambda: "two-byte-as"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                        class FourByteAs(Entity):
                            """
                            four byte as
                            
                            .. attribute:: four_byte_as
                            
                            	4 Byte AS Number
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs, self).__init__()

                                self.yang_name = "four-byte-as"
                                self.yang_parent_name = "rd-configured"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.four_byte_as = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "four-byte-as"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                        class V4Addr(Entity):
                            """
                            v4 addr
                            
                            .. attribute:: ipv4_address
                            
                            	IPv4 Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: two_byte_index
                            
                            	2 Byte Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr, self).__init__()

                                self.yang_name = "v4-addr"
                                self.yang_parent_name = "rd-configured"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                ])
                                self.ipv4_address = None
                                self.two_byte_index = None
                                self._segment_path = lambda: "v4-addr"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Pwr.Summary.RdConfigured.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


            class XconnectMp2mpCe2ces(Entity):
                """
                XConnect MP2MP CE2CE Table
                
                .. attribute:: xconnect_mp2mp_ce2ce
                
                	XConnect MP2MP CE2CE information
                	**type**\: list of  		 :py:class:`XconnectMp2mpCe2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces, self).__init__()

                    self.yang_name = "xconnect-mp2mp-ce2ces"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("xconnect-mp2mp-ce2ce", ("xconnect_mp2mp_ce2ce", L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce))])
                    self._leafs = OrderedDict()

                    self.xconnect_mp2mp_ce2ce = YList(self)
                    self._segment_path = lambda: "xconnect-mp2mp-ce2ces"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces, [], name, value)


                class XconnectMp2mpCe2ce(Entity):
                    """
                    XConnect MP2MP CE2CE information
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\: str
                    
                    	**length:** 1..26
                    
                    .. attribute:: local_ceid
                    
                    	Local CE ID
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: remote_ceid
                    
                    	Remote CE ID
                    	**type**\: int
                    
                    	**range:** 1..4294967295
                    
                    .. attribute:: local_customer_edge_id
                    
                    	Local CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: remote_customer_edge_id
                    
                    	Remote CE ID
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: ce_added
                    
                    	CE2CE Advertised
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, self).__init__()

                        self.yang_name = "xconnect-mp2mp-ce2ce"
                        self.yang_parent_name = "xconnect-mp2mp-ce2ces"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                            ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                            ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                            ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                        ])
                        self.group_name = None
                        self.mp2_mp_name = None
                        self.local_ceid = None
                        self.remote_ceid = None
                        self.local_customer_edge_id = None
                        self.remote_customer_edge_id = None
                        self.ce_added = None
                        self._segment_path = lambda: "xconnect-mp2mp-ce2ce"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mpCe2ces.XconnectMp2mpCe2ce, ['group_name', 'mp2_mp_name', 'local_ceid', 'remote_ceid', 'local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


            class Xconnects(Entity):
                """
                XConnect Table
                
                .. attribute:: xconnect
                
                	XConnect information
                	**type**\: list of  		 :py:class:`Xconnect <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Xconnects, self).__init__()

                    self.yang_name = "xconnects"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("xconnect", ("xconnect", L2vpnv2.Nodes.Node.Xconnects.Xconnect))])
                    self._leafs = OrderedDict()

                    self.xconnect = YList(self)
                    self._segment_path = lambda: "xconnects"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects, [], name, value)


                class Xconnect(Entity):
                    """
                    XConnect information
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: xconnect_name
                    
                    	XConnect Name
                    	**type**\: str
                    
                    	**length:** 1..38
                    
                    .. attribute:: backup
                    
                    	LCR backup
                    	**type**\:  :py:class:`Backup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup>`
                    
                    .. attribute:: segment1
                    
                    	Segment 1
                    	**type**\:  :py:class:`Segment1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1>`
                    
                    .. attribute:: segment2
                    
                    	Segment 2
                    	**type**\:  :py:class:`Segment2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2>`
                    
                    .. attribute:: ce2ce
                    
                    	CE2CE
                    	**type**\:  :py:class:`Ce2ce <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2ce>`
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: xconnect_name_xr
                    
                    	XConnect name
                    	**type**\: str
                    
                    .. attribute:: number_of_backup_p_ws
                    
                    	Number of backups
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: state
                    
                    	State of the xconnect
                    	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                    
                    .. attribute:: interworking
                    
                    	Interworking type
                    	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                    
                    .. attribute:: diag_mask
                    
                    	Mask indicating what if anything is missing before the XC can be provisioned
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: description
                    
                    	P2P Description
                    	**type**\: str
                    
                    .. attribute:: is_mp2mp
                    
                    	xconnect is mp2mp
                    	**type**\: bool
                    
                    .. attribute:: backup_segment
                    
                    	Backup Segment
                    	**type**\: list of  		 :py:class:`BackupSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect, self).__init__()

                        self.yang_name = "xconnect"
                        self.yang_parent_name = "xconnects"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("backup", ("backup", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup)), ("segment1", ("segment1", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1)), ("segment2", ("segment2", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2)), ("ce2ce", ("ce2ce", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2ce)), ("backup-segment", ("backup_segment", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment))])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('xconnect_name', YLeaf(YType.str, 'xconnect-name')),
                            ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                            ('xconnect_name_xr', YLeaf(YType.str, 'xconnect-name-xr')),
                            ('number_of_backup_p_ws', YLeaf(YType.uint32, 'number-of-backup-p-ws')),
                            ('state', YLeaf(YType.enumeration, 'state')),
                            ('interworking', YLeaf(YType.enumeration, 'interworking')),
                            ('diag_mask', YLeaf(YType.uint32, 'diag-mask')),
                            ('description', YLeaf(YType.str, 'description')),
                            ('is_mp2mp', YLeaf(YType.boolean, 'is-mp2mp')),
                        ])
                        self.group_name = None
                        self.xconnect_name = None
                        self.group_name_xr = None
                        self.xconnect_name_xr = None
                        self.number_of_backup_p_ws = None
                        self.state = None
                        self.interworking = None
                        self.diag_mask = None
                        self.description = None
                        self.is_mp2mp = None

                        self.backup = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup()
                        self.backup.parent = self
                        self._children_name_map["backup"] = "backup"

                        self.segment1 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1()
                        self.segment1.parent = self
                        self._children_name_map["segment1"] = "segment1"

                        self.segment2 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2()
                        self.segment2.parent = self
                        self._children_name_map["segment2"] = "segment2"

                        self.ce2ce = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2ce()
                        self.ce2ce.parent = self
                        self._children_name_map["ce2ce"] = "ce2ce"

                        self.backup_segment = YList(self)
                        self._segment_path = lambda: "xconnect"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect, ['group_name', 'xconnect_name', 'group_name_xr', 'xconnect_name_xr', 'number_of_backup_p_ws', 'state', 'interworking', 'diag_mask', 'description', 'is_mp2mp'], name, value)


                    class Backup(Entity):
                        """
                        LCR backup
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup, self).__init__()

                            self.yang_name = "backup"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire))])
                            self._leafs = OrderedDict([
                                ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                            ])
                            self.segment_type = None

                            self.attachment_circuit = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.pseudo_wire = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._segment_path = lambda: "backup"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup, ['segment_type'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "backup"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudo-wire"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Backup.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                    class Segment1(Entity):
                        """
                        Segment 1
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1, self).__init__()

                            self.yang_name = "segment1"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire))])
                            self._leafs = OrderedDict([
                                ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                            ])
                            self.segment_type = None

                            self.attachment_circuit = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.pseudo_wire = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._segment_path = lambda: "segment1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1, ['segment_type'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "segment1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudo-wire"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment1.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                    class Segment2(Entity):
                        """
                        Segment 2
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2, self).__init__()

                            self.yang_name = "segment2"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire))])
                            self._leafs = OrderedDict([
                                ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                            ])
                            self.segment_type = None

                            self.attachment_circuit = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.pseudo_wire = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._segment_path = lambda: "segment2"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2, ['segment_type'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "segment2"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudo-wire"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Segment2.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                    class Ce2ce(Entity):
                        """
                        CE2CE
                        
                        .. attribute:: local_customer_edge_id
                        
                        	Local CE ID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: remote_customer_edge_id
                        
                        	Remote CE ID
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: ce_added
                        
                        	CE2CE Advertised
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2ce, self).__init__()

                            self.yang_name = "ce2ce"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('local_customer_edge_id', YLeaf(YType.uint16, 'local-customer-edge-id')),
                                ('remote_customer_edge_id', YLeaf(YType.uint16, 'remote-customer-edge-id')),
                                ('ce_added', YLeaf(YType.boolean, 'ce-added')),
                            ])
                            self.local_customer_edge_id = None
                            self.remote_customer_edge_id = None
                            self.ce_added = None
                            self._segment_path = lambda: "ce2ce"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.Ce2ce, ['local_customer_edge_id', 'remote_customer_edge_id', 'ce_added'], name, value)


                    class BackupSegment(Entity):
                        """
                        Backup Segment
                        
                        .. attribute:: attachment_circuit
                        
                        	Attachment Circuit
                        	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit>`
                        
                        .. attribute:: pseudo_wire
                        
                        	Pseudowire
                        	**type**\:  :py:class:`PseudoWire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire>`
                        
                        .. attribute:: segment_type
                        
                        	SegmentType
                        	**type**\:  :py:class:`L2vpnSegment <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegment>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment, self).__init__()

                            self.yang_name = "backup-segment"
                            self.yang_parent_name = "xconnect"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit)), ("pseudo-wire", ("pseudo_wire", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire))])
                            self._leafs = OrderedDict([
                                ('segment_type', YLeaf(YType.enumeration, 'segment-type')),
                            ])
                            self.segment_type = None

                            self.attachment_circuit = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit()
                            self.attachment_circuit.parent = self
                            self._children_name_map["attachment_circuit"] = "attachment-circuit"

                            self.pseudo_wire = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire()
                            self.pseudo_wire.parent = self
                            self._children_name_map["pseudo_wire"] = "pseudo-wire"
                            self._segment_path = lambda: "backup-segment"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment, ['segment_type'], name, value)


                        class AttachmentCircuit(Entity):
                            """
                            Attachment Circuit
                            
                            .. attribute:: interface
                            
                            	Interface
                            	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics>`
                            
                            .. attribute:: l2vpn_protection
                            
                            	Protection object used for this segment
                            	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection>`
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: msti
                            
                            	MSTi
                            	**type**\: str
                            
                            .. attribute:: internal_ms_ti
                            
                            	Internal MSTi
                            	**type**\: str
                            
                            .. attribute:: interface_handle
                            
                            	Interface Handler
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: node_id
                            
                            	Node ID
                            	**type**\: str
                            
                            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: ms_ti_mismatch
                            
                            	MSTi mismatch
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: tdm_media_mismatched
                            
                            	TDM media parms mismatched
                            	**type**\: bool
                            
                            .. attribute:: bvi_mac_conflict
                            
                            	BVI Mac Conflict
                            	**type**\: bool
                            
                            .. attribute:: bvi_no_port_up
                            
                            	BVI no BP Up
                            	**type**\: bool
                            
                            .. attribute:: control_word_mismatched
                            
                            	Control word mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_mismatched
                            
                            	Encapsulation mismatched
                            	**type**\: bool
                            
                            .. attribute:: encapsulation_error
                            
                            	Encapsulation Error
                            	**type**\: str
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: msti_mismatch_down
                            
                            	Oper down due to MSTI mismatch
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: redundancy_group_id
                            
                            	Redundancy Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: redundancy_group_state
                            
                            	Redundancy Group State
                            	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                            
                            .. attribute:: redundancy_object_id
                            
                            	Redundancy Object ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_ac_partially_programmed
                            
                            	Is attachment\-circuit partially programmed
                            	**type**\: bool
                            
                            .. attribute:: evpn_internal_label
                            
                            	EVPN Internal Label
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, self).__init__()

                                self.yang_name = "attachment-circuit"
                                self.yang_parent_name = "backup-segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection))])
                                self._leafs = OrderedDict([
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('msti', YLeaf(YType.str, 'msti')),
                                    ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                    ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                    ('node_id', YLeaf(YType.str, 'node-id')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                    ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                    ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                    ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                    ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                    ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                    ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                    ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                    ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                    ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                ])
                                self.state = None
                                self.msti = None
                                self.internal_ms_ti = None
                                self.interface_handle = None
                                self.node_id = None
                                self.xconnect_id = None
                                self.ms_ti_mismatch = None
                                self.mtu_mismatched = None
                                self.tdm_media_mismatched = None
                                self.bvi_mac_conflict = None
                                self.bvi_no_port_up = None
                                self.control_word_mismatched = None
                                self.encapsulation_mismatched = None
                                self.encapsulation_error = None
                                self.interworking = None
                                self.out_of_memory_state = None
                                self.msti_mismatch_down = None
                                self.mac_limit_oper_down = None
                                self.redundancy_group_id = None
                                self.redundancy_group_state = None
                                self.redundancy_object_id = None
                                self.is_ac_partially_programmed = None
                                self.evpn_internal_label = None

                                self.interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface()
                                self.interface.parent = self
                                self._children_name_map["interface"] = "interface"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.l2vpn_protection = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection()
                                self.l2vpn_protection.parent = self
                                self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                self._segment_path = lambda: "attachment-circuit"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                            class Interface(Entity):
                                """
                                Interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, self).__init__()

                                    self.yang_name = "interface"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface_(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class L2vpnProtection(Entity):
                                """
                                Protection object used for this segment
                                
                                .. attribute:: protection_type
                                
                                	Type of the protection
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                
                                .. attribute:: protection_configured
                                
                                	Protection configured
                                	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                
                                .. attribute:: protection_name
                                
                                	Name of the segment acting as backup
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: protected_name
                                
                                	Name of the protected segment
                                	**type**\: str
                                
                                	**length:** 0..65
                                
                                .. attribute:: active
                                
                                	Active
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, self).__init__()

                                    self.yang_name = "l2vpn-protection"
                                    self.yang_parent_name = "attachment-circuit"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                        ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                        ('protection_name', YLeaf(YType.str, 'protection-name')),
                                        ('protected_name', YLeaf(YType.str, 'protected-name')),
                                        ('active', YLeaf(YType.boolean, 'active')),
                                    ])
                                    self.protection_type = None
                                    self.protection_configured = None
                                    self.protection_name = None
                                    self.protected_name = None
                                    self.active = None
                                    self._segment_path = lambda: "l2vpn-protection"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                        class PseudoWire(Entity):
                            """
                            Pseudowire
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire, self).__init__()

                                self.yang_name = "pseudo-wire"
                                self.yang_parent_name = "backup-segment"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudo-wire"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudo-wire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Xconnects.Xconnect.BackupSegment.PseudoWire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


            class XconnectGroups(Entity):
                """
                XConnect group Table
                
                .. attribute:: xconnect_group
                
                	XConnect group information
                	**type**\: list of  		 :py:class:`XconnectGroup <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectGroups.XconnectGroup>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.XconnectGroups, self).__init__()

                    self.yang_name = "xconnect-groups"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("xconnect-group", ("xconnect_group", L2vpnv2.Nodes.Node.XconnectGroups.XconnectGroup))])
                    self._leafs = OrderedDict()

                    self.xconnect_group = YList(self)
                    self._segment_path = lambda: "xconnect-groups"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectGroups, [], name, value)


                class XconnectGroup(Entity):
                    """
                    XConnect group information
                    
                    .. attribute:: group_name  (key)
                    
                    	XConnect Group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: number_xconnects
                    
                    	Number of xconnects
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.XconnectGroups.XconnectGroup, self).__init__()

                        self.yang_name = "xconnect-group"
                        self.yang_parent_name = "xconnect-groups"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['group_name']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                            ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                        ])
                        self.group_name = None
                        self.group_name_xr = None
                        self.number_xconnects = None
                        self._segment_path = lambda: "xconnect-group" + "[group-name='" + str(self.group_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.XconnectGroups.XconnectGroup, ['group_name', 'group_name_xr', 'number_xconnects'], name, value)


            class XconnectMp2mps(Entity):
                """
                XConnect MP2MP Table
                
                .. attribute:: xconnect_mp2mp
                
                	XConnect MP2MP information
                	**type**\: list of  		 :py:class:`XconnectMp2mp <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.XconnectMp2mps, self).__init__()

                    self.yang_name = "xconnect-mp2mps"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("xconnect-mp2mp", ("xconnect_mp2mp", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp))])
                    self._leafs = OrderedDict()

                    self.xconnect_mp2mp = YList(self)
                    self._segment_path = lambda: "xconnect-mp2mps"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps, [], name, value)


                class XconnectMp2mp(Entity):
                    """
                    XConnect MP2MP information
                    
                    .. attribute:: group_name
                    
                    	XConnect Group
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: mp2_mp_name
                    
                    	Mp2Mp Name
                    	**type**\: str
                    
                    	**length:** 1..26
                    
                    .. attribute:: discovery
                    
                    	l2vpn xc auto discovery info
                    	**type**\:  :py:class:`Discovery <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery>`
                    
                    .. attribute:: group_name_xr
                    
                    	Group name
                    	**type**\: str
                    
                    .. attribute:: mp2mp_name
                    
                    	MP2MP name
                    	**type**\: str
                    
                    .. attribute:: mp2mpid
                    
                    	Identification Number
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_id
                    
                    	Vpn ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: vpn_mtu
                    
                    	VPN MTU
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: l2_encapsulation
                    
                    	L2 Encapsulation
                    	**type**\:  :py:class:`L2vpnBagAdEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagAdEncap>`
                    
                    .. attribute:: xconnect_shutdown
                    
                    	Administratively disabled
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp, self).__init__()

                        self.yang_name = "xconnect-mp2mp"
                        self.yang_parent_name = "xconnect-mp2mps"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("discovery", ("discovery", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery))])
                        self._leafs = OrderedDict([
                            ('group_name', YLeaf(YType.str, 'group-name')),
                            ('mp2_mp_name', YLeaf(YType.str, 'mp2-mp-name')),
                            ('group_name_xr', YLeaf(YType.str, 'group-name-xr')),
                            ('mp2mp_name', YLeaf(YType.str, 'mp2mp-name')),
                            ('mp2mpid', YLeaf(YType.uint32, 'mp2mpid')),
                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                            ('vpn_mtu', YLeaf(YType.uint32, 'vpn-mtu')),
                            ('l2_encapsulation', YLeaf(YType.enumeration, 'l2-encapsulation')),
                            ('xconnect_shutdown', YLeaf(YType.boolean, 'xconnect-shutdown')),
                        ])
                        self.group_name = None
                        self.mp2_mp_name = None
                        self.group_name_xr = None
                        self.mp2mp_name = None
                        self.mp2mpid = None
                        self.vpn_id = None
                        self.vpn_mtu = None
                        self.l2_encapsulation = None
                        self.xconnect_shutdown = None

                        self.discovery = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery()
                        self.discovery.parent = self
                        self._children_name_map["discovery"] = "discovery"
                        self._segment_path = lambda: "xconnect-mp2mp"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp, ['group_name', 'mp2_mp_name', 'group_name_xr', 'mp2mp_name', 'mp2mpid', 'vpn_id', 'vpn_mtu', 'l2_encapsulation', 'xconnect_shutdown'], name, value)


                    class Discovery(Entity):
                        """
                        l2vpn xc auto discovery info
                        
                        .. attribute:: rd_value
                        
                        	Route Distinguisher
                        	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue>`
                        
                        .. attribute:: ad_method
                        
                        	Autodiscovery Method
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: vpn_added
                        
                        	VPN Added
                        	**type**\: bool
                        
                        .. attribute:: ad_service_connected
                        
                        	Service Connected
                        	**type**\: bool
                        
                        .. attribute:: ad_signalling_method
                        
                        	Signaling Protocol
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ce_range
                        
                        	CE Range
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: export_route_policy
                        
                        	Export Route Policy
                        	**type**\: str
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2ce_advertised
                        
                        	Number of ce2ce Advertised
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_ce2c_es
                        
                        	Number of ce2ce
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: import_rt
                        
                        	Import Route Targets
                        	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt>`
                        
                        .. attribute:: export_rt
                        
                        	Export Route Targets
                        	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery, self).__init__()

                            self.yang_name = "discovery"
                            self.yang_parent_name = "xconnect-mp2mp"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue)), ("import-rt", ("import_rt", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt))])
                            self._leafs = OrderedDict([
                                ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                ('ad_service_connected', YLeaf(YType.boolean, 'ad-service-connected')),
                                ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                ('ce_range', YLeaf(YType.uint16, 'ce-range')),
                                ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                                ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                                ('number_ce2ce_advertised', YLeaf(YType.uint32, 'number-ce2ce-advertised')),
                                ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                                ('number_ce2c_es', YLeaf(YType.uint32, 'number-ce2c-es')),
                            ])
                            self.ad_method = None
                            self.vpn_added = None
                            self.ad_service_connected = None
                            self.ad_signalling_method = None
                            self.ce_range = None
                            self.export_route_policy = None
                            self.number_a_cs_up = None
                            self.number_p_ws_up = None
                            self.number_ce2ce_advertised = None
                            self.number_a_cs = None
                            self.number_pseudowires = None
                            self.number_ce2c_es = None

                            self.rd_value = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue()
                            self.rd_value.parent = self
                            self._children_name_map["rd_value"] = "rd-value"

                            self.import_rt = YList(self)
                            self.export_rt = YList(self)
                            self._segment_path = lambda: "discovery"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery, ['ad_method', 'vpn_added', 'ad_service_connected', 'ad_signalling_method', 'ce_range', 'export_route_policy', 'number_a_cs_up', 'number_p_ws_up', 'number_ce2ce_advertised', 'number_a_cs', 'number_pseudowires', 'number_ce2c_es'], name, value)


                        class RdValue(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, self).__init__()

                                self.yang_name = "rd-value"
                                self.yang_parent_name = "discovery"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr))])
                                self._leafs = OrderedDict([
                                    ('rd', YLeaf(YType.enumeration, 'rd')),
                                ])
                                self.rd = None

                                self.auto = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"

                                self.two_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.four_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"

                                self.v4_addr = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._segment_path = lambda: "rd-value"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue, ['rd'], name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd-value"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('router_id', YLeaf(YType.str, 'router-id')),
                                        ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                    ])
                                    self.router_id = None
                                    self.auto_index = None
                                    self._segment_path = lambda: "auto"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd-value"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd-value"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.four_byte_as = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "four-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd-value"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class ImportRt(Entity):
                            """
                            Import Route Targets
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr>`
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, self).__init__()

                                self.yang_name = "import-rt"
                                self.yang_parent_name = "discovery"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport))])
                                self._leafs = OrderedDict([
                                    ('rt', YLeaf(YType.enumeration, 'rt')),
                                ])
                                self.rt = None

                                self.two_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.four_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"

                                self.v4_addr = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"

                                self.es_import = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._segment_path = lambda: "import-rt"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt, ['rt'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "import-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "import-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.four_byte_as = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "four-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "import-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "import-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                        ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                    ])
                                    self.high_bytes = None
                                    self.low_bytes = None
                                    self._segment_path = lambda: "es-import"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                        class ExportRt(Entity):
                            """
                            Export Route Targets
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr>`
                            
                            .. attribute:: es_import
                            
                            	es import
                            	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport>`
                            
                            .. attribute:: rt
                            
                            	RT
                            	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, self).__init__()

                                self.yang_name = "export-rt"
                                self.yang_parent_name = "discovery"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport))])
                                self._leafs = OrderedDict([
                                    ('rt', YLeaf(YType.enumeration, 'rt')),
                                ])
                                self.rt = None

                                self.two_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.four_byte_as = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"

                                self.v4_addr = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"

                                self.es_import = L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport()
                                self.es_import.parent = self
                                self._children_name_map["es_import"] = "es-import"
                                self._segment_path = lambda: "export-rt"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt, ['rt'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "export-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "export-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.four_byte_as = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "four-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "export-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                            class EsImport(Entity):
                                """
                                es import
                                
                                .. attribute:: high_bytes
                                
                                	Top 4 bytes of ES Import
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: low_bytes
                                
                                	Low 2 bytes of ES Import
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, self).__init__()

                                    self.yang_name = "es-import"
                                    self.yang_parent_name = "export-rt"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                        ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                    ])
                                    self.high_bytes = None
                                    self.low_bytes = None
                                    self._segment_path = lambda: "es-import"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectMp2mps.XconnectMp2mp.Discovery.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


            class Indexes(Entity):
                """
                ID Manager Index Table
                
                .. attribute:: index
                
                	ID Manager Index Pool
                	**type**\: list of  		 :py:class:`Index <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Indexes.Index>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Indexes, self).__init__()

                    self.yang_name = "indexes"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("index", ("index", L2vpnv2.Nodes.Node.Indexes.Index))])
                    self._leafs = OrderedDict()

                    self.index = YList(self)
                    self._segment_path = lambda: "indexes"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Indexes, [], name, value)


                class Index(Entity):
                    """
                    ID Manager Index Pool
                    
                    .. attribute:: pool_id  (key)
                    
                    	Pool ID
                    	**type**\: str
                    
                    	**pattern:** [0\-9a\-fA\-F]{1,8}
                    
                    .. attribute:: pool_id_xr
                    
                    	Pool Id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: application_type
                    
                    	Application Type
                    	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                    
                    .. attribute:: allocated_ids
                    
                    	Number of IDs allocated
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: zombied_ids
                    
                    	Number of IDs allocated
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pool_size
                    
                    	Pool size
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: max_num_id_mgr
                    
                    	Maximum number of pool extensions
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: num_id_mgr_in_use
                    
                    	ID mgr instances in use
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Indexes.Index, self).__init__()

                        self.yang_name = "index"
                        self.yang_parent_name = "indexes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pool_id']
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('pool_id', YLeaf(YType.str, 'pool-id')),
                            ('pool_id_xr', YLeaf(YType.uint32, 'pool-id-xr')),
                            ('application_type', YLeaf(YType.enumeration, 'application-type')),
                            ('allocated_ids', YLeaf(YType.uint32, 'allocated-ids')),
                            ('zombied_ids', YLeaf(YType.uint32, 'zombied-ids')),
                            ('pool_size', YLeaf(YType.uint32, 'pool-size')),
                            ('max_num_id_mgr', YLeaf(YType.uint32, 'max-num-id-mgr')),
                            ('num_id_mgr_in_use', YLeaf(YType.uint32, 'num-id-mgr-in-use')),
                        ])
                        self.pool_id = None
                        self.pool_id_xr = None
                        self.application_type = None
                        self.allocated_ids = None
                        self.zombied_ids = None
                        self.pool_size = None
                        self.max_num_id_mgr = None
                        self.num_id_mgr_in_use = None
                        self._segment_path = lambda: "index" + "[pool-id='" + str(self.pool_id) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Indexes.Index, ['pool_id', 'pool_id_xr', 'application_type', 'allocated_ids', 'zombied_ids', 'pool_size', 'max_num_id_mgr', 'num_id_mgr_in_use'], name, value)


            class XconnectSummary(Entity):
                """
                XConnect summary information
                
                .. attribute:: number_groups
                
                	Number of groups
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects
                
                	Number of xconnects
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_up
                
                	Numxber of xconnects whose state is up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_down
                
                	Number of xconnects whose state is down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_unresolved
                
                	Number of xconnects whose state is unresolved
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_administratively_down
                
                	Number of xconnects with segments in admin down state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_attachment_circuit_to_pseudo_wire
                
                	Number of xconnects of type attachment circuit to pseudowire
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_monitor_session_to_pseudo_wire
                
                	Number of xconnects of type monitor session to pseudowire
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_locally_switched
                
                	Number of locally switched xconnects
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_pw
                
                	Number of XCs configured with backup PW
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup
                
                	Number of XCs currently using backup PW (UP state)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_xconnects
                
                	Number of XCs with backup PW in down state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: admin_down_backup_xconnects
                
                	Number of XCs with backup PW in admin down state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_xconnects
                
                	Number of XCs with backup PW in unresolved state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_xconnects
                
                	Number of XCs with backup PW in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_ready_backup_xconnects
                
                	Number of XCs with backup PW in standby ready state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_type_pseudo_wire_to_pseudo_wire
                
                	Number of xconnects of type PseudoWire To PseudoWire
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects
                
                	Number of mp2mp xconnects
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_up
                
                	Number of Mp2mp XCs that have been admined up
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_down
                
                	Number of Mp2mp XCs that have ben admined down
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnects_advertised
                
                	Number of Mp2mp XCs that have been advertized
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2mp_xconnectss_not_advertised
                
                	Number of Mp2mp XCs that have not been advertized
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2_ceconnections
                
                	Number of Ce2Ce connections
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_advertized
                
                	Number of CE2CE connections that have been advertized
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_ce2ce_not_advertized
                
                	Number of CE2CE connections that have not been advertized
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: partially_programmed_xconnects
                
                	Number of cross\-connects partially programmed
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_with_backup_interface
                
                	Number of XCs configured with backup interface
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_xconnects_currently_using_backup_interface
                
                	Number of XCs currently using backup interface (UP state)
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: down_backup_interface_xconnects
                
                	Number of XCs with backup interface in down state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: admin_down_backup_interface_xconnects
                
                	Number of XCs with backup interface in admin down state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: unresolved_backup_interface_xconnects
                
                	Number of XCs with backup interface in unresolved state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: standby_backup_interface_xconnects
                
                	Number of XCs with backup interface in standby state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.XconnectSummary, self).__init__()

                    self.yang_name = "xconnect-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number_groups', YLeaf(YType.uint32, 'number-groups')),
                        ('number_xconnects', YLeaf(YType.uint32, 'number-xconnects')),
                        ('number_xconnects_up', YLeaf(YType.uint32, 'number-xconnects-up')),
                        ('number_xconnects_down', YLeaf(YType.uint32, 'number-xconnects-down')),
                        ('number_xconnects_unresolved', YLeaf(YType.uint32, 'number-xconnects-unresolved')),
                        ('number_xconnects_administratively_down', YLeaf(YType.uint32, 'number-xconnects-administratively-down')),
                        ('number_xconnects_type_attachment_circuit_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-attachment-circuit-to-pseudo-wire')),
                        ('number_xconnects_type_monitor_session_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-monitor-session-to-pseudo-wire')),
                        ('number_xconnects_locally_switched', YLeaf(YType.uint32, 'number-xconnects-locally-switched')),
                        ('number_xconnects_with_backup_pw', YLeaf(YType.uint32, 'number-xconnects-with-backup-pw')),
                        ('number_xconnects_currently_using_backup', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup')),
                        ('down_backup_xconnects', YLeaf(YType.uint32, 'down-backup-xconnects')),
                        ('admin_down_backup_xconnects', YLeaf(YType.uint32, 'admin-down-backup-xconnects')),
                        ('unresolved_backup_xconnects', YLeaf(YType.uint32, 'unresolved-backup-xconnects')),
                        ('standby_backup_xconnects', YLeaf(YType.uint32, 'standby-backup-xconnects')),
                        ('standby_ready_backup_xconnects', YLeaf(YType.uint32, 'standby-ready-backup-xconnects')),
                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                        ('number_xconnects_type_pseudo_wire_to_pseudo_wire', YLeaf(YType.uint32, 'number-xconnects-type-pseudo-wire-to-pseudo-wire')),
                        ('number_mp2mp_xconnects', YLeaf(YType.uint32, 'number-mp2mp-xconnects')),
                        ('number_mp2mp_xconnects_up', YLeaf(YType.uint32, 'number-mp2mp-xconnects-up')),
                        ('number_mp2mp_xconnects_down', YLeaf(YType.uint32, 'number-mp2mp-xconnects-down')),
                        ('number_mp2mp_xconnects_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnects-advertised')),
                        ('number_mp2mp_xconnectss_not_advertised', YLeaf(YType.uint32, 'number-mp2mp-xconnectss-not-advertised')),
                        ('number_ce2_ceconnections', YLeaf(YType.uint32, 'number-ce2-ceconnections')),
                        ('number_ce2ce_advertized', YLeaf(YType.uint32, 'number-ce2ce-advertized')),
                        ('number_ce2ce_not_advertized', YLeaf(YType.uint32, 'number-ce2ce-not-advertized')),
                        ('partially_programmed_xconnects', YLeaf(YType.uint32, 'partially-programmed-xconnects')),
                        ('number_xconnects_with_backup_interface', YLeaf(YType.uint32, 'number-xconnects-with-backup-interface')),
                        ('number_xconnects_currently_using_backup_interface', YLeaf(YType.uint32, 'number-xconnects-currently-using-backup-interface')),
                        ('down_backup_interface_xconnects', YLeaf(YType.uint32, 'down-backup-interface-xconnects')),
                        ('admin_down_backup_interface_xconnects', YLeaf(YType.uint32, 'admin-down-backup-interface-xconnects')),
                        ('unresolved_backup_interface_xconnects', YLeaf(YType.uint32, 'unresolved-backup-interface-xconnects')),
                        ('standby_backup_interface_xconnects', YLeaf(YType.uint32, 'standby-backup-interface-xconnects')),
                    ])
                    self.number_groups = None
                    self.number_xconnects = None
                    self.number_xconnects_up = None
                    self.number_xconnects_down = None
                    self.number_xconnects_unresolved = None
                    self.number_xconnects_administratively_down = None
                    self.number_xconnects_type_attachment_circuit_to_pseudo_wire = None
                    self.number_xconnects_type_monitor_session_to_pseudo_wire = None
                    self.number_xconnects_locally_switched = None
                    self.number_xconnects_with_backup_pw = None
                    self.number_xconnects_currently_using_backup = None
                    self.down_backup_xconnects = None
                    self.admin_down_backup_xconnects = None
                    self.unresolved_backup_xconnects = None
                    self.standby_backup_xconnects = None
                    self.standby_ready_backup_xconnects = None
                    self.out_of_memory_state = None
                    self.number_xconnects_type_pseudo_wire_to_pseudo_wire = None
                    self.number_mp2mp_xconnects = None
                    self.number_mp2mp_xconnects_up = None
                    self.number_mp2mp_xconnects_down = None
                    self.number_mp2mp_xconnects_advertised = None
                    self.number_mp2mp_xconnectss_not_advertised = None
                    self.number_ce2_ceconnections = None
                    self.number_ce2ce_advertized = None
                    self.number_ce2ce_not_advertized = None
                    self.partially_programmed_xconnects = None
                    self.number_xconnects_with_backup_interface = None
                    self.number_xconnects_currently_using_backup_interface = None
                    self.down_backup_interface_xconnects = None
                    self.admin_down_backup_interface_xconnects = None
                    self.unresolved_backup_interface_xconnects = None
                    self.standby_backup_interface_xconnects = None
                    self._segment_path = lambda: "xconnect-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectSummary, ['number_groups', 'number_xconnects', 'number_xconnects_up', 'number_xconnects_down', 'number_xconnects_unresolved', 'number_xconnects_administratively_down', 'number_xconnects_type_attachment_circuit_to_pseudo_wire', 'number_xconnects_type_monitor_session_to_pseudo_wire', 'number_xconnects_locally_switched', 'number_xconnects_with_backup_pw', 'number_xconnects_currently_using_backup', 'down_backup_xconnects', 'admin_down_backup_xconnects', 'unresolved_backup_xconnects', 'standby_backup_xconnects', 'standby_ready_backup_xconnects', 'out_of_memory_state', 'number_xconnects_type_pseudo_wire_to_pseudo_wire', 'number_mp2mp_xconnects', 'number_mp2mp_xconnects_up', 'number_mp2mp_xconnects_down', 'number_mp2mp_xconnects_advertised', 'number_mp2mp_xconnectss_not_advertised', 'number_ce2_ceconnections', 'number_ce2ce_advertized', 'number_ce2ce_not_advertized', 'partially_programmed_xconnects', 'number_xconnects_with_backup_interface', 'number_xconnects_currently_using_backup_interface', 'down_backup_interface_xconnects', 'admin_down_backup_interface_xconnects', 'unresolved_backup_interface_xconnects', 'standby_backup_interface_xconnects'], name, value)


            class ProcFsm(Entity):
                """
                L2VPN Process FSM information
                
                .. attribute:: failover_status
                
                	L2VPN failover status
                	**type**\:  :py:class:`FailoverStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.FailoverStatus>`
                
                .. attribute:: nsr_status
                
                	L2VPN NSR status and timestamp
                	**type**\:  :py:class:`NsrStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.NsrStatus>`
                
                .. attribute:: issu_status
                
                	L2VPN ISSU Status and timestamp
                	**type**\:  :py:class:`IssuStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.IssuStatus>`
                
                .. attribute:: process_role
                
                	Current Process Role
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: process_state
                
                	Current Process State
                	**type**\: int
                
                	**range:** 0..255
                
                .. attribute:: sync_flags
                
                	Sync complete flags
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: sw_install_in_progress
                
                	Is s/w install currently in progress?
                	**type**\: bool
                
                .. attribute:: state_transition_time
                
                	Transition time for all states
                	**type**\: list of  		 :py:class:`StateTransitionTime <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.StateTransitionTime>`
                
                .. attribute:: xid_info
                
                	XID information
                	**type**\: list of  		 :py:class:`XidInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.XidInfo>`
                
                .. attribute:: report_card
                
                	L2VPN Collaborator report card
                	**type**\: list of  		 :py:class:`ReportCard <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.ReportCard>`
                
                .. attribute:: event_history
                
                	L2VPN Process event history
                	**type**\: list of  		 :py:class:`EventHistory <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.EventHistory>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.ProcFsm, self).__init__()

                    self.yang_name = "proc-fsm"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("failover-status", ("failover_status", L2vpnv2.Nodes.Node.ProcFsm.FailoverStatus)), ("nsr-status", ("nsr_status", L2vpnv2.Nodes.Node.ProcFsm.NsrStatus)), ("issu-status", ("issu_status", L2vpnv2.Nodes.Node.ProcFsm.IssuStatus)), ("state-transition-time", ("state_transition_time", L2vpnv2.Nodes.Node.ProcFsm.StateTransitionTime)), ("xid-info", ("xid_info", L2vpnv2.Nodes.Node.ProcFsm.XidInfo)), ("report-card", ("report_card", L2vpnv2.Nodes.Node.ProcFsm.ReportCard)), ("event-history", ("event_history", L2vpnv2.Nodes.Node.ProcFsm.EventHistory))])
                    self._leafs = OrderedDict([
                        ('process_role', YLeaf(YType.uint8, 'process-role')),
                        ('process_state', YLeaf(YType.uint8, 'process-state')),
                        ('sync_flags', YLeaf(YType.uint32, 'sync-flags')),
                        ('sw_install_in_progress', YLeaf(YType.boolean, 'sw-install-in-progress')),
                    ])
                    self.process_role = None
                    self.process_state = None
                    self.sync_flags = None
                    self.sw_install_in_progress = None

                    self.failover_status = L2vpnv2.Nodes.Node.ProcFsm.FailoverStatus()
                    self.failover_status.parent = self
                    self._children_name_map["failover_status"] = "failover-status"

                    self.nsr_status = L2vpnv2.Nodes.Node.ProcFsm.NsrStatus()
                    self.nsr_status.parent = self
                    self._children_name_map["nsr_status"] = "nsr-status"

                    self.issu_status = L2vpnv2.Nodes.Node.ProcFsm.IssuStatus()
                    self.issu_status.parent = self
                    self._children_name_map["issu_status"] = "issu-status"

                    self.state_transition_time = YList(self)
                    self.xid_info = YList(self)
                    self.report_card = YList(self)
                    self.event_history = YList(self)
                    self._segment_path = lambda: "proc-fsm"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm, ['process_role', 'process_state', 'sync_flags', 'sw_install_in_progress'], name, value)


                class FailoverStatus(Entity):
                    """
                    L2VPN failover status
                    
                    .. attribute:: triggered_time
                    
                    	Triggered time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: start_time
                    
                    	Start time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: master_time
                    
                    	Master time
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.FailoverStatus, self).__init__()

                        self.yang_name = "failover-status"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('triggered_time', YLeaf(YType.uint32, 'triggered-time')),
                            ('start_time', YLeaf(YType.uint32, 'start-time')),
                            ('master_time', YLeaf(YType.uint32, 'master-time')),
                        ])
                        self.triggered_time = None
                        self.start_time = None
                        self.master_time = None
                        self._segment_path = lambda: "failover-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.FailoverStatus, ['triggered_time', 'start_time', 'master_time'], name, value)


                class NsrStatus(Entity):
                    """
                    L2VPN NSR status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus, self).__init__()

                        self.yang_name = "nsr-status"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus))])
                        self._leafs = OrderedDict([
                            ('role', YLeaf(YType.enumeration, 'role')),
                        ])
                        self.role = None

                        self.idt_status = L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"

                        self.previ_ous_idt_status = L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._segment_path = lambda: "nsr-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus, ['role'], name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "nsr-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "nsr-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "previ-ous-idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.NsrStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class IssuStatus(Entity):
                    """
                    L2VPN ISSU Status and timestamp
                    
                    .. attribute:: idt_status
                    
                    	IDT status
                    	**type**\:  :py:class:`IdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus>`
                    
                    .. attribute:: previ_ous_idt_status
                    
                    	Previous IDT status
                    	**type**\:  :py:class:`PreviOusIdtStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus>`
                    
                    .. attribute:: role
                    
                    	Process role
                    	**type**\:  :py:class:`L2vpnProcRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcRole>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus, self).__init__()

                        self.yang_name = "issu-status"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("idt-status", ("idt_status", L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus)), ("previ-ous-idt-status", ("previ_ous_idt_status", L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus))])
                        self._leafs = OrderedDict([
                            ('role', YLeaf(YType.enumeration, 'role')),
                        ])
                        self.role = None

                        self.idt_status = L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus()
                        self.idt_status.parent = self
                        self._children_name_map["idt_status"] = "idt-status"

                        self.previ_ous_idt_status = L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus()
                        self.previ_ous_idt_status.parent = self
                        self._children_name_map["previ_ous_idt_status"] = "previ-ous-idt-status"
                        self._segment_path = lambda: "issu-status"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus, ['role'], name, value)


                    class IdtStatus(Entity):
                        """
                        IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus, self).__init__()

                            self.yang_name = "idt-status"
                            self.yang_parent_name = "issu-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.IdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                    class PreviOusIdtStatus(Entity):
                        """
                        Previous IDT status
                        
                        .. attribute:: sync_status
                        
                        	Sync status
                        	**type**\:  :py:class:`L2vpnSyncStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSyncStatus>`
                        
                        .. attribute:: not_ready_reason
                        
                        	Not ready reason
                        	**type**\:  :py:class:`L2vpnProcNsrNotReadyReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProcNsrNotReadyReason>`
                        
                        .. attribute:: idt_start_time
                        
                        	IDT start timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: idt_end_time
                        
                        	IDT end timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: declare_time
                        
                        	Declare ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        .. attribute:: withdraw_time
                        
                        	Withdraw ready timestamp in seconds
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        	**units**\: second
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus, self).__init__()

                            self.yang_name = "previ-ous-idt-status"
                            self.yang_parent_name = "issu-status"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('sync_status', YLeaf(YType.enumeration, 'sync-status')),
                                ('not_ready_reason', YLeaf(YType.enumeration, 'not-ready-reason')),
                                ('idt_start_time', YLeaf(YType.uint32, 'idt-start-time')),
                                ('idt_end_time', YLeaf(YType.uint32, 'idt-end-time')),
                                ('declare_time', YLeaf(YType.uint32, 'declare-time')),
                                ('withdraw_time', YLeaf(YType.uint32, 'withdraw-time')),
                            ])
                            self.sync_status = None
                            self.not_ready_reason = None
                            self.idt_start_time = None
                            self.idt_end_time = None
                            self.declare_time = None
                            self.withdraw_time = None
                            self._segment_path = lambda: "previ-ous-idt-status"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.IssuStatus.PreviOusIdtStatus, ['sync_status', 'not_ready_reason', 'idt_start_time', 'idt_end_time', 'declare_time', 'withdraw_time'], name, value)


                class StateTransitionTime(Entity):
                    """
                    Transition time for all states
                    
                    .. attribute:: entry
                    
                    	
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.StateTransitionTime, self).__init__()

                        self.yang_name = "state-transition-time"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('entry', YLeaf(YType.uint32, 'entry')),
                        ])
                        self.entry = None
                        self._segment_path = lambda: "state-transition-time"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.StateTransitionTime, ['entry'], name, value)


                class XidInfo(Entity):
                    """
                    XID information
                    
                    .. attribute:: app_type
                    
                    	App type
                    	**type**\:  :py:class:`L2vpnIdMgrAppBag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIdMgrAppBag>`
                    
                    .. attribute:: sent_ids
                    
                    	Number of XIDs transferred
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.XidInfo, self).__init__()

                        self.yang_name = "xid-info"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('app_type', YLeaf(YType.enumeration, 'app-type')),
                            ('sent_ids', YLeaf(YType.uint32, 'sent-ids')),
                        ])
                        self.app_type = None
                        self.sent_ids = None
                        self._segment_path = lambda: "xid-info"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.XidInfo, ['app_type', 'sent_ids'], name, value)


                class ReportCard(Entity):
                    """
                    L2VPN Collaborator report card
                    
                    .. attribute:: collaborator_is_connected
                    
                    	Is the collaborator connected
                    	**type**\: bool
                    
                    .. attribute:: connection_change_time
                    
                    	Time when connection state (UP/DOWN) changed
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: collaborator_idt_done
                    
                    	Is IDT done for this collaborator
                    	**type**\: bool
                    
                    .. attribute:: idt_time
                    
                    	Time when IDT was done
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: collaborator_skipped
                    
                    	Was this collaborator skipped for not connecting in time
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.ReportCard, self).__init__()

                        self.yang_name = "report-card"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('collaborator_is_connected', YLeaf(YType.boolean, 'collaborator-is-connected')),
                            ('connection_change_time', YLeaf(YType.uint32, 'connection-change-time')),
                            ('collaborator_idt_done', YLeaf(YType.boolean, 'collaborator-idt-done')),
                            ('idt_time', YLeaf(YType.uint32, 'idt-time')),
                            ('collaborator_skipped', YLeaf(YType.boolean, 'collaborator-skipped')),
                        ])
                        self.collaborator_is_connected = None
                        self.connection_change_time = None
                        self.collaborator_idt_done = None
                        self.idt_time = None
                        self.collaborator_skipped = None
                        self._segment_path = lambda: "report-card"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.ReportCard, ['collaborator_is_connected', 'connection_change_time', 'collaborator_idt_done', 'idt_time', 'collaborator_skipped'], name, value)


                class EventHistory(Entity):
                    """
                    L2VPN Process event history
                    
                    .. attribute:: previous_state
                    
                    	Previous state
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: new_state
                    
                    	New state
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: process_event
                    
                    	Process event
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: process_collaborator
                    
                    	Process collaborator
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: event_timestamp
                    
                    	Event timestamp
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.ProcFsm.EventHistory, self).__init__()

                        self.yang_name = "event-history"
                        self.yang_parent_name = "proc-fsm"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('previous_state', YLeaf(YType.uint8, 'previous-state')),
                            ('new_state', YLeaf(YType.uint8, 'new-state')),
                            ('process_event', YLeaf(YType.uint16, 'process-event')),
                            ('process_collaborator', YLeaf(YType.uint16, 'process-collaborator')),
                            ('event_timestamp', YLeaf(YType.uint32, 'event-timestamp')),
                        ])
                        self.previous_state = None
                        self.new_state = None
                        self.process_event = None
                        self.process_collaborator = None
                        self.event_timestamp = None
                        self._segment_path = lambda: "event-history"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.ProcFsm.EventHistory, ['previous_state', 'new_state', 'process_event', 'process_collaborator', 'event_timestamp'], name, value)


            class MstpPorts(Entity):
                """
                L2VPN MSTP Port Table
                
                .. attribute:: mstp_port
                
                	MSTP Port information
                	**type**\: list of  		 :py:class:`MstpPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpPorts.MstpPort>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.MstpPorts, self).__init__()

                    self.yang_name = "mstp-ports"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mstp-port", ("mstp_port", L2vpnv2.Nodes.Node.MstpPorts.MstpPort))])
                    self._leafs = OrderedDict()

                    self.mstp_port = YList(self)
                    self._segment_path = lambda: "mstp-ports"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.MstpPorts, [], name, value)


                class MstpPort(Entity):
                    """
                    MSTP Port information
                    
                    .. attribute:: interface  (key)
                    
                    	Interface
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: mstp_interface_handle
                    
                    	Interface handle
                    	**type**\: str
                    
                    	**pattern:** [a\-zA\-Z0\-9./\-]+
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: protected
                    
                    	Protected
                    	**type**\: bool
                    
                    .. attribute:: reference_count
                    
                    	Reference Count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_entry
                    
                    	MSTI
                    	**type**\: list of  		 :py:class:`MstiEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.MstpPorts.MstpPort, self).__init__()

                        self.yang_name = "mstp-port"
                        self.yang_parent_name = "mstp-ports"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface']
                        self._child_classes = OrderedDict([("msti-entry", ("msti_entry", L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry))])
                        self._leafs = OrderedDict([
                            ('interface', YLeaf(YType.str, 'interface')),
                            ('mstp_interface_handle', YLeaf(YType.str, 'mstp-interface-handle')),
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('protected', YLeaf(YType.boolean, 'protected')),
                            ('reference_count', YLeaf(YType.uint32, 'reference-count')),
                        ])
                        self.interface = None
                        self.mstp_interface_handle = None
                        self.interface_name = None
                        self.protected = None
                        self.reference_count = None

                        self.msti_entry = YList(self)
                        self._segment_path = lambda: "mstp-port" + "[interface='" + str(self.interface) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.MstpPorts.MstpPort, ['interface', 'mstp_interface_handle', 'interface_name', 'protected', 'reference_count'], name, value)


                    class MstiEntry(Entity):
                        """
                        MSTI
                        
                        .. attribute:: cfg_ms_ti
                        
                        	 Configured MSTi
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: rcv_count
                        
                        	Receive count 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ack_count
                        
                        	Ack count 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nack_count
                        
                        	Nack count 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: flush_count
                        
                        	Flush count 
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface_count
                        
                        	Interface count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bd_count
                        
                        	BD count
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_flags
                        
                        	Msti Flags
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: msti_state
                        
                        	Msti State
                        	**type**\:  :py:class:`L2vpnMstiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMstiState>`
                        
                        .. attribute:: bd_entry
                        
                        	BD entries
                        	**type**\: list of  		 :py:class:`BdEntry <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry, self).__init__()

                            self.yang_name = "msti-entry"
                            self.yang_parent_name = "mstp-port"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bd-entry", ("bd_entry", L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry))])
                            self._leafs = OrderedDict([
                                ('cfg_ms_ti', YLeaf(YType.uint32, 'cfg-ms-ti')),
                                ('rcv_count', YLeaf(YType.uint32, 'rcv-count')),
                                ('ack_count', YLeaf(YType.uint32, 'ack-count')),
                                ('nack_count', YLeaf(YType.uint32, 'nack-count')),
                                ('flush_count', YLeaf(YType.uint32, 'flush-count')),
                                ('interface_count', YLeaf(YType.uint32, 'interface-count')),
                                ('bd_count', YLeaf(YType.uint32, 'bd-count')),
                                ('msti_flags', YLeaf(YType.uint32, 'msti-flags')),
                                ('msti_state', YLeaf(YType.enumeration, 'msti-state')),
                            ])
                            self.cfg_ms_ti = None
                            self.rcv_count = None
                            self.ack_count = None
                            self.nack_count = None
                            self.flush_count = None
                            self.interface_count = None
                            self.bd_count = None
                            self.msti_flags = None
                            self.msti_state = None

                            self.bd_entry = YList(self)
                            self._segment_path = lambda: "msti-entry"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry, ['cfg_ms_ti', 'rcv_count', 'ack_count', 'nack_count', 'flush_count', 'interface_count', 'bd_count', 'msti_flags', 'msti_state'], name, value)


                        class BdEntry(Entity):
                            """
                            BD entries
                            
                            .. attribute:: bdid
                            
                            	BD ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: bdif_count
                            
                            	BD Intf Count
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry, self).__init__()

                                self.yang_name = "bd-entry"
                                self.yang_parent_name = "msti-entry"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('bdid', YLeaf(YType.uint32, 'bdid')),
                                    ('bdif_count', YLeaf(YType.uint32, 'bdif-count')),
                                ])
                                self.bdid = None
                                self.bdif_count = None
                                self._segment_path = lambda: "bd-entry"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.MstpPorts.MstpPort.MstiEntry.BdEntry, ['bdid', 'bdif_count'], name, value)


            class GenericInterfaceListDetails(Entity):
                """
                L2VPN generic interface list Detail Table
                
                .. attribute:: generic_interface_list_detail
                
                	Generic Interface List detail information
                	**type**\: list of  		 :py:class:`GenericInterfaceListDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails, self).__init__()

                    self.yang_name = "generic-interface-list-details"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("generic-interface-list-detail", ("generic_interface_list_detail", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail))])
                    self._leafs = OrderedDict()

                    self.generic_interface_list_detail = YList(self)
                    self._segment_path = lambda: "generic-interface-list-details"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails, [], name, value)


                class GenericInterfaceListDetail(Entity):
                    """
                    Generic Interface List detail information
                    
                    .. attribute:: interface_list_name  (key)
                    
                    	Generic Interface List Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: summary
                    
                    	Summary information
                    	**type**\:  :py:class:`Summary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary>`
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\: bool
                    
                    .. attribute:: psedowire_ether_items
                    
                    	Number PW Ether Items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: pseudowire_iw_items
                    
                    	Number PW IW Items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface>`
                    
                    .. attribute:: pseudowire_ether_range
                    
                    	PW\-Ether ranges
                    	**type**\: list of  		 :py:class:`PseudowireEtherRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange>`
                    
                    .. attribute:: pseudowire_iw_range
                    
                    	PW\-IW ranges
                    	**type**\: list of  		 :py:class:`PseudowireIwRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail, self).__init__()

                        self.yang_name = "generic-interface-list-detail"
                        self.yang_parent_name = "generic-interface-list-details"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_list_name']
                        self._child_classes = OrderedDict([("summary", ("summary", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary)), ("interface", ("interface", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface)), ("pseudowire-ether-range", ("pseudowire_ether_range", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange)), ("pseudowire-iw-range", ("pseudowire_iw_range", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange))])
                        self._leafs = OrderedDict([
                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                            ('items', YLeaf(YType.uint32, 'items')),
                            ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                            ('psedowire_ether_items', YLeaf(YType.uint32, 'psedowire-ether-items')),
                            ('pseudowire_iw_items', YLeaf(YType.uint32, 'pseudowire-iw-items')),
                        ])
                        self.interface_list_name = None
                        self.items = None
                        self.is_provisioned = None
                        self.psedowire_ether_items = None
                        self.pseudowire_iw_items = None

                        self.summary = L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary()
                        self.summary.parent = self
                        self._children_name_map["summary"] = "summary"

                        self.interface = YList(self)
                        self.pseudowire_ether_range = YList(self)
                        self.pseudowire_iw_range = YList(self)
                        self._segment_path = lambda: "generic-interface-list-detail" + "[interface-list-name='" + str(self.interface_list_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail, ['interface_list_name', 'items', 'is_provisioned', 'psedowire_ether_items', 'pseudowire_iw_items'], name, value)


                    class Summary(Entity):
                        """
                        Summary information
                        
                        .. attribute:: interface_list_name_xr
                        
                        	Interface\-list name
                        	**type**\: str
                        
                        	**length:** 0..33
                        
                        .. attribute:: interface_list_id
                        
                        	Interface internal ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_of_interfaces
                        
                        	Number of interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: items
                        
                        	Number of items
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: interface
                        
                        	Interfaces
                        	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, self).__init__()

                            self.yang_name = "summary"
                            self.yang_parent_name = "generic-interface-list-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface))])
                            self._leafs = OrderedDict([
                                ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                                ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                                ('items', YLeaf(YType.uint32, 'items')),
                            ])
                            self.interface_list_name_xr = None
                            self.interface_list_id = None
                            self.number_of_interfaces = None
                            self.items = None

                            self.interface = YList(self)
                            self._segment_path = lambda: "summary"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary, ['interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                        class Interface(Entity):
                            """
                            Interfaces
                            
                            .. attribute:: interface_name
                            
                            	Interface name
                            	**type**\: str
                            
                            .. attribute:: pending_replications
                            
                            	Number of pending replications
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: not_supported_replications
                            
                            	Number of replications failed because unsupported
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_fib_downloaded
                            
                            	Is interface downloaded to FIB
                            	**type**\: bool
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, self).__init__()

                                self.yang_name = "interface"
                                self.yang_parent_name = "summary"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                    ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                    ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                                ])
                                self.interface_name = None
                                self.pending_replications = None
                                self.not_supported_replications = None
                                self.is_fib_downloaded = None
                                self._segment_path = lambda: "interface"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Summary.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface-list-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                            ])
                            self.interface_name = None
                            self.pending_replications = None
                            self.not_supported_replications = None
                            self.is_fib_downloaded = None
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


                    class PseudowireEtherRange(Entity):
                        """
                        PW\-Ether ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, self).__init__()

                            self.yang_name = "pseudowire-ether-range"
                            self.yang_parent_name = "generic-interface-list-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lower', YLeaf(YType.uint16, 'lower')),
                                ('upper', YLeaf(YType.uint16, 'upper')),
                            ])
                            self.lower = None
                            self.upper = None
                            self._segment_path = lambda: "pseudowire-ether-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireEtherRange, ['lower', 'upper'], name, value)


                    class PseudowireIwRange(Entity):
                        """
                        PW\-IW ranges
                        
                        .. attribute:: lower
                        
                        	lower range
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        .. attribute:: upper
                        
                        	upper range
                        	**type**\: int
                        
                        	**range:** 0..65535
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, self).__init__()

                            self.yang_name = "pseudowire-iw-range"
                            self.yang_parent_name = "generic-interface-list-detail"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('lower', YLeaf(YType.uint16, 'lower')),
                                ('upper', YLeaf(YType.uint16, 'upper')),
                            ])
                            self.lower = None
                            self.upper = None
                            self._segment_path = lambda: "pseudowire-iw-range"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceListDetails.GenericInterfaceListDetail.PseudowireIwRange, ['lower', 'upper'], name, value)


            class L2vpnResourceState(Entity):
                """
                L2VPN resource state information
                
                .. attribute:: resource_out_of_memory_state
                
                	L2VPN Out of memory state
                	**type**\: int
                
                	**range:** 0..4294967295
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.L2vpnResourceState, self).__init__()

                    self.yang_name = "l2vpn-resource-state"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('resource_out_of_memory_state', YLeaf(YType.uint32, 'resource-out-of-memory-state')),
                    ])
                    self.resource_out_of_memory_state = None
                    self._segment_path = lambda: "l2vpn-resource-state"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.L2vpnResourceState, ['resource_out_of_memory_state'], name, value)


            class BridgeDomains(Entity):
                """
                Bridge Domain Information
                
                .. attribute:: bridge_domain
                
                	Bridge Domain Information
                	**type**\: list of  		 :py:class:`BridgeDomain <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.BridgeDomains, self).__init__()

                    self.yang_name = "bridge-domains"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("bridge-domain", ("bridge_domain", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain))])
                    self._leafs = OrderedDict()

                    self.bridge_domain = YList(self)
                    self._segment_path = lambda: "bridge-domains"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains, [], name, value)


                class BridgeDomain(Entity):
                    """
                    Bridge Domain Information
                    
                    .. attribute:: bridge_access_vfi_table
                    
                    	Bridge Domain Access VFI Table
                    	**type**\:  :py:class:`BridgeAccessVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable>`
                    
                    .. attribute:: bridge_core_vfi_table
                    
                    	Bridge Domain Core VFI Table
                    	**type**\:  :py:class:`BridgeCoreVfiTable <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable>`
                    
                    .. attribute:: bridge_acs
                    
                    	Bridge Domain Attachment Circuit Table
                    	**type**\:  :py:class:`BridgeAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs>`
                    
                    .. attribute:: bridge_access_pws
                    
                    	Bridge Domain Access Pseudowire Table
                    	**type**\:  :py:class:`BridgeAccessPws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws>`
                    
                    .. attribute:: bridge_domain_info
                    
                    	Bridge Domain Information
                    	**type**\:  :py:class:`BridgeDomainInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo>`
                    
                    .. attribute:: bridge_domain_group_name
                    
                    	Bridge Domain Group Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: bridge_domain_name
                    
                    	Bridge Domain Name
                    	**type**\: str
                    
                    	**length:** 1..27
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain, self).__init__()

                        self.yang_name = "bridge-domain"
                        self.yang_parent_name = "bridge-domains"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("bridge-access-vfi-table", ("bridge_access_vfi_table", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable)), ("bridge-core-vfi-table", ("bridge_core_vfi_table", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable)), ("bridge-acs", ("bridge_acs", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs)), ("bridge-access-pws", ("bridge_access_pws", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws)), ("bridge-domain-info", ("bridge_domain_info", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo))])
                        self._leafs = OrderedDict([
                            ('bridge_domain_group_name', YLeaf(YType.str, 'bridge-domain-group-name')),
                            ('bridge_domain_name', YLeaf(YType.str, 'bridge-domain-name')),
                        ])
                        self.bridge_domain_group_name = None
                        self.bridge_domain_name = None

                        self.bridge_access_vfi_table = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable()
                        self.bridge_access_vfi_table.parent = self
                        self._children_name_map["bridge_access_vfi_table"] = "bridge-access-vfi-table"

                        self.bridge_core_vfi_table = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable()
                        self.bridge_core_vfi_table.parent = self
                        self._children_name_map["bridge_core_vfi_table"] = "bridge-core-vfi-table"

                        self.bridge_acs = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs()
                        self.bridge_acs.parent = self
                        self._children_name_map["bridge_acs"] = "bridge-acs"

                        self.bridge_access_pws = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws()
                        self.bridge_access_pws.parent = self
                        self._children_name_map["bridge_access_pws"] = "bridge-access-pws"

                        self.bridge_domain_info = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo()
                        self.bridge_domain_info.parent = self
                        self._children_name_map["bridge_domain_info"] = "bridge-domain-info"
                        self._segment_path = lambda: "bridge-domain"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain, ['bridge_domain_group_name', 'bridge_domain_name'], name, value)


                    class BridgeAccessVfiTable(Entity):
                        """
                        Bridge Domain Access VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, self).__init__()

                            self.yang_name = "bridge-access-vfi-table"
                            self.yang_parent_name = "bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws))])
                            self._leafs = OrderedDict()

                            self.bridge_pws = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                            self._segment_path = lambda: "bridge-access-vfi-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable, [], name, value)


                        class BridgePws(Entity):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	Bridge Domain Pseudowire
                            	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, self).__init__()

                                self.yang_name = "bridge-pws"
                                self.yang_parent_name = "bridge-access-vfi-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw))])
                                self._leafs = OrderedDict()

                                self.bridge_pw = YList(self)
                                self._segment_path = lambda: "bridge-pws"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws, [], name, value)


                            class BridgePw(Entity):
                                """
                                Bridge Domain Pseudowire
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\: bool
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, self).__init__()

                                    self.yang_name = "bridge-pw"
                                    self.yang_parent_name = "bridge-pws"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac))])
                                    self._leafs = OrderedDict([
                                        ('neighbor', YLeaf(YType.str, 'neighbor')),
                                        ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                        ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                        ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                        ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                        ('is_access', YLeaf(YType.boolean, 'is-access')),
                                    ])
                                    self.neighbor = None
                                    self.pw_type = None
                                    self.pseudowire_id = None
                                    self.ve_id_vpls_id_0_3 = None
                                    self.vpls_id_4_7 = None
                                    self.is_access = None

                                    self.pseudowire = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"

                                    self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"

                                    self.static_mac = YList(self)
                                    self._segment_path = lambda: "bridge-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                                class Pseudowire(Entity):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_vpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\: bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\: bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\: bool
                                    
                                    .. attribute:: data_path_down
                                    
                                    	True if LSP down
                                    	**type**\: bool
                                    
                                    .. attribute:: use_tunnel_path
                                    
                                    	True if using TE tunnel
                                    	**type**\: bool
                                    
                                    .. attribute:: odn_configured
                                    
                                    	True if ODN is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\: bool
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\: bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\: bool
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\: bool
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\: bool
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\: bool
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\: bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\: bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\: bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\: bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\: bool
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                        self.yang_name = "pseudowire"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                        self._leafs = OrderedDict([
                                            ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                            ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                            ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                            ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                            ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('state', YLeaf(YType.enumeration, 'state')),
                                            ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                            ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                            ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                            ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                            ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                            ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                            ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                            ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                            ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                            ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                            ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                            ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                            ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                            ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                            ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                            ('time_created', YLeaf(YType.str, 'time-created')),
                                            ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                            ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                            ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                            ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                            ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                            ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                            ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                            ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                            ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                            ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                            ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                            ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                            ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                            ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                            ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                            ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                            ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                            ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                            ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                            ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                            ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                            ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                            ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                            ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                            ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                            ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                            ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                            ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                            ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                            ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                            ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                            ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                            ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                            ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                            ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                            ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                            ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                            ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                            ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                            ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                            ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                            ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                            ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                            ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                            ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                            ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                            ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                            ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                            ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                            ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                            ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                            ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                            ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                            ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                            ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                            ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                            ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                            ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                            ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                        ])
                                        self.local_source_address = None
                                        self.ipv6_local_source_address = None
                                        self.pseudo_wire_id = None
                                        self.is_pwr_type = None
                                        self.is_evpn_vpws_type = None
                                        self.xconnect_id = None
                                        self.state = None
                                        self.pseudo_wire_state = None
                                        self.protocol = None
                                        self.pw_class_name = None
                                        self.tag_rewrite = None
                                        self.interworking = None
                                        self.fe_ctype = None
                                        self.evpn_src_acid = None
                                        self.sequencing_type = None
                                        self.resync_enabled = None
                                        self.resync_threshold = None
                                        self.local_control_word = None
                                        self.remote_control_word = None
                                        self.local_pseudo_wire_type = None
                                        self.remote_pseudo_wire_type = None
                                        self.imposed_vlan_id = None
                                        self.time_created = None
                                        self.time_elapsed_creation = None
                                        self.last_time_status_changed = None
                                        self.time_elapsed_status_changed = None
                                        self.last_time_status_down = None
                                        self.time_elapsed_status_down = None
                                        self.shutdown = None
                                        self.data_path_down = None
                                        self.use_tunnel_path = None
                                        self.odn_configured = None
                                        self.pseudo_wire_type_mismatched = None
                                        self.payload_bytes_mismatched = None
                                        self.bitrate_mismatched = None
                                        self.rtp_mismatched = None
                                        self.diff_ts_mismatched = None
                                        self.sig_pkts_mismatched = None
                                        self.cas_mismatched = None
                                        self.payload_type_mismatched = None
                                        self.freq_mismatched = None
                                        self.ssrc_mismatched = None
                                        self.mtu_mismatched = None
                                        self.illegal_control_word = None
                                        self.ad_remote_down = None
                                        self.not_supported_qinq = None
                                        self.local_label_failed = None
                                        self.remote_label_failed = None
                                        self.preferred_path_disable_fallback = None
                                        self.backup_pw = None
                                        self.primary_pw = None
                                        self.backup_active = None
                                        self.backup_force_active = None
                                        self.disable_never = None
                                        self.disable_delay = None
                                        self.primary_peer_id = None
                                        self.primary_pseudo_wire_id = None
                                        self.number_ma_cwithdraw_message_sent = None
                                        self.num_ma_cwithdraw_msg_received = None
                                        self.out_of_memory_state = None
                                        self.transport_lsp_down = None
                                        self.mac_limit_oper_down = None
                                        self.pw_status_use = None
                                        self.auto_discovery = None
                                        self.ad_method = None
                                        self.pwlsd_rewrite_failed = None
                                        self.ldp_label_advertise_failed = None
                                        self.is_vfi = None
                                        self.is_multi_segment_pseudowire = None
                                        self.pw_redundancy_one_way = None
                                        self.load_balance = None
                                        self.pw_flow_label_type = None
                                        self.pw_flow_label_type_cfg = None
                                        self.pw_flow_label_code17_disabled = None
                                        self.is_flow_label_static = None
                                        self.is_partially_programmed = None
                                        self.pw_redundancy_initial_delay = None
                                        self.bridge_pw_type_mismatch = None
                                        self.required_bw = None
                                        self.admited_bw = None
                                        self.forward_class = None
                                        self.table_policy_name = None

                                        self.peer_id = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"

                                        self.encapsulation_info = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                        self.local_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"

                                        self.remote_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"

                                        self.preferred_path = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"

                                        self.local_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"

                                        self.remote_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"

                                        self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"

                                        self.p2mp_pw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        self._segment_path = lambda: "pseudowire"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                    class PeerId(Entity):
                                        """
                                        Peer
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                            self.yang_name = "peer-id"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                                ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                                ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.type = None
                                            self.ipv4_peer_id = None
                                            self.ipv6_peer_id = None
                                            self.internal_label = None
                                            self._segment_path = lambda: "peer-id"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                    class EncapsulationInfo(Entity):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                            self.yang_name = "encapsulation-info"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                            self._leafs = OrderedDict([
                                                ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                            ])
                                            self.encapsulation = None

                                            self.atom = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"

                                            self.l2tpv3 = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                            self._segment_path = lambda: "encapsulation-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                        class Atom(Entity):
                                            """
                                            atom
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\: bool
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\: bool
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\: bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                                self.yang_name = "atom"
                                                self.yang_parent_name = "encapsulation-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                                self._leafs = OrderedDict([
                                                    ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                    ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                    ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                    ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                    ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                    ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                    ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                    ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                    ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                    ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                    ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                    ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                    ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                    ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                    ('saii', YLeaf(YType.str, 'saii')),
                                                    ('taii', YLeaf(YType.str, 'taii')),
                                                    ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                    ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                    ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                    ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                    ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                    ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                    ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                    ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                    ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                    ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                    ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                    ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                    ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                    ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                                ])
                                                self.is_pseudowire_headend = None
                                                self.local_label = None
                                                self.remote_label = None
                                                self.local_group_id = None
                                                self.remote_group_id = None
                                                self.local_cv_type = None
                                                self.local_c_ctype = None
                                                self.remote_cv_type = None
                                                self.remote_c_ctype = None
                                                self.local_veid = None
                                                self.remote_veid = None
                                                self.local_ceid = None
                                                self.remote_ceid = None
                                                self.source_address = None
                                                self.remote_source_address = None
                                                self.local_ldp_id = None
                                                self.remote_ldp_id = None
                                                self.saii = None
                                                self.taii = None
                                                self.is_sai_itype2 = None
                                                self.local_saii_gbl_id = None
                                                self.local_saiiac_id = None
                                                self.is_tai_itype2 = None
                                                self.local_taii_gbl_id = None
                                                self.local_taiiac_id = None
                                                self.rem_saii_gbl_id = None
                                                self.rem_saiiac_id = None
                                                self.rem_taii_gbl_id = None
                                                self.rem_taiiac_id = None
                                                self.rem_saii = None
                                                self.rem_taii = None
                                                self.lsd_rewrite_failed = None
                                                self.ldp_label_advertisment_failed = None

                                                self.local_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"

                                                self.remote_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"

                                                self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                self._segment_path = lambda: "atom"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                            class LocalAgi(Entity):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                    self.yang_name = "local-agi"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                    self._leafs = OrderedDict([
                                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                    ])
                                                    self.vpls_id_type = None

                                                    self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"

                                                    self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                                    self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._segment_path = lambda: "local-agi"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                        ])
                                                        self.asn = None
                                                        self.vpn_id = None
                                                        self._segment_path = lambda: "auto"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                        ])
                                                        self.two_byte_as = None
                                                        self.four_byte_index = None
                                                        self._segment_path = lambda: "two-byte-as"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                        ])
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None
                                                        self._segment_path = lambda: "v4-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                            class RemoteAgi(Entity):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                    self.yang_name = "remote-agi"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                    self._leafs = OrderedDict([
                                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                    ])
                                                    self.vpls_id_type = None

                                                    self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"

                                                    self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                                    self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._segment_path = lambda: "remote-agi"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                        ])
                                                        self.asn = None
                                                        self.vpn_id = None
                                                        self._segment_path = lambda: "auto"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                        ])
                                                        self.two_byte_as = None
                                                        self.four_byte_index = None
                                                        self._segment_path = lambda: "two-byte-as"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                        ])
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None
                                                        self._segment_path = lambda: "v4-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                            class MultiSegmentPseudowireStats(Entity):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                    self.yang_name = "multi-segment-pseudowire-stats"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                        ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                    ])
                                                    self.received_packets = None
                                                    self.received_bytes = None
                                                    self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                        class L2tpv3(Entity):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\: str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\: bool
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                                self.yang_name = "l2tpv3"
                                                self.yang_parent_name = "encapsulation-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                    ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                    ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                    ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                    ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                    ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                    ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                    ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                    ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                    ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                    ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                    ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                    ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                    ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                    ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                    ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                    ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                    ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                    ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                    ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                    ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                                ])
                                                self.l2tp_class_name = None
                                                self.ipv4_source_address = None
                                                self.ipv6_source_address = None
                                                self.path_mtu_enabled = None
                                                self.path_mtu_max_value = None
                                                self.dont_fragment_bit = None
                                                self.tos_mode = None
                                                self.tos = None
                                                self.ttl = None
                                                self.local_session_id = None
                                                self.remote_session_id = None
                                                self.local_cookie_size = None
                                                self.remote_cookie_size = None
                                                self.local_cookie_low_value = None
                                                self.remote_cookie_low_value = None
                                                self.local_cookie_high_value = None
                                                self.remote_cookie_high_value = None
                                                self.remote_circuit_status_up = None
                                                self.tunnel_state = None
                                                self.local_secondary_cookie_size = None
                                                self.local_secondary_cookie_low_value = None
                                                self.local_secondary_cookie_high_value = None
                                                self._segment_path = lambda: "l2tpv3"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                    class LocalInterface(Entity):
                                        """
                                        Local interface
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                            self.yang_name = "local-interface"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                            self._leafs = OrderedDict([
                                                ('name', YLeaf(YType.str, 'name')),
                                                ('mtu', YLeaf(YType.uint32, 'mtu')),
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                            ])
                                            self.name = None
                                            self.mtu = None
                                            self.payload_bytes = None

                                            self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._segment_path = lambda: "local-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "local-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.enumeration, 'type')),
                                                ])
                                                self.type = None

                                                self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"

                                                self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"

                                                self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"

                                                self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"

                                                self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"

                                                self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                                self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._segment_path = lambda: "parameters"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self._segment_path = lambda: "ethernet"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                        ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                        ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                        ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                        ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self.vlan_rewrite_tag = None
                                                    self.simple_efp = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None

                                                    self.rewrite_tag = YList(self)
                                                    self.vlan_range = YList(self)
                                                    self._segment_path = lambda: "vlan"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                                class RewriteTag(Entity):
                                                    """
                                                    Rewrite Tags
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                        self.yang_name = "rewrite-tag"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rewrite-tag"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                                        ])
                                                        self.lower = None
                                                        self.upper = None
                                                        self._segment_path = lambda: "vlan-range"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\: str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                    self._leafs = OrderedDict([
                                                        ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                        ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                        ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                    ])
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None
                                                    self.tdm_mode = None

                                                    self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._segment_path = lambda: "tdm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                            ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                            ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                            ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                            ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                            ('cas', YLeaf(YType.uint8, 'cas')),
                                                            ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                            ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                            ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                        ])
                                                        self.payload_bytes = None
                                                        self.bit_rate = None
                                                        self.rtp = None
                                                        self.timestamp_mode = None
                                                        self.signalling_packets = None
                                                        self.cas = None
                                                        self.rtp_header_payload_type = None
                                                        self.timestamp_clock_freq = None
                                                        self.ssrc = None
                                                        self._segment_path = lambda: "tdm-options"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                        ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                        ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                        ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                        ('vci', YLeaf(YType.uint16, 'vci')),
                                                    ])
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.atm_mode = None
                                                    self.vpi = None
                                                    self.vci = None
                                                    self._segment_path = lambda: "atm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                        ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                    ])
                                                    self.fr_mode = None
                                                    self.dlci = None
                                                    self._segment_path = lambda: "fr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-ether"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-iw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class RemoteInterface(Entity):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                            self.yang_name = "remote-interface"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                            self._leafs = OrderedDict([
                                                ('name', YLeaf(YType.str, 'name')),
                                                ('mtu', YLeaf(YType.uint32, 'mtu')),
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                            ])
                                            self.name = None
                                            self.mtu = None
                                            self.payload_bytes = None

                                            self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._segment_path = lambda: "remote-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "remote-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.enumeration, 'type')),
                                                ])
                                                self.type = None

                                                self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"

                                                self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"

                                                self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"

                                                self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"

                                                self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"

                                                self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                                self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._segment_path = lambda: "parameters"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self._segment_path = lambda: "ethernet"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                        ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                        ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                        ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                        ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self.vlan_rewrite_tag = None
                                                    self.simple_efp = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None

                                                    self.rewrite_tag = YList(self)
                                                    self.vlan_range = YList(self)
                                                    self._segment_path = lambda: "vlan"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                                class RewriteTag(Entity):
                                                    """
                                                    Rewrite Tags
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                        self.yang_name = "rewrite-tag"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rewrite-tag"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                                        ])
                                                        self.lower = None
                                                        self.upper = None
                                                        self._segment_path = lambda: "vlan-range"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\: str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                    self._leafs = OrderedDict([
                                                        ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                        ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                        ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                    ])
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None
                                                    self.tdm_mode = None

                                                    self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._segment_path = lambda: "tdm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                            ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                            ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                            ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                            ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                            ('cas', YLeaf(YType.uint8, 'cas')),
                                                            ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                            ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                            ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                        ])
                                                        self.payload_bytes = None
                                                        self.bit_rate = None
                                                        self.rtp = None
                                                        self.timestamp_mode = None
                                                        self.signalling_packets = None
                                                        self.cas = None
                                                        self.rtp_header_payload_type = None
                                                        self.timestamp_clock_freq = None
                                                        self.ssrc = None
                                                        self._segment_path = lambda: "tdm-options"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                        ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                        ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                        ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                        ('vci', YLeaf(YType.uint16, 'vci')),
                                                    ])
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.atm_mode = None
                                                    self.vpi = None
                                                    self.vci = None
                                                    self._segment_path = lambda: "atm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                        ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                    ])
                                                    self.fr_mode = None
                                                    self.dlci = None
                                                    self._segment_path = lambda: "fr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-ether"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-iw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PreferredPath(Entity):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: srte_policy
                                        
                                        	srte policy
                                        	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                            self.yang_name = "preferred-path"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                            self._leafs = OrderedDict([
                                                ('option', YLeaf(YType.enumeration, 'option')),
                                                ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                                ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                                ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                                ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                            ])
                                            self.option = None
                                            self.next_hop_ip = None
                                            self.te_tunnel_interface_number = None
                                            self.ip_tunnel_interface_number = None
                                            self.tp_tunnel_interface_number = None

                                            self.srte_policy = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                            self.srte_policy.parent = self
                                            self._children_name_map["srte_policy"] = "srte-policy"
                                            self._segment_path = lambda: "preferred-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                        class SrtePolicy(Entity):
                                            """
                                            srte policy
                                            
                                            .. attribute:: policy_name
                                            
                                            	SR TE Policy Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                                self.yang_name = "srte-policy"
                                                self.yang_parent_name = "preferred-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('policy_name', YLeaf(YType.str, 'policy-name')),
                                                ])
                                                self.policy_name = None
                                                self._segment_path = lambda: "srte-policy"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                    class LocalSignalling(Entity):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                            self.yang_name = "local-signalling"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                            self._leafs = OrderedDict([
                                                ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                            ])
                                            self.pw_status = None

                                            self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "local-signalling"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "local-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "status-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "local-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class RemoteSignalling(Entity):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                            self.yang_name = "remote-signalling"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                            self._leafs = OrderedDict([
                                                ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                            ])
                                            self.pw_status = None

                                            self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "remote-signalling"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "remote-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "status-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "remote-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                            self._leafs = OrderedDict()

                                            self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"

                                            self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                            self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._segment_path = lambda: "statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                                self._leafs = OrderedDict()

                                                self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"

                                                self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                                self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                                self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                                self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"

                                                self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._segment_path = lambda: "impostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "impostion-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class L2fsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "l2fsbi-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unknown-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                                self._leafs = OrderedDict()

                                                self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"

                                                self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                                self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                                self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"

                                                self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"

                                                self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                                self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"

                                                self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"

                                                self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                                self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                                self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._segment_path = lambda: "dispostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "received-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "dai-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "ipsg-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-oo-o-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionP2mpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-p2mp-stats"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "mac-move"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                    ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                    ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                    ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                                ])
                                                self.sequence_number_sent = None
                                                self.sequence_number_expected = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self._segment_path = lambda: "sequence-number"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                    class P2mpPw(Entity):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                            self.yang_name = "p2mp-pw"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_available', YLeaf(YType.boolean, 'local-available')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                                ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                                ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                                ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                                ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                                ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                                ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                                ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                                ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                                ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                            ])
                                            self.local_available = None
                                            self.local_label = None
                                            self.local_ptree_type = None
                                            self.local_tunnel_id = None
                                            self.local_extended_tunnel_id = None
                                            self.local_p2mp_id = None
                                            self.local_flags = None
                                            self.remote_available = None
                                            self.remote_label = None
                                            self.remote_ptree_type = None
                                            self.remote_tunnel_id = None
                                            self.remote_extended_tunnel_id = None
                                            self.remote_p2mp_id = None
                                            self.remote_flags = None
                                            self._segment_path = lambda: "p2mp-pw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StaticMac(Entity):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                        self.yang_name = "static-mac"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', YLeaf(YType.str, 'address')),
                                            ('bmac', YLeaf(YType.str, 'bmac')),
                                            ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                        ])
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None
                                        self._segment_path = lambda: "static-mac"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeCoreVfiTable(Entity):
                        """
                        Bridge Domain Core VFI Table
                        
                        .. attribute:: bridge_pws
                        
                        	Bridge Domain Access/Core Pseudowire Table
                        	**type**\:  :py:class:`BridgePws <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, self).__init__()

                            self.yang_name = "bridge-core-vfi-table"
                            self.yang_parent_name = "bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-pws", ("bridge_pws", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws))])
                            self._leafs = OrderedDict()

                            self.bridge_pws = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws()
                            self.bridge_pws.parent = self
                            self._children_name_map["bridge_pws"] = "bridge-pws"
                            self._segment_path = lambda: "bridge-core-vfi-table"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable, [], name, value)


                        class BridgePws(Entity):
                            """
                            Bridge Domain Access/Core Pseudowire Table
                            
                            .. attribute:: bridge_pw
                            
                            	Bridge Domain Pseudowire
                            	**type**\: list of  		 :py:class:`BridgePw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, self).__init__()

                                self.yang_name = "bridge-pws"
                                self.yang_parent_name = "bridge-core-vfi-table"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("bridge-pw", ("bridge_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw))])
                                self._leafs = OrderedDict()

                                self.bridge_pw = YList(self)
                                self._segment_path = lambda: "bridge-pws"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws, [], name, value)


                            class BridgePw(Entity):
                                """
                                Bridge Domain Pseudowire
                                
                                .. attribute:: neighbor
                                
                                	Neighbor IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pw_type
                                
                                	PW Type
                                	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                                
                                .. attribute:: pseudowire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 1..4294967295
                                
                                .. attribute:: ve_id_vpls_id_0_3
                                
                                	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: vpls_id_4_7
                                
                                	Zero or Last 4 bytes of VPLS\-ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pseudowire
                                
                                	Pseudowire
                                	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire>`
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters>`
                                
                                .. attribute:: is_access
                                
                                	Is Access PW
                                	**type**\: bool
                                
                                .. attribute:: static_mac
                                
                                	Static MAC addresses
                                	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, self).__init__()

                                    self.yang_name = "bridge-pw"
                                    self.yang_parent_name = "bridge-pws"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac))])
                                    self._leafs = OrderedDict([
                                        ('neighbor', YLeaf(YType.str, 'neighbor')),
                                        ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                        ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                        ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                        ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                        ('is_access', YLeaf(YType.boolean, 'is-access')),
                                    ])
                                    self.neighbor = None
                                    self.pw_type = None
                                    self.pseudowire_id = None
                                    self.ve_id_vpls_id_0_3 = None
                                    self.vpls_id_4_7 = None
                                    self.is_access = None

                                    self.pseudowire = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire()
                                    self.pseudowire.parent = self
                                    self._children_name_map["pseudowire"] = "pseudowire"

                                    self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"

                                    self.static_mac = YList(self)
                                    self._segment_path = lambda: "bridge-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                                class Pseudowire(Entity):
                                    """
                                    Pseudowire
                                    
                                    .. attribute:: peer_id
                                    
                                    	Peer
                                    	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId>`
                                    
                                    .. attribute:: encapsulation_info
                                    
                                    	Encapsulation specific pseudowire information
                                    	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo>`
                                    
                                    .. attribute:: local_interface
                                    
                                    	Local interface
                                    	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface>`
                                    
                                    .. attribute:: remote_interface
                                    
                                    	Remote interface
                                    	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface>`
                                    
                                    .. attribute:: preferred_path
                                    
                                    	MPLS Preferred Path
                                    	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath>`
                                    
                                    .. attribute:: local_signalling
                                    
                                    	Local signalling
                                    	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling>`
                                    
                                    .. attribute:: remote_signalling
                                    
                                    	Remote signalling
                                    	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics>`
                                    
                                    .. attribute:: p2mp_pw
                                    
                                    	P2MP Pseudowire Information
                                    	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw>`
                                    
                                    .. attribute:: local_source_address
                                    
                                    	Local Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_local_source_address
                                    
                                    	Local IPv6 Source Address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: pseudo_wire_id
                                    
                                    	Pseudowire ID
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: is_pwr_type
                                    
                                    	is Pseudowire\-routed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_evpn_vpws_type
                                    
                                    	is EVPN VPWS
                                    	**type**\: bool
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	XConnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: state
                                    
                                    	State
                                    	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                    
                                    .. attribute:: pseudo_wire_state
                                    
                                    	Pseudowire state
                                    	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                    
                                    .. attribute:: protocol
                                    
                                    	Protocol
                                    	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                    
                                    .. attribute:: pw_class_name
                                    
                                    	Pseudowire class name
                                    	**type**\: str
                                    
                                    	**length:** 0..33
                                    
                                    .. attribute:: tag_rewrite
                                    
                                    	StaticTagRewrite
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: interworking
                                    
                                    	Interworking type
                                    	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                    
                                    .. attribute:: fe_ctype
                                    
                                    	Pseudowire FEC type
                                    	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                    
                                    .. attribute:: evpn_src_acid
                                    
                                    	EVPN VPWS Source AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequencing_type
                                    
                                    	Sequencing Type
                                    	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                    
                                    .. attribute:: resync_enabled
                                    
                                    	Resync if packets out of sequence
                                    	**type**\: bool
                                    
                                    .. attribute:: resync_threshold
                                    
                                    	Number of Packets Out of Seqence to trigger resync
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_control_word
                                    
                                    	Local control word
                                    	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                    
                                    .. attribute:: remote_control_word
                                    
                                    	Remote control word
                                    	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                    
                                    .. attribute:: local_pseudo_wire_type
                                    
                                    	Local pseudowire type
                                    	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                    
                                    .. attribute:: remote_pseudo_wire_type
                                    
                                    	Remote pseudowire type
                                    	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                    
                                    .. attribute:: imposed_vlan_id
                                    
                                    	Imposed vlan id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: time_created
                                    
                                    	Time when the pseudowire was created
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_creation
                                    
                                    	Time elapsed since creation
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_changed
                                    
                                    	Last time the pseudowire status changed
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_changed
                                    
                                    	Time elapsed since status changed
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: last_time_status_down
                                    
                                    	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                    	**type**\: str
                                    
                                    	**length:** 0..50
                                    
                                    .. attribute:: time_elapsed_status_down
                                    
                                    	Time elapsed since last status down in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: shutdown
                                    
                                    	Shutdown
                                    	**type**\: bool
                                    
                                    .. attribute:: data_path_down
                                    
                                    	True if LSP down
                                    	**type**\: bool
                                    
                                    .. attribute:: use_tunnel_path
                                    
                                    	True if using TE tunnel
                                    	**type**\: bool
                                    
                                    .. attribute:: odn_configured
                                    
                                    	True if ODN is configured
                                    	**type**\: bool
                                    
                                    .. attribute:: pseudo_wire_type_mismatched
                                    
                                    	Pseudowire type mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: payload_bytes_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: bitrate_mismatched
                                    
                                    	Bitrate mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: rtp_mismatched
                                    
                                    	RTP mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: diff_ts_mismatched
                                    
                                    	Differential timestamp mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: sig_pkts_mismatched
                                    
                                    	Signalling packets mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: cas_mismatched
                                    
                                    	CAS mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: payload_type_mismatched
                                    
                                    	Payload bytes mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: freq_mismatched
                                    
                                    	Frequency mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: ssrc_mismatched
                                    
                                    	SSRC mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: mtu_mismatched
                                    
                                    	MTU mismatched
                                    	**type**\: bool
                                    
                                    .. attribute:: illegal_control_word
                                    
                                    	Illegal control word
                                    	**type**\: bool
                                    
                                    .. attribute:: ad_remote_down
                                    
                                    	Auto\-Discovered PW remote state down
                                    	**type**\: bool
                                    
                                    .. attribute:: not_supported_qinq
                                    
                                    	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label_failed
                                    
                                    	Failed to set BGP advertised local label
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label_failed
                                    
                                    	Failed to set BGP advertised remote label
                                    	**type**\: bool
                                    
                                    .. attribute:: preferred_path_disable_fallback
                                    
                                    	Prefpath fallback enable/disable
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_pw
                                    
                                    	TRUE if PW is a backup PW
                                    	**type**\: bool
                                    
                                    .. attribute:: primary_pw
                                    
                                    	TRUE if PW is a primary PW
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_active
                                    
                                    	TRUE if backup is active
                                    	**type**\: bool
                                    
                                    .. attribute:: backup_force_active
                                    
                                    	TRUE if backup is active due to switchover
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_never
                                    
                                    	TRUE if backup is not automatically disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: disable_delay
                                    
                                    	Backup disable delay
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: primary_peer_id
                                    
                                    	Primary Peer IP address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: primary_pseudo_wire_id
                                    
                                    	Primary Pseudowire ID
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: number_ma_cwithdraw_message_sent
                                    
                                    	Num MW messages sent over PW
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: num_ma_cwithdraw_msg_received
                                    
                                    	Num MW messages received over PW
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: out_of_memory_state
                                    
                                    	L2VPN Out of memory state
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: transport_lsp_down
                                    
                                    	Oper down due to Transport LSP down
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_oper_down
                                    
                                    	Oper down because MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_status_use
                                    
                                    	PW status in use
                                    	**type**\: bool
                                    
                                    .. attribute:: auto_discovery
                                    
                                    	Is autodiscovery
                                    	**type**\: bool
                                    
                                    .. attribute:: ad_method
                                    
                                    	Autodiscovery method
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: pwlsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertise_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    .. attribute:: is_vfi
                                    
                                    	Is VFI interface
                                    	**type**\: bool
                                    
                                    .. attribute:: is_multi_segment_pseudowire
                                    
                                    	Is Multi\-Segment Pseudowire
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_redundancy_one_way
                                    
                                    	Force one\-way PW redundancy behaviour in Redundancy Group
                                    	**type**\: bool
                                    
                                    .. attribute:: load_balance
                                    
                                    	Load Balance Type
                                    	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                    
                                    .. attribute:: pw_flow_label_type
                                    
                                    	Negotiated pseudowire flow label type
                                    	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_type_cfg
                                    
                                    	Configured pseudowire flow label Type
                                    	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                    
                                    .. attribute:: pw_flow_label_code17_disabled
                                    
                                    	Disable sending Code 17 TLV
                                    	**type**\: bool
                                    
                                    .. attribute:: is_flow_label_static
                                    
                                    	is flow label static
                                    	**type**\: bool
                                    
                                    .. attribute:: is_partially_programmed
                                    
                                    	Is Pseudowire partially programmed
                                    	**type**\: bool
                                    
                                    .. attribute:: pw_redundancy_initial_delay
                                    
                                    	Initial delay for redundant PW in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: bridge_pw_type_mismatch
                                    
                                    	Oper down because Bridge has mismatched PW Types
                                    	**type**\: bool
                                    
                                    .. attribute:: required_bw
                                    
                                    	Required Bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: admited_bw
                                    
                                    	Admited Bandwidth
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: forward_class
                                    
                                    	Forward Class attribute
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: table_policy_name
                                    
                                    	Table\-policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, self).__init__()

                                        self.yang_name = "pseudowire"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw))])
                                        self._leafs = OrderedDict([
                                            ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                            ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                            ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                            ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                            ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('state', YLeaf(YType.enumeration, 'state')),
                                            ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                            ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                            ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                            ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                            ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                            ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                            ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                            ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                            ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                            ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                            ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                            ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                            ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                            ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                            ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                            ('time_created', YLeaf(YType.str, 'time-created')),
                                            ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                            ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                            ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                            ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                            ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                            ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                            ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                            ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                            ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                            ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                            ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                            ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                            ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                            ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                            ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                            ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                            ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                            ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                            ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                            ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                            ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                            ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                            ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                            ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                            ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                            ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                            ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                            ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                            ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                            ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                            ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                            ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                            ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                            ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                            ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                            ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                            ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                            ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                            ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                            ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                            ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                            ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                            ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                            ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                            ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                            ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                            ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                            ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                            ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                            ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                            ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                            ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                            ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                            ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                            ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                            ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                            ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                            ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                            ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                        ])
                                        self.local_source_address = None
                                        self.ipv6_local_source_address = None
                                        self.pseudo_wire_id = None
                                        self.is_pwr_type = None
                                        self.is_evpn_vpws_type = None
                                        self.xconnect_id = None
                                        self.state = None
                                        self.pseudo_wire_state = None
                                        self.protocol = None
                                        self.pw_class_name = None
                                        self.tag_rewrite = None
                                        self.interworking = None
                                        self.fe_ctype = None
                                        self.evpn_src_acid = None
                                        self.sequencing_type = None
                                        self.resync_enabled = None
                                        self.resync_threshold = None
                                        self.local_control_word = None
                                        self.remote_control_word = None
                                        self.local_pseudo_wire_type = None
                                        self.remote_pseudo_wire_type = None
                                        self.imposed_vlan_id = None
                                        self.time_created = None
                                        self.time_elapsed_creation = None
                                        self.last_time_status_changed = None
                                        self.time_elapsed_status_changed = None
                                        self.last_time_status_down = None
                                        self.time_elapsed_status_down = None
                                        self.shutdown = None
                                        self.data_path_down = None
                                        self.use_tunnel_path = None
                                        self.odn_configured = None
                                        self.pseudo_wire_type_mismatched = None
                                        self.payload_bytes_mismatched = None
                                        self.bitrate_mismatched = None
                                        self.rtp_mismatched = None
                                        self.diff_ts_mismatched = None
                                        self.sig_pkts_mismatched = None
                                        self.cas_mismatched = None
                                        self.payload_type_mismatched = None
                                        self.freq_mismatched = None
                                        self.ssrc_mismatched = None
                                        self.mtu_mismatched = None
                                        self.illegal_control_word = None
                                        self.ad_remote_down = None
                                        self.not_supported_qinq = None
                                        self.local_label_failed = None
                                        self.remote_label_failed = None
                                        self.preferred_path_disable_fallback = None
                                        self.backup_pw = None
                                        self.primary_pw = None
                                        self.backup_active = None
                                        self.backup_force_active = None
                                        self.disable_never = None
                                        self.disable_delay = None
                                        self.primary_peer_id = None
                                        self.primary_pseudo_wire_id = None
                                        self.number_ma_cwithdraw_message_sent = None
                                        self.num_ma_cwithdraw_msg_received = None
                                        self.out_of_memory_state = None
                                        self.transport_lsp_down = None
                                        self.mac_limit_oper_down = None
                                        self.pw_status_use = None
                                        self.auto_discovery = None
                                        self.ad_method = None
                                        self.pwlsd_rewrite_failed = None
                                        self.ldp_label_advertise_failed = None
                                        self.is_vfi = None
                                        self.is_multi_segment_pseudowire = None
                                        self.pw_redundancy_one_way = None
                                        self.load_balance = None
                                        self.pw_flow_label_type = None
                                        self.pw_flow_label_type_cfg = None
                                        self.pw_flow_label_code17_disabled = None
                                        self.is_flow_label_static = None
                                        self.is_partially_programmed = None
                                        self.pw_redundancy_initial_delay = None
                                        self.bridge_pw_type_mismatch = None
                                        self.required_bw = None
                                        self.admited_bw = None
                                        self.forward_class = None
                                        self.table_policy_name = None

                                        self.peer_id = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId()
                                        self.peer_id.parent = self
                                        self._children_name_map["peer_id"] = "peer-id"

                                        self.encapsulation_info = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo()
                                        self.encapsulation_info.parent = self
                                        self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                        self.local_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface()
                                        self.local_interface.parent = self
                                        self._children_name_map["local_interface"] = "local-interface"

                                        self.remote_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface()
                                        self.remote_interface.parent = self
                                        self._children_name_map["remote_interface"] = "remote-interface"

                                        self.preferred_path = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath()
                                        self.preferred_path.parent = self
                                        self._children_name_map["preferred_path"] = "preferred-path"

                                        self.local_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling()
                                        self.local_signalling.parent = self
                                        self._children_name_map["local_signalling"] = "local-signalling"

                                        self.remote_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling()
                                        self.remote_signalling.parent = self
                                        self._children_name_map["remote_signalling"] = "remote-signalling"

                                        self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"

                                        self.p2mp_pw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw()
                                        self.p2mp_pw.parent = self
                                        self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                        self._segment_path = lambda: "pseudowire"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                    class PeerId(Entity):
                                        """
                                        Peer
                                        
                                        .. attribute:: type
                                        
                                        	type
                                        	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                        
                                        .. attribute:: ipv4_peer_id
                                        
                                        	Peer IPv4 address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_peer_id
                                        
                                        	Peer IPv6 address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, self).__init__()

                                            self.yang_name = "peer-id"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                                ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                                ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.type = None
                                            self.ipv4_peer_id = None
                                            self.ipv6_peer_id = None
                                            self.internal_label = None
                                            self._segment_path = lambda: "peer-id"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                    class EncapsulationInfo(Entity):
                                        """
                                        Encapsulation specific pseudowire information
                                        
                                        .. attribute:: atom
                                        
                                        	atom
                                        	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom>`
                                        
                                        .. attribute:: l2tpv3
                                        
                                        	l2tpv3
                                        	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                        
                                        .. attribute:: encapsulation
                                        
                                        	Encapsulation
                                        	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, self).__init__()

                                            self.yang_name = "encapsulation-info"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                            self._leafs = OrderedDict([
                                                ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                            ])
                                            self.encapsulation = None

                                            self.atom = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom()
                                            self.atom.parent = self
                                            self._children_name_map["atom"] = "atom"

                                            self.l2tpv3 = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3()
                                            self.l2tpv3.parent = self
                                            self._children_name_map["l2tpv3"] = "l2tpv3"
                                            self._segment_path = lambda: "encapsulation-info"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                        class Atom(Entity):
                                            """
                                            atom
                                            
                                            .. attribute:: local_agi
                                            
                                            	Local Attachment Group Identifier
                                            	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                            
                                            .. attribute:: remote_agi
                                            
                                            	Remote Attachment Group Identifier
                                            	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                            
                                            .. attribute:: multi_segment_pseudowire_stats
                                            
                                            	Multisegment pseudowire statistics
                                            	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                            
                                            .. attribute:: is_pseudowire_headend
                                            
                                            	Is this connected to a PW\-HE AC
                                            	**type**\: bool
                                            
                                            .. attribute:: local_label
                                            
                                            	Local label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_label
                                            
                                            	Remote label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_group_id
                                            
                                            	Local group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_group_id
                                            
                                            	Remote group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cv_type
                                            
                                            	Local VCCV CV type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_c_ctype
                                            
                                            	Local VCCV CC type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_cv_type
                                            
                                            	Remote VCCV CV type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_c_ctype
                                            
                                            	Remote VCCV CC type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_veid
                                            
                                            	Local VE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_veid
                                            
                                            	Remote VE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_ceid
                                            
                                            	Local CE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_ceid
                                            
                                            	Remote CE ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: source_address
                                            
                                            	Local BGP source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_source_address
                                            
                                            	Remote BGP source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: local_ldp_id
                                            
                                            	Local LDP ID
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_ldp_id
                                            
                                            	Remote LDP ID
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: saii
                                            
                                            	Source Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: taii
                                            
                                            	Target Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: is_sai_itype2
                                            
                                            	Is SAII FEC129 Type 2
                                            	**type**\: bool
                                            
                                            .. attribute:: local_saii_gbl_id
                                            
                                            	Local SAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_saiiac_id
                                            
                                            	Local SAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_tai_itype2
                                            
                                            	Is TAII type 2
                                            	**type**\: bool
                                            
                                            .. attribute:: local_taii_gbl_id
                                            
                                            	Local TAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_taiiac_id
                                            
                                            	Local TAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saii_gbl_id
                                            
                                            	Remote SAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saiiac_id
                                            
                                            	Remote SAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taii_gbl_id
                                            
                                            	Remote TAII Global ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_taiiac_id
                                            
                                            	Remote TAII AC ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: rem_saii
                                            
                                            	Remote Source Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: rem_taii
                                            
                                            	Remote Target Attachment Individual Identifer
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: lsd_rewrite_failed
                                            
                                            	LSD rewrite failed
                                            	**type**\: bool
                                            
                                            .. attribute:: ldp_label_advertisment_failed
                                            
                                            	LDP label advertisment failed
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                                self.yang_name = "atom"
                                                self.yang_parent_name = "encapsulation-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                                self._leafs = OrderedDict([
                                                    ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                    ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                    ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                    ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                    ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                    ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                    ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                    ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                    ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                    ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                    ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                    ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                    ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                    ('source_address', YLeaf(YType.str, 'source-address')),
                                                    ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                    ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                    ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                    ('saii', YLeaf(YType.str, 'saii')),
                                                    ('taii', YLeaf(YType.str, 'taii')),
                                                    ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                    ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                    ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                    ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                    ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                    ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                    ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                    ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                    ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                    ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                    ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                    ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                    ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                    ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                                ])
                                                self.is_pseudowire_headend = None
                                                self.local_label = None
                                                self.remote_label = None
                                                self.local_group_id = None
                                                self.remote_group_id = None
                                                self.local_cv_type = None
                                                self.local_c_ctype = None
                                                self.remote_cv_type = None
                                                self.remote_c_ctype = None
                                                self.local_veid = None
                                                self.remote_veid = None
                                                self.local_ceid = None
                                                self.remote_ceid = None
                                                self.source_address = None
                                                self.remote_source_address = None
                                                self.local_ldp_id = None
                                                self.remote_ldp_id = None
                                                self.saii = None
                                                self.taii = None
                                                self.is_sai_itype2 = None
                                                self.local_saii_gbl_id = None
                                                self.local_saiiac_id = None
                                                self.is_tai_itype2 = None
                                                self.local_taii_gbl_id = None
                                                self.local_taiiac_id = None
                                                self.rem_saii_gbl_id = None
                                                self.rem_saiiac_id = None
                                                self.rem_taii_gbl_id = None
                                                self.rem_taiiac_id = None
                                                self.rem_saii = None
                                                self.rem_taii = None
                                                self.lsd_rewrite_failed = None
                                                self.ldp_label_advertisment_failed = None

                                                self.local_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                                self.local_agi.parent = self
                                                self._children_name_map["local_agi"] = "local-agi"

                                                self.remote_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                                self.remote_agi.parent = self
                                                self._children_name_map["remote_agi"] = "remote-agi"

                                                self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                                self.multi_segment_pseudowire_stats.parent = self
                                                self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                                self._segment_path = lambda: "atom"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                            class LocalAgi(Entity):
                                                """
                                                Local Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                    self.yang_name = "local-agi"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                    self._leafs = OrderedDict([
                                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                    ])
                                                    self.vpls_id_type = None

                                                    self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"

                                                    self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                                    self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._segment_path = lambda: "local-agi"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                        ])
                                                        self.asn = None
                                                        self.vpn_id = None
                                                        self._segment_path = lambda: "auto"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                        ])
                                                        self.two_byte_as = None
                                                        self.four_byte_index = None
                                                        self._segment_path = lambda: "two-byte-as"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "local-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                        ])
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None
                                                        self._segment_path = lambda: "v4-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                            class RemoteAgi(Entity):
                                                """
                                                Remote Attachment Group Identifier
                                                
                                                .. attribute:: auto
                                                
                                                	auto
                                                	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	two byte as
                                                	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                                
                                                .. attribute:: v4_addr
                                                
                                                	v4 addr
                                                	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                                
                                                .. attribute:: vpls_id_type
                                                
                                                	VPLS ID TYPE
                                                	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                    self.yang_name = "remote-agi"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                    self._leafs = OrderedDict([
                                                        ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                    ])
                                                    self.vpls_id_type = None

                                                    self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                    self.auto.parent = self
                                                    self._children_name_map["auto"] = "auto"

                                                    self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                    self.two_byte_as.parent = self
                                                    self._children_name_map["two_byte_as"] = "two-byte-as"

                                                    self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                    self.v4_addr.parent = self
                                                    self._children_name_map["v4_addr"] = "v4-addr"
                                                    self._segment_path = lambda: "remote-agi"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                                class Auto(Entity):
                                                    """
                                                    auto
                                                    
                                                    .. attribute:: asn
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: vpn_id
                                                    
                                                    	VPN ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                        self.yang_name = "auto"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('asn', YLeaf(YType.uint16, 'asn')),
                                                            ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                        ])
                                                        self.asn = None
                                                        self.vpn_id = None
                                                        self._segment_path = lambda: "auto"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                                class TwoByteAs(Entity):
                                                    """
                                                    two byte as
                                                    
                                                    .. attribute:: two_byte_as
                                                    
                                                    	2 Byte AS Number
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: four_byte_index
                                                    
                                                    	4 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                        self.yang_name = "two-byte-as"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                            ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                        ])
                                                        self.two_byte_as = None
                                                        self.four_byte_index = None
                                                        self._segment_path = lambda: "two-byte-as"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                                class V4Addr(Entity):
                                                    """
                                                    v4 addr
                                                    
                                                    .. attribute:: ipv4_address
                                                    
                                                    	IPv4 Address
                                                    	**type**\: str
                                                    
                                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                    
                                                    .. attribute:: two_byte_index
                                                    
                                                    	2 Byte Index
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                        self.yang_name = "v4-addr"
                                                        self.yang_parent_name = "remote-agi"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                            ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                        ])
                                                        self.ipv4_address = None
                                                        self.two_byte_index = None
                                                        self._segment_path = lambda: "v4-addr"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                            class MultiSegmentPseudowireStats(Entity):
                                                """
                                                Multisegment pseudowire statistics
                                                
                                                .. attribute:: received_packets
                                                
                                                	Packets received
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: received_bytes
                                                
                                                	Bytes received
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                    self.yang_name = "multi-segment-pseudowire-stats"
                                                    self.yang_parent_name = "atom"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                        ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                    ])
                                                    self.received_packets = None
                                                    self.received_bytes = None
                                                    self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                        class L2tpv3(Entity):
                                            """
                                            l2tpv3
                                            
                                            .. attribute:: l2tp_class_name
                                            
                                            	L2TPClassName
                                            	**type**\: str
                                            
                                            	**length:** 0..32
                                            
                                            .. attribute:: ipv4_source_address
                                            
                                            	IPv4 source address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: ipv6_source_address
                                            
                                            	IPv6 source address
                                            	**type**\: str
                                            
                                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: path_mtu_enabled
                                            
                                            	Path MTU enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: path_mtu_max_value
                                            
                                            	Path MTU Maximum allowable session MTU
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: dont_fragment_bit
                                            
                                            	Don't Fragment Bit
                                            	**type**\: bool
                                            
                                            .. attribute:: tos_mode
                                            
                                            	Type Of Service Mode
                                            	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                            
                                            .. attribute:: tos
                                            
                                            	Type Of Service Value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: ttl
                                            
                                            	Time To Live value
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_session_id
                                            
                                            	Local session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_session_id
                                            
                                            	Remote session id
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_size
                                            
                                            	Local cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: remote_cookie_size
                                            
                                            	Remote cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the remote cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the remote cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: remote_circuit_status_up
                                            
                                            	RemoteCircuitStatusUp
                                            	**type**\: bool
                                            
                                            .. attribute:: tunnel_state
                                            
                                            	L2TP tunnel state
                                            	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                            
                                            .. attribute:: local_secondary_cookie_size
                                            
                                            	Local secondary cookie size\: 0, 4, or 8 bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: local_secondary_cookie_low_value
                                            
                                            	Lower 4 bytes of the value of the local secondary cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_secondary_cookie_high_value
                                            
                                            	Upper 4 bytes of the value of the local secondary cookie
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                                self.yang_name = "l2tpv3"
                                                self.yang_parent_name = "encapsulation-info"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                    ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                    ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                    ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                    ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                    ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                    ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                                    ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                    ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                    ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                    ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                    ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                    ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                    ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                    ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                    ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                    ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                    ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                    ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                    ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                    ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                                ])
                                                self.l2tp_class_name = None
                                                self.ipv4_source_address = None
                                                self.ipv6_source_address = None
                                                self.path_mtu_enabled = None
                                                self.path_mtu_max_value = None
                                                self.dont_fragment_bit = None
                                                self.tos_mode = None
                                                self.tos = None
                                                self.ttl = None
                                                self.local_session_id = None
                                                self.remote_session_id = None
                                                self.local_cookie_size = None
                                                self.remote_cookie_size = None
                                                self.local_cookie_low_value = None
                                                self.remote_cookie_low_value = None
                                                self.local_cookie_high_value = None
                                                self.remote_cookie_high_value = None
                                                self.remote_circuit_status_up = None
                                                self.tunnel_state = None
                                                self.local_secondary_cookie_size = None
                                                self.local_secondary_cookie_low_value = None
                                                self.local_secondary_cookie_high_value = None
                                                self._segment_path = lambda: "l2tpv3"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                    class LocalInterface(Entity):
                                        """
                                        Local interface
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters>`
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, self).__init__()

                                            self.yang_name = "local-interface"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters))])
                                            self._leafs = OrderedDict([
                                                ('name', YLeaf(YType.str, 'name')),
                                                ('mtu', YLeaf(YType.uint32, 'mtu')),
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                            ])
                                            self.name = None
                                            self.mtu = None
                                            self.payload_bytes = None

                                            self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._segment_path = lambda: "local-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "local-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.enumeration, 'type')),
                                                ])
                                                self.type = None

                                                self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"

                                                self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"

                                                self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"

                                                self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"

                                                self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"

                                                self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                                self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._segment_path = lambda: "parameters"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self._segment_path = lambda: "ethernet"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                        ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                        ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                        ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                        ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self.vlan_rewrite_tag = None
                                                    self.simple_efp = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None

                                                    self.rewrite_tag = YList(self)
                                                    self.vlan_range = YList(self)
                                                    self._segment_path = lambda: "vlan"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                                class RewriteTag(Entity):
                                                    """
                                                    Rewrite Tags
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                        self.yang_name = "rewrite-tag"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rewrite-tag"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                                        ])
                                                        self.lower = None
                                                        self.upper = None
                                                        self._segment_path = lambda: "vlan-range"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\: str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                    self._leafs = OrderedDict([
                                                        ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                        ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                        ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                    ])
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None
                                                    self.tdm_mode = None

                                                    self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._segment_path = lambda: "tdm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                            ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                            ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                            ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                            ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                            ('cas', YLeaf(YType.uint8, 'cas')),
                                                            ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                            ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                            ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                        ])
                                                        self.payload_bytes = None
                                                        self.bit_rate = None
                                                        self.rtp = None
                                                        self.timestamp_mode = None
                                                        self.signalling_packets = None
                                                        self.cas = None
                                                        self.rtp_header_payload_type = None
                                                        self.timestamp_clock_freq = None
                                                        self.ssrc = None
                                                        self._segment_path = lambda: "tdm-options"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                        ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                        ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                        ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                        ('vci', YLeaf(YType.uint16, 'vci')),
                                                    ])
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.atm_mode = None
                                                    self.vpi = None
                                                    self.vci = None
                                                    self._segment_path = lambda: "atm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                        ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                    ])
                                                    self.fr_mode = None
                                                    self.dlci = None
                                                    self._segment_path = lambda: "fr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-ether"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-iw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class RemoteInterface(Entity):
                                        """
                                        Remote interface
                                        
                                        .. attribute:: parameters
                                        
                                        	Interface parameters
                                        	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters>`
                                        
                                        .. attribute:: name
                                        
                                        	Interface name
                                        	**type**\: str
                                        
                                        	**length:** 0..81
                                        
                                        .. attribute:: mtu
                                        
                                        	Interface MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: payload_bytes
                                        
                                        	Payload bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, self).__init__()

                                            self.yang_name = "remote-interface"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters))])
                                            self._leafs = OrderedDict([
                                                ('name', YLeaf(YType.str, 'name')),
                                                ('mtu', YLeaf(YType.uint32, 'mtu')),
                                                ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                            ])
                                            self.name = None
                                            self.mtu = None
                                            self.payload_bytes = None

                                            self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters()
                                            self.parameters.parent = self
                                            self._children_name_map["parameters"] = "parameters"
                                            self._segment_path = lambda: "remote-interface"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                        class Parameters(Entity):
                                            """
                                            Interface parameters
                                            
                                            .. attribute:: ethernet
                                            
                                            	Ethernet
                                            	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                            
                                            .. attribute:: vlan
                                            
                                            	VLAN
                                            	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                            
                                            .. attribute:: tdm
                                            
                                            	TDM
                                            	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                            
                                            .. attribute:: atm
                                            
                                            	ATM
                                            	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                            
                                            .. attribute:: fr
                                            
                                            	Frame Relay
                                            	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                            
                                            .. attribute:: pseudowire_ether
                                            
                                            	PW Ether
                                            	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                            
                                            .. attribute:: pseudowire_iw
                                            
                                            	PW IW
                                            	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                            
                                            .. attribute:: type
                                            
                                            	Type
                                            	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                                self.yang_name = "parameters"
                                                self.yang_parent_name = "remote-interface"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                                self._leafs = OrderedDict([
                                                    ('type', YLeaf(YType.enumeration, 'type')),
                                                ])
                                                self.type = None

                                                self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                                self.ethernet.parent = self
                                                self._children_name_map["ethernet"] = "ethernet"

                                                self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                                self.vlan.parent = self
                                                self._children_name_map["vlan"] = "vlan"

                                                self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                                self.tdm.parent = self
                                                self._children_name_map["tdm"] = "tdm"

                                                self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm()
                                                self.atm.parent = self
                                                self._children_name_map["atm"] = "atm"

                                                self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr()
                                                self.fr.parent = self
                                                self._children_name_map["fr"] = "fr"

                                                self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                                self.pseudowire_ether.parent = self
                                                self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                                self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                                self.pseudowire_iw.parent = self
                                                self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                                self._segment_path = lambda: "parameters"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                            class Ethernet(Entity):
                                                """
                                                Ethernet
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                    self.yang_name = "ethernet"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self._segment_path = lambda: "ethernet"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                            class Vlan(Entity):
                                                """
                                                VLAN
                                                
                                                .. attribute:: xconnect_tags
                                                
                                                	XConnect tags
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: vlan_rewrite_tag
                                                
                                                	VLAN rewrite tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: simple_efp
                                                
                                                	Simple EFP
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: encapsulation_type
                                                
                                                	Encapsulation Type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: outer_tag
                                                
                                                	Outer Tag
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: rewrite_tag
                                                
                                                	Rewrite Tags
                                                	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                                
                                                .. attribute:: vlan_range
                                                
                                                	vlan range
                                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                    self.yang_name = "vlan"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                    self._leafs = OrderedDict([
                                                        ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                        ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                        ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                        ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                        ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                    ])
                                                    self.xconnect_tags = None
                                                    self.vlan_rewrite_tag = None
                                                    self.simple_efp = None
                                                    self.encapsulation_type = None
                                                    self.outer_tag = None

                                                    self.rewrite_tag = YList(self)
                                                    self.vlan_range = YList(self)
                                                    self._segment_path = lambda: "vlan"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                                class RewriteTag(Entity):
                                                    """
                                                    Rewrite Tags
                                                    
                                                    .. attribute:: entry
                                                    
                                                    	
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                        self.yang_name = "rewrite-tag"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                                        ])
                                                        self.entry = None
                                                        self._segment_path = lambda: "rewrite-tag"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                                class VlanRange(Entity):
                                                    """
                                                    vlan range
                                                    
                                                    .. attribute:: lower
                                                    
                                                    	Lower
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: upper
                                                    
                                                    	Upper
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                        self.yang_name = "vlan-range"
                                                        self.yang_parent_name = "vlan"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                                        ])
                                                        self.lower = None
                                                        self.upper = None
                                                        self._segment_path = lambda: "vlan-range"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                            class Tdm(Entity):
                                                """
                                                TDM
                                                
                                                .. attribute:: tdm_options
                                                
                                                	TDM options
                                                	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                                
                                                .. attribute:: timeslot_group
                                                
                                                	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                                	**type**\: str
                                                
                                                .. attribute:: timeslot_rate
                                                
                                                	Timeslot rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: tdm_mode
                                                
                                                	TDM mode
                                                	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                    self.yang_name = "tdm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                    self._leafs = OrderedDict([
                                                        ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                        ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                        ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                    ])
                                                    self.timeslot_group = None
                                                    self.timeslot_rate = None
                                                    self.tdm_mode = None

                                                    self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                    self.tdm_options.parent = self
                                                    self._children_name_map["tdm_options"] = "tdm-options"
                                                    self._segment_path = lambda: "tdm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                                class TdmOptions(Entity):
                                                    """
                                                    TDM options
                                                    
                                                    .. attribute:: payload_bytes
                                                    
                                                    	TDM payload bytes
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    	**units**\: byte
                                                    
                                                    .. attribute:: bit_rate
                                                    
                                                    	TDM bit rate in units of Kbps
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    	**units**\: kbit/s
                                                    
                                                    .. attribute:: rtp
                                                    
                                                    	RTP header
                                                    	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                    
                                                    .. attribute:: timestamp_mode
                                                    
                                                    	TDM Timestamping mode
                                                    	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                    
                                                    .. attribute:: signalling_packets
                                                    
                                                    	Signalling packets
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: cas
                                                    
                                                    	CAS
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: rtp_header_payload_type
                                                    
                                                    	RTP header payload type
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..255
                                                    
                                                    .. attribute:: timestamp_clock_freq
                                                    
                                                    	Timestamping clock frequency in units of 8Khz
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..65535
                                                    
                                                    .. attribute:: ssrc
                                                    
                                                    	Synchronization Source identifier
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                        self.yang_name = "tdm-options"
                                                        self.yang_parent_name = "tdm"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                            ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                            ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                            ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                            ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                            ('cas', YLeaf(YType.uint8, 'cas')),
                                                            ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                            ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                            ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                        ])
                                                        self.payload_bytes = None
                                                        self.bit_rate = None
                                                        self.rtp = None
                                                        self.timestamp_mode = None
                                                        self.signalling_packets = None
                                                        self.cas = None
                                                        self.rtp_header_payload_type = None
                                                        self.timestamp_clock_freq = None
                                                        self.ssrc = None
                                                        self._segment_path = lambda: "tdm-options"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                            class Atm(Entity):
                                                """
                                                ATM
                                                
                                                .. attribute:: maximum_number_cells_packed
                                                
                                                	Max number of cells packed
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: maximum_number_cells_un_packed
                                                
                                                	Max number of cells unpacked
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: atm_mode
                                                
                                                	ATM mode
                                                	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                                
                                                .. attribute:: vpi
                                                
                                                	Virtual path identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vci
                                                
                                                	Virtual channel identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                    self.yang_name = "atm"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                        ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                        ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                        ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                        ('vci', YLeaf(YType.uint16, 'vci')),
                                                    ])
                                                    self.maximum_number_cells_packed = None
                                                    self.maximum_number_cells_un_packed = None
                                                    self.atm_mode = None
                                                    self.vpi = None
                                                    self.vci = None
                                                    self._segment_path = lambda: "atm"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                            class Fr(Entity):
                                                """
                                                Frame Relay
                                                
                                                .. attribute:: fr_mode
                                                
                                                	Frame Relay mode
                                                	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                                
                                                .. attribute:: dlci
                                                
                                                	Data\-link connection identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                    self.yang_name = "fr"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                        ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                    ])
                                                    self.fr_mode = None
                                                    self.dlci = None
                                                    self._segment_path = lambda: "fr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                            class PseudowireEther(Entity):
                                                """
                                                PW Ether
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                    self.yang_name = "pseudowire-ether"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-ether"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-ether"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                            class PseudowireIw(Entity):
                                                """
                                                PW IW
                                                
                                                .. attribute:: interface_list
                                                
                                                	Interface list data
                                                	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                                
                                                .. attribute:: is_valid
                                                
                                                	Is this Interface list valid
                                                	**type**\: bool
                                                
                                                .. attribute:: internal_label
                                                
                                                	Internal Label
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                    self.yang_name = "pseudowire-iw"
                                                    self.yang_parent_name = "parameters"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                    self._leafs = OrderedDict([
                                                        ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                    ])
                                                    self.is_valid = None
                                                    self.internal_label = None

                                                    self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                    self.interface_list.parent = self
                                                    self._children_name_map["interface_list"] = "interface-list"
                                                    self._segment_path = lambda: "pseudowire-iw"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                                class InterfaceList(Entity):
                                                    """
                                                    Interface list data
                                                    
                                                    .. attribute:: interface_list_name
                                                    
                                                    	Interface\-list name
                                                    	**type**\: str
                                                    
                                                    	**length:** 0..33
                                                    
                                                    .. attribute:: interface_list_id
                                                    
                                                    	Interface internal ID
                                                    	**type**\: int
                                                    
                                                    	**range:** 0..4294967295
                                                    
                                                    .. attribute:: interface
                                                    
                                                    	Interfaces
                                                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                        self.yang_name = "interface-list"
                                                        self.yang_parent_name = "pseudowire-iw"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                        self._leafs = OrderedDict([
                                                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                        ])
                                                        self.interface_list_name = None
                                                        self.interface_list_id = None

                                                        self.interface = YList(self)
                                                        self._segment_path = lambda: "interface-list"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                    class Interface(Entity):
                                                        """
                                                        Interfaces
                                                        
                                                        .. attribute:: interface_name
                                                        
                                                        	Interface name
                                                        	**type**\: str
                                                        
                                                        .. attribute:: replicate_status
                                                        
                                                        	Replicate status
                                                        	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                        
                                                        

                                                        """

                                                        _prefix = 'l2vpn-oper'
                                                        _revision = '2017-09-07'

                                                        def __init__(self):
                                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                            self.yang_name = "interface"
                                                            self.yang_parent_name = "interface-list"
                                                            self.is_top_level_class = False
                                                            self.has_list_ancestor = True
                                                            self.ylist_key_names = []
                                                            self._child_classes = OrderedDict([])
                                                            self._leafs = OrderedDict([
                                                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                                ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                            ])
                                                            self.interface_name = None
                                                            self.replicate_status = None
                                                            self._segment_path = lambda: "interface"

                                                        def __setattr__(self, name, value):
                                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PreferredPath(Entity):
                                        """
                                        MPLS Preferred Path
                                        
                                        .. attribute:: srte_policy
                                        
                                        	srte policy
                                        	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy>`
                                        
                                        .. attribute:: option
                                        
                                        	Option
                                        	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	NextHopIP
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: te_tunnel_interface_number
                                        
                                        	TETunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: ip_tunnel_interface_number
                                        
                                        	IPTunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tp_tunnel_interface_number
                                        
                                        	TPTunnelInterfaceNumber
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, self).__init__()

                                            self.yang_name = "preferred-path"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy))])
                                            self._leafs = OrderedDict([
                                                ('option', YLeaf(YType.enumeration, 'option')),
                                                ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                                ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                                ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                                ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                            ])
                                            self.option = None
                                            self.next_hop_ip = None
                                            self.te_tunnel_interface_number = None
                                            self.ip_tunnel_interface_number = None
                                            self.tp_tunnel_interface_number = None

                                            self.srte_policy = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy()
                                            self.srte_policy.parent = self
                                            self._children_name_map["srte_policy"] = "srte-policy"
                                            self._segment_path = lambda: "preferred-path"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                        class SrtePolicy(Entity):
                                            """
                                            srte policy
                                            
                                            .. attribute:: policy_name
                                            
                                            	SR TE Policy Name
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                                self.yang_name = "srte-policy"
                                                self.yang_parent_name = "preferred-path"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('policy_name', YLeaf(YType.str, 'policy-name')),
                                                ])
                                                self.policy_name = None
                                                self._segment_path = lambda: "srte-policy"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                    class LocalSignalling(Entity):
                                        """
                                        Local signalling
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv>`
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, self).__init__()

                                            self.yang_name = "local-signalling"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv))])
                                            self._leafs = OrderedDict([
                                                ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                            ])
                                            self.pw_status = None

                                            self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "local-signalling"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "local-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "status-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "local-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class RemoteSignalling(Entity):
                                        """
                                        Remote signalling
                                        
                                        .. attribute:: status_tlv
                                        
                                        	PW Status Switching TLV
                                        	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv>`
                                        
                                        .. attribute:: pw_status
                                        
                                        	PW Status
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: tlv
                                        
                                        	Switching TLV info
                                        	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, self).__init__()

                                            self.yang_name = "remote-signalling"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv))])
                                            self._leafs = OrderedDict([
                                                ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                            ])
                                            self.pw_status = None

                                            self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv()
                                            self.status_tlv.parent = self
                                            self._children_name_map["status_tlv"] = "status-tlv"

                                            self.tlv = YList(self)
                                            self._segment_path = lambda: "remote-signalling"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                        class StatusTlv(Entity):
                                            """
                                            PW Status Switching TLV
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                                self.yang_name = "status-tlv"
                                                self.yang_parent_name = "remote-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "status-tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                        class Tlv(Entity):
                                            """
                                            Switching TLV info
                                            
                                            .. attribute:: pw_id
                                            
                                            	PW ID of last PW segment traversed
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: local_address
                                            
                                            	Local IP Address of PW Switching Point
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: remote_address
                                            
                                            	Remote IP Address of Last PW Switching Point traversed
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: description
                                            
                                            	PW Switching Point description
                                            	**type**\: str
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                                self.yang_name = "tlv"
                                                self.yang_parent_name = "remote-signalling"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                    ('local_address', YLeaf(YType.str, 'local-address')),
                                                    ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                    ('description', YLeaf(YType.str, 'description')),
                                                ])
                                                self.pw_id = None
                                                self.local_address = None
                                                self.remote_address = None
                                                self.description = None
                                                self._segment_path = lambda: "tlv"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber))])
                                            self._leafs = OrderedDict()

                                            self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"

                                            self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                            self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._segment_path = lambda: "statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics, [], name, value)


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                                self._leafs = OrderedDict()

                                                self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"

                                                self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                                self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                                self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                                self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"

                                                self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._segment_path = lambda: "impostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "impostion-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class L2fsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "l2fsbi-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unknown-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                                self._leafs = OrderedDict()

                                                self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"

                                                self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                                self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                                self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"

                                                self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"

                                                self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                                self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"

                                                self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"

                                                self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                                self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                                self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._segment_path = lambda: "dispostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "received-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "dai-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "ipsg-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-oo-o-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionP2mpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-p2mp-stats"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "mac-move"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                    ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                    ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                    ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                                ])
                                                self.sequence_number_sent = None
                                                self.sequence_number_expected = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self._segment_path = lambda: "sequence-number"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                    class P2mpPw(Entity):
                                        """
                                        P2MP Pseudowire Information
                                        
                                        .. attribute:: local_available
                                        
                                        	Local LSM info available
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ptree_type
                                        
                                        	Local P\-Tree Type
                                        	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                        
                                        .. attribute:: local_tunnel_id
                                        
                                        	Local Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_extended_tunnel_id
                                        
                                        	Local Extended Tunnel ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_p2mp_id
                                        
                                        	Local P2MP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_flags
                                        
                                        	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_available
                                        
                                        	Remote LSM info available
                                        	**type**\: bool
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ptree_type
                                        
                                        	Remote P\-Tree Type
                                        	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                        
                                        .. attribute:: remote_tunnel_id
                                        
                                        	Remote Tunnel ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_extended_tunnel_id
                                        
                                        	Remote Extended Tunnel ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_p2mp_id
                                        
                                        	Remote P2MP ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_flags
                                        
                                        	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, self).__init__()

                                            self.yang_name = "p2mp-pw"
                                            self.yang_parent_name = "pseudowire"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('local_available', YLeaf(YType.boolean, 'local-available')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                                ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                                ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                                ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                                ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                                ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                                ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                                ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                                ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                                ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                            ])
                                            self.local_available = None
                                            self.local_label = None
                                            self.local_ptree_type = None
                                            self.local_tunnel_id = None
                                            self.local_extended_tunnel_id = None
                                            self.local_p2mp_id = None
                                            self.local_flags = None
                                            self.remote_available = None
                                            self.remote_label = None
                                            self.remote_ptree_type = None
                                            self.remote_tunnel_id = None
                                            self.remote_extended_tunnel_id = None
                                            self.remote_p2mp_id = None
                                            self.remote_flags = None
                                            self._segment_path = lambda: "p2mp-pw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StaticMac(Entity):
                                    """
                                    Static MAC addresses
                                    
                                    .. attribute:: address
                                    
                                    	MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: bmac
                                    
                                    	Backbone MAC address
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	Next Hop IP
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, self).__init__()

                                        self.yang_name = "static-mac"
                                        self.yang_parent_name = "bridge-pw"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('address', YLeaf(YType.str, 'address')),
                                            ('bmac', YLeaf(YType.str, 'bmac')),
                                            ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                        ])
                                        self.address = None
                                        self.bmac = None
                                        self.next_hop_ip = None
                                        self._segment_path = lambda: "static-mac"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeCoreVfiTable.BridgePws.BridgePw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeAcs(Entity):
                        """
                        Bridge Domain Attachment Circuit Table
                        
                        .. attribute:: bridge_ac
                        
                        	Bridge Domain Attachment Circuit
                        	**type**\: list of  		 :py:class:`BridgeAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs, self).__init__()

                            self.yang_name = "bridge-acs"
                            self.yang_parent_name = "bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-ac", ("bridge_ac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc))])
                            self._leafs = OrderedDict()

                            self.bridge_ac = YList(self)
                            self._segment_path = lambda: "bridge-acs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs, [], name, value)


                        class BridgeAc(Entity):
                            """
                            Bridge Domain Attachment Circuit
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit
                            
                            	Attachment Circuit
                            	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters>`
                            
                            .. attribute:: bvi_mac_index
                            
                            	MyMac Index
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac>`
                            
                            .. attribute:: bvimac
                            
                            	BVI MAC addresses
                            	**type**\: list of  		 :py:class:`Bvimac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, self).__init__()

                                self.yang_name = "bridge-ac"
                                self.yang_parent_name = "bridge-acs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit)), ("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac)), ("bvimac", ("bvimac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                    ('bvi_mac_index', YLeaf(YType.uint16, 'bvi-mac-index')),
                                ])
                                self.interface_name = None
                                self.bvi_mac_index = None

                                self.attachment_circuit = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"

                                self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self.bvimac = YList(self)
                                self._segment_path = lambda: "bridge-ac" + "[interface-name='" + str(self.interface_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc, ['interface_name', 'bvi_mac_index'], name, value)


                            class AttachmentCircuit(Entity):
                                """
                                Attachment Circuit
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection>`
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\: str
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\: str
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\: str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\: bool
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\: bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\: bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\: str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\: bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, self).__init__()

                                    self.yang_name = "attachment-circuit"
                                    self.yang_parent_name = "bridge-ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection))])
                                    self._leafs = OrderedDict([
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('msti', YLeaf(YType.str, 'msti')),
                                        ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                        ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                        ('node_id', YLeaf(YType.str, 'node-id')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                        ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                        ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                        ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                        ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                        ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                        ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                        ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                        ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                        ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ])
                                    self.state = None
                                    self.msti = None
                                    self.internal_ms_ti = None
                                    self.interface_handle = None
                                    self.node_id = None
                                    self.xconnect_id = None
                                    self.ms_ti_mismatch = None
                                    self.mtu_mismatched = None
                                    self.tdm_media_mismatched = None
                                    self.bvi_mac_conflict = None
                                    self.bvi_no_port_up = None
                                    self.control_word_mismatched = None
                                    self.encapsulation_mismatched = None
                                    self.encapsulation_error = None
                                    self.interworking = None
                                    self.out_of_memory_state = None
                                    self.msti_mismatch_down = None
                                    self.mac_limit_oper_down = None
                                    self.redundancy_group_id = None
                                    self.redundancy_group_state = None
                                    self.redundancy_object_id = None
                                    self.is_ac_partially_programmed = None
                                    self.evpn_internal_label = None

                                    self.interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"

                                    self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.l2vpn_protection = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    self._segment_path = lambda: "attachment-circuit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                                class Interface(Entity):
                                    """
                                    Interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface_(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface_(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class L2vpnProtection(Entity):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\: str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\: str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                        self.yang_name = "l2vpn-protection"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                            ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                            ('protection_name', YLeaf(YType.str, 'protection-name')),
                                            ('protected_name', YLeaf(YType.str, 'protected-name')),
                                            ('active', YLeaf(YType.boolean, 'active')),
                                        ])
                                        self.protection_type = None
                                        self.protection_configured = None
                                        self.protection_name = None
                                        self.protected_name = None
                                        self.active = None
                                        self._segment_path = lambda: "l2vpn-protection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                            class Bvimac(Entity):
                                """
                                BVI MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, self).__init__()

                                    self.yang_name = "bvimac"
                                    self.yang_parent_name = "bridge-ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "bvimac"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAcs.BridgeAc.Bvimac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeAccessPws(Entity):
                        """
                        Bridge Domain Access Pseudowire Table
                        
                        .. attribute:: bridge_access_pw
                        
                        	Bridge Domain Access Pseudowire
                        	**type**\: list of  		 :py:class:`BridgeAccessPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws, self).__init__()

                            self.yang_name = "bridge-access-pws"
                            self.yang_parent_name = "bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("bridge-access-pw", ("bridge_access_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw))])
                            self._leafs = OrderedDict()

                            self.bridge_access_pw = YList(self)
                            self._segment_path = lambda: "bridge-access-pws"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws, [], name, value)


                        class BridgeAccessPw(Entity):
                            """
                            Bridge Domain Access Pseudowire
                            
                            .. attribute:: neighbor
                            
                            	Neighbor IPv4 address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pw_type
                            
                            	PW Type
                            	**type**\:  :py:class:`L2vpnpw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnpw>`
                            
                            .. attribute:: pseudowire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 1..4294967295
                            
                            .. attribute:: ve_id_vpls_id_0_3
                            
                            	Zero or concatenation of local and remote VE\-ID or first 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vpls_id_4_7
                            
                            	Zero or Last 4 bytes of VPLS\-ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pseudowire
                            
                            	Pseudowire
                            	**type**\:  :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire>`
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters>`
                            
                            .. attribute:: is_access
                            
                            	Is Access PW
                            	**type**\: bool
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, self).__init__()

                                self.yang_name = "bridge-access-pw"
                                self.yang_parent_name = "bridge-access-pws"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire)), ("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters)), ("static-mac", ("static_mac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('neighbor', YLeaf(YType.str, 'neighbor')),
                                    ('pw_type', YLeaf(YType.enumeration, 'pw-type')),
                                    ('pseudowire_id', YLeaf(YType.uint32, 'pseudowire-id')),
                                    ('ve_id_vpls_id_0_3', YLeaf(YType.uint32, 've-id-vpls-id-0-3')),
                                    ('vpls_id_4_7', YLeaf(YType.uint32, 'vpls-id-4-7')),
                                    ('is_access', YLeaf(YType.boolean, 'is-access')),
                                ])
                                self.neighbor = None
                                self.pw_type = None
                                self.pseudowire_id = None
                                self.ve_id_vpls_id_0_3 = None
                                self.vpls_id_4_7 = None
                                self.is_access = None

                                self.pseudowire = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire()
                                self.pseudowire.parent = self
                                self._children_name_map["pseudowire"] = "pseudowire"

                                self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "bridge-access-pw"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw, ['neighbor', 'pw_type', 'pseudowire_id', 've_id_vpls_id_0_3', 'vpls_id_4_7', 'is_access'], name, value)


                            class Pseudowire(Entity):
                                """
                                Pseudowire
                                
                                .. attribute:: peer_id
                                
                                	Peer
                                	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId>`
                                
                                .. attribute:: encapsulation_info
                                
                                	Encapsulation specific pseudowire information
                                	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo>`
                                
                                .. attribute:: local_interface
                                
                                	Local interface
                                	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface>`
                                
                                .. attribute:: remote_interface
                                
                                	Remote interface
                                	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface>`
                                
                                .. attribute:: preferred_path
                                
                                	MPLS Preferred Path
                                	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath>`
                                
                                .. attribute:: local_signalling
                                
                                	Local signalling
                                	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling>`
                                
                                .. attribute:: remote_signalling
                                
                                	Remote signalling
                                	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics>`
                                
                                .. attribute:: p2mp_pw
                                
                                	P2MP Pseudowire Information
                                	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw>`
                                
                                .. attribute:: local_source_address
                                
                                	Local Source Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_local_source_address
                                
                                	Local IPv6 Source Address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: pseudo_wire_id
                                
                                	Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_pwr_type
                                
                                	is Pseudowire\-routed
                                	**type**\: bool
                                
                                .. attribute:: is_evpn_vpws_type
                                
                                	is EVPN VPWS
                                	**type**\: bool
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: pseudo_wire_state
                                
                                	Pseudowire state
                                	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                                
                                .. attribute:: protocol
                                
                                	Protocol
                                	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                                
                                .. attribute:: pw_class_name
                                
                                	Pseudowire class name
                                	**type**\: str
                                
                                	**length:** 0..33
                                
                                .. attribute:: tag_rewrite
                                
                                	StaticTagRewrite
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: fe_ctype
                                
                                	Pseudowire FEC type
                                	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                                
                                .. attribute:: evpn_src_acid
                                
                                	EVPN VPWS Source AC ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: sequencing_type
                                
                                	Sequencing Type
                                	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                                
                                .. attribute:: resync_enabled
                                
                                	Resync if packets out of sequence
                                	**type**\: bool
                                
                                .. attribute:: resync_threshold
                                
                                	Number of Packets Out of Seqence to trigger resync
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_control_word
                                
                                	Local control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: remote_control_word
                                
                                	Remote control word
                                	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                                
                                .. attribute:: local_pseudo_wire_type
                                
                                	Local pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: remote_pseudo_wire_type
                                
                                	Remote pseudowire type
                                	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                                
                                .. attribute:: imposed_vlan_id
                                
                                	Imposed vlan id
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: time_created
                                
                                	Time when the pseudowire was created
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_creation
                                
                                	Time elapsed since creation
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_changed
                                
                                	Last time the pseudowire status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_changed
                                
                                	Time elapsed since status changed
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: last_time_status_down
                                
                                	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                                	**type**\: str
                                
                                	**length:** 0..50
                                
                                .. attribute:: time_elapsed_status_down
                                
                                	Time elapsed since last status down in seconds
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                	**units**\: second
                                
                                .. attribute:: shutdown
                                
                                	Shutdown
                                	**type**\: bool
                                
                                .. attribute:: data_path_down
                                
                                	True if LSP down
                                	**type**\: bool
                                
                                .. attribute:: use_tunnel_path
                                
                                	True if using TE tunnel
                                	**type**\: bool
                                
                                .. attribute:: odn_configured
                                
                                	True if ODN is configured
                                	**type**\: bool
                                
                                .. attribute:: pseudo_wire_type_mismatched
                                
                                	Pseudowire type mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_bytes_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: bitrate_mismatched
                                
                                	Bitrate mismatched
                                	**type**\: bool
                                
                                .. attribute:: rtp_mismatched
                                
                                	RTP mismatched
                                	**type**\: bool
                                
                                .. attribute:: diff_ts_mismatched
                                
                                	Differential timestamp mismatched
                                	**type**\: bool
                                
                                .. attribute:: sig_pkts_mismatched
                                
                                	Signalling packets mismatched
                                	**type**\: bool
                                
                                .. attribute:: cas_mismatched
                                
                                	CAS mismatched
                                	**type**\: bool
                                
                                .. attribute:: payload_type_mismatched
                                
                                	Payload bytes mismatched
                                	**type**\: bool
                                
                                .. attribute:: freq_mismatched
                                
                                	Frequency mismatched
                                	**type**\: bool
                                
                                .. attribute:: ssrc_mismatched
                                
                                	SSRC mismatched
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: illegal_control_word
                                
                                	Illegal control word
                                	**type**\: bool
                                
                                .. attribute:: ad_remote_down
                                
                                	Auto\-Discovered PW remote state down
                                	**type**\: bool
                                
                                .. attribute:: not_supported_qinq
                                
                                	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                                	**type**\: bool
                                
                                .. attribute:: local_label_failed
                                
                                	Failed to set BGP advertised local label
                                	**type**\: bool
                                
                                .. attribute:: remote_label_failed
                                
                                	Failed to set BGP advertised remote label
                                	**type**\: bool
                                
                                .. attribute:: preferred_path_disable_fallback
                                
                                	Prefpath fallback enable/disable
                                	**type**\: bool
                                
                                .. attribute:: backup_pw
                                
                                	TRUE if PW is a backup PW
                                	**type**\: bool
                                
                                .. attribute:: primary_pw
                                
                                	TRUE if PW is a primary PW
                                	**type**\: bool
                                
                                .. attribute:: backup_active
                                
                                	TRUE if backup is active
                                	**type**\: bool
                                
                                .. attribute:: backup_force_active
                                
                                	TRUE if backup is active due to switchover
                                	**type**\: bool
                                
                                .. attribute:: disable_never
                                
                                	TRUE if backup is not automatically disabled
                                	**type**\: bool
                                
                                .. attribute:: disable_delay
                                
                                	Backup disable delay
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: primary_peer_id
                                
                                	Primary Peer IP address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: primary_pseudo_wire_id
                                
                                	Primary Pseudowire ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: number_ma_cwithdraw_message_sent
                                
                                	Num MW messages sent over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: num_ma_cwithdraw_msg_received
                                
                                	Num MW messages received over PW
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: transport_lsp_down
                                
                                	Oper down due to Transport LSP down
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: pw_status_use
                                
                                	PW status in use
                                	**type**\: bool
                                
                                .. attribute:: auto_discovery
                                
                                	Is autodiscovery
                                	**type**\: bool
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: pwlsd_rewrite_failed
                                
                                	LSD rewrite failed
                                	**type**\: bool
                                
                                .. attribute:: ldp_label_advertise_failed
                                
                                	LDP label advertisment failed
                                	**type**\: bool
                                
                                .. attribute:: is_vfi
                                
                                	Is VFI interface
                                	**type**\: bool
                                
                                .. attribute:: is_multi_segment_pseudowire
                                
                                	Is Multi\-Segment Pseudowire
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_one_way
                                
                                	Force one\-way PW redundancy behaviour in Redundancy Group
                                	**type**\: bool
                                
                                .. attribute:: load_balance
                                
                                	Load Balance Type
                                	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                                
                                .. attribute:: pw_flow_label_type
                                
                                	Negotiated pseudowire flow label type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_type_cfg
                                
                                	Configured pseudowire flow label Type
                                	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                                
                                .. attribute:: pw_flow_label_code17_disabled
                                
                                	Disable sending Code 17 TLV
                                	**type**\: bool
                                
                                .. attribute:: is_flow_label_static
                                
                                	is flow label static
                                	**type**\: bool
                                
                                .. attribute:: is_partially_programmed
                                
                                	Is Pseudowire partially programmed
                                	**type**\: bool
                                
                                .. attribute:: pw_redundancy_initial_delay
                                
                                	Initial delay for redundant PW in seconds
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                	**units**\: second
                                
                                .. attribute:: bridge_pw_type_mismatch
                                
                                	Oper down because Bridge has mismatched PW Types
                                	**type**\: bool
                                
                                .. attribute:: required_bw
                                
                                	Required Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: admited_bw
                                
                                	Admited Bandwidth
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: forward_class
                                
                                	Forward Class attribute
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: table_policy_name
                                
                                	Table\-policy Name
                                	**type**\: str
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, self).__init__()

                                    self.yang_name = "pseudowire"
                                    self.yang_parent_name = "bridge-access-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw))])
                                    self._leafs = OrderedDict([
                                        ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                        ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                        ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                        ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                        ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                        ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                        ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                        ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                        ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                        ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                        ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                        ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                        ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                        ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                        ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                        ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                        ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                        ('time_created', YLeaf(YType.str, 'time-created')),
                                        ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                        ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                        ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                        ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                        ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                        ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                        ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                        ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                        ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                        ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                        ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                        ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                        ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                        ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                        ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                        ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                        ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                        ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                        ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                        ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                        ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                        ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                        ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                        ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                        ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                        ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                        ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                        ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                        ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                        ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                        ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                        ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                        ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                        ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                        ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                        ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                        ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                        ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                        ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                        ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                        ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                        ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                        ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                        ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                        ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                        ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                        ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                        ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                        ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                        ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                        ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                    ])
                                    self.local_source_address = None
                                    self.ipv6_local_source_address = None
                                    self.pseudo_wire_id = None
                                    self.is_pwr_type = None
                                    self.is_evpn_vpws_type = None
                                    self.xconnect_id = None
                                    self.state = None
                                    self.pseudo_wire_state = None
                                    self.protocol = None
                                    self.pw_class_name = None
                                    self.tag_rewrite = None
                                    self.interworking = None
                                    self.fe_ctype = None
                                    self.evpn_src_acid = None
                                    self.sequencing_type = None
                                    self.resync_enabled = None
                                    self.resync_threshold = None
                                    self.local_control_word = None
                                    self.remote_control_word = None
                                    self.local_pseudo_wire_type = None
                                    self.remote_pseudo_wire_type = None
                                    self.imposed_vlan_id = None
                                    self.time_created = None
                                    self.time_elapsed_creation = None
                                    self.last_time_status_changed = None
                                    self.time_elapsed_status_changed = None
                                    self.last_time_status_down = None
                                    self.time_elapsed_status_down = None
                                    self.shutdown = None
                                    self.data_path_down = None
                                    self.use_tunnel_path = None
                                    self.odn_configured = None
                                    self.pseudo_wire_type_mismatched = None
                                    self.payload_bytes_mismatched = None
                                    self.bitrate_mismatched = None
                                    self.rtp_mismatched = None
                                    self.diff_ts_mismatched = None
                                    self.sig_pkts_mismatched = None
                                    self.cas_mismatched = None
                                    self.payload_type_mismatched = None
                                    self.freq_mismatched = None
                                    self.ssrc_mismatched = None
                                    self.mtu_mismatched = None
                                    self.illegal_control_word = None
                                    self.ad_remote_down = None
                                    self.not_supported_qinq = None
                                    self.local_label_failed = None
                                    self.remote_label_failed = None
                                    self.preferred_path_disable_fallback = None
                                    self.backup_pw = None
                                    self.primary_pw = None
                                    self.backup_active = None
                                    self.backup_force_active = None
                                    self.disable_never = None
                                    self.disable_delay = None
                                    self.primary_peer_id = None
                                    self.primary_pseudo_wire_id = None
                                    self.number_ma_cwithdraw_message_sent = None
                                    self.num_ma_cwithdraw_msg_received = None
                                    self.out_of_memory_state = None
                                    self.transport_lsp_down = None
                                    self.mac_limit_oper_down = None
                                    self.pw_status_use = None
                                    self.auto_discovery = None
                                    self.ad_method = None
                                    self.pwlsd_rewrite_failed = None
                                    self.ldp_label_advertise_failed = None
                                    self.is_vfi = None
                                    self.is_multi_segment_pseudowire = None
                                    self.pw_redundancy_one_way = None
                                    self.load_balance = None
                                    self.pw_flow_label_type = None
                                    self.pw_flow_label_type_cfg = None
                                    self.pw_flow_label_code17_disabled = None
                                    self.is_flow_label_static = None
                                    self.is_partially_programmed = None
                                    self.pw_redundancy_initial_delay = None
                                    self.bridge_pw_type_mismatch = None
                                    self.required_bw = None
                                    self.admited_bw = None
                                    self.forward_class = None
                                    self.table_policy_name = None

                                    self.peer_id = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId()
                                    self.peer_id.parent = self
                                    self._children_name_map["peer_id"] = "peer-id"

                                    self.encapsulation_info = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo()
                                    self.encapsulation_info.parent = self
                                    self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                    self.local_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface()
                                    self.local_interface.parent = self
                                    self._children_name_map["local_interface"] = "local-interface"

                                    self.remote_interface = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface()
                                    self.remote_interface.parent = self
                                    self._children_name_map["remote_interface"] = "remote-interface"

                                    self.preferred_path = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath()
                                    self.preferred_path.parent = self
                                    self._children_name_map["preferred_path"] = "preferred-path"

                                    self.local_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling()
                                    self.local_signalling.parent = self
                                    self._children_name_map["local_signalling"] = "local-signalling"

                                    self.remote_signalling = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling()
                                    self.remote_signalling.parent = self
                                    self._children_name_map["remote_signalling"] = "remote-signalling"

                                    self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.p2mp_pw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw()
                                    self.p2mp_pw.parent = self
                                    self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                    self._segment_path = lambda: "pseudowire"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                                class PeerId(Entity):
                                    """
                                    Peer
                                    
                                    .. attribute:: type
                                    
                                    	type
                                    	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                    
                                    .. attribute:: ipv4_peer_id
                                    
                                    	Peer IPv4 address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_peer_id
                                    
                                    	Peer IPv6 address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: internal_label
                                    
                                    	Internal Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, self).__init__()

                                        self.yang_name = "peer-id"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                            ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                            ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                            ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                        ])
                                        self.type = None
                                        self.ipv4_peer_id = None
                                        self.ipv6_peer_id = None
                                        self.internal_label = None
                                        self._segment_path = lambda: "peer-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                                class EncapsulationInfo(Entity):
                                    """
                                    Encapsulation specific pseudowire information
                                    
                                    .. attribute:: atom
                                    
                                    	atom
                                    	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom>`
                                    
                                    .. attribute:: l2tpv3
                                    
                                    	l2tpv3
                                    	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3>`
                                    
                                    .. attribute:: encapsulation
                                    
                                    	Encapsulation
                                    	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, self).__init__()

                                        self.yang_name = "encapsulation-info"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3))])
                                        self._leafs = OrderedDict([
                                            ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                        ])
                                        self.encapsulation = None

                                        self.atom = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom()
                                        self.atom.parent = self
                                        self._children_name_map["atom"] = "atom"

                                        self.l2tpv3 = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3()
                                        self.l2tpv3.parent = self
                                        self._children_name_map["l2tpv3"] = "l2tpv3"
                                        self._segment_path = lambda: "encapsulation-info"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                    class Atom(Entity):
                                        """
                                        atom
                                        
                                        .. attribute:: local_agi
                                        
                                        	Local Attachment Group Identifier
                                        	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                        
                                        .. attribute:: remote_agi
                                        
                                        	Remote Attachment Group Identifier
                                        	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                        
                                        .. attribute:: multi_segment_pseudowire_stats
                                        
                                        	Multisegment pseudowire statistics
                                        	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                        
                                        .. attribute:: is_pseudowire_headend
                                        
                                        	Is this connected to a PW\-HE AC
                                        	**type**\: bool
                                        
                                        .. attribute:: local_label
                                        
                                        	Local label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_label
                                        
                                        	Remote label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_group_id
                                        
                                        	Local group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_group_id
                                        
                                        	Remote group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cv_type
                                        
                                        	Local VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_c_ctype
                                        
                                        	Local VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cv_type
                                        
                                        	Remote VCCV CV type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_c_ctype
                                        
                                        	Remote VCCV CC type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_veid
                                        
                                        	Local VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_veid
                                        
                                        	Remote VE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_ceid
                                        
                                        	Local CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_ceid
                                        
                                        	Remote CE ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: source_address
                                        
                                        	Local BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_source_address
                                        
                                        	Remote BGP source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: local_ldp_id
                                        
                                        	Local LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_ldp_id
                                        
                                        	Remote LDP ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: saii
                                        
                                        	Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: taii
                                        
                                        	Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: is_sai_itype2
                                        
                                        	Is SAII FEC129 Type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_saii_gbl_id
                                        
                                        	Local SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_saiiac_id
                                        
                                        	Local SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_tai_itype2
                                        
                                        	Is TAII type 2
                                        	**type**\: bool
                                        
                                        .. attribute:: local_taii_gbl_id
                                        
                                        	Local TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_taiiac_id
                                        
                                        	Local TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii_gbl_id
                                        
                                        	Remote SAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saiiac_id
                                        
                                        	Remote SAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taii_gbl_id
                                        
                                        	Remote TAII Global ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_taiiac_id
                                        
                                        	Remote TAII AC ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: rem_saii
                                        
                                        	Remote Source Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: rem_taii
                                        
                                        	Remote Target Attachment Individual Identifer
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: lsd_rewrite_failed
                                        
                                        	LSD rewrite failed
                                        	**type**\: bool
                                        
                                        .. attribute:: ldp_label_advertisment_failed
                                        
                                        	LDP label advertisment failed
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                            self.yang_name = "atom"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                            self._leafs = OrderedDict([
                                                ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                                ('local_label', YLeaf(YType.uint32, 'local-label')),
                                                ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                                ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                                ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                                ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                                ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                                ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                                ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                                ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                                ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                                ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                                ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                                ('source_address', YLeaf(YType.str, 'source-address')),
                                                ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                                ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                                ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                                ('saii', YLeaf(YType.str, 'saii')),
                                                ('taii', YLeaf(YType.str, 'taii')),
                                                ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                                ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                                ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                                ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                                ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                                ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                                ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                                ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                                ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                                ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                                ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                                ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                                ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                                ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                            ])
                                            self.is_pseudowire_headend = None
                                            self.local_label = None
                                            self.remote_label = None
                                            self.local_group_id = None
                                            self.remote_group_id = None
                                            self.local_cv_type = None
                                            self.local_c_ctype = None
                                            self.remote_cv_type = None
                                            self.remote_c_ctype = None
                                            self.local_veid = None
                                            self.remote_veid = None
                                            self.local_ceid = None
                                            self.remote_ceid = None
                                            self.source_address = None
                                            self.remote_source_address = None
                                            self.local_ldp_id = None
                                            self.remote_ldp_id = None
                                            self.saii = None
                                            self.taii = None
                                            self.is_sai_itype2 = None
                                            self.local_saii_gbl_id = None
                                            self.local_saiiac_id = None
                                            self.is_tai_itype2 = None
                                            self.local_taii_gbl_id = None
                                            self.local_taiiac_id = None
                                            self.rem_saii_gbl_id = None
                                            self.rem_saiiac_id = None
                                            self.rem_taii_gbl_id = None
                                            self.rem_taiiac_id = None
                                            self.rem_saii = None
                                            self.rem_taii = None
                                            self.lsd_rewrite_failed = None
                                            self.ldp_label_advertisment_failed = None

                                            self.local_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                            self.local_agi.parent = self
                                            self._children_name_map["local_agi"] = "local-agi"

                                            self.remote_agi = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                            self.remote_agi.parent = self
                                            self._children_name_map["remote_agi"] = "remote-agi"

                                            self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                            self.multi_segment_pseudowire_stats.parent = self
                                            self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                            self._segment_path = lambda: "atom"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                        class LocalAgi(Entity):
                                            """
                                            Local Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                                self.yang_name = "local-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "local-agi"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "local-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class RemoteAgi(Entity):
                                            """
                                            Remote Attachment Group Identifier
                                            
                                            .. attribute:: auto
                                            
                                            	auto
                                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	two byte as
                                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                            
                                            .. attribute:: v4_addr
                                            
                                            	v4 addr
                                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                            
                                            .. attribute:: vpls_id_type
                                            
                                            	VPLS ID TYPE
                                            	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                                self.yang_name = "remote-agi"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                                self._leafs = OrderedDict([
                                                    ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                                ])
                                                self.vpls_id_type = None

                                                self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                                self.auto.parent = self
                                                self._children_name_map["auto"] = "auto"

                                                self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                                self.two_byte_as.parent = self
                                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                                self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                                self.v4_addr.parent = self
                                                self._children_name_map["v4_addr"] = "v4-addr"
                                                self._segment_path = lambda: "remote-agi"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                            class Auto(Entity):
                                                """
                                                auto
                                                
                                                .. attribute:: asn
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: vpn_id
                                                
                                                	VPN ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                    self.yang_name = "auto"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('asn', YLeaf(YType.uint16, 'asn')),
                                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                    ])
                                                    self.asn = None
                                                    self.vpn_id = None
                                                    self._segment_path = lambda: "auto"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                            class TwoByteAs(Entity):
                                                """
                                                two byte as
                                                
                                                .. attribute:: two_byte_as
                                                
                                                	2 Byte AS Number
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: four_byte_index
                                                
                                                	4 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                    self.yang_name = "two-byte-as"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                    ])
                                                    self.two_byte_as = None
                                                    self.four_byte_index = None
                                                    self._segment_path = lambda: "two-byte-as"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                            class V4Addr(Entity):
                                                """
                                                v4 addr
                                                
                                                .. attribute:: ipv4_address
                                                
                                                	IPv4 Address
                                                	**type**\: str
                                                
                                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                                
                                                .. attribute:: two_byte_index
                                                
                                                	2 Byte Index
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                    self.yang_name = "v4-addr"
                                                    self.yang_parent_name = "remote-agi"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                    ])
                                                    self.ipv4_address = None
                                                    self.two_byte_index = None
                                                    self._segment_path = lambda: "v4-addr"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                        class MultiSegmentPseudowireStats(Entity):
                                            """
                                            Multisegment pseudowire statistics
                                            
                                            .. attribute:: received_packets
                                            
                                            	Packets received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: received_bytes
                                            
                                            	Bytes received
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                                self.yang_name = "multi-segment-pseudowire-stats"
                                                self.yang_parent_name = "atom"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                    ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                                ])
                                                self.received_packets = None
                                                self.received_bytes = None
                                                self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                    class L2tpv3(Entity):
                                        """
                                        l2tpv3
                                        
                                        .. attribute:: l2tp_class_name
                                        
                                        	L2TPClassName
                                        	**type**\: str
                                        
                                        	**length:** 0..32
                                        
                                        .. attribute:: ipv4_source_address
                                        
                                        	IPv4 source address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: ipv6_source_address
                                        
                                        	IPv6 source address
                                        	**type**\: str
                                        
                                        	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: path_mtu_enabled
                                        
                                        	Path MTU enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: path_mtu_max_value
                                        
                                        	Path MTU Maximum allowable session MTU
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: dont_fragment_bit
                                        
                                        	Don't Fragment Bit
                                        	**type**\: bool
                                        
                                        .. attribute:: tos_mode
                                        
                                        	Type Of Service Mode
                                        	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                        
                                        .. attribute:: tos
                                        
                                        	Type Of Service Value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: ttl
                                        
                                        	Time To Live value
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_session_id
                                        
                                        	Local session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_session_id
                                        
                                        	Remote session id
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_size
                                        
                                        	Local cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: remote_cookie_size
                                        
                                        	Remote cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the remote cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: remote_circuit_status_up
                                        
                                        	RemoteCircuitStatusUp
                                        	**type**\: bool
                                        
                                        .. attribute:: tunnel_state
                                        
                                        	L2TP tunnel state
                                        	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                        
                                        .. attribute:: local_secondary_cookie_size
                                        
                                        	Local secondary cookie size\: 0, 4, or 8 bytes
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: local_secondary_cookie_low_value
                                        
                                        	Lower 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_secondary_cookie_high_value
                                        
                                        	Upper 4 bytes of the value of the local secondary cookie
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                            self.yang_name = "l2tpv3"
                                            self.yang_parent_name = "encapsulation-info"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                                ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                                ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                                ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                                ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                                ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                                ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                                ('tos', YLeaf(YType.uint8, 'tos')),
                                                ('ttl', YLeaf(YType.uint8, 'ttl')),
                                                ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                                ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                                ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                                ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                                ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                                ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                                ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                                ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                                ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                                ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                                ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                                ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                                ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                            ])
                                            self.l2tp_class_name = None
                                            self.ipv4_source_address = None
                                            self.ipv6_source_address = None
                                            self.path_mtu_enabled = None
                                            self.path_mtu_max_value = None
                                            self.dont_fragment_bit = None
                                            self.tos_mode = None
                                            self.tos = None
                                            self.ttl = None
                                            self.local_session_id = None
                                            self.remote_session_id = None
                                            self.local_cookie_size = None
                                            self.remote_cookie_size = None
                                            self.local_cookie_low_value = None
                                            self.remote_cookie_low_value = None
                                            self.local_cookie_high_value = None
                                            self.remote_cookie_high_value = None
                                            self.remote_circuit_status_up = None
                                            self.tunnel_state = None
                                            self.local_secondary_cookie_size = None
                                            self.local_secondary_cookie_low_value = None
                                            self.local_secondary_cookie_high_value = None
                                            self._segment_path = lambda: "l2tpv3"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                                class LocalInterface(Entity):
                                    """
                                    Local interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, self).__init__()

                                        self.yang_name = "local-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "local-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "local-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class RemoteInterface(Entity):
                                    """
                                    Remote interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, self).__init__()

                                        self.yang_name = "remote-interface"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "remote-interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "remote-interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                class PreferredPath(Entity):
                                    """
                                    MPLS Preferred Path
                                    
                                    .. attribute:: srte_policy
                                    
                                    	srte policy
                                    	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy>`
                                    
                                    .. attribute:: option
                                    
                                    	Option
                                    	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                    
                                    .. attribute:: next_hop_ip
                                    
                                    	NextHopIP
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: te_tunnel_interface_number
                                    
                                    	TETunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: ip_tunnel_interface_number
                                    
                                    	IPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tp_tunnel_interface_number
                                    
                                    	TPTunnelInterfaceNumber
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, self).__init__()

                                        self.yang_name = "preferred-path"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy))])
                                        self._leafs = OrderedDict([
                                            ('option', YLeaf(YType.enumeration, 'option')),
                                            ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                            ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                            ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                            ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                        ])
                                        self.option = None
                                        self.next_hop_ip = None
                                        self.te_tunnel_interface_number = None
                                        self.ip_tunnel_interface_number = None
                                        self.tp_tunnel_interface_number = None

                                        self.srte_policy = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy()
                                        self.srte_policy.parent = self
                                        self._children_name_map["srte_policy"] = "srte-policy"
                                        self._segment_path = lambda: "preferred-path"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                    class SrtePolicy(Entity):
                                        """
                                        srte policy
                                        
                                        .. attribute:: policy_name
                                        
                                        	SR TE Policy Name
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                            self.yang_name = "srte-policy"
                                            self.yang_parent_name = "preferred-path"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('policy_name', YLeaf(YType.str, 'policy-name')),
                                            ])
                                            self.policy_name = None
                                            self._segment_path = lambda: "srte-policy"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                                class LocalSignalling(Entity):
                                    """
                                    Local signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, self).__init__()

                                        self.yang_name = "local-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "local-signalling"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "local-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class RemoteSignalling(Entity):
                                    """
                                    Remote signalling
                                    
                                    .. attribute:: status_tlv
                                    
                                    	PW Status Switching TLV
                                    	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv>`
                                    
                                    .. attribute:: pw_status
                                    
                                    	PW Status
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: tlv
                                    
                                    	Switching TLV info
                                    	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, self).__init__()

                                        self.yang_name = "remote-signalling"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv))])
                                        self._leafs = OrderedDict([
                                            ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                        ])
                                        self.pw_status = None

                                        self.status_tlv = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv()
                                        self.status_tlv.parent = self
                                        self._children_name_map["status_tlv"] = "status-tlv"

                                        self.tlv = YList(self)
                                        self._segment_path = lambda: "remote-signalling"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                    class StatusTlv(Entity):
                                        """
                                        PW Status Switching TLV
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                            self.yang_name = "status-tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "status-tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                    class Tlv(Entity):
                                        """
                                        Switching TLV info
                                        
                                        .. attribute:: pw_id
                                        
                                        	PW ID of last PW segment traversed
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: local_address
                                        
                                        	Local IP Address of PW Switching Point
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: remote_address
                                        
                                        	Remote IP Address of Last PW Switching Point traversed
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: description
                                        
                                        	PW Switching Point description
                                        	**type**\: str
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                            self.yang_name = "tlv"
                                            self.yang_parent_name = "remote-signalling"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                                ('local_address', YLeaf(YType.str, 'local-address')),
                                                ('remote_address', YLeaf(YType.str, 'remote-address')),
                                                ('description', YLeaf(YType.str, 'description')),
                                            ])
                                            self.pw_id = None
                                            self.local_address = None
                                            self.remote_address = None
                                            self.description = None
                                            self._segment_path = lambda: "tlv"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class P2mpPw(Entity):
                                    """
                                    P2MP Pseudowire Information
                                    
                                    .. attribute:: local_available
                                    
                                    	Local LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ptree_type
                                    
                                    	Local P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: local_tunnel_id
                                    
                                    	Local Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_extended_tunnel_id
                                    
                                    	Local Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_p2mp_id
                                    
                                    	Local P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_flags
                                    
                                    	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_available
                                    
                                    	Remote LSM info available
                                    	**type**\: bool
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote Label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ptree_type
                                    
                                    	Remote P\-Tree Type
                                    	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                    
                                    .. attribute:: remote_tunnel_id
                                    
                                    	Remote Tunnel ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_extended_tunnel_id
                                    
                                    	Remote Extended Tunnel ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_p2mp_id
                                    
                                    	Remote P2MP ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_flags
                                    
                                    	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, self).__init__()

                                        self.yang_name = "p2mp-pw"
                                        self.yang_parent_name = "pseudowire"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('local_available', YLeaf(YType.boolean, 'local-available')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                            ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                            ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                            ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                            ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                            ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                            ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                            ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                            ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                            ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                        ])
                                        self.local_available = None
                                        self.local_label = None
                                        self.local_ptree_type = None
                                        self.local_tunnel_id = None
                                        self.local_extended_tunnel_id = None
                                        self.local_p2mp_id = None
                                        self.local_flags = None
                                        self.remote_available = None
                                        self.remote_label = None
                                        self.remote_ptree_type = None
                                        self.remote_tunnel_id = None
                                        self.remote_extended_tunnel_id = None
                                        self.remote_p2mp_id = None
                                        self.remote_flags = None
                                        self._segment_path = lambda: "p2mp-pw"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "bridge-access-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "bridge-access-pw"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeAccessPws.BridgeAccessPw.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                    class BridgeDomainInfo(Entity):
                        """
                        Bridge Domain Information
                        
                        .. attribute:: security_parameters
                        
                        	Security parameters
                        	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters>`
                        
                        .. attribute:: pbb_parameters
                        
                        	PBB parameters
                        	**type**\:  :py:class:`PbbParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters>`
                        
                        .. attribute:: evpn_parameters
                        
                        	EVPN parameters
                        	**type**\:  :py:class:`EvpnParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters>`
                        
                        .. attribute:: vni_parameters
                        
                        	VNI parameters
                        	**type**\:  :py:class:`VniParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters>`
                        
                        .. attribute:: rd
                        
                        	Route Distinguisher
                        	**type**\:  :py:class:`Rd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd>`
                        
                        .. attribute:: group_name
                        
                        	Group name
                        	**type**\: str
                        
                        .. attribute:: bridge_name
                        
                        	Bridge\-domain name
                        	**type**\: str
                        
                        .. attribute:: bridge_domain_id
                        
                        	Identification number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_description
                        
                        	Human\-readable bridge\-domain description
                        	**type**\: str
                        
                        .. attribute:: bridge_state
                        
                        	Bridge\-domain state
                        	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                        
                        .. attribute:: bridge_coupled_state
                        
                        	Bridge\-domain coupled state
                        	**type**\:  :py:class:`L2vpnBridgeCoupledState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeCoupledState>`
                        
                        .. attribute:: bridge_shg_id
                        
                        	Bridge\-domain shgid
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_msti
                        
                        	Bridge\-domain msti
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: acpwup
                        
                        	Number of bridge ports (AC,PW) which are up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_internal_msti
                        
                        	Bridge\-domain internal msti
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: configured
                        
                        	Bridge\-domain is configured
                        	**type**\: bool
                        
                        .. attribute:: number_vf_is
                        
                        	Number of virtual forwarding interfaces
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_access_vf_is
                        
                        	Number of Access VFIs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs
                        
                        	Number of attachment circuits
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_a_cs_up
                        
                        	Number of attachment circuits up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pseudowires
                        
                        	Number of pseudowires
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_p_ws_up
                        
                        	Number of pseudowires up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: standby_pseudowires
                        
                        	Number of pseudowires standby
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: number_pb_bs
                        
                        	Number of pbbs
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: number_pb_bs_up
                        
                        	Number of pbbs up
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: num_vn_is
                        
                        	Number of VNIs
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: num_vn_is_up
                        
                        	Number of VNIs up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partially_programmed_pseudowires
                        
                        	Number of pseudowires partially programmed
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: partially_programmed_a_cs
                        
                        	Number of attachment circuits partially programmed
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: bridge_mtu
                        
                        	Maximum transmission unit
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: shutdown
                        
                        	Administratively disabled
                        	**type**\: bool
                        
                        .. attribute:: mac_limit_down
                        
                        	Oper down because MAC limit reached
                        	**type**\: bool
                        
                        .. attribute:: flodd_group_id_down
                        
                        	Oper down because no FGID
                        	**type**\: bool
                        
                        .. attribute:: mac_withdraw
                        
                        	MAC withdraw enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_withdraw_access
                        
                        	MAC Access PW withdraw enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_withdraw_relay
                        
                        	MAC Access PW withdraw relaying from access to access enabled
                        	**type**\: bool
                        
                        .. attribute:: mac_withdraw_option
                        
                        	Event on which MAC withdraw is sent
                        	**type**\:  :py:class:`L2vpnBagMacWithdrawOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacWithdrawOption>`
                        
                        .. attribute:: p2mp_enabled
                        
                        	P2MP Enabled on this Bridge Domain
                        	**type**\: bool
                        
                        .. attribute:: bridge_type
                        
                        	Bridge\-domain type
                        	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                        
                        .. attribute:: vine_fsm_state
                        
                        	VNI, IRB, Native\-Evpn state
                        	**type**\: str
                        
                        .. attribute:: time_created
                        
                        	Time when the bridge domain was created
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_creation
                        
                        	Time elapsed since creation
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: last_time_status_changed
                        
                        	Last time the bridge domain status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: time_elapsed_status_changed
                        
                        	Time elapsed since status changed
                        	**type**\: str
                        
                        	**length:** 0..50
                        
                        .. attribute:: load_balance
                        
                        	Load Balance Type
                        	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                        
                        .. attribute:: is_bridge_partially_programmed
                        
                        	Bridge is partially programmed
                        	**type**\: bool
                        
                        .. attribute:: evi
                        
                        	E\-VPN id
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_rd_configured
                        
                        	Config or Auto
                        	**type**\: bool
                        
                        .. attribute:: imposition_pkt_count
                        
                        	EVPN Imposition Packet Count
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: imposition_byte_count
                        
                        	EVPN Imposition Byte Count
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: disposition_pkt_count
                        
                        	EVPN Disposition Packet Count
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: disposition_bytecount
                        
                        	EVPN Disposition Byte Count
                        	**type**\: int
                        
                        	**range:** 0..18446744073709551615
                        
                        .. attribute:: as_
                        
                        	BGP AS number
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: nv_satellite_offload_ipv4_multicast_disabled
                        
                        	nV Satellite Offload IPv4 Multicast Disabled
                        	**type**\: bool
                        
                        .. attribute:: mac_filter
                        
                        	MAC addresses for filtering
                        	**type**\: list of  		 :py:class:`MacFilter <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter>`
                        
                        .. attribute:: bridge_vfi
                        
                        	Virtual Forwarding Interfaces
                        	**type**\: list of  		 :py:class:`BridgeVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi>`
                        
                        .. attribute:: bridge_access_vfi
                        
                        	Access Virtual Forwarding Interfaces
                        	**type**\: list of  		 :py:class:`BridgeAccessVfi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo, self).__init__()

                            self.yang_name = "bridge-domain-info"
                            self.yang_parent_name = "bridge-domain"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters)), ("pbb-parameters", ("pbb_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters)), ("evpn-parameters", ("evpn_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters)), ("vni-parameters", ("vni_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters)), ("rd", ("rd", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd)), ("mac-filter", ("mac_filter", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter)), ("bridge-vfi", ("bridge_vfi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi)), ("bridge-access-vfi", ("bridge_access_vfi", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi))])
                            self._leafs = OrderedDict([
                                ('group_name', YLeaf(YType.str, 'group-name')),
                                ('bridge_name', YLeaf(YType.str, 'bridge-name')),
                                ('bridge_domain_id', YLeaf(YType.uint32, 'bridge-domain-id')),
                                ('bridge_description', YLeaf(YType.str, 'bridge-description')),
                                ('bridge_state', YLeaf(YType.enumeration, 'bridge-state')),
                                ('bridge_coupled_state', YLeaf(YType.enumeration, 'bridge-coupled-state')),
                                ('bridge_shg_id', YLeaf(YType.uint32, 'bridge-shg-id')),
                                ('bridge_msti', YLeaf(YType.uint32, 'bridge-msti')),
                                ('acpwup', YLeaf(YType.uint32, 'acpwup')),
                                ('bridge_internal_msti', YLeaf(YType.uint32, 'bridge-internal-msti')),
                                ('configured', YLeaf(YType.boolean, 'configured')),
                                ('number_vf_is', YLeaf(YType.uint32, 'number-vf-is')),
                                ('number_access_vf_is', YLeaf(YType.uint32, 'number-access-vf-is')),
                                ('number_a_cs', YLeaf(YType.uint32, 'number-a-cs')),
                                ('number_a_cs_up', YLeaf(YType.uint32, 'number-a-cs-up')),
                                ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                                ('number_p_ws_up', YLeaf(YType.uint32, 'number-p-ws-up')),
                                ('standby_pseudowires', YLeaf(YType.uint32, 'standby-pseudowires')),
                                ('number_pb_bs', YLeaf(YType.uint8, 'number-pb-bs')),
                                ('number_pb_bs_up', YLeaf(YType.uint8, 'number-pb-bs-up')),
                                ('num_vn_is', YLeaf(YType.uint32, 'num-vn-is')),
                                ('num_vn_is_up', YLeaf(YType.uint32, 'num-vn-is-up')),
                                ('partially_programmed_pseudowires', YLeaf(YType.uint32, 'partially-programmed-pseudowires')),
                                ('partially_programmed_a_cs', YLeaf(YType.uint32, 'partially-programmed-a-cs')),
                                ('bridge_mtu', YLeaf(YType.uint32, 'bridge-mtu')),
                                ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                ('mac_limit_down', YLeaf(YType.boolean, 'mac-limit-down')),
                                ('flodd_group_id_down', YLeaf(YType.boolean, 'flodd-group-id-down')),
                                ('mac_withdraw', YLeaf(YType.boolean, 'mac-withdraw')),
                                ('mac_withdraw_access', YLeaf(YType.boolean, 'mac-withdraw-access')),
                                ('mac_withdraw_relay', YLeaf(YType.boolean, 'mac-withdraw-relay')),
                                ('mac_withdraw_option', YLeaf(YType.enumeration, 'mac-withdraw-option')),
                                ('p2mp_enabled', YLeaf(YType.boolean, 'p2mp-enabled')),
                                ('bridge_type', YLeaf(YType.enumeration, 'bridge-type')),
                                ('vine_fsm_state', YLeaf(YType.str, 'vine-fsm-state')),
                                ('time_created', YLeaf(YType.str, 'time-created')),
                                ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                ('is_bridge_partially_programmed', YLeaf(YType.boolean, 'is-bridge-partially-programmed')),
                                ('evi', YLeaf(YType.uint32, 'evi')),
                                ('is_rd_configured', YLeaf(YType.boolean, 'is-rd-configured')),
                                ('imposition_pkt_count', YLeaf(YType.uint64, 'imposition-pkt-count')),
                                ('imposition_byte_count', YLeaf(YType.uint64, 'imposition-byte-count')),
                                ('disposition_pkt_count', YLeaf(YType.uint64, 'disposition-pkt-count')),
                                ('disposition_bytecount', YLeaf(YType.uint64, 'disposition-bytecount')),
                                ('as_', YLeaf(YType.uint32, 'as')),
                                ('nv_satellite_offload_ipv4_multicast_disabled', YLeaf(YType.boolean, 'nv-satellite-offload-ipv4-multicast-disabled')),
                            ])
                            self.group_name = None
                            self.bridge_name = None
                            self.bridge_domain_id = None
                            self.bridge_description = None
                            self.bridge_state = None
                            self.bridge_coupled_state = None
                            self.bridge_shg_id = None
                            self.bridge_msti = None
                            self.acpwup = None
                            self.bridge_internal_msti = None
                            self.configured = None
                            self.number_vf_is = None
                            self.number_access_vf_is = None
                            self.number_a_cs = None
                            self.number_a_cs_up = None
                            self.number_pseudowires = None
                            self.number_p_ws_up = None
                            self.standby_pseudowires = None
                            self.number_pb_bs = None
                            self.number_pb_bs_up = None
                            self.num_vn_is = None
                            self.num_vn_is_up = None
                            self.partially_programmed_pseudowires = None
                            self.partially_programmed_a_cs = None
                            self.bridge_mtu = None
                            self.shutdown = None
                            self.mac_limit_down = None
                            self.flodd_group_id_down = None
                            self.mac_withdraw = None
                            self.mac_withdraw_access = None
                            self.mac_withdraw_relay = None
                            self.mac_withdraw_option = None
                            self.p2mp_enabled = None
                            self.bridge_type = None
                            self.vine_fsm_state = None
                            self.time_created = None
                            self.time_elapsed_creation = None
                            self.last_time_status_changed = None
                            self.time_elapsed_status_changed = None
                            self.load_balance = None
                            self.is_bridge_partially_programmed = None
                            self.evi = None
                            self.is_rd_configured = None
                            self.imposition_pkt_count = None
                            self.imposition_byte_count = None
                            self.disposition_pkt_count = None
                            self.disposition_bytecount = None
                            self.as_ = None
                            self.nv_satellite_offload_ipv4_multicast_disabled = None

                            self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters()
                            self.security_parameters.parent = self
                            self._children_name_map["security_parameters"] = "security-parameters"

                            self.pbb_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters()
                            self.pbb_parameters.parent = self
                            self._children_name_map["pbb_parameters"] = "pbb-parameters"

                            self.evpn_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters()
                            self.evpn_parameters.parent = self
                            self._children_name_map["evpn_parameters"] = "evpn-parameters"

                            self.vni_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters()
                            self.vni_parameters.parent = self
                            self._children_name_map["vni_parameters"] = "vni-parameters"

                            self.rd = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd()
                            self.rd.parent = self
                            self._children_name_map["rd"] = "rd"

                            self.mac_filter = YList(self)
                            self.bridge_vfi = YList(self)
                            self.bridge_access_vfi = YList(self)
                            self._segment_path = lambda: "bridge-domain-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo, ['group_name', 'bridge_name', 'bridge_domain_id', 'bridge_description', 'bridge_state', 'bridge_coupled_state', 'bridge_shg_id', 'bridge_msti', 'acpwup', 'bridge_internal_msti', 'configured', 'number_vf_is', 'number_access_vf_is', 'number_a_cs', 'number_a_cs_up', 'number_pseudowires', 'number_p_ws_up', 'standby_pseudowires', 'number_pb_bs', 'number_pb_bs_up', 'num_vn_is', 'num_vn_is_up', 'partially_programmed_pseudowires', 'partially_programmed_a_cs', 'bridge_mtu', 'shutdown', 'mac_limit_down', 'flodd_group_id_down', 'mac_withdraw', 'mac_withdraw_access', 'mac_withdraw_relay', 'mac_withdraw_option', 'p2mp_enabled', 'bridge_type', 'vine_fsm_state', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'load_balance', 'is_bridge_partially_programmed', 'evi', 'is_rd_configured', 'imposition_pkt_count', 'imposition_byte_count', 'disposition_pkt_count', 'disposition_bytecount', 'as_', 'nv_satellite_offload_ipv4_multicast_disabled'], name, value)


                        class SecurityParameters(Entity):
                            """
                            Security parameters
                            
                            .. attribute:: storm_control
                            
                            	Storm Control Configuration
                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl>`
                            
                            .. attribute:: mac_limit
                            
                            	MAC address limit
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: mac_limit_action
                            
                            	MAC limit action
                            	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                            
                            .. attribute:: mac_limit_notification
                            
                            	MAC limit notification
                            	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                            
                            .. attribute:: mac_aging_time
                            
                            	MAC aging time in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: mac_aging_mode
                            
                            	MAC Aging Mode
                            	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                            
                            .. attribute:: mac_flooding
                            
                            	MAC flooding enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_learning
                            
                            	MAC learning enabled
                            	**type**\: bool
                            
                            .. attribute:: learn_disabled_mac_limit_action
                            
                            	Learning disabled due to MAC limit action
                            	**type**\: bool
                            
                            .. attribute:: flood_uu_disabled_mac_limit_action
                            
                            	Flooding of unknown\-unicast disabled due to MAC limit action
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_reached
                            
                            	MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_threshold
                            
                            	MAC Limit Threshold Percentage
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: percentage
                            
                            .. attribute:: flood_unknown_unicast_enabled
                            
                            	Flooding unknown unicast enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_port_down_flush_enabled
                            
                            	MAC Flush when port goes down
                            	**type**\: bool
                            
                            .. attribute:: split_horizon_group_id
                            
                            	Split Horizon Group ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: is_ip_source_guard_enabled
                            
                            	Is IP Source Guard Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_ipsg_logging_enabled
                            
                            	Is IP Source Guard Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_enabled
                            
                            	Is Dynamic ARP Inspection Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_logging_enabled
                            
                            	Is DAI Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                            
                            	Is DAI Source MAC Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                            
                            	Is DAI Dstination MAC Address Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                            
                            	Is DAI IPv4 Addr Validation Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_enabled
                            
                            	Is MAC Secure Enabled
                            	**type**\: bool
                            
                            .. attribute:: mac_secure_action
                            
                            	MAC Secure Action
                            	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                            
                            .. attribute:: is_mac_secure_logging_enabled
                            
                            	Is MAC Secure Logging Enabled
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                            
                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                            	**type**\: bool
                            
                            .. attribute:: is_mac_secure_threshold_enabled
                            
                            	Is MAC Secure Threshold Enabled
                            	**type**\: bool
                            
                            .. attribute:: dai_address_validation_mask
                            
                            	DAI Address Validation mask
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: dhcpv4_snoop
                            
                            	DHCPv4 Snoop Status
                            	**type**\: bool
                            
                            .. attribute:: dhcpv4_profile_name
                            
                            	DHCPv4 Profile Name
                            	**type**\: str
                            
                            .. attribute:: igm_pv4_disabled
                            
                            	IGMPv4 Disabled
                            	**type**\: bool
                            
                            .. attribute:: igm_pv4_profile_name
                            
                            	IGMPv4 Profile Name
                            	**type**\: str
                            
                            .. attribute:: mld_profile_name
                            
                            	MLD Profile Name
                            	**type**\: str
                            
                            .. attribute:: mmrp_flood_optimization
                            
                            	MMRP Flood Optimization Status
                            	**type**\: bool
                            
                            .. attribute:: unicast_storm_control_rate_unit
                            
                            	Unicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: unicast_storm_control_pps
                            
                            	Unicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: unicast_storm_control_kb_ps
                            
                            	Unicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: multicast_storm_control_rate_unit
                            
                            	Multicast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: multicast_storm_control_pps
                            
                            	Multicast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: multicast_storm_control_kb_ps
                            
                            	Multicast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            .. attribute:: broadcast_storm_control_rate_unit
                            
                            	Broadcast Storm Control Rate Unit
                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                            
                            .. attribute:: broadcast_storm_control_pps
                            
                            	Broadcast Storm Control PPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: broadcast_storm_control_kb_ps
                            
                            	Broadcast Storm Control KbPS
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            	**units**\: kbit/s
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, self).__init__()

                                self.yang_name = "security-parameters"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl))])
                                self._leafs = OrderedDict([
                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                    ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                    ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                    ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                    ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                    ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                    ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                    ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                    ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                    ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                    ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                    ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                    ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                    ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                    ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                    ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                    ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                    ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                    ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                    ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                    ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                    ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                ])
                                self.mac_limit = None
                                self.mac_limit_action = None
                                self.mac_limit_notification = None
                                self.mac_aging_time = None
                                self.mac_aging_mode = None
                                self.mac_flooding = None
                                self.mac_learning = None
                                self.learn_disabled_mac_limit_action = None
                                self.flood_uu_disabled_mac_limit_action = None
                                self.mac_limit_reached = None
                                self.mac_limit_threshold = None
                                self.flood_unknown_unicast_enabled = None
                                self.mac_port_down_flush_enabled = None
                                self.split_horizon_group_id = None
                                self.is_ip_source_guard_enabled = None
                                self.is_ipsg_logging_enabled = None
                                self.is_dai_enabled = None
                                self.is_dai_logging_enabled = None
                                self.is_dai_addr_validate_source_mac_enabled = None
                                self.is_dai_addr_validate_destination_mac_enabled = None
                                self.is_dai_addr_validate_ipv4_enabled = None
                                self.is_mac_secure_enabled = None
                                self.mac_secure_action = None
                                self.is_mac_secure_logging_enabled = None
                                self.is_mac_secure_accept_shutdown_enabled = None
                                self.is_mac_secure_threshold_enabled = None
                                self.dai_address_validation_mask = None
                                self.dhcpv4_snoop = None
                                self.dhcpv4_profile_name = None
                                self.igm_pv4_disabled = None
                                self.igm_pv4_profile_name = None
                                self.mld_profile_name = None
                                self.mmrp_flood_optimization = None
                                self.unicast_storm_control_rate_unit = None
                                self.unicast_storm_control_pps = None
                                self.unicast_storm_control_kb_ps = None
                                self.multicast_storm_control_rate_unit = None
                                self.multicast_storm_control_pps = None
                                self.multicast_storm_control_kb_ps = None
                                self.broadcast_storm_control_rate_unit = None
                                self.broadcast_storm_control_pps = None
                                self.broadcast_storm_control_kb_ps = None

                                self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl()
                                self.storm_control.parent = self
                                self._children_name_map["storm_control"] = "storm-control"
                                self._segment_path = lambda: "security-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                            class StormControl(Entity):
                                """
                                Storm Control Configuration
                                
                                .. attribute:: bd_policer
                                
                                	Bridge Domain Policer
                                	**type**\: bool
                                
                                .. attribute:: unicast
                                
                                	Unknown\-unicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: multicast
                                
                                	Multicast Storm Control
                                	**type**\: bool
                                
                                .. attribute:: broadcast
                                
                                	Broadcast Storm Control
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, self).__init__()

                                    self.yang_name = "storm-control"
                                    self.yang_parent_name = "security-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                    ])
                                    self.bd_policer = None
                                    self.unicast = None
                                    self.multicast = None
                                    self.broadcast = None
                                    self._segment_path = lambda: "storm-control"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class PbbParameters(Entity):
                            """
                            PBB parameters
                            
                            .. attribute:: pbb_edge
                            
                            	PBB Edge
                            	**type**\:  :py:class:`PbbEdge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge>`
                            
                            .. attribute:: pbb_core
                            
                            	PBB Core
                            	**type**\:  :py:class:`PbbCore <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore>`
                            
                            .. attribute:: type
                            
                            	Type
                            	**type**\:  :py:class:`L2vpnBridge <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridge>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, self).__init__()

                                self.yang_name = "pbb-parameters"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("pbb-edge", ("pbb_edge", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge)), ("pbb-core", ("pbb_core", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore))])
                                self._leafs = OrderedDict([
                                    ('type', YLeaf(YType.enumeration, 'type')),
                                ])
                                self.type = None

                                self.pbb_edge = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge()
                                self.pbb_edge.parent = self
                                self._children_name_map["pbb_edge"] = "pbb-edge"

                                self.pbb_core = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore()
                                self.pbb_core.parent = self
                                self._children_name_map["pbb_core"] = "pbb-core"
                                self._segment_path = lambda: "pbb-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters, ['type'], name, value)


                            class PbbEdge(Entity):
                                """
                                PBB Edge
                                
                                .. attribute:: edge_port
                                
                                	PBB Edge Port
                                	**type**\:  :py:class:`EdgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort>`
                                
                                .. attribute:: i_sid
                                
                                	SID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: core_bridge_name
                                
                                	Core Bridge Domain Name
                                	**type**\: str
                                
                                .. attribute:: core_bridge_state
                                
                                	Core Bridge State
                                	**type**\:  :py:class:`L2vpnBridgeState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBridgeState>`
                                
                                .. attribute:: mirp_lite_status
                                
                                	MIRP\-lite Status
                                	**type**\:  :py:class:`L2vpnMirpLiteStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteStatus>`
                                
                                .. attribute:: mirp_lite_protocol
                                
                                	MIRP\-lite protocol info
                                	**type**\:  :py:class:`L2vpnMirpLiteProtocolInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMirpLiteProtocolInfo>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, self).__init__()

                                    self.yang_name = "pbb-edge"
                                    self.yang_parent_name = "pbb-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("edge-port", ("edge_port", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort))])
                                    self._leafs = OrderedDict([
                                        ('i_sid', YLeaf(YType.uint32, 'i-sid')),
                                        ('core_bridge_name', YLeaf(YType.str, 'core-bridge-name')),
                                        ('core_bridge_state', YLeaf(YType.enumeration, 'core-bridge-state')),
                                        ('mirp_lite_status', YLeaf(YType.enumeration, 'mirp-lite-status')),
                                        ('mirp_lite_protocol', YLeaf(YType.enumeration, 'mirp-lite-protocol')),
                                    ])
                                    self.i_sid = None
                                    self.core_bridge_name = None
                                    self.core_bridge_state = None
                                    self.mirp_lite_status = None
                                    self.mirp_lite_protocol = None

                                    self.edge_port = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort()
                                    self.edge_port.parent = self
                                    self._children_name_map["edge_port"] = "edge-port"
                                    self._segment_path = lambda: "pbb-edge"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge, ['i_sid', 'core_bridge_name', 'core_bridge_state', 'mirp_lite_status', 'mirp_lite_protocol'], name, value)


                                class EdgePort(Entity):
                                    """
                                    PBB Edge Port
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters>`
                                    
                                    .. attribute:: statistics
                                    
                                    	Statistics
                                    	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics>`
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: unknown_unicast_mac_set
                                    
                                    	Unknown Unicast MAC Configured
                                    	**type**\: bool
                                    
                                    .. attribute:: unknown_unicast_mac
                                    
                                    	Unknown Unicast MAC
                                    	**type**\: str
                                    
                                    	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                    
                                    .. attribute:: edge_port_state
                                    
                                    	PBB Edge Port State
                                    	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                    
                                    .. attribute:: bmac_mapping
                                    
                                    	CMAC to BMAC Mapping
                                    	**type**\: list of  		 :py:class:`BmacMapping <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, self).__init__()

                                        self.yang_name = "edge-port"
                                        self.yang_parent_name = "pbb-edge"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics)), ("bmac-mapping", ("bmac_mapping", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('unknown_unicast_mac_set', YLeaf(YType.boolean, 'unknown-unicast-mac-set')),
                                            ('unknown_unicast_mac', YLeaf(YType.str, 'unknown-unicast-mac')),
                                            ('edge_port_state', YLeaf(YType.enumeration, 'edge-port-state')),
                                        ])
                                        self.xconnect_id = None
                                        self.unknown_unicast_mac_set = None
                                        self.unknown_unicast_mac = None
                                        self.edge_port_state = None

                                        self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"

                                        self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics()
                                        self.statistics.parent = self
                                        self._children_name_map["statistics"] = "statistics"

                                        self.bmac_mapping = YList(self)
                                        self._segment_path = lambda: "edge-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort, ['xconnect_id', 'unknown_unicast_mac_set', 'unknown_unicast_mac', 'edge_port_state'], name, value)


                                    class SecurityParameters(Entity):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, self).__init__()

                                            self.yang_name = "security-parameters"
                                            self.yang_parent_name = "edge-port"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                                ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                            ])
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.dhcpv4_trust = None

                                            self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"

                                            self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "security-parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                        class Base(Entity):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\: bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_threshold
                                            
                                            	MAC Limit Threshold Percentage
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\: bool
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_threshold_enabled
                                            
                                            	Is MAC Secure Threshold Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\: bool
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, self).__init__()

                                                self.yang_name = "base"
                                                self.yang_parent_name = "security-parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl))])
                                                self._leafs = OrderedDict([
                                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                    ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                    ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                    ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                    ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                    ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                    ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                    ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                    ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                    ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                    ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                    ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                    ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                    ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                    ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                    ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                    ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                    ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                    ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                    ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                    ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                    ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                                ])
                                                self.mac_limit = None
                                                self.mac_limit_action = None
                                                self.mac_limit_notification = None
                                                self.mac_aging_time = None
                                                self.mac_aging_mode = None
                                                self.mac_flooding = None
                                                self.mac_learning = None
                                                self.learn_disabled_mac_limit_action = None
                                                self.flood_uu_disabled_mac_limit_action = None
                                                self.mac_limit_reached = None
                                                self.mac_limit_threshold = None
                                                self.flood_unknown_unicast_enabled = None
                                                self.mac_port_down_flush_enabled = None
                                                self.split_horizon_group_id = None
                                                self.is_ip_source_guard_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_dai_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_dai_addr_validate_source_mac_enabled = None
                                                self.is_dai_addr_validate_destination_mac_enabled = None
                                                self.is_dai_addr_validate_ipv4_enabled = None
                                                self.is_mac_secure_enabled = None
                                                self.mac_secure_action = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.is_mac_secure_accept_shutdown_enabled = None
                                                self.is_mac_secure_threshold_enabled = None
                                                self.dai_address_validation_mask = None
                                                self.dhcpv4_snoop = None
                                                self.dhcpv4_profile_name = None
                                                self.igm_pv4_disabled = None
                                                self.igm_pv4_profile_name = None
                                                self.mld_profile_name = None
                                                self.mmrp_flood_optimization = None
                                                self.unicast_storm_control_rate_unit = None
                                                self.unicast_storm_control_pps = None
                                                self.unicast_storm_control_kb_ps = None
                                                self.multicast_storm_control_rate_unit = None
                                                self.multicast_storm_control_pps = None
                                                self.multicast_storm_control_kb_ps = None
                                                self.broadcast_storm_control_rate_unit = None
                                                self.broadcast_storm_control_pps = None
                                                self.broadcast_storm_control_kb_ps = None

                                                self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                                self._segment_path = lambda: "base"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                            class StormControl(Entity):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\: bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\: bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\: bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, self).__init__()

                                                    self.yang_name = "storm-control"
                                                    self.yang_parent_name = "base"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                    ])
                                                    self.bd_policer = None
                                                    self.unicast = None
                                                    self.multicast = None
                                                    self.broadcast = None
                                                    self._segment_path = lambda: "storm-control"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "security-parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class Statistics(Entity):
                                        """
                                        Statistics
                                        
                                        .. attribute:: impostion_stats
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats>`
                                        
                                        .. attribute:: dispostion_stats
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats>`
                                        
                                        .. attribute:: sequence_number
                                        
                                        	sequence numbers
                                        	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, self).__init__()

                                            self.yang_name = "statistics"
                                            self.yang_parent_name = "edge-port"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber))])
                                            self._leafs = OrderedDict()

                                            self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats()
                                            self.impostion_stats.parent = self
                                            self._children_name_map["impostion_stats"] = "impostion-stats"

                                            self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats()
                                            self.dispostion_stats.parent = self
                                            self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                            self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber()
                                            self.sequence_number.parent = self
                                            self._children_name_map["sequence_number"] = "sequence-number"
                                            self._segment_path = lambda: "statistics"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics, [], name, value)


                                        class ImpostionStats(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: imposition_stat
                                            
                                            	imposition stats
                                            	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat>`
                                            
                                            .. attribute:: imposition_mtu_drop
                                            
                                            	imposition mtu drop stats
                                            	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                            
                                            .. attribute:: impostion_tail_drop
                                            
                                            	imposition tail drop stats
                                            	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                            
                                            .. attribute:: l2fsbi_drop
                                            
                                            	rx discards
                                            	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop>`
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast
                                            	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast>`
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast
                                            	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast>`
                                            
                                            .. attribute:: unknown_unicast
                                            
                                            	Unknown Unicast
                                            	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, self).__init__()

                                                self.yang_name = "impostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast))])
                                                self._leafs = OrderedDict()

                                                self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat()
                                                self.imposition_stat.parent = self
                                                self._children_name_map["imposition_stat"] = "imposition-stat"

                                                self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                                self.imposition_mtu_drop.parent = self
                                                self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                                self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop()
                                                self.impostion_tail_drop.parent = self
                                                self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                                self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop()
                                                self.l2fsbi_drop.parent = self
                                                self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                                self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast()
                                                self.multicast.parent = self
                                                self._children_name_map["multicast"] = "multicast"

                                                self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast()
                                                self.broadcast.parent = self
                                                self._children_name_map["broadcast"] = "broadcast"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast()
                                                self.unknown_unicast.parent = self
                                                self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                                self._segment_path = lambda: "impostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats, [], name, value)


                                            class ImpositionStat(Entity):
                                                """
                                                imposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                    self.yang_name = "imposition-stat"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpositionMtuDrop(Entity):
                                                """
                                                imposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                    self.yang_name = "imposition-mtu-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "imposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ImpostionTailDrop(Entity):
                                                """
                                                imposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                    self.yang_name = "impostion-tail-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "impostion-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class L2fsbiDrop(Entity):
                                                """
                                                rx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                    self.yang_name = "l2fsbi-drop"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "l2fsbi-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class Multicast(Entity):
                                                """
                                                Multicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                    self.yang_name = "multicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                            class Broadcast(Entity):
                                                """
                                                Broadcast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                    self.yang_name = "broadcast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class UnknownUnicast(Entity):
                                                """
                                                Unknown Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                    self.yang_name = "unknown-unicast"
                                                    self.yang_parent_name = "impostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unknown-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class DispostionStats(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: disposition_stat
                                            
                                            	disposition stats
                                            	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat>`
                                            
                                            .. attribute:: disposition_mtu_drop
                                            
                                            	disposition mtu drop stats
                                            	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop>`
                                            
                                            .. attribute:: disposition_tail_drop
                                            
                                            	disposition tail drop stats
                                            	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop>`
                                            
                                            .. attribute:: multicast_drop
                                            
                                            	disposition storm control multicast drop stats
                                            	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop>`
                                            
                                            .. attribute:: unicast_drop
                                            
                                            	disposition storm control unknown unicast drop stats
                                            	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop>`
                                            
                                            .. attribute:: broadcast_drop
                                            
                                            	disposition storm control broadcast drop stats
                                            	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop>`
                                            
                                            .. attribute:: received_drops
                                            
                                            	tx discards
                                            	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops>`
                                            
                                            .. attribute:: dai_drop
                                            
                                            	Disposition dynamic ARP inspection drop statistics
                                            	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop>`
                                            
                                            .. attribute:: ipsg_drop
                                            
                                            	disposition IP source guard drop statistics
                                            	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop>`
                                            
                                            .. attribute:: disposition_oo_o_drops
                                            
                                            	Disposition Out\-of\-Order Drops
                                            	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops>`
                                            
                                            .. attribute:: disposition_p2mp_stats
                                            
                                            	Disposition P2MP Stats
                                            	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats>`
                                            
                                            .. attribute:: known_unicast
                                            
                                            	Known Unicast
                                            	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast>`
                                            
                                            .. attribute:: mac_move
                                            
                                            	MAC Move
                                            	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, self).__init__()

                                                self.yang_name = "dispostion-stats"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove))])
                                                self._leafs = OrderedDict()

                                                self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat()
                                                self.disposition_stat.parent = self
                                                self._children_name_map["disposition_stat"] = "disposition-stat"

                                                self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop()
                                                self.disposition_mtu_drop.parent = self
                                                self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                                self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop()
                                                self.disposition_tail_drop.parent = self
                                                self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                                self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop()
                                                self.multicast_drop.parent = self
                                                self._children_name_map["multicast_drop"] = "multicast-drop"

                                                self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop()
                                                self.unicast_drop.parent = self
                                                self._children_name_map["unicast_drop"] = "unicast-drop"

                                                self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop()
                                                self.broadcast_drop.parent = self
                                                self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                                self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops()
                                                self.received_drops.parent = self
                                                self._children_name_map["received_drops"] = "received-drops"

                                                self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop()
                                                self.dai_drop.parent = self
                                                self._children_name_map["dai_drop"] = "dai-drop"

                                                self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop()
                                                self.ipsg_drop.parent = self
                                                self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                                self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops()
                                                self.disposition_oo_o_drops.parent = self
                                                self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                                self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats()
                                                self.disposition_p2mp_stats.parent = self
                                                self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                                self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast()
                                                self.known_unicast.parent = self
                                                self._children_name_map["known_unicast"] = "known-unicast"

                                                self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove()
                                                self.mac_move.parent = self
                                                self._children_name_map["mac_move"] = "mac-move"
                                                self._segment_path = lambda: "dispostion-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats, [], name, value)


                                            class DispositionStat(Entity):
                                                """
                                                disposition stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                    self.yang_name = "disposition-stat"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-stat"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionMtuDrop(Entity):
                                                """
                                                disposition mtu drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                    self.yang_name = "disposition-mtu-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-mtu-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionTailDrop(Entity):
                                                """
                                                disposition tail drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                    self.yang_name = "disposition-tail-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-tail-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class MulticastDrop(Entity):
                                                """
                                                disposition storm control multicast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                    self.yang_name = "multicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "multicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class UnicastDrop(Entity):
                                                """
                                                disposition storm control unknown unicast drop
                                                stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                    self.yang_name = "unicast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "unicast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class BroadcastDrop(Entity):
                                                """
                                                disposition storm control broadcast drop stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                    self.yang_name = "broadcast-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "broadcast-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class ReceivedDrops(Entity):
                                                """
                                                tx discards
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                    self.yang_name = "received-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "received-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DaiDrop(Entity):
                                                """
                                                Disposition dynamic ARP inspection drop
                                                statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                    self.yang_name = "dai-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "dai-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class IpsgDrop(Entity):
                                                """
                                                disposition IP source guard drop statistics
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                    self.yang_name = "ipsg-drop"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "ipsg-drop"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionOoODrops(Entity):
                                                """
                                                Disposition Out\-of\-Order Drops
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                    self.yang_name = "disposition-oo-o-drops"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-oo-o-drops"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                            class DispositionP2mpStats(Entity):
                                                """
                                                Disposition P2MP Stats
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                    self.yang_name = "disposition-p2mp-stats"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "disposition-p2mp-stats"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                            class KnownUnicast(Entity):
                                                """
                                                Known Unicast
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                    self.yang_name = "known-unicast"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "known-unicast"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                            class MacMove(Entity):
                                                """
                                                MAC Move
                                                
                                                .. attribute:: packet_counts
                                                
                                                	packets counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                .. attribute:: byte_counts
                                                
                                                	bytes counters
                                                	**type**\: int
                                                
                                                	**range:** 0..18446744073709551615
                                                
                                                	**units**\: byte
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, self).__init__()

                                                    self.yang_name = "mac-move"
                                                    self.yang_parent_name = "dispostion-stats"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                        ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                    ])
                                                    self.packet_counts = None
                                                    self.byte_counts = None
                                                    self._segment_path = lambda: "mac-move"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                        class SequenceNumber(Entity):
                                            """
                                            sequence numbers
                                            
                                            .. attribute:: sequence_number_sent
                                            
                                            	sequence number sent
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: sequence_number_expected
                                            
                                            	sequence number expected
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: bypassed_inbound_sequence_packet
                                            
                                            	Bypassed inbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: bypassed_out_sequence_packet
                                            
                                            	Bypassed outbound sequence packets
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, self).__init__()

                                                self.yang_name = "sequence-number"
                                                self.yang_parent_name = "statistics"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                    ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                    ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                    ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                                ])
                                                self.sequence_number_sent = None
                                                self.sequence_number_expected = None
                                                self.bypassed_inbound_sequence_packet = None
                                                self.bypassed_out_sequence_packet = None
                                                self._segment_path = lambda: "sequence-number"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                    class BmacMapping(Entity):
                                        """
                                        CMAC to BMAC Mapping
                                        
                                        .. attribute:: address
                                        
                                        	MAC address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: bmac
                                        
                                        	Backbone MAC address
                                        	**type**\: str
                                        
                                        	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                        
                                        .. attribute:: next_hop_ip
                                        
                                        	Next Hop IP
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, self).__init__()

                                            self.yang_name = "bmac-mapping"
                                            self.yang_parent_name = "edge-port"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('address', YLeaf(YType.str, 'address')),
                                                ('bmac', YLeaf(YType.str, 'bmac')),
                                                ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                            ])
                                            self.address = None
                                            self.bmac = None
                                            self.next_hop_ip = None
                                            self._segment_path = lambda: "bmac-mapping"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbEdge.EdgePort.BmacMapping, ['address', 'bmac', 'next_hop_ip'], name, value)


                            class PbbCore(Entity):
                                """
                                PBB Core
                                
                                .. attribute:: core_port
                                
                                	PBB Core Port
                                	**type**\:  :py:class:`CorePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort>`
                                
                                .. attribute:: num_ass_edge
                                
                                	Number of Associated PBB Edges
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, self).__init__()

                                    self.yang_name = "pbb-core"
                                    self.yang_parent_name = "pbb-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("core-port", ("core_port", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort))])
                                    self._leafs = OrderedDict([
                                        ('num_ass_edge', YLeaf(YType.uint32, 'num-ass-edge')),
                                    ])
                                    self.num_ass_edge = None

                                    self.core_port = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort()
                                    self.core_port.parent = self
                                    self._children_name_map["core_port"] = "core-port"
                                    self._segment_path = lambda: "pbb-core"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore, ['num_ass_edge'], name, value)


                                class CorePort(Entity):
                                    """
                                    PBB Core Port
                                    
                                    .. attribute:: security_parameters
                                    
                                    	Security Parameters
                                    	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters>`
                                    
                                    .. attribute:: xconnect_id
                                    
                                    	Xconnect ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: vlan_id
                                    
                                    	Vlan ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: core_port_state
                                    
                                    	PBB Core Port State
                                    	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, self).__init__()

                                        self.yang_name = "core-port"
                                        self.yang_parent_name = "pbb-core"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters))])
                                        self._leafs = OrderedDict([
                                            ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                                            ('core_port_state', YLeaf(YType.enumeration, 'core-port-state')),
                                        ])
                                        self.xconnect_id = None
                                        self.vlan_id = None
                                        self.core_port_state = None

                                        self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters()
                                        self.security_parameters.parent = self
                                        self._children_name_map["security_parameters"] = "security-parameters"
                                        self._segment_path = lambda: "core-port"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort, ['xconnect_id', 'vlan_id', 'core_port_state'], name, value)


                                    class SecurityParameters(Entity):
                                        """
                                        Security Parameters
                                        
                                        .. attribute:: base
                                        
                                        	Basic Security Parameters
                                        	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base>`
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl>`
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: dhcpv4_trust
                                        
                                        	DHCPv4 Trust Status
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, self).__init__()

                                            self.yang_name = "security-parameters"
                                            self.yang_parent_name = "core-port"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                                ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                            ])
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None
                                            self.dhcpv4_trust = None

                                            self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base()
                                            self.base.parent = self
                                            self._children_name_map["base"] = "base"

                                            self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "security-parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                        class Base(Entity):
                                            """
                                            Basic Security Parameters
                                            
                                            .. attribute:: storm_control
                                            
                                            	Storm Control Configuration
                                            	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl>`
                                            
                                            .. attribute:: mac_limit
                                            
                                            	MAC address limit
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: mac_limit_action
                                            
                                            	MAC limit action
                                            	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                            
                                            .. attribute:: mac_limit_notification
                                            
                                            	MAC limit notification
                                            	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                            
                                            .. attribute:: mac_aging_time
                                            
                                            	MAC aging time in seconds
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: second
                                            
                                            .. attribute:: mac_aging_mode
                                            
                                            	MAC Aging Mode
                                            	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                            
                                            .. attribute:: mac_flooding
                                            
                                            	MAC flooding enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_learning
                                            
                                            	MAC learning enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: learn_disabled_mac_limit_action
                                            
                                            	Learning disabled due to MAC limit action
                                            	**type**\: bool
                                            
                                            .. attribute:: flood_uu_disabled_mac_limit_action
                                            
                                            	Flooding of unknown\-unicast disabled due to MAC limit action
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_reached
                                            
                                            	MAC limit reached
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_limit_threshold
                                            
                                            	MAC Limit Threshold Percentage
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: percentage
                                            
                                            .. attribute:: flood_unknown_unicast_enabled
                                            
                                            	Flooding unknown unicast enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_port_down_flush_enabled
                                            
                                            	MAC Flush when port goes down
                                            	**type**\: bool
                                            
                                            .. attribute:: split_horizon_group_id
                                            
                                            	Split Horizon Group ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: is_ip_source_guard_enabled
                                            
                                            	Is IP Source Guard Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_ipsg_logging_enabled
                                            
                                            	Is IP Source Guard Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_enabled
                                            
                                            	Is Dynamic ARP Inspection Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_logging_enabled
                                            
                                            	Is DAI Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_source_mac_enabled
                                            
                                            	Is DAI Source MAC Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                            
                                            	Is DAI Dstination MAC Address Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_dai_addr_validate_ipv4_enabled
                                            
                                            	Is DAI IPv4 Addr Validation Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_enabled
                                            
                                            	Is MAC Secure Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: mac_secure_action
                                            
                                            	MAC Secure Action
                                            	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                            
                                            .. attribute:: is_mac_secure_logging_enabled
                                            
                                            	Is MAC Secure Logging Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_accept_shutdown_enabled
                                            
                                            	Is MAC Secure Accept Shutdown Enabled (BP only)
                                            	**type**\: bool
                                            
                                            .. attribute:: is_mac_secure_threshold_enabled
                                            
                                            	Is MAC Secure Threshold Enabled
                                            	**type**\: bool
                                            
                                            .. attribute:: dai_address_validation_mask
                                            
                                            	DAI Address Validation mask
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: dhcpv4_snoop
                                            
                                            	DHCPv4 Snoop Status
                                            	**type**\: bool
                                            
                                            .. attribute:: dhcpv4_profile_name
                                            
                                            	DHCPv4 Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: igm_pv4_disabled
                                            
                                            	IGMPv4 Disabled
                                            	**type**\: bool
                                            
                                            .. attribute:: igm_pv4_profile_name
                                            
                                            	IGMPv4 Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: mld_profile_name
                                            
                                            	MLD Profile Name
                                            	**type**\: str
                                            
                                            .. attribute:: mmrp_flood_optimization
                                            
                                            	MMRP Flood Optimization Status
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast_storm_control_rate_unit
                                            
                                            	Unicast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: unicast_storm_control_pps
                                            
                                            	Unicast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: unicast_storm_control_kb_ps
                                            
                                            	Unicast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: multicast_storm_control_rate_unit
                                            
                                            	Multicast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: multicast_storm_control_pps
                                            
                                            	Multicast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: multicast_storm_control_kb_ps
                                            
                                            	Multicast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: broadcast_storm_control_rate_unit
                                            
                                            	Broadcast Storm Control Rate Unit
                                            	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                            
                                            .. attribute:: broadcast_storm_control_pps
                                            
                                            	Broadcast Storm Control PPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: broadcast_storm_control_kb_ps
                                            
                                            	Broadcast Storm Control KbPS
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: kbit/s
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, self).__init__()

                                                self.yang_name = "base"
                                                self.yang_parent_name = "security-parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl))])
                                                self._leafs = OrderedDict([
                                                    ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                    ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                    ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                    ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                    ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                    ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                    ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                    ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                    ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                    ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                    ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                    ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                    ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                    ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                    ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                    ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                    ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                    ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                    ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                    ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                    ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                    ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                    ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                    ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                    ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                    ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                    ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                    ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                    ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                    ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                    ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                    ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                    ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                    ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                    ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                    ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                    ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                    ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                    ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                    ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                    ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                    ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                                ])
                                                self.mac_limit = None
                                                self.mac_limit_action = None
                                                self.mac_limit_notification = None
                                                self.mac_aging_time = None
                                                self.mac_aging_mode = None
                                                self.mac_flooding = None
                                                self.mac_learning = None
                                                self.learn_disabled_mac_limit_action = None
                                                self.flood_uu_disabled_mac_limit_action = None
                                                self.mac_limit_reached = None
                                                self.mac_limit_threshold = None
                                                self.flood_unknown_unicast_enabled = None
                                                self.mac_port_down_flush_enabled = None
                                                self.split_horizon_group_id = None
                                                self.is_ip_source_guard_enabled = None
                                                self.is_ipsg_logging_enabled = None
                                                self.is_dai_enabled = None
                                                self.is_dai_logging_enabled = None
                                                self.is_dai_addr_validate_source_mac_enabled = None
                                                self.is_dai_addr_validate_destination_mac_enabled = None
                                                self.is_dai_addr_validate_ipv4_enabled = None
                                                self.is_mac_secure_enabled = None
                                                self.mac_secure_action = None
                                                self.is_mac_secure_logging_enabled = None
                                                self.is_mac_secure_accept_shutdown_enabled = None
                                                self.is_mac_secure_threshold_enabled = None
                                                self.dai_address_validation_mask = None
                                                self.dhcpv4_snoop = None
                                                self.dhcpv4_profile_name = None
                                                self.igm_pv4_disabled = None
                                                self.igm_pv4_profile_name = None
                                                self.mld_profile_name = None
                                                self.mmrp_flood_optimization = None
                                                self.unicast_storm_control_rate_unit = None
                                                self.unicast_storm_control_pps = None
                                                self.unicast_storm_control_kb_ps = None
                                                self.multicast_storm_control_rate_unit = None
                                                self.multicast_storm_control_pps = None
                                                self.multicast_storm_control_kb_ps = None
                                                self.broadcast_storm_control_rate_unit = None
                                                self.broadcast_storm_control_pps = None
                                                self.broadcast_storm_control_kb_ps = None

                                                self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl()
                                                self.storm_control.parent = self
                                                self._children_name_map["storm_control"] = "storm-control"
                                                self._segment_path = lambda: "base"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                            class StormControl(Entity):
                                                """
                                                Storm Control Configuration
                                                
                                                .. attribute:: bd_policer
                                                
                                                	Bridge Domain Policer
                                                	**type**\: bool
                                                
                                                .. attribute:: unicast
                                                
                                                	Unknown\-unicast Storm Control
                                                	**type**\: bool
                                                
                                                .. attribute:: multicast
                                                
                                                	Multicast Storm Control
                                                	**type**\: bool
                                                
                                                .. attribute:: broadcast
                                                
                                                	Broadcast Storm Control
                                                	**type**\: bool
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, self).__init__()

                                                    self.yang_name = "storm-control"
                                                    self.yang_parent_name = "base"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                        ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                        ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                        ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                    ])
                                                    self.bd_policer = None
                                                    self.unicast = None
                                                    self.multicast = None
                                                    self.broadcast = None
                                                    self._segment_path = lambda: "storm-control"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "security-parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.PbbParameters.PbbCore.CorePort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                        class EvpnParameters(Entity):
                            """
                            EVPN parameters
                            
                            .. attribute:: evpn_port
                            
                            	EVPN Port
                            	**type**\:  :py:class:`EvpnPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort>`
                            
                            .. attribute:: evi
                            
                            	E\-VPN id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, self).__init__()

                                self.yang_name = "evpn-parameters"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("evpn-port", ("evpn_port", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort))])
                                self._leafs = OrderedDict([
                                    ('evi', YLeaf(YType.uint32, 'evi')),
                                ])
                                self.evi = None

                                self.evpn_port = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort()
                                self.evpn_port.parent = self
                                self._children_name_map["evpn_port"] = "evpn-port"
                                self._segment_path = lambda: "evpn-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters, ['evi'], name, value)


                            class EvpnPort(Entity):
                                """
                                EVPN Port
                                
                                .. attribute:: security_parameters
                                
                                	Security Parameters
                                	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics>`
                                
                                .. attribute:: xconnect_id
                                
                                	Xconnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: evpn_port_state
                                
                                	EVPN Port State
                                	**type**\:  :py:class:`L2vpnVirtualportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVirtualportState>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, self).__init__()

                                    self.yang_name = "evpn-port"
                                    self.yang_parent_name = "evpn-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics))])
                                    self._leafs = OrderedDict([
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('evpn_port_state', YLeaf(YType.enumeration, 'evpn-port-state')),
                                    ])
                                    self.xconnect_id = None
                                    self.evpn_port_state = None

                                    self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters()
                                    self.security_parameters.parent = self
                                    self._children_name_map["security_parameters"] = "security-parameters"

                                    self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"
                                    self._segment_path = lambda: "evpn-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort, ['xconnect_id', 'evpn_port_state'], name, value)


                                class SecurityParameters(Entity):
                                    """
                                    Security Parameters
                                    
                                    .. attribute:: base
                                    
                                    	Basic Security Parameters
                                    	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base>`
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl>`
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: dhcpv4_trust
                                    
                                    	DHCPv4 Trust Status
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, self).__init__()

                                        self.yang_name = "security-parameters"
                                        self.yang_parent_name = "evpn-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                        ])
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None
                                        self.dhcpv4_trust = None

                                        self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base()
                                        self.base.parent = self
                                        self._children_name_map["base"] = "base"

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "security-parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                    class Base(Entity):
                                        """
                                        Basic Security Parameters
                                        
                                        .. attribute:: storm_control
                                        
                                        	Storm Control Configuration
                                        	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl>`
                                        
                                        .. attribute:: mac_limit
                                        
                                        	MAC address limit
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: mac_limit_action
                                        
                                        	MAC limit action
                                        	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                        
                                        .. attribute:: mac_limit_notification
                                        
                                        	MAC limit notification
                                        	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                        
                                        .. attribute:: mac_aging_time
                                        
                                        	MAC aging time in seconds
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: second
                                        
                                        .. attribute:: mac_aging_mode
                                        
                                        	MAC Aging Mode
                                        	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                        
                                        .. attribute:: mac_flooding
                                        
                                        	MAC flooding enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_learning
                                        
                                        	MAC learning enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: learn_disabled_mac_limit_action
                                        
                                        	Learning disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: flood_uu_disabled_mac_limit_action
                                        
                                        	Flooding of unknown\-unicast disabled due to MAC limit action
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_reached
                                        
                                        	MAC limit reached
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_limit_threshold
                                        
                                        	MAC Limit Threshold Percentage
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        	**units**\: percentage
                                        
                                        .. attribute:: flood_unknown_unicast_enabled
                                        
                                        	Flooding unknown unicast enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_port_down_flush_enabled
                                        
                                        	MAC Flush when port goes down
                                        	**type**\: bool
                                        
                                        .. attribute:: split_horizon_group_id
                                        
                                        	Split Horizon Group ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: is_ip_source_guard_enabled
                                        
                                        	Is IP Source Guard Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_ipsg_logging_enabled
                                        
                                        	Is IP Source Guard Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_enabled
                                        
                                        	Is Dynamic ARP Inspection Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_logging_enabled
                                        
                                        	Is DAI Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_source_mac_enabled
                                        
                                        	Is DAI Source MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                        
                                        	Is DAI Dstination MAC Address Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_dai_addr_validate_ipv4_enabled
                                        
                                        	Is DAI IPv4 Addr Validation Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_enabled
                                        
                                        	Is MAC Secure Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: mac_secure_action
                                        
                                        	MAC Secure Action
                                        	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                        
                                        .. attribute:: is_mac_secure_logging_enabled
                                        
                                        	Is MAC Secure Logging Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_accept_shutdown_enabled
                                        
                                        	Is MAC Secure Accept Shutdown Enabled (BP only)
                                        	**type**\: bool
                                        
                                        .. attribute:: is_mac_secure_threshold_enabled
                                        
                                        	Is MAC Secure Threshold Enabled
                                        	**type**\: bool
                                        
                                        .. attribute:: dai_address_validation_mask
                                        
                                        	DAI Address Validation mask
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: dhcpv4_snoop
                                        
                                        	DHCPv4 Snoop Status
                                        	**type**\: bool
                                        
                                        .. attribute:: dhcpv4_profile_name
                                        
                                        	DHCPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: igm_pv4_disabled
                                        
                                        	IGMPv4 Disabled
                                        	**type**\: bool
                                        
                                        .. attribute:: igm_pv4_profile_name
                                        
                                        	IGMPv4 Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mld_profile_name
                                        
                                        	MLD Profile Name
                                        	**type**\: str
                                        
                                        .. attribute:: mmrp_flood_optimization
                                        
                                        	MMRP Flood Optimization Status
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast_storm_control_rate_unit
                                        
                                        	Unicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: unicast_storm_control_pps
                                        
                                        	Unicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: unicast_storm_control_kb_ps
                                        
                                        	Unicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: multicast_storm_control_rate_unit
                                        
                                        	Multicast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: multicast_storm_control_pps
                                        
                                        	Multicast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: multicast_storm_control_kb_ps
                                        
                                        	Multicast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: broadcast_storm_control_rate_unit
                                        
                                        	Broadcast Storm Control Rate Unit
                                        	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                        
                                        .. attribute:: broadcast_storm_control_pps
                                        
                                        	Broadcast Storm Control PPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: broadcast_storm_control_kb_ps
                                        
                                        	Broadcast Storm Control KbPS
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: kbit/s
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, self).__init__()

                                            self.yang_name = "base"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl))])
                                            self._leafs = OrderedDict([
                                                ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                                ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                                ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                                ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                                ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                                ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                                ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                                ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                                ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                                ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                                ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                                ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                                ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                                ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                                ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                                ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                                ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                                ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                                ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                                ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                                ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                                ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                                ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                                ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                                ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                                ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                                ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                                ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                                ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                                ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                                ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                                ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                                ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                                ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                                ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                                ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                                ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                                ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                                ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                                ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                                ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                                ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                            ])
                                            self.mac_limit = None
                                            self.mac_limit_action = None
                                            self.mac_limit_notification = None
                                            self.mac_aging_time = None
                                            self.mac_aging_mode = None
                                            self.mac_flooding = None
                                            self.mac_learning = None
                                            self.learn_disabled_mac_limit_action = None
                                            self.flood_uu_disabled_mac_limit_action = None
                                            self.mac_limit_reached = None
                                            self.mac_limit_threshold = None
                                            self.flood_unknown_unicast_enabled = None
                                            self.mac_port_down_flush_enabled = None
                                            self.split_horizon_group_id = None
                                            self.is_ip_source_guard_enabled = None
                                            self.is_ipsg_logging_enabled = None
                                            self.is_dai_enabled = None
                                            self.is_dai_logging_enabled = None
                                            self.is_dai_addr_validate_source_mac_enabled = None
                                            self.is_dai_addr_validate_destination_mac_enabled = None
                                            self.is_dai_addr_validate_ipv4_enabled = None
                                            self.is_mac_secure_enabled = None
                                            self.mac_secure_action = None
                                            self.is_mac_secure_logging_enabled = None
                                            self.is_mac_secure_accept_shutdown_enabled = None
                                            self.is_mac_secure_threshold_enabled = None
                                            self.dai_address_validation_mask = None
                                            self.dhcpv4_snoop = None
                                            self.dhcpv4_profile_name = None
                                            self.igm_pv4_disabled = None
                                            self.igm_pv4_profile_name = None
                                            self.mld_profile_name = None
                                            self.mmrp_flood_optimization = None
                                            self.unicast_storm_control_rate_unit = None
                                            self.unicast_storm_control_pps = None
                                            self.unicast_storm_control_kb_ps = None
                                            self.multicast_storm_control_rate_unit = None
                                            self.multicast_storm_control_pps = None
                                            self.multicast_storm_control_kb_ps = None
                                            self.broadcast_storm_control_rate_unit = None
                                            self.broadcast_storm_control_pps = None
                                            self.broadcast_storm_control_kb_ps = None

                                            self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl()
                                            self.storm_control.parent = self
                                            self._children_name_map["storm_control"] = "storm-control"
                                            self._segment_path = lambda: "base"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                        class StormControl(Entity):
                                            """
                                            Storm Control Configuration
                                            
                                            .. attribute:: bd_policer
                                            
                                            	Bridge Domain Policer
                                            	**type**\: bool
                                            
                                            .. attribute:: unicast
                                            
                                            	Unknown\-unicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: multicast
                                            
                                            	Multicast Storm Control
                                            	**type**\: bool
                                            
                                            .. attribute:: broadcast
                                            
                                            	Broadcast Storm Control
                                            	**type**\: bool
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, self).__init__()

                                                self.yang_name = "storm-control"
                                                self.yang_parent_name = "base"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                    ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                    ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                    ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                                ])
                                                self.bd_policer = None
                                                self.unicast = None
                                                self.multicast = None
                                                self.broadcast = None
                                                self._segment_path = lambda: "storm-control"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "security-parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "evpn-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.EvpnParameters.EvpnPort.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                        class VniParameters(Entity):
                            """
                            VNI parameters
                            
                            .. attribute:: security_parameters
                            
                            	Security Parameters
                            	**type**\:  :py:class:`SecurityParameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics>`
                            
                            .. attribute:: vni
                            
                            	VNI
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: overlay
                            
                            	NVE Overlay
                            	**type**\: str
                            
                            .. attribute:: source_ip_addr
                            
                            	Source IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: multicast_group_addr
                            
                            	Multicast Group Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_vtep_ip_addr
                            
                            	Anycast VTEP IP Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: anycast_mcast_group_addr
                            
                            	Anycast Multicast Group Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: udp_port
                            
                            	UDP Port
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: vni_encap_type
                            
                            	VNI Encapsulation Type
                            	**type**\:  :py:class:`L2vpnVniEncaps <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniEncaps>`
                            
                            .. attribute:: vni_port_state
                            
                            	VNI Port State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: vni_mode
                            
                            	VNI Mode
                            	**type**\:  :py:class:`L2vpnVniMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVniMode>`
                            
                            .. attribute:: ingress_replication
                            
                            	VNI Ingress Replication is enabled
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	Xconnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: static_mac
                            
                            	Static MAC addresses
                            	**type**\: list of  		 :py:class:`StaticMac <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, self).__init__()

                                self.yang_name = "vni-parameters"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("security-parameters", ("security_parameters", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics)), ("static-mac", ("static_mac", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac))])
                                self._leafs = OrderedDict([
                                    ('vni', YLeaf(YType.uint32, 'vni')),
                                    ('overlay', YLeaf(YType.str, 'overlay')),
                                    ('source_ip_addr', YLeaf(YType.str, 'source-ip-addr')),
                                    ('multicast_group_addr', YLeaf(YType.str, 'multicast-group-addr')),
                                    ('anycast_vtep_ip_addr', YLeaf(YType.str, 'anycast-vtep-ip-addr')),
                                    ('anycast_mcast_group_addr', YLeaf(YType.str, 'anycast-mcast-group-addr')),
                                    ('udp_port', YLeaf(YType.uint32, 'udp-port')),
                                    ('vni_encap_type', YLeaf(YType.enumeration, 'vni-encap-type')),
                                    ('vni_port_state', YLeaf(YType.enumeration, 'vni-port-state')),
                                    ('vni_mode', YLeaf(YType.enumeration, 'vni-mode')),
                                    ('ingress_replication', YLeaf(YType.boolean, 'ingress-replication')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                ])
                                self.vni = None
                                self.overlay = None
                                self.source_ip_addr = None
                                self.multicast_group_addr = None
                                self.anycast_vtep_ip_addr = None
                                self.anycast_mcast_group_addr = None
                                self.udp_port = None
                                self.vni_encap_type = None
                                self.vni_port_state = None
                                self.vni_mode = None
                                self.ingress_replication = None
                                self.xconnect_id = None

                                self.security_parameters = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters()
                                self.security_parameters.parent = self
                                self._children_name_map["security_parameters"] = "security-parameters"

                                self.statistics = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.static_mac = YList(self)
                                self._segment_path = lambda: "vni-parameters"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters, ['vni', 'overlay', 'source_ip_addr', 'multicast_group_addr', 'anycast_vtep_ip_addr', 'anycast_mcast_group_addr', 'udp_port', 'vni_encap_type', 'vni_port_state', 'vni_mode', 'ingress_replication', 'xconnect_id'], name, value)


                            class SecurityParameters(Entity):
                                """
                                Security Parameters
                                
                                .. attribute:: base
                                
                                	Basic Security Parameters
                                	**type**\:  :py:class:`Base <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base>`
                                
                                .. attribute:: storm_control
                                
                                	Storm Control Configuration
                                	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl>`
                                
                                .. attribute:: unicast_storm_control_rate_unit
                                
                                	Unicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: unicast_storm_control_pps
                                
                                	Unicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: unicast_storm_control_kb_ps
                                
                                	Unicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: multicast_storm_control_rate_unit
                                
                                	Multicast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: multicast_storm_control_pps
                                
                                	Multicast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: multicast_storm_control_kb_ps
                                
                                	Multicast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: broadcast_storm_control_rate_unit
                                
                                	Broadcast Storm Control Rate Unit
                                	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                
                                .. attribute:: broadcast_storm_control_pps
                                
                                	Broadcast Storm Control PPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: broadcast_storm_control_kb_ps
                                
                                	Broadcast Storm Control KbPS
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                	**units**\: kbit/s
                                
                                .. attribute:: dhcpv4_trust
                                
                                	DHCPv4 Trust Status
                                	**type**\: bool
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, self).__init__()

                                    self.yang_name = "security-parameters"
                                    self.yang_parent_name = "vni-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("base", ("base", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base)), ("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl))])
                                    self._leafs = OrderedDict([
                                        ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                        ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                        ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                        ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                        ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                        ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                        ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                        ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                        ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ('dhcpv4_trust', YLeaf(YType.boolean, 'dhcpv4-trust')),
                                    ])
                                    self.unicast_storm_control_rate_unit = None
                                    self.unicast_storm_control_pps = None
                                    self.unicast_storm_control_kb_ps = None
                                    self.multicast_storm_control_rate_unit = None
                                    self.multicast_storm_control_pps = None
                                    self.multicast_storm_control_kb_ps = None
                                    self.broadcast_storm_control_rate_unit = None
                                    self.broadcast_storm_control_pps = None
                                    self.broadcast_storm_control_kb_ps = None
                                    self.dhcpv4_trust = None

                                    self.base = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base()
                                    self.base.parent = self
                                    self._children_name_map["base"] = "base"

                                    self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl()
                                    self.storm_control.parent = self
                                    self._children_name_map["storm_control"] = "storm-control"
                                    self._segment_path = lambda: "security-parameters"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters, ['unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps', 'dhcpv4_trust'], name, value)


                                class Base(Entity):
                                    """
                                    Basic Security Parameters
                                    
                                    .. attribute:: storm_control
                                    
                                    	Storm Control Configuration
                                    	**type**\:  :py:class:`StormControl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl>`
                                    
                                    .. attribute:: mac_limit
                                    
                                    	MAC address limit
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: mac_limit_action
                                    
                                    	MAC limit action
                                    	**type**\:  :py:class:`L2vpnBagMacLimitAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitAction>`
                                    
                                    .. attribute:: mac_limit_notification
                                    
                                    	MAC limit notification
                                    	**type**\:  :py:class:`L2vpnBagMacLimitNotify <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacLimitNotify>`
                                    
                                    .. attribute:: mac_aging_time
                                    
                                    	MAC aging time in seconds
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: second
                                    
                                    .. attribute:: mac_aging_mode
                                    
                                    	MAC Aging Mode
                                    	**type**\:  :py:class:`L2vpnBagMacAgingMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacAgingMode>`
                                    
                                    .. attribute:: mac_flooding
                                    
                                    	MAC flooding enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_learning
                                    
                                    	MAC learning enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: learn_disabled_mac_limit_action
                                    
                                    	Learning disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: flood_uu_disabled_mac_limit_action
                                    
                                    	Flooding of unknown\-unicast disabled due to MAC limit action
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_reached
                                    
                                    	MAC limit reached
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_limit_threshold
                                    
                                    	MAC Limit Threshold Percentage
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    	**units**\: percentage
                                    
                                    .. attribute:: flood_unknown_unicast_enabled
                                    
                                    	Flooding unknown unicast enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_port_down_flush_enabled
                                    
                                    	MAC Flush when port goes down
                                    	**type**\: bool
                                    
                                    .. attribute:: split_horizon_group_id
                                    
                                    	Split Horizon Group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_ip_source_guard_enabled
                                    
                                    	Is IP Source Guard Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_ipsg_logging_enabled
                                    
                                    	Is IP Source Guard Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_enabled
                                    
                                    	Is Dynamic ARP Inspection Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_logging_enabled
                                    
                                    	Is DAI Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_source_mac_enabled
                                    
                                    	Is DAI Source MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_destination_mac_enabled
                                    
                                    	Is DAI Dstination MAC Address Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_dai_addr_validate_ipv4_enabled
                                    
                                    	Is DAI IPv4 Addr Validation Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_enabled
                                    
                                    	Is MAC Secure Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: mac_secure_action
                                    
                                    	MAC Secure Action
                                    	**type**\:  :py:class:`L2vpnBagMacSecureAction <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagMacSecureAction>`
                                    
                                    .. attribute:: is_mac_secure_logging_enabled
                                    
                                    	Is MAC Secure Logging Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_accept_shutdown_enabled
                                    
                                    	Is MAC Secure Accept Shutdown Enabled (BP only)
                                    	**type**\: bool
                                    
                                    .. attribute:: is_mac_secure_threshold_enabled
                                    
                                    	Is MAC Secure Threshold Enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: dai_address_validation_mask
                                    
                                    	DAI Address Validation mask
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: dhcpv4_snoop
                                    
                                    	DHCPv4 Snoop Status
                                    	**type**\: bool
                                    
                                    .. attribute:: dhcpv4_profile_name
                                    
                                    	DHCPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: igm_pv4_disabled
                                    
                                    	IGMPv4 Disabled
                                    	**type**\: bool
                                    
                                    .. attribute:: igm_pv4_profile_name
                                    
                                    	IGMPv4 Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mld_profile_name
                                    
                                    	MLD Profile Name
                                    	**type**\: str
                                    
                                    .. attribute:: mmrp_flood_optimization
                                    
                                    	MMRP Flood Optimization Status
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast_storm_control_rate_unit
                                    
                                    	Unicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: unicast_storm_control_pps
                                    
                                    	Unicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: unicast_storm_control_kb_ps
                                    
                                    	Unicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: multicast_storm_control_rate_unit
                                    
                                    	Multicast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: multicast_storm_control_pps
                                    
                                    	Multicast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: multicast_storm_control_kb_ps
                                    
                                    	Multicast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    .. attribute:: broadcast_storm_control_rate_unit
                                    
                                    	Broadcast Storm Control Rate Unit
                                    	**type**\:  :py:class:`L2vpnBagStormControlRateUnit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBagStormControlRateUnit>`
                                    
                                    .. attribute:: broadcast_storm_control_pps
                                    
                                    	Broadcast Storm Control PPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: broadcast_storm_control_kb_ps
                                    
                                    	Broadcast Storm Control KbPS
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    	**units**\: kbit/s
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, self).__init__()

                                        self.yang_name = "base"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("storm-control", ("storm_control", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl))])
                                        self._leafs = OrderedDict([
                                            ('mac_limit', YLeaf(YType.uint32, 'mac-limit')),
                                            ('mac_limit_action', YLeaf(YType.enumeration, 'mac-limit-action')),
                                            ('mac_limit_notification', YLeaf(YType.enumeration, 'mac-limit-notification')),
                                            ('mac_aging_time', YLeaf(YType.uint32, 'mac-aging-time')),
                                            ('mac_aging_mode', YLeaf(YType.enumeration, 'mac-aging-mode')),
                                            ('mac_flooding', YLeaf(YType.boolean, 'mac-flooding')),
                                            ('mac_learning', YLeaf(YType.boolean, 'mac-learning')),
                                            ('learn_disabled_mac_limit_action', YLeaf(YType.boolean, 'learn-disabled-mac-limit-action')),
                                            ('flood_uu_disabled_mac_limit_action', YLeaf(YType.boolean, 'flood-uu-disabled-mac-limit-action')),
                                            ('mac_limit_reached', YLeaf(YType.boolean, 'mac-limit-reached')),
                                            ('mac_limit_threshold', YLeaf(YType.uint32, 'mac-limit-threshold')),
                                            ('flood_unknown_unicast_enabled', YLeaf(YType.boolean, 'flood-unknown-unicast-enabled')),
                                            ('mac_port_down_flush_enabled', YLeaf(YType.boolean, 'mac-port-down-flush-enabled')),
                                            ('split_horizon_group_id', YLeaf(YType.uint32, 'split-horizon-group-id')),
                                            ('is_ip_source_guard_enabled', YLeaf(YType.boolean, 'is-ip-source-guard-enabled')),
                                            ('is_ipsg_logging_enabled', YLeaf(YType.boolean, 'is-ipsg-logging-enabled')),
                                            ('is_dai_enabled', YLeaf(YType.boolean, 'is-dai-enabled')),
                                            ('is_dai_logging_enabled', YLeaf(YType.boolean, 'is-dai-logging-enabled')),
                                            ('is_dai_addr_validate_source_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-source-mac-enabled')),
                                            ('is_dai_addr_validate_destination_mac_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-destination-mac-enabled')),
                                            ('is_dai_addr_validate_ipv4_enabled', YLeaf(YType.boolean, 'is-dai-addr-validate-ipv4-enabled')),
                                            ('is_mac_secure_enabled', YLeaf(YType.boolean, 'is-mac-secure-enabled')),
                                            ('mac_secure_action', YLeaf(YType.enumeration, 'mac-secure-action')),
                                            ('is_mac_secure_logging_enabled', YLeaf(YType.boolean, 'is-mac-secure-logging-enabled')),
                                            ('is_mac_secure_accept_shutdown_enabled', YLeaf(YType.boolean, 'is-mac-secure-accept-shutdown-enabled')),
                                            ('is_mac_secure_threshold_enabled', YLeaf(YType.boolean, 'is-mac-secure-threshold-enabled')),
                                            ('dai_address_validation_mask', YLeaf(YType.uint8, 'dai-address-validation-mask')),
                                            ('dhcpv4_snoop', YLeaf(YType.boolean, 'dhcpv4-snoop')),
                                            ('dhcpv4_profile_name', YLeaf(YType.str, 'dhcpv4-profile-name')),
                                            ('igm_pv4_disabled', YLeaf(YType.boolean, 'igm-pv4-disabled')),
                                            ('igm_pv4_profile_name', YLeaf(YType.str, 'igm-pv4-profile-name')),
                                            ('mld_profile_name', YLeaf(YType.str, 'mld-profile-name')),
                                            ('mmrp_flood_optimization', YLeaf(YType.boolean, 'mmrp-flood-optimization')),
                                            ('unicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'unicast-storm-control-rate-unit')),
                                            ('unicast_storm_control_pps', YLeaf(YType.uint64, 'unicast-storm-control-pps')),
                                            ('unicast_storm_control_kb_ps', YLeaf(YType.uint64, 'unicast-storm-control-kb-ps')),
                                            ('multicast_storm_control_rate_unit', YLeaf(YType.enumeration, 'multicast-storm-control-rate-unit')),
                                            ('multicast_storm_control_pps', YLeaf(YType.uint64, 'multicast-storm-control-pps')),
                                            ('multicast_storm_control_kb_ps', YLeaf(YType.uint64, 'multicast-storm-control-kb-ps')),
                                            ('broadcast_storm_control_rate_unit', YLeaf(YType.enumeration, 'broadcast-storm-control-rate-unit')),
                                            ('broadcast_storm_control_pps', YLeaf(YType.uint64, 'broadcast-storm-control-pps')),
                                            ('broadcast_storm_control_kb_ps', YLeaf(YType.uint64, 'broadcast-storm-control-kb-ps')),
                                        ])
                                        self.mac_limit = None
                                        self.mac_limit_action = None
                                        self.mac_limit_notification = None
                                        self.mac_aging_time = None
                                        self.mac_aging_mode = None
                                        self.mac_flooding = None
                                        self.mac_learning = None
                                        self.learn_disabled_mac_limit_action = None
                                        self.flood_uu_disabled_mac_limit_action = None
                                        self.mac_limit_reached = None
                                        self.mac_limit_threshold = None
                                        self.flood_unknown_unicast_enabled = None
                                        self.mac_port_down_flush_enabled = None
                                        self.split_horizon_group_id = None
                                        self.is_ip_source_guard_enabled = None
                                        self.is_ipsg_logging_enabled = None
                                        self.is_dai_enabled = None
                                        self.is_dai_logging_enabled = None
                                        self.is_dai_addr_validate_source_mac_enabled = None
                                        self.is_dai_addr_validate_destination_mac_enabled = None
                                        self.is_dai_addr_validate_ipv4_enabled = None
                                        self.is_mac_secure_enabled = None
                                        self.mac_secure_action = None
                                        self.is_mac_secure_logging_enabled = None
                                        self.is_mac_secure_accept_shutdown_enabled = None
                                        self.is_mac_secure_threshold_enabled = None
                                        self.dai_address_validation_mask = None
                                        self.dhcpv4_snoop = None
                                        self.dhcpv4_profile_name = None
                                        self.igm_pv4_disabled = None
                                        self.igm_pv4_profile_name = None
                                        self.mld_profile_name = None
                                        self.mmrp_flood_optimization = None
                                        self.unicast_storm_control_rate_unit = None
                                        self.unicast_storm_control_pps = None
                                        self.unicast_storm_control_kb_ps = None
                                        self.multicast_storm_control_rate_unit = None
                                        self.multicast_storm_control_pps = None
                                        self.multicast_storm_control_kb_ps = None
                                        self.broadcast_storm_control_rate_unit = None
                                        self.broadcast_storm_control_pps = None
                                        self.broadcast_storm_control_kb_ps = None

                                        self.storm_control = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl()
                                        self.storm_control.parent = self
                                        self._children_name_map["storm_control"] = "storm-control"
                                        self._segment_path = lambda: "base"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base, ['mac_limit', 'mac_limit_action', 'mac_limit_notification', 'mac_aging_time', 'mac_aging_mode', 'mac_flooding', 'mac_learning', 'learn_disabled_mac_limit_action', 'flood_uu_disabled_mac_limit_action', 'mac_limit_reached', 'mac_limit_threshold', 'flood_unknown_unicast_enabled', 'mac_port_down_flush_enabled', 'split_horizon_group_id', 'is_ip_source_guard_enabled', 'is_ipsg_logging_enabled', 'is_dai_enabled', 'is_dai_logging_enabled', 'is_dai_addr_validate_source_mac_enabled', 'is_dai_addr_validate_destination_mac_enabled', 'is_dai_addr_validate_ipv4_enabled', 'is_mac_secure_enabled', 'mac_secure_action', 'is_mac_secure_logging_enabled', 'is_mac_secure_accept_shutdown_enabled', 'is_mac_secure_threshold_enabled', 'dai_address_validation_mask', 'dhcpv4_snoop', 'dhcpv4_profile_name', 'igm_pv4_disabled', 'igm_pv4_profile_name', 'mld_profile_name', 'mmrp_flood_optimization', 'unicast_storm_control_rate_unit', 'unicast_storm_control_pps', 'unicast_storm_control_kb_ps', 'multicast_storm_control_rate_unit', 'multicast_storm_control_pps', 'multicast_storm_control_kb_ps', 'broadcast_storm_control_rate_unit', 'broadcast_storm_control_pps', 'broadcast_storm_control_kb_ps'], name, value)


                                    class StormControl(Entity):
                                        """
                                        Storm Control Configuration
                                        
                                        .. attribute:: bd_policer
                                        
                                        	Bridge Domain Policer
                                        	**type**\: bool
                                        
                                        .. attribute:: unicast
                                        
                                        	Unknown\-unicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast Storm Control
                                        	**type**\: bool
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast Storm Control
                                        	**type**\: bool
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, self).__init__()

                                            self.yang_name = "storm-control"
                                            self.yang_parent_name = "base"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                                ('unicast', YLeaf(YType.boolean, 'unicast')),
                                                ('multicast', YLeaf(YType.boolean, 'multicast')),
                                                ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                            ])
                                            self.bd_policer = None
                                            self.unicast = None
                                            self.multicast = None
                                            self.broadcast = None
                                            self._segment_path = lambda: "storm-control"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.Base.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                                class StormControl(Entity):
                                    """
                                    Storm Control Configuration
                                    
                                    .. attribute:: bd_policer
                                    
                                    	Bridge Domain Policer
                                    	**type**\: bool
                                    
                                    .. attribute:: unicast
                                    
                                    	Unknown\-unicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast Storm Control
                                    	**type**\: bool
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast Storm Control
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, self).__init__()

                                        self.yang_name = "storm-control"
                                        self.yang_parent_name = "security-parameters"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('bd_policer', YLeaf(YType.boolean, 'bd-policer')),
                                            ('unicast', YLeaf(YType.boolean, 'unicast')),
                                            ('multicast', YLeaf(YType.boolean, 'multicast')),
                                            ('broadcast', YLeaf(YType.boolean, 'broadcast')),
                                        ])
                                        self.bd_policer = None
                                        self.unicast = None
                                        self.multicast = None
                                        self.broadcast = None
                                        self._segment_path = lambda: "storm-control"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.SecurityParameters.StormControl, ['bd_policer', 'unicast', 'multicast', 'broadcast'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "vni-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class StaticMac(Entity):
                                """
                                Static MAC addresses
                                
                                .. attribute:: address
                                
                                	MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: bmac
                                
                                	Backbone MAC address
                                	**type**\: str
                                
                                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                                
                                .. attribute:: next_hop_ip
                                
                                	Next Hop IP
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, self).__init__()

                                    self.yang_name = "static-mac"
                                    self.yang_parent_name = "vni-parameters"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('address', YLeaf(YType.str, 'address')),
                                        ('bmac', YLeaf(YType.str, 'bmac')),
                                        ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                    ])
                                    self.address = None
                                    self.bmac = None
                                    self.next_hop_ip = None
                                    self._segment_path = lambda: "static-mac"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.VniParameters.StaticMac, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class Rd(Entity):
                            """
                            Route Distinguisher
                            
                            .. attribute:: auto
                            
                            	auto
                            	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto>`
                            
                            .. attribute:: two_byte_as
                            
                            	two byte as
                            	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs>`
                            
                            .. attribute:: four_byte_as
                            
                            	four byte as
                            	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs>`
                            
                            .. attribute:: v4_addr
                            
                            	v4 addr
                            	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr>`
                            
                            .. attribute:: rd
                            
                            	RD
                            	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, self).__init__()

                                self.yang_name = "rd"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr))])
                                self._leafs = OrderedDict([
                                    ('rd', YLeaf(YType.enumeration, 'rd')),
                                ])
                                self.rd = None

                                self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto()
                                self.auto.parent = self
                                self._children_name_map["auto"] = "auto"

                                self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs()
                                self.two_byte_as.parent = self
                                self._children_name_map["two_byte_as"] = "two-byte-as"

                                self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs()
                                self.four_byte_as.parent = self
                                self._children_name_map["four_byte_as"] = "four-byte-as"

                                self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr()
                                self.v4_addr.parent = self
                                self._children_name_map["v4_addr"] = "v4-addr"
                                self._segment_path = lambda: "rd"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd, ['rd'], name, value)


                            class Auto(Entity):
                                """
                                auto
                                
                                .. attribute:: router_id
                                
                                	BGP Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: auto_index
                                
                                	Auto\-generated Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, self).__init__()

                                    self.yang_name = "auto"
                                    self.yang_parent_name = "rd"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('router_id', YLeaf(YType.str, 'router-id')),
                                        ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                    ])
                                    self.router_id = None
                                    self.auto_index = None
                                    self._segment_path = lambda: "auto"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.Auto, ['router_id', 'auto_index'], name, value)


                            class TwoByteAs(Entity):
                                """
                                two byte as
                                
                                .. attribute:: two_byte_as
                                
                                	2 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: four_byte_index
                                
                                	4 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, self).__init__()

                                    self.yang_name = "two-byte-as"
                                    self.yang_parent_name = "rd"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                        ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                    ])
                                    self.two_byte_as = None
                                    self.four_byte_index = None
                                    self._segment_path = lambda: "two-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                            class FourByteAs(Entity):
                                """
                                four byte as
                                
                                .. attribute:: four_byte_as
                                
                                	4 Byte AS Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, self).__init__()

                                    self.yang_name = "four-byte-as"
                                    self.yang_parent_name = "rd"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.four_byte_as = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "four-byte-as"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                            class V4Addr(Entity):
                                """
                                v4 addr
                                
                                .. attribute:: ipv4_address
                                
                                	IPv4 Address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: two_byte_index
                                
                                	2 Byte Index
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, self).__init__()

                                    self.yang_name = "v4-addr"
                                    self.yang_parent_name = "rd"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                        ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                    ])
                                    self.ipv4_address = None
                                    self.two_byte_index = None
                                    self._segment_path = lambda: "v4-addr"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.Rd.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                        class MacFilter(Entity):
                            """
                            MAC addresses for filtering
                            
                            .. attribute:: address
                            
                            	MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: bmac
                            
                            	Backbone MAC address
                            	**type**\: str
                            
                            	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                            
                            .. attribute:: next_hop_ip
                            
                            	Next Hop IP
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, self).__init__()

                                self.yang_name = "mac-filter"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('address', YLeaf(YType.str, 'address')),
                                    ('bmac', YLeaf(YType.str, 'bmac')),
                                    ('next_hop_ip', YLeaf(YType.str, 'next-hop-ip')),
                                ])
                                self.address = None
                                self.bmac = None
                                self.next_hop_ip = None
                                self._segment_path = lambda: "mac-filter"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.MacFilter, ['address', 'bmac', 'next_hop_ip'], name, value)


                        class BridgeVfi(Entity):
                            """
                            Virtual Forwarding Interfaces
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation>`
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\: bool
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, self).__init__()

                                self.yang_name = "bridge-vfi"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation))])
                                self._leafs = OrderedDict([
                                    ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('access', YLeaf(YType.boolean, 'access')),
                                    ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                    ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                                ])
                                self.vfi_name = None
                                self.shutdown = None
                                self.access = None
                                self.vfi_state = None
                                self.number_pseudowires = None

                                self.discovery_information = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"

                                self.p2mp_information = YList(self)
                                self._segment_path = lambda: "bridge-vfi"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                            class DiscoveryInformation(Entity):
                                """
                                Auto Discovery information
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\: bool
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\: bool
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\: bool
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\: str
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, self).__init__()

                                    self.yang_name = "discovery-information"
                                    self.yang_parent_name = "bridge-vfi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt))])
                                    self._leafs = OrderedDict([
                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('ve_id', YLeaf(YType.uint32, 've-id')),
                                        ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                        ('ve_range', YLeaf(YType.uint16, 've-range')),
                                        ('as_number', YLeaf(YType.uint32, 'as-number')),
                                        ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                        ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                        ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                        ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                        ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                    ])
                                    self.vpn_id = None
                                    self.ad_signalling_method = None
                                    self.ad_method = None
                                    self.ve_id = None
                                    self.provisioned_ve_id = None
                                    self.ve_range = None
                                    self.as_number = None
                                    self.l2vpn_router_id = None
                                    self.vpn_added = None
                                    self.service_connected = None
                                    self.vpls_id_conflict = None
                                    self.export_route_policy = None

                                    self.rd_value = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"

                                    self.vpls_id = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"

                                    self.import_rt = YList(self)
                                    self.export_rt = YList(self)
                                    self._segment_path = lambda: "discovery-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                                class RdValue(Entity):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, self).__init__()

                                        self.yang_name = "rd-value"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('rd', YLeaf(YType.enumeration, 'rd')),
                                        ])
                                        self.rd = None

                                        self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "rd-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('router_id', YLeaf(YType.str, 'router-id')),
                                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                            ])
                                            self.router_id = None
                                            self.auto_index = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class VplsId(Entity):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, self).__init__()

                                        self.yang_name = "vpls-id"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "vpls-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class ImportRt(Entity):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, self).__init__()

                                        self.yang_name = "import-rt"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport))])
                                        self._leafs = OrderedDict([
                                            ('rt', YLeaf(YType.enumeration, 'rt')),
                                        ])
                                        self.rt = None

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"

                                        self.es_import = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._segment_path = lambda: "import-rt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                                ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                            ])
                                            self.high_bytes = None
                                            self.low_bytes = None
                                            self._segment_path = lambda: "es-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                                class ExportRt(Entity):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, self).__init__()

                                        self.yang_name = "export-rt"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport))])
                                        self._leafs = OrderedDict([
                                            ('rt', YLeaf(YType.enumeration, 'rt')),
                                        ])
                                        self.rt = None

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"

                                        self.es_import = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._segment_path = lambda: "export-rt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                                ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                            ])
                                            self.high_bytes = None
                                            self.low_bytes = None
                                            self._segment_path = lambda: "es-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class P2mpInformation(Entity):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\: str
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, self).__init__()

                                    self.yang_name = "p2mp-information"
                                    self.yang_parent_name = "bridge-vfi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('transport', YLeaf(YType.enumeration, 'transport')),
                                        ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                        ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                        ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                        ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                    ])
                                    self.transport = None
                                    self.signaling = None
                                    self.ptree_id = None
                                    self.attribute_set_name = None
                                    self.transport_status = None
                                    self.local_label = None
                                    self.tunnel_interface = None
                                    self._segment_path = lambda: "p2mp-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


                        class BridgeAccessVfi(Entity):
                            """
                            Access Virtual Forwarding Interfaces
                            
                            .. attribute:: discovery_information
                            
                            	Auto Discovery information
                            	**type**\:  :py:class:`DiscoveryInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation>`
                            
                            .. attribute:: vfi_name
                            
                            	Virtual forwarding instance name
                            	**type**\: str
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: access
                            
                            	VFI is an Access VFI
                            	**type**\: bool
                            
                            .. attribute:: vfi_state
                            
                            	VFI state
                            	**type**\:  :py:class:`L2vpnVfiState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiState>`
                            
                            .. attribute:: number_pseudowires
                            
                            	Number of Pseudowires
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: p2mp_information
                            
                            	Multicast P2MP information
                            	**type**\: list of  		 :py:class:`P2mpInformation <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, self).__init__()

                                self.yang_name = "bridge-access-vfi"
                                self.yang_parent_name = "bridge-domain-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("discovery-information", ("discovery_information", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation)), ("p2mp-information", ("p2mp_information", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation))])
                                self._leafs = OrderedDict([
                                    ('vfi_name', YLeaf(YType.str, 'vfi-name')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('access', YLeaf(YType.boolean, 'access')),
                                    ('vfi_state', YLeaf(YType.enumeration, 'vfi-state')),
                                    ('number_pseudowires', YLeaf(YType.uint32, 'number-pseudowires')),
                                ])
                                self.vfi_name = None
                                self.shutdown = None
                                self.access = None
                                self.vfi_state = None
                                self.number_pseudowires = None

                                self.discovery_information = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation()
                                self.discovery_information.parent = self
                                self._children_name_map["discovery_information"] = "discovery-information"

                                self.p2mp_information = YList(self)
                                self._segment_path = lambda: "bridge-access-vfi"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi, ['vfi_name', 'shutdown', 'access', 'vfi_state', 'number_pseudowires'], name, value)


                            class DiscoveryInformation(Entity):
                                """
                                Auto Discovery information
                                
                                .. attribute:: rd_value
                                
                                	Route Distinguisher
                                	**type**\:  :py:class:`RdValue <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue>`
                                
                                .. attribute:: vpls_id
                                
                                	VPLS ID
                                	**type**\:  :py:class:`VplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId>`
                                
                                .. attribute:: vpn_id
                                
                                	Vpn ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_signalling_method
                                
                                	Signaling protocol
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ad_method
                                
                                	Autodiscovery method
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_id
                                
                                	VPLS Edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: provisioned_ve_id
                                
                                	Provisioned VPLS edge ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ve_range
                                
                                	VE range
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: as_number
                                
                                	Autonomous System Number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: l2vpn_router_id
                                
                                	L2PVN Router ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: vpn_added
                                
                                	Is VPN id configured
                                	**type**\: bool
                                
                                .. attribute:: service_connected
                                
                                	Is the BGP service connected?
                                	**type**\: bool
                                
                                .. attribute:: vpls_id_conflict
                                
                                	VPLS\-ID Conflict
                                	**type**\: bool
                                
                                .. attribute:: export_route_policy
                                
                                	Export Route Policy
                                	**type**\: str
                                
                                .. attribute:: import_rt
                                
                                	List of import route targets
                                	**type**\: list of  		 :py:class:`ImportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt>`
                                
                                .. attribute:: export_rt
                                
                                	List of export route targets
                                	**type**\: list of  		 :py:class:`ExportRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, self).__init__()

                                    self.yang_name = "discovery-information"
                                    self.yang_parent_name = "bridge-access-vfi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("rd-value", ("rd_value", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue)), ("vpls-id", ("vpls_id", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId)), ("import-rt", ("import_rt", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt)), ("export-rt", ("export_rt", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt))])
                                    self._leafs = OrderedDict([
                                        ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                        ('ad_signalling_method', YLeaf(YType.uint32, 'ad-signalling-method')),
                                        ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                        ('ve_id', YLeaf(YType.uint32, 've-id')),
                                        ('provisioned_ve_id', YLeaf(YType.uint32, 'provisioned-ve-id')),
                                        ('ve_range', YLeaf(YType.uint16, 've-range')),
                                        ('as_number', YLeaf(YType.uint32, 'as-number')),
                                        ('l2vpn_router_id', YLeaf(YType.str, 'l2vpn-router-id')),
                                        ('vpn_added', YLeaf(YType.boolean, 'vpn-added')),
                                        ('service_connected', YLeaf(YType.boolean, 'service-connected')),
                                        ('vpls_id_conflict', YLeaf(YType.boolean, 'vpls-id-conflict')),
                                        ('export_route_policy', YLeaf(YType.str, 'export-route-policy')),
                                    ])
                                    self.vpn_id = None
                                    self.ad_signalling_method = None
                                    self.ad_method = None
                                    self.ve_id = None
                                    self.provisioned_ve_id = None
                                    self.ve_range = None
                                    self.as_number = None
                                    self.l2vpn_router_id = None
                                    self.vpn_added = None
                                    self.service_connected = None
                                    self.vpls_id_conflict = None
                                    self.export_route_policy = None

                                    self.rd_value = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue()
                                    self.rd_value.parent = self
                                    self._children_name_map["rd_value"] = "rd-value"

                                    self.vpls_id = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId()
                                    self.vpls_id.parent = self
                                    self._children_name_map["vpls_id"] = "vpls-id"

                                    self.import_rt = YList(self)
                                    self.export_rt = YList(self)
                                    self._segment_path = lambda: "discovery-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation, ['vpn_id', 'ad_signalling_method', 'ad_method', 've_id', 'provisioned_ve_id', 've_range', 'as_number', 'l2vpn_router_id', 'vpn_added', 'service_connected', 'vpls_id_conflict', 'export_route_policy'], name, value)


                                class RdValue(Entity):
                                    """
                                    Route Distinguisher
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr>`
                                    
                                    .. attribute:: rd
                                    
                                    	RD
                                    	**type**\:  :py:class:`L2vpnAdRd <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRd>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, self).__init__()

                                        self.yang_name = "rd-value"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('rd', YLeaf(YType.enumeration, 'rd')),
                                        ])
                                        self.rd = None

                                        self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "rd-value"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue, ['rd'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: router_id
                                        
                                        	BGP Router ID
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: auto_index
                                        
                                        	Auto\-generated Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('router_id', YLeaf(YType.str, 'router-id')),
                                                ('auto_index', YLeaf(YType.uint16, 'auto-index')),
                                            ])
                                            self.router_id = None
                                            self.auto_index = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.Auto, ['router_id', 'auto_index'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "rd-value"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.RdValue.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class VplsId(Entity):
                                    """
                                    VPLS ID
                                    
                                    .. attribute:: auto
                                    
                                    	auto
                                    	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto>`
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr>`
                                    
                                    .. attribute:: vpls_id_type
                                    
                                    	VPLS ID TYPE
                                    	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, self).__init__()

                                        self.yang_name = "vpls-id"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr))])
                                        self._leafs = OrderedDict([
                                            ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                        ])
                                        self.vpls_id_type = None

                                        self.auto = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto()
                                        self.auto.parent = self
                                        self._children_name_map["auto"] = "auto"

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"
                                        self._segment_path = lambda: "vpls-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId, ['vpls_id_type'], name, value)


                                    class Auto(Entity):
                                        """
                                        auto
                                        
                                        .. attribute:: asn
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vpn_id
                                        
                                        	VPN ID
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, self).__init__()

                                            self.yang_name = "auto"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('asn', YLeaf(YType.uint16, 'asn')),
                                                ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                            ])
                                            self.asn = None
                                            self.vpn_id = None
                                            self._segment_path = lambda: "auto"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.Auto, ['asn', 'vpn_id'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "vpls-id"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.VplsId.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                class ImportRt(Entity):
                                    """
                                    List of import route targets
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr>`
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, self).__init__()

                                        self.yang_name = "import-rt"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport))])
                                        self._leafs = OrderedDict([
                                            ('rt', YLeaf(YType.enumeration, 'rt')),
                                        ])
                                        self.rt = None

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"

                                        self.es_import = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._segment_path = lambda: "import-rt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt, ['rt'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "import-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                                ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                            ])
                                            self.high_bytes = None
                                            self.low_bytes = None
                                            self._segment_path = lambda: "es-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ImportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                                class ExportRt(Entity):
                                    """
                                    List of export route targets
                                    
                                    .. attribute:: two_byte_as
                                    
                                    	two byte as
                                    	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs>`
                                    
                                    .. attribute:: four_byte_as
                                    
                                    	four byte as
                                    	**type**\:  :py:class:`FourByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs>`
                                    
                                    .. attribute:: v4_addr
                                    
                                    	v4 addr
                                    	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr>`
                                    
                                    .. attribute:: es_import
                                    
                                    	es import
                                    	**type**\:  :py:class:`EsImport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport>`
                                    
                                    .. attribute:: rt
                                    
                                    	RT
                                    	**type**\:  :py:class:`L2vpnAdRt <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdRt>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, self).__init__()

                                        self.yang_name = "export-rt"
                                        self.yang_parent_name = "discovery-information"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs)), ("four-byte-as", ("four_byte_as", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr)), ("es-import", ("es_import", L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport))])
                                        self._leafs = OrderedDict([
                                            ('rt', YLeaf(YType.enumeration, 'rt')),
                                        ])
                                        self.rt = None

                                        self.two_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs()
                                        self.two_byte_as.parent = self
                                        self._children_name_map["two_byte_as"] = "two-byte-as"

                                        self.four_byte_as = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs()
                                        self.four_byte_as.parent = self
                                        self._children_name_map["four_byte_as"] = "four-byte-as"

                                        self.v4_addr = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr()
                                        self.v4_addr.parent = self
                                        self._children_name_map["v4_addr"] = "v4-addr"

                                        self.es_import = L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport()
                                        self.es_import.parent = self
                                        self._children_name_map["es_import"] = "es-import"
                                        self._segment_path = lambda: "export-rt"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt, ['rt'], name, value)


                                    class TwoByteAs(Entity):
                                        """
                                        two byte as
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	2 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: four_byte_index
                                        
                                        	4 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, self).__init__()

                                            self.yang_name = "two-byte-as"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                            ])
                                            self.two_byte_as = None
                                            self.four_byte_index = None
                                            self._segment_path = lambda: "two-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                    class FourByteAs(Entity):
                                        """
                                        four byte as
                                        
                                        .. attribute:: four_byte_as
                                        
                                        	4 Byte AS Number
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, self).__init__()

                                            self.yang_name = "four-byte-as"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('four_byte_as', YLeaf(YType.uint32, 'four-byte-as')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.four_byte_as = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "four-byte-as"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.FourByteAs, ['four_byte_as', 'two_byte_index'], name, value)


                                    class V4Addr(Entity):
                                        """
                                        v4 addr
                                        
                                        .. attribute:: ipv4_address
                                        
                                        	IPv4 Address
                                        	**type**\: str
                                        
                                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                        
                                        .. attribute:: two_byte_index
                                        
                                        	2 Byte Index
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, self).__init__()

                                            self.yang_name = "v4-addr"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                            ])
                                            self.ipv4_address = None
                                            self.two_byte_index = None
                                            self._segment_path = lambda: "v4-addr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class EsImport(Entity):
                                        """
                                        es import
                                        
                                        .. attribute:: high_bytes
                                        
                                        	Top 4 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: low_bytes
                                        
                                        	Low 2 bytes of ES Import
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, self).__init__()

                                            self.yang_name = "es-import"
                                            self.yang_parent_name = "export-rt"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('high_bytes', YLeaf(YType.uint32, 'high-bytes')),
                                                ('low_bytes', YLeaf(YType.uint16, 'low-bytes')),
                                            ])
                                            self.high_bytes = None
                                            self.low_bytes = None
                                            self._segment_path = lambda: "es-import"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.DiscoveryInformation.ExportRt.EsImport, ['high_bytes', 'low_bytes'], name, value)


                            class P2mpInformation(Entity):
                                """
                                Multicast P2MP information
                                
                                .. attribute:: transport
                                
                                	P2MP transport
                                	**type**\:  :py:class:`L2vpnVfiP2mpTransport <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpTransport>`
                                
                                .. attribute:: signaling
                                
                                	P2MP signaling
                                	**type**\:  :py:class:`L2vpnVfiP2mpSignaling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnVfiP2mpSignaling>`
                                
                                .. attribute:: ptree_id
                                
                                	PTree ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: attribute_set_name
                                
                                	TE Attribute Set Name
                                	**type**\: str
                                
                                .. attribute:: transport_status
                                
                                	Transport Status
                                	**type**\:  :py:class:`P2mpTransportState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.P2mpTransportState>`
                                
                                .. attribute:: local_label
                                
                                	P2MP Tunnel Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tunnel_interface
                                
                                	P2MP Tunnel Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, self).__init__()

                                    self.yang_name = "p2mp-information"
                                    self.yang_parent_name = "bridge-access-vfi"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('transport', YLeaf(YType.enumeration, 'transport')),
                                        ('signaling', YLeaf(YType.enumeration, 'signaling')),
                                        ('ptree_id', YLeaf(YType.uint32, 'ptree-id')),
                                        ('attribute_set_name', YLeaf(YType.str, 'attribute-set-name')),
                                        ('transport_status', YLeaf(YType.enumeration, 'transport-status')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('tunnel_interface', YLeaf(YType.str, 'tunnel-interface')),
                                    ])
                                    self.transport = None
                                    self.signaling = None
                                    self.ptree_id = None
                                    self.attribute_set_name = None
                                    self.transport_status = None
                                    self.local_label = None
                                    self.tunnel_interface = None
                                    self._segment_path = lambda: "p2mp-information"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.BridgeDomains.BridgeDomain.BridgeDomainInfo.BridgeAccessVfi.P2mpInformation, ['transport', 'signaling', 'ptree_id', 'attribute_set_name', 'transport_status', 'local_label', 'tunnel_interface'], name, value)


            class DiscoverySummary(Entity):
                """
                Discovery summary information
                
                .. attribute:: number_bridge_domainvpns
                
                	Number of BDs registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_mp2m_pxconnect_vpns
                
                	Number of XCs registered
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_bridge_domain
                
                	Number of local Edges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_bridge_domain
                
                	Number of Remote Edges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_bridge_domain
                
                	Number of NLRI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_local_edges_xconnect
                
                	Number of local Edges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_remote_edges_xconnect
                
                	Number of Remote Edges
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: number_nlri_xconnect
                
                	Number of NLRI
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: bgp_stateon_active_rp
                
                	BGP state on the active RP
                	**type**\: bool
                
                .. attribute:: bgp_stateon_standby_rp
                
                	BGP state on standby RP
                	**type**\: bool
                
                .. attribute:: vpls_registered
                
                	Is the VPLS service registered
                	**type**\: bool
                
                .. attribute:: vpws_registered
                
                	Is the VPWS service registered
                	**type**\: bool
                
                .. attribute:: bgp_ipc_transport_mode
                
                	IPC Transport mode with BGP
                	**type**\:  :py:class:`L2vpnIpcTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnIpcTransportMode>`
                
                .. attribute:: bgp_current_node_id
                
                	BGP current node id
                	**type**\: str
                
                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.DiscoverySummary, self).__init__()

                    self.yang_name = "discovery-summary"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('number_bridge_domainvpns', YLeaf(YType.uint32, 'number-bridge-domainvpns')),
                        ('number_mp2m_pxconnect_vpns', YLeaf(YType.uint32, 'number-mp2m-pxconnect-vpns')),
                        ('number_local_edges_bridge_domain', YLeaf(YType.uint32, 'number-local-edges-bridge-domain')),
                        ('number_remote_edges_bridge_domain', YLeaf(YType.uint32, 'number-remote-edges-bridge-domain')),
                        ('number_nlri_bridge_domain', YLeaf(YType.uint32, 'number-nlri-bridge-domain')),
                        ('number_local_edges_xconnect', YLeaf(YType.uint32, 'number-local-edges-xconnect')),
                        ('number_remote_edges_xconnect', YLeaf(YType.uint32, 'number-remote-edges-xconnect')),
                        ('number_nlri_xconnect', YLeaf(YType.uint32, 'number-nlri-xconnect')),
                        ('bgp_stateon_active_rp', YLeaf(YType.boolean, 'bgp-stateon-active-rp')),
                        ('bgp_stateon_standby_rp', YLeaf(YType.boolean, 'bgp-stateon-standby-rp')),
                        ('vpls_registered', YLeaf(YType.boolean, 'vpls-registered')),
                        ('vpws_registered', YLeaf(YType.boolean, 'vpws-registered')),
                        ('bgp_ipc_transport_mode', YLeaf(YType.enumeration, 'bgp-ipc-transport-mode')),
                        ('bgp_current_node_id', YLeaf(YType.str, 'bgp-current-node-id')),
                    ])
                    self.number_bridge_domainvpns = None
                    self.number_mp2m_pxconnect_vpns = None
                    self.number_local_edges_bridge_domain = None
                    self.number_remote_edges_bridge_domain = None
                    self.number_nlri_bridge_domain = None
                    self.number_local_edges_xconnect = None
                    self.number_remote_edges_xconnect = None
                    self.number_nlri_xconnect = None
                    self.bgp_stateon_active_rp = None
                    self.bgp_stateon_standby_rp = None
                    self.vpls_registered = None
                    self.vpws_registered = None
                    self.bgp_ipc_transport_mode = None
                    self.bgp_current_node_id = None
                    self._segment_path = lambda: "discovery-summary"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.DiscoverySummary, ['number_bridge_domainvpns', 'number_mp2m_pxconnect_vpns', 'number_local_edges_bridge_domain', 'number_remote_edges_bridge_domain', 'number_nlri_bridge_domain', 'number_local_edges_xconnect', 'number_remote_edges_xconnect', 'number_nlri_xconnect', 'bgp_stateon_active_rp', 'bgp_stateon_standby_rp', 'vpls_registered', 'vpws_registered', 'bgp_ipc_transport_mode', 'bgp_current_node_id'], name, value)


            class G8032(Entity):
                """
                G8032 information
                
                .. attribute:: g8032_rings
                
                	G8032 Ring table
                	**type**\:  :py:class:`G8032Rings <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.G8032, self).__init__()

                    self.yang_name = "g8032"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("g8032-rings", ("g8032_rings", L2vpnv2.Nodes.Node.G8032.G8032Rings))])
                    self._leafs = OrderedDict()

                    self.g8032_rings = L2vpnv2.Nodes.Node.G8032.G8032Rings()
                    self.g8032_rings.parent = self
                    self._children_name_map["g8032_rings"] = "g8032-rings"
                    self._segment_path = lambda: "g8032"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.G8032, [], name, value)


                class G8032Rings(Entity):
                    """
                    G8032 Ring table
                    
                    .. attribute:: g8032_ring
                    
                    	G8032 Ring
                    	**type**\: list of  		 :py:class:`G8032Ring <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.G8032.G8032Rings, self).__init__()

                        self.yang_name = "g8032-rings"
                        self.yang_parent_name = "g8032"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("g8032-ring", ("g8032_ring", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring))])
                        self._leafs = OrderedDict()

                        self.g8032_ring = YList(self)
                        self._segment_path = lambda: "g8032-rings"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings, [], name, value)


                    class G8032Ring(Entity):
                        """
                        G8032 Ring
                        
                        .. attribute:: ring_name  (key)
                        
                        	Ring Name
                        	**type**\: str
                        
                        	**length:** 1..32
                        
                        .. attribute:: g8032_ring_detail
                        
                        	G8032 Ring detailed information
                        	**type**\:  :py:class:`G8032RingDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail>`
                        
                        .. attribute:: g8032_ring_instance_summaries
                        
                        	G8032 Ring Instance summary table
                        	**type**\:  :py:class:`G8032RingInstanceSummaries <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries>`
                        
                        .. attribute:: g8032_ring_summary
                        
                        	G8032 Ring summary information
                        	**type**\:  :py:class:`G8032RingSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary>`
                        
                        .. attribute:: g8032_ring_instance_details
                        
                        	G8032 Ring Instance detail table
                        	**type**\:  :py:class:`G8032RingInstanceDetails <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring, self).__init__()

                            self.yang_name = "g8032-ring"
                            self.yang_parent_name = "g8032-rings"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['ring_name']
                            self._child_classes = OrderedDict([("g8032-ring-detail", ("g8032_ring_detail", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail)), ("g8032-ring-instance-summaries", ("g8032_ring_instance_summaries", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries)), ("g8032-ring-summary", ("g8032_ring_summary", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary)), ("g8032-ring-instance-details", ("g8032_ring_instance_details", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails))])
                            self._leafs = OrderedDict([
                                ('ring_name', YLeaf(YType.str, 'ring-name')),
                            ])
                            self.ring_name = None

                            self.g8032_ring_detail = L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail()
                            self.g8032_ring_detail.parent = self
                            self._children_name_map["g8032_ring_detail"] = "g8032-ring-detail"

                            self.g8032_ring_instance_summaries = L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries()
                            self.g8032_ring_instance_summaries.parent = self
                            self._children_name_map["g8032_ring_instance_summaries"] = "g8032-ring-instance-summaries"

                            self.g8032_ring_summary = L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary()
                            self.g8032_ring_summary.parent = self
                            self._children_name_map["g8032_ring_summary"] = "g8032-ring-summary"

                            self.g8032_ring_instance_details = L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails()
                            self.g8032_ring_instance_details.parent = self
                            self._children_name_map["g8032_ring_instance_details"] = "g8032-ring-instance-details"
                            self._segment_path = lambda: "g8032-ring" + "[ring-name='" + str(self.ring_name) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring, ['ring_name'], name, value)


                        class G8032RingDetail(Entity):
                            """
                            G8032 Ring detailed information
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\: str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\: str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\: str
                            
                            .. attribute:: monitor0
                            
                            	Monitor port 0
                            	**type**\: str
                            
                            .. attribute:: monitor1
                            
                            	Monitor port 1
                            	**type**\: str
                            
                            .. attribute:: is_provider_bridge
                            
                            	Operating mode Customer/Provider 
                            	**type**\: bool
                            
                            .. attribute:: is_open_ring
                            
                            	Flag open ring
                            	**type**\: bool
                            
                            .. attribute:: tcn_propagation
                            
                            	Global TCN propagation
                            	**type**\: bool
                            
                            .. attribute:: excluded_vlan_id
                            
                            	Exclusion Vlan ids list 
                            	**type**\: list of  		 :py:class:`ExcludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail, self).__init__()

                                self.yang_name = "g8032-ring-detail"
                                self.yang_parent_name = "g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("excluded-vlan-id", ("excluded_vlan_id", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId))])
                                self._leafs = OrderedDict([
                                    ('ring_name', YLeaf(YType.str, 'ring-name')),
                                    ('port0', YLeaf(YType.str, 'port0')),
                                    ('port1', YLeaf(YType.str, 'port1')),
                                    ('monitor0', YLeaf(YType.str, 'monitor0')),
                                    ('monitor1', YLeaf(YType.str, 'monitor1')),
                                    ('is_provider_bridge', YLeaf(YType.boolean, 'is-provider-bridge')),
                                    ('is_open_ring', YLeaf(YType.boolean, 'is-open-ring')),
                                    ('tcn_propagation', YLeaf(YType.boolean, 'tcn-propagation')),
                                ])
                                self.ring_name = None
                                self.port0 = None
                                self.port1 = None
                                self.monitor0 = None
                                self.monitor1 = None
                                self.is_provider_bridge = None
                                self.is_open_ring = None
                                self.tcn_propagation = None

                                self.excluded_vlan_id = YList(self)
                                self._segment_path = lambda: "g8032-ring-detail"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail, ['ring_name', 'port0', 'port1', 'monitor0', 'monitor1', 'is_provider_bridge', 'is_open_ring', 'tcn_propagation'], name, value)


                            class ExcludedVlanId(Entity):
                                """
                                Exclusion Vlan ids list 
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, self).__init__()

                                    self.yang_name = "excluded-vlan-id"
                                    self.yang_parent_name = "g8032-ring-detail"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "excluded-vlan-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingDetail.ExcludedVlanId, ['entry'], name, value)


                        class G8032RingInstanceSummaries(Entity):
                            """
                            G8032 Ring Instance summary table
                            
                            .. attribute:: g8032_ring_instance_summary
                            
                            	G8032 Ring Instance summary information
                            	**type**\: list of  		 :py:class:`G8032RingInstanceSummary <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, self).__init__()

                                self.yang_name = "g8032-ring-instance-summaries"
                                self.yang_parent_name = "g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("g8032-ring-instance-summary", ("g8032_ring_instance_summary", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary))])
                                self._leafs = OrderedDict()

                                self.g8032_ring_instance_summary = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-summaries"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries, [], name, value)


                            class G8032RingInstanceSummary(Entity):
                                """
                                G8032 Ring Instance summary information
                                
                                .. attribute:: instance  (key)
                                
                                	Instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\: bool
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, self).__init__()

                                    self.yang_name = "g8032-ring-instance-summary"
                                    self.yang_parent_name = "g8032-ring-instance-summaries"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance']
                                    self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId))])
                                    self._leafs = OrderedDict([
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                        ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                        ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                        ('config_state', YLeaf(YType.boolean, 'config-state')),
                                    ])
                                    self.instance = None
                                    self.ring_instance = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.config_state = None

                                    self.included_vlan_id = YList(self)
                                    self._segment_path = lambda: "g8032-ring-instance-summary" + "[instance='" + str(self.instance) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary, ['instance', 'ring_instance', 'aps_port0', 'aps_port1', 'config_state'], name, value)


                                class IncludedVlanId(Entity):
                                    """
                                    Inclusion list Vlan Ids
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, self).__init__()

                                        self.yang_name = "included-vlan-id"
                                        self.yang_parent_name = "g8032-ring-instance-summary"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "included-vlan-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceSummaries.G8032RingInstanceSummary.IncludedVlanId, ['entry'], name, value)


                        class G8032RingSummary(Entity):
                            """
                            G8032 Ring summary information
                            
                            .. attribute:: ring_name
                            
                            	Name of the ring
                            	**type**\: str
                            
                            .. attribute:: port0
                            
                            	Port 0
                            	**type**\: str
                            
                            .. attribute:: port1
                            
                            	Port 1
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary, self).__init__()

                                self.yang_name = "g8032-ring-summary"
                                self.yang_parent_name = "g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('ring_name', YLeaf(YType.str, 'ring-name')),
                                    ('port0', YLeaf(YType.str, 'port0')),
                                    ('port1', YLeaf(YType.str, 'port1')),
                                ])
                                self.ring_name = None
                                self.port0 = None
                                self.port1 = None
                                self._segment_path = lambda: "g8032-ring-summary"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingSummary, ['ring_name', 'port0', 'port1'], name, value)


                        class G8032RingInstanceDetails(Entity):
                            """
                            G8032 Ring Instance detail table
                            
                            .. attribute:: g8032_ring_instance_detail
                            
                            	G8032 Ring Instance detailed information
                            	**type**\: list of  		 :py:class:`G8032RingInstanceDetail <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, self).__init__()

                                self.yang_name = "g8032-ring-instance-details"
                                self.yang_parent_name = "g8032-ring"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("g8032-ring-instance-detail", ("g8032_ring_instance_detail", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail))])
                                self._leafs = OrderedDict()

                                self.g8032_ring_instance_detail = YList(self)
                                self._segment_path = lambda: "g8032-ring-instance-details"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails, [], name, value)


                            class G8032RingInstanceDetail(Entity):
                                """
                                G8032 Ring Instance detailed information
                                
                                .. attribute:: instance  (key)
                                
                                	Instance
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_instance
                                
                                	Ring instance number
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ring_description
                                
                                	Ring description
                                	**type**\: str
                                
                                .. attribute:: ring_profile
                                
                                	Ring Profile
                                	**type**\: str
                                
                                .. attribute:: rpl
                                
                                	RPL
                                	**type**\:  :py:class:`L2vpnG8032Rpl <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032Rpl>`
                                
                                .. attribute:: aps_port0
                                
                                	Port 0 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: aps_port1
                                
                                	Port 1 of aps\-channel
                                	**type**\: str
                                
                                .. attribute:: config_state
                                
                                	State of the instance
                                	**type**\: bool
                                
                                .. attribute:: unresolved_reason
                                
                                	Reason of unresolved state state
                                	**type**\:  :py:class:`L2vpnG8032UncfgReason <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnG8032UncfgReason>`
                                
                                .. attribute:: aps_channel_level
                                
                                	APS channel level
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: included_vlan_id
                                
                                	Inclusion list Vlan Ids
                                	**type**\: list of  		 :py:class:`IncludedVlanId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, self).__init__()

                                    self.yang_name = "g8032-ring-instance-detail"
                                    self.yang_parent_name = "g8032-ring-instance-details"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['instance']
                                    self._child_classes = OrderedDict([("included-vlan-id", ("included_vlan_id", L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId))])
                                    self._leafs = OrderedDict([
                                        ('instance', YLeaf(YType.uint32, 'instance')),
                                        ('ring_instance', YLeaf(YType.uint32, 'ring-instance')),
                                        ('ring_description', YLeaf(YType.str, 'ring-description')),
                                        ('ring_profile', YLeaf(YType.str, 'ring-profile')),
                                        ('rpl', YLeaf(YType.enumeration, 'rpl')),
                                        ('aps_port0', YLeaf(YType.str, 'aps-port0')),
                                        ('aps_port1', YLeaf(YType.str, 'aps-port1')),
                                        ('config_state', YLeaf(YType.boolean, 'config-state')),
                                        ('unresolved_reason', YLeaf(YType.enumeration, 'unresolved-reason')),
                                        ('aps_channel_level', YLeaf(YType.uint32, 'aps-channel-level')),
                                    ])
                                    self.instance = None
                                    self.ring_instance = None
                                    self.ring_description = None
                                    self.ring_profile = None
                                    self.rpl = None
                                    self.aps_port0 = None
                                    self.aps_port1 = None
                                    self.config_state = None
                                    self.unresolved_reason = None
                                    self.aps_channel_level = None

                                    self.included_vlan_id = YList(self)
                                    self._segment_path = lambda: "g8032-ring-instance-detail" + "[instance='" + str(self.instance) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail, ['instance', 'ring_instance', 'ring_description', 'ring_profile', 'rpl', 'aps_port0', 'aps_port1', 'config_state', 'unresolved_reason', 'aps_channel_level'], name, value)


                                class IncludedVlanId(Entity):
                                    """
                                    Inclusion list Vlan Ids
                                    
                                    .. attribute:: entry
                                    
                                    	
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, self).__init__()

                                        self.yang_name = "included-vlan-id"
                                        self.yang_parent_name = "g8032-ring-instance-detail"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('entry', YLeaf(YType.uint16, 'entry')),
                                        ])
                                        self.entry = None
                                        self._segment_path = lambda: "included-vlan-id"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.G8032.G8032Rings.G8032Ring.G8032RingInstanceDetails.G8032RingInstanceDetail.IncludedVlanId, ['entry'], name, value)


            class PseudowireClasses(Entity):
                """
                List of pseudowire classes
                
                .. attribute:: pseudowire_class
                
                	Pseudowire class information
                	**type**\: list of  		 :py:class:`PseudowireClass <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.PseudowireClasses, self).__init__()

                    self.yang_name = "pseudowire-classes"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("pseudowire-class", ("pseudowire_class", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass))])
                    self._leafs = OrderedDict()

                    self.pseudowire_class = YList(self)
                    self._segment_path = lambda: "pseudowire-classes"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses, [], name, value)


                class PseudowireClass(Entity):
                    """
                    Pseudowire class information
                    
                    .. attribute:: pseudowire_class_name  (key)
                    
                    	Pseudowire Class Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: encapsulation_info
                    
                    	Encapsulation specific pseudowire information
                    	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo>`
                    
                    .. attribute:: preferred_path
                    
                    	MPLS Preferred Path
                    	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath>`
                    
                    .. attribute:: local_source_address
                    
                    	Local source address
                    	**type**\:  :py:class:`LocalSourceAddress <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress>`
                    
                    .. attribute:: pw_class_name
                    
                    	Pseudowire class name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: control_word
                    
                    	Control word
                    	**type**\:  :py:class:`L2vpnPwClassControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwClassControlWord>`
                    
                    .. attribute:: transport_mode
                    
                    	Transport mode
                    	**type**\:  :py:class:`L2vpnTransportMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTransportMode>`
                    
                    .. attribute:: sequencing_type
                    
                    	Sequencing Type
                    	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                    
                    .. attribute:: resync_enabled
                    
                    	Resync if packets out of sequence
                    	**type**\: bool
                    
                    .. attribute:: resync_threshold
                    
                    	Number of Packets Out of Seqence to trigger resync
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: protocol
                    
                    	Protocol
                    	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                    
                    .. attribute:: disable_never
                    
                    	TRUE if backup is not automatically disabled
                    	**type**\: bool
                    
                    .. attribute:: disable_delay
                    
                    	Disable Deley
                    	**type**\: int
                    
                    	**range:** 0..255
                    
                    .. attribute:: backup_mac_withdraw
                    
                    	TRUE if MAC withdraw message is sent
                    	**type**\: bool
                    
                    .. attribute:: tag_rewrite
                    
                    	Static tag rewrite
                    	**type**\: int
                    
                    	**range:** 0..65535
                    
                    .. attribute:: preferred_path_disable_fallback
                    
                    	PreferredPathDisableFallback
                    	**type**\: bool
                    
                    .. attribute:: load_balance
                    
                    	Load Balance Type
                    	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                    
                    .. attribute:: pw_flow_label_type_cfg
                    
                    	Configured pseudowire flow label type
                    	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                    
                    .. attribute:: pw_flow_label_code17_disabled
                    
                    	Disable sending Code 17 TLV
                    	**type**\: bool
                    
                    .. attribute:: is_flow_label_static
                    
                    	is flow label static
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass, self).__init__()

                        self.yang_name = "pseudowire-class"
                        self.yang_parent_name = "pseudowire-classes"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['pseudowire_class_name']
                        self._child_classes = OrderedDict([("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath)), ("local-source-address", ("local_source_address", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress))])
                        self._leafs = OrderedDict([
                            ('pseudowire_class_name', YLeaf(YType.str, 'pseudowire-class-name')),
                            ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                            ('control_word', YLeaf(YType.enumeration, 'control-word')),
                            ('transport_mode', YLeaf(YType.enumeration, 'transport-mode')),
                            ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                            ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                            ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                            ('protocol', YLeaf(YType.enumeration, 'protocol')),
                            ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                            ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                            ('backup_mac_withdraw', YLeaf(YType.boolean, 'backup-mac-withdraw')),
                            ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                            ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                            ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                            ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                            ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                            ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                        ])
                        self.pseudowire_class_name = None
                        self.pw_class_name = None
                        self.control_word = None
                        self.transport_mode = None
                        self.sequencing_type = None
                        self.resync_enabled = None
                        self.resync_threshold = None
                        self.protocol = None
                        self.disable_never = None
                        self.disable_delay = None
                        self.backup_mac_withdraw = None
                        self.tag_rewrite = None
                        self.preferred_path_disable_fallback = None
                        self.load_balance = None
                        self.pw_flow_label_type_cfg = None
                        self.pw_flow_label_code17_disabled = None
                        self.is_flow_label_static = None

                        self.encapsulation_info = L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo()
                        self.encapsulation_info.parent = self
                        self._children_name_map["encapsulation_info"] = "encapsulation-info"

                        self.preferred_path = L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath()
                        self.preferred_path.parent = self
                        self._children_name_map["preferred_path"] = "preferred-path"

                        self.local_source_address = L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress()
                        self.local_source_address.parent = self
                        self._children_name_map["local_source_address"] = "local-source-address"
                        self._segment_path = lambda: "pseudowire-class" + "[pseudowire-class-name='" + str(self.pseudowire_class_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass, ['pseudowire_class_name', 'pw_class_name', 'control_word', 'transport_mode', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'protocol', 'disable_never', 'disable_delay', 'backup_mac_withdraw', 'tag_rewrite', 'preferred_path_disable_fallback', 'load_balance', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static'], name, value)


                    class EncapsulationInfo(Entity):
                        """
                        Encapsulation specific pseudowire information
                        
                        .. attribute:: l2tpv3
                        
                        	l2tpv3
                        	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3>`
                        
                        .. attribute:: encapsulation
                        
                        	Encapsulation
                        	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo, self).__init__()

                            self.yang_name = "encapsulation-info"
                            self.yang_parent_name = "pseudowire-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3))])
                            self._leafs = OrderedDict([
                                ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                            ])
                            self.encapsulation = None

                            self.l2tpv3 = L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3()
                            self.l2tpv3.parent = self
                            self._children_name_map["l2tpv3"] = "l2tpv3"
                            self._segment_path = lambda: "encapsulation-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo, ['encapsulation'], name, value)


                        class L2tpv3(Entity):
                            """
                            l2tpv3
                            
                            .. attribute:: l2tp_class_name
                            
                            	L2TPClassName
                            	**type**\: str
                            
                            	**length:** 0..32
                            
                            .. attribute:: ipv4_source_address
                            
                            	IPv4 source address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: path_mtu_enabled
                            
                            	Path MTU enabled
                            	**type**\: bool
                            
                            .. attribute:: path_mtu_max_value
                            
                            	Path MTU Maximum allowable session MTU
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: dont_fragment_bit
                            
                            	Don't Fragment Bit
                            	**type**\: bool
                            
                            .. attribute:: tos_mode
                            
                            	Type Of Service Mode
                            	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                            
                            .. attribute:: tos
                            
                            	Type Of Service Value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: ttl
                            
                            	Time To Live value
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: cookie_size
                            
                            	Cookie size\: 0, 4, or 8 bytes
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, self).__init__()

                                self.yang_name = "l2tpv3"
                                self.yang_parent_name = "encapsulation-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                    ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                    ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                    ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                    ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                    ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                    ('tos', YLeaf(YType.uint8, 'tos')),
                                    ('ttl', YLeaf(YType.uint8, 'ttl')),
                                    ('cookie_size', YLeaf(YType.uint8, 'cookie-size')),
                                ])
                                self.l2tp_class_name = None
                                self.ipv4_source_address = None
                                self.path_mtu_enabled = None
                                self.path_mtu_max_value = None
                                self.dont_fragment_bit = None
                                self.tos_mode = None
                                self.tos = None
                                self.ttl = None
                                self.cookie_size = None
                                self._segment_path = lambda: "l2tpv3"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'cookie_size'], name, value)


                    class PreferredPath(Entity):
                        """
                        MPLS Preferred Path
                        
                        .. attribute:: srte_policy
                        
                        	srte policy
                        	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy>`
                        
                        .. attribute:: option
                        
                        	Option
                        	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                        
                        .. attribute:: next_hop_ip
                        
                        	NextHopIP
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: te_tunnel_interface_number
                        
                        	TETunnelInterfaceNumber
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: ip_tunnel_interface_number
                        
                        	IPTunnelInterfaceNumber
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: tp_tunnel_interface_number
                        
                        	TPTunnelInterfaceNumber
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath, self).__init__()

                            self.yang_name = "preferred-path"
                            self.yang_parent_name = "pseudowire-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy))])
                            self._leafs = OrderedDict([
                                ('option', YLeaf(YType.enumeration, 'option')),
                                ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                            ])
                            self.option = None
                            self.next_hop_ip = None
                            self.te_tunnel_interface_number = None
                            self.ip_tunnel_interface_number = None
                            self.tp_tunnel_interface_number = None

                            self.srte_policy = L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy()
                            self.srte_policy.parent = self
                            self._children_name_map["srte_policy"] = "srte-policy"
                            self._segment_path = lambda: "preferred-path"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                        class SrtePolicy(Entity):
                            """
                            srte policy
                            
                            .. attribute:: policy_name
                            
                            	SR TE Policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, self).__init__()

                                self.yang_name = "srte-policy"
                                self.yang_parent_name = "preferred-path"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([])
                                self._leafs = OrderedDict([
                                    ('policy_name', YLeaf(YType.str, 'policy-name')),
                                ])
                                self.policy_name = None
                                self._segment_path = lambda: "srte-policy"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                    class LocalSourceAddress(Entity):
                        """
                        Local source address
                        
                        .. attribute:: configuration
                        
                        	Configuration
                        	**type**\:  :py:class:`L2vpnSrcAddressSet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSrcAddressSet>`
                        
                        .. attribute:: address
                        
                        	Local source address
                        	**type**\: str
                        
                        	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress, self).__init__()

                            self.yang_name = "local-source-address"
                            self.yang_parent_name = "pseudowire-class"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('configuration', YLeaf(YType.enumeration, 'configuration')),
                                ('address', YLeaf(YType.str, 'address')),
                            ])
                            self.configuration = None
                            self.address = None
                            self._segment_path = lambda: "local-source-address"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.PseudowireClasses.PseudowireClass.LocalSourceAddress, ['configuration', 'address'], name, value)


            class L2vpnCollaborators(Entity):
                """
                L2VPN collaborator information
                
                .. attribute:: collaborator_statistics
                
                	Collaborator Statistics
                	**type**\:  :py:class:`CollaboratorStatistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.L2vpnCollaborators, self).__init__()

                    self.yang_name = "l2vpn-collaborators"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("collaborator-statistics", ("collaborator_statistics", L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics))])
                    self._leafs = OrderedDict()

                    self.collaborator_statistics = L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics()
                    self.collaborator_statistics.parent = self
                    self._children_name_map["collaborator_statistics"] = "collaborator-statistics"
                    self._segment_path = lambda: "l2vpn-collaborators"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.L2vpnCollaborators, [], name, value)


                class CollaboratorStatistics(Entity):
                    """
                    Collaborator Statistics
                    
                    .. attribute:: count
                    
                    	count
                    	**type**\: list of  		 :py:class:`Count <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics.Count>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics, self).__init__()

                        self.yang_name = "collaborator-statistics"
                        self.yang_parent_name = "l2vpn-collaborators"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("count", ("count", L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics.Count))])
                        self._leafs = OrderedDict()

                        self.count = YList(self)
                        self._segment_path = lambda: "collaborator-statistics"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics, [], name, value)


                    class Count(Entity):
                        """
                        count
                        
                        .. attribute:: collaborator_name
                        
                        	Collaborator Name
                        	**type**\: str
                        
                        .. attribute:: up
                        
                        	Up
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: down
                        
                        	Down
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_up
                        
                        	Is up
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics.Count, self).__init__()

                            self.yang_name = "count"
                            self.yang_parent_name = "collaborator-statistics"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('collaborator_name', YLeaf(YType.str, 'collaborator-name')),
                                ('up', YLeaf(YType.uint32, 'up')),
                                ('down', YLeaf(YType.uint32, 'down')),
                                ('is_up', YLeaf(YType.boolean, 'is-up')),
                            ])
                            self.collaborator_name = None
                            self.up = None
                            self.down = None
                            self.is_up = None
                            self._segment_path = lambda: "count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.L2vpnCollaborators.CollaboratorStatistics.Count, ['collaborator_name', 'up', 'down', 'is_up'], name, value)


            class Mvrp(Entity):
                """
                MVRP
                
                .. attribute:: mvrp_main_ports
                
                	MVRP Main Port Table
                	**type**\:  :py:class:`MvrpMainPorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.Mvrp, self).__init__()

                    self.yang_name = "mvrp"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mvrp-main-ports", ("mvrp_main_ports", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts))])
                    self._leafs = OrderedDict()

                    self.mvrp_main_ports = L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts()
                    self.mvrp_main_ports.parent = self
                    self._children_name_map["mvrp_main_ports"] = "mvrp-main-ports"
                    self._segment_path = lambda: "mvrp"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp, [], name, value)


                class MvrpMainPorts(Entity):
                    """
                    MVRP Main Port Table
                    
                    .. attribute:: mvrp_main_port
                    
                    	MVRP Main Port
                    	**type**\: list of  		 :py:class:`MvrpMainPort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts, self).__init__()

                        self.yang_name = "mvrp-main-ports"
                        self.yang_parent_name = "mvrp"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("mvrp-main-port", ("mvrp_main_port", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort))])
                        self._leafs = OrderedDict()

                        self.mvrp_main_port = YList(self)
                        self._segment_path = lambda: "mvrp-main-ports"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts, [], name, value)


                    class MvrpMainPort(Entity):
                        """
                        MVRP Main Port
                        
                        .. attribute:: main_port_interface_name  (key)
                        
                        	Main Port interface
                        	**type**\: str
                        
                        	**pattern:** [a\-zA\-Z0\-9./\-]+
                        
                        .. attribute:: mvrp_main_port_info
                        
                        	MVRP Main Port Information
                        	**type**\:  :py:class:`MvrpMainPortInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo>`
                        
                        .. attribute:: mvrp_bridge_ports
                        
                        	MVRP Bridge Port Table
                        	**type**\:  :py:class:`MvrpBridgePorts <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort, self).__init__()

                            self.yang_name = "mvrp-main-port"
                            self.yang_parent_name = "mvrp-main-ports"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = ['main_port_interface_name']
                            self._child_classes = OrderedDict([("mvrp-main-port-info", ("mvrp_main_port_info", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo)), ("mvrp-bridge-ports", ("mvrp_bridge_ports", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts))])
                            self._leafs = OrderedDict([
                                ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                            ])
                            self.main_port_interface_name = None

                            self.mvrp_main_port_info = L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo()
                            self.mvrp_main_port_info.parent = self
                            self._children_name_map["mvrp_main_port_info"] = "mvrp-main-port-info"

                            self.mvrp_bridge_ports = L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts()
                            self.mvrp_bridge_ports.parent = self
                            self._children_name_map["mvrp_bridge_ports"] = "mvrp-bridge-ports"
                            self._segment_path = lambda: "mvrp-main-port" + "[main-port-interface-name='" + str(self.main_port_interface_name) + "']"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort, ['main_port_interface_name'], name, value)


                        class MvrpMainPortInfo(Entity):
                            """
                            MVRP Main Port Information
                            
                            .. attribute:: default_bridge_port
                            
                            	Trunk or default Bridge Port
                            	**type**\:  :py:class:`DefaultBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort>`
                            
                            .. attribute:: main_port_interface_name
                            
                            	Main Port Interface name
                            	**type**\: str
                            
                            .. attribute:: is_trunk
                            
                            	Is main port a trunk
                            	**type**\: bool
                            
                            .. attribute:: is_default_encap
                            
                            	Is default encap set
                            	**type**\: bool
                            
                            .. attribute:: number_of_bridge_ports
                            
                            	Number of Bridge Ports
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, self).__init__()

                                self.yang_name = "mvrp-main-port-info"
                                self.yang_parent_name = "mvrp-main-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("default-bridge-port", ("default_bridge_port", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort))])
                                self._leafs = OrderedDict([
                                    ('main_port_interface_name', YLeaf(YType.str, 'main-port-interface-name')),
                                    ('is_trunk', YLeaf(YType.boolean, 'is-trunk')),
                                    ('is_default_encap', YLeaf(YType.boolean, 'is-default-encap')),
                                    ('number_of_bridge_ports', YLeaf(YType.uint32, 'number-of-bridge-ports')),
                                ])
                                self.main_port_interface_name = None
                                self.is_trunk = None
                                self.is_default_encap = None
                                self.number_of_bridge_ports = None

                                self.default_bridge_port = L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort()
                                self.default_bridge_port.parent = self
                                self._children_name_map["default_bridge_port"] = "default-bridge-port"
                                self._segment_path = lambda: "mvrp-main-port-info"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo, ['main_port_interface_name', 'is_trunk', 'is_default_encap', 'number_of_bridge_ports'], name, value)


                            class DefaultBridgePort(Entity):
                                """
                                Trunk or default Bridge Port
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\: str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, self).__init__()

                                    self.yang_name = "default-bridge-port"
                                    self.yang_parent_name = "mvrp-main-port-info"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange))])
                                    self._leafs = OrderedDict([
                                        ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                        ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                        ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ])
                                    self.bridge_port_interface_name = None
                                    self.bridge_port_xconnect_id = None
                                    self.mvrp_sequence_number = None

                                    self.vlan_range = YList(self)
                                    self._segment_path = lambda: "default-bridge-port"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort, ['bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                                class VlanRange(Entity):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "default-bridge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                        ])
                                        self.lower = None
                                        self.upper = None
                                        self._segment_path = lambda: "vlan-range"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpMainPortInfo.DefaultBridgePort.VlanRange, ['lower', 'upper'], name, value)


                        class MvrpBridgePorts(Entity):
                            """
                            MVRP Bridge Port Table
                            
                            .. attribute:: mvrp_bridge_port
                            
                            	MVRP Bridge Port Information
                            	**type**\: list of  		 :py:class:`MvrpBridgePort <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, self).__init__()

                                self.yang_name = "mvrp-bridge-ports"
                                self.yang_parent_name = "mvrp-main-port"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("mvrp-bridge-port", ("mvrp_bridge_port", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort))])
                                self._leafs = OrderedDict()

                                self.mvrp_bridge_port = YList(self)
                                self._segment_path = lambda: "mvrp-bridge-ports"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts, [], name, value)


                            class MvrpBridgePort(Entity):
                                """
                                MVRP Bridge Port Information
                                
                                .. attribute:: interface_name  (key)
                                
                                	Bridge Port Interface Name
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: bridge_port_interface_name
                                
                                	Bridge port Interface name
                                	**type**\: str
                                
                                .. attribute:: bridge_port_xconnect_id
                                
                                	Bridge port XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: mvrp_sequence_number
                                
                                	MVRP Sequence Number
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                .. attribute:: vlan_range
                                
                                	VLAN IDs
                                	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, self).__init__()

                                    self.yang_name = "mvrp-bridge-port"
                                    self.yang_parent_name = "mvrp-bridge-ports"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = ['interface_name']
                                    self._child_classes = OrderedDict([("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange))])
                                    self._leafs = OrderedDict([
                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                        ('bridge_port_interface_name', YLeaf(YType.str, 'bridge-port-interface-name')),
                                        ('bridge_port_xconnect_id', YLeaf(YType.uint32, 'bridge-port-xconnect-id')),
                                        ('mvrp_sequence_number', YLeaf(YType.uint16, 'mvrp-sequence-number')),
                                    ])
                                    self.interface_name = None
                                    self.bridge_port_interface_name = None
                                    self.bridge_port_xconnect_id = None
                                    self.mvrp_sequence_number = None

                                    self.vlan_range = YList(self)
                                    self._segment_path = lambda: "mvrp-bridge-port" + "[interface-name='" + str(self.interface_name) + "']"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort, ['interface_name', 'bridge_port_interface_name', 'bridge_port_xconnect_id', 'mvrp_sequence_number'], name, value)


                                class VlanRange(Entity):
                                    """
                                    VLAN IDs
                                    
                                    .. attribute:: lower
                                    
                                    	Lower
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: upper
                                    
                                    	Upper
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, self).__init__()

                                        self.yang_name = "vlan-range"
                                        self.yang_parent_name = "mvrp-bridge-port"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('lower', YLeaf(YType.uint16, 'lower')),
                                            ('upper', YLeaf(YType.uint16, 'upper')),
                                        ])
                                        self.lower = None
                                        self.upper = None
                                        self._segment_path = lambda: "vlan-range"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.Mvrp.MvrpMainPorts.MvrpMainPort.MvrpBridgePorts.MvrpBridgePort.VlanRange, ['lower', 'upper'], name, value)


            class GenericInterfaceLists(Entity):
                """
                L2VPN generic interface list Table
                
                .. attribute:: generic_interface_list
                
                	Generic Interface List information
                	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.GenericInterfaceLists, self).__init__()

                    self.yang_name = "generic-interface-lists"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList))])
                    self._leafs = OrderedDict()

                    self.generic_interface_list = YList(self)
                    self._segment_path = lambda: "generic-interface-lists"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceLists, [], name, value)


                class GenericInterfaceList(Entity):
                    """
                    Generic Interface List information
                    
                    .. attribute:: interface_list_name  (key)
                    
                    	Generic Interface List Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface_list_name_xr
                    
                    	Interface\-list name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: number_of_interfaces
                    
                    	Number of interfaces
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: items
                    
                    	Number of items
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                        self.yang_name = "generic-interface-list"
                        self.yang_parent_name = "generic-interface-lists"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['interface_list_name']
                        self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface))])
                        self._leafs = OrderedDict([
                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                            ('interface_list_name_xr', YLeaf(YType.str, 'interface-list-name-xr')),
                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                            ('number_of_interfaces', YLeaf(YType.uint32, 'number-of-interfaces')),
                            ('items', YLeaf(YType.uint32, 'items')),
                        ])
                        self.interface_list_name = None
                        self.interface_list_name_xr = None
                        self.interface_list_id = None
                        self.number_of_interfaces = None
                        self.items = None

                        self.interface = YList(self)
                        self._segment_path = lambda: "generic-interface-list" + "[interface-list-name='" + str(self.interface_list_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList, ['interface_list_name', 'interface_list_name_xr', 'interface_list_id', 'number_of_interfaces', 'items'], name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                            ])
                            self.interface_name = None
                            self.pending_replications = None
                            self.not_supported_replications = None
                            self.is_fib_downloaded = None
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


            class MstpVlans(Entity):
                """
                L2VPN MSTP VLAN Table
                
                .. attribute:: mstp_vlan
                
                	L2VPN MSTP VLAN information
                	**type**\: list of  		 :py:class:`MstpVlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpVlans.MstpVlan>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.MstpVlans, self).__init__()

                    self.yang_name = "mstp-vlans"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("mstp-vlan", ("mstp_vlan", L2vpnv2.Nodes.Node.MstpVlans.MstpVlan))])
                    self._leafs = OrderedDict()

                    self.mstp_vlan = YList(self)
                    self._segment_path = lambda: "mstp-vlans"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.MstpVlans, [], name, value)


                class MstpVlan(Entity):
                    """
                    L2VPN MSTP VLAN information
                    
                    .. attribute:: vlan_id  (key)
                    
                    	vlan id
                    	**type**\: int
                    
                    	**range:** 0..4098
                    
                    .. attribute:: vlan_id_xr
                    
                    	Vlan id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: msti_id
                    
                    	MSTI id
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: port_count
                    
                    	Port Count
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: sub_interface
                    
                    	Sub interfaces
                    	**type**\: list of  		 :py:class:`SubInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.MstpVlans.MstpVlan, self).__init__()

                        self.yang_name = "mstp-vlan"
                        self.yang_parent_name = "mstp-vlans"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['vlan_id']
                        self._child_classes = OrderedDict([("sub-interface", ("sub_interface", L2vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface))])
                        self._leafs = OrderedDict([
                            ('vlan_id', YLeaf(YType.uint32, 'vlan-id')),
                            ('vlan_id_xr', YLeaf(YType.uint32, 'vlan-id-xr')),
                            ('msti_id', YLeaf(YType.uint32, 'msti-id')),
                            ('port_count', YLeaf(YType.uint32, 'port-count')),
                        ])
                        self.vlan_id = None
                        self.vlan_id_xr = None
                        self.msti_id = None
                        self.port_count = None

                        self.sub_interface = YList(self)
                        self._segment_path = lambda: "mstp-vlan" + "[vlan-id='" + str(self.vlan_id) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.MstpVlans.MstpVlan, ['vlan_id', 'vlan_id_xr', 'msti_id', 'port_count'], name, value)


                    class SubInterface(Entity):
                        """
                        Sub interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface, self).__init__()

                            self.yang_name = "sub-interface"
                            self.yang_parent_name = "mstp-vlan"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ])
                            self.interface_name = None
                            self._segment_path = lambda: "sub-interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.MstpVlans.MstpVlan.SubInterface, ['interface_name'], name, value)


            class L2vpnPbbBsa(Entity):
                """
                L2VPN PBB Backbone Source MAC information
                
                .. attribute:: provisioned
                
                	BMAC SA configured
                	**type**\: bool
                
                .. attribute:: chassis_is_provisioned
                
                	Chassis MAC is configured
                	**type**\: bool
                
                .. attribute:: bmac_sa
                
                	BMAC SA
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                .. attribute:: chassis_mac
                
                	Chassis MAC
                	**type**\: str
                
                	**pattern:** [0\-9a\-fA\-F]{2}(\:[0\-9a\-fA\-F]{2}){5}
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.L2vpnPbbBsa, self).__init__()

                    self.yang_name = "l2vpn-pbb-bsa"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([])
                    self._leafs = OrderedDict([
                        ('provisioned', YLeaf(YType.boolean, 'provisioned')),
                        ('chassis_is_provisioned', YLeaf(YType.boolean, 'chassis-is-provisioned')),
                        ('bmac_sa', YLeaf(YType.str, 'bmac-sa')),
                        ('chassis_mac', YLeaf(YType.str, 'chassis-mac')),
                    ])
                    self.provisioned = None
                    self.chassis_is_provisioned = None
                    self.bmac_sa = None
                    self.chassis_mac = None
                    self._segment_path = lambda: "l2vpn-pbb-bsa"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.L2vpnPbbBsa, ['provisioned', 'chassis_is_provisioned', 'bmac_sa', 'chassis_mac'], name, value)


            class FlexibleXconnectServices(Entity):
                """
                Flexible XConnect Service Table
                
                .. attribute:: flexible_xconnect_service
                
                	Flexible XConnect Service Information
                	**type**\: list of  		 :py:class:`FlexibleXconnectService <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices, self).__init__()

                    self.yang_name = "flexible-xconnect-services"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("flexible-xconnect-service", ("flexible_xconnect_service", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService))])
                    self._leafs = OrderedDict()

                    self.flexible_xconnect_service = YList(self)
                    self._segment_path = lambda: "flexible-xconnect-services"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices, [], name, value)


                class FlexibleXconnectService(Entity):
                    """
                    Flexible XConnect Service Information
                    
                    .. attribute:: name  (key)
                    
                    	Flexible XConnect Service Name
                    	**type**\: str
                    
                    	**length:** 1..23
                    
                    .. attribute:: flexible_xconnect_service_acs
                    
                    	Flexible XConnect Service Attachment Circuit Table
                    	**type**\:  :py:class:`FlexibleXconnectServiceAcs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs>`
                    
                    .. attribute:: flexible_xconnect_service_info
                    
                    	Flexible XConnect Service Information
                    	**type**\:  :py:class:`FlexibleXconnectServiceInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService, self).__init__()

                        self.yang_name = "flexible-xconnect-service"
                        self.yang_parent_name = "flexible-xconnect-services"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['name']
                        self._child_classes = OrderedDict([("flexible-xconnect-service-acs", ("flexible_xconnect_service_acs", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs)), ("flexible-xconnect-service-info", ("flexible_xconnect_service_info", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo))])
                        self._leafs = OrderedDict([
                            ('name', YLeaf(YType.str, 'name')),
                        ])
                        self.name = None

                        self.flexible_xconnect_service_acs = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs()
                        self.flexible_xconnect_service_acs.parent = self
                        self._children_name_map["flexible_xconnect_service_acs"] = "flexible-xconnect-service-acs"

                        self.flexible_xconnect_service_info = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo()
                        self.flexible_xconnect_service_info.parent = self
                        self._children_name_map["flexible_xconnect_service_info"] = "flexible-xconnect-service-info"
                        self._segment_path = lambda: "flexible-xconnect-service" + "[name='" + str(self.name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService, ['name'], name, value)


                    class FlexibleXconnectServiceAcs(Entity):
                        """
                        Flexible XConnect Service Attachment Circuit
                        Table
                        
                        .. attribute:: flexible_xconnect_service_ac
                        
                        	Flexible XConnect Service Attachment Circuit
                        	**type**\: list of  		 :py:class:`FlexibleXconnectServiceAc <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, self).__init__()

                            self.yang_name = "flexible-xconnect-service-acs"
                            self.yang_parent_name = "flexible-xconnect-service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("flexible-xconnect-service-ac", ("flexible_xconnect_service_ac", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc))])
                            self._leafs = OrderedDict()

                            self.flexible_xconnect_service_ac = YList(self)
                            self._segment_path = lambda: "flexible-xconnect-service-acs"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs, [], name, value)


                        class FlexibleXconnectServiceAc(Entity):
                            """
                            Flexible XConnect Service Attachment Circuit
                            
                            .. attribute:: interface_name  (key)
                            
                            	Interface Name
                            	**type**\: str
                            
                            	**pattern:** [a\-zA\-Z0\-9./\-]+
                            
                            .. attribute:: attachment_circuit
                            
                            	Flexible XConnect Service Attachment Circuit
                            	**type**\:  :py:class:`AttachmentCircuit <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, self).__init__()

                                self.yang_name = "flexible-xconnect-service-ac"
                                self.yang_parent_name = "flexible-xconnect-service-acs"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = ['interface_name']
                                self._child_classes = OrderedDict([("attachment-circuit", ("attachment_circuit", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit))])
                                self._leafs = OrderedDict([
                                    ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ])
                                self.interface_name = None

                                self.attachment_circuit = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit()
                                self.attachment_circuit.parent = self
                                self._children_name_map["attachment_circuit"] = "attachment-circuit"
                                self._segment_path = lambda: "flexible-xconnect-service-ac" + "[interface-name='" + str(self.interface_name) + "']"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc, ['interface_name'], name, value)


                            class AttachmentCircuit(Entity):
                                """
                                Flexible XConnect Service Attachment Circuit
                                
                                .. attribute:: interface
                                
                                	Interface
                                	**type**\:  :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface>`
                                
                                .. attribute:: statistics
                                
                                	Statistics
                                	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics>`
                                
                                .. attribute:: l2vpn_protection
                                
                                	Protection object used for this segment
                                	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection>`
                                
                                .. attribute:: state
                                
                                	State
                                	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                                
                                .. attribute:: msti
                                
                                	MSTi
                                	**type**\: str
                                
                                .. attribute:: internal_ms_ti
                                
                                	Internal MSTi
                                	**type**\: str
                                
                                .. attribute:: interface_handle
                                
                                	Interface Handler
                                	**type**\: str
                                
                                	**pattern:** [a\-zA\-Z0\-9./\-]+
                                
                                .. attribute:: node_id
                                
                                	Node ID
                                	**type**\: str
                                
                                	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
                                
                                .. attribute:: xconnect_id
                                
                                	XConnect ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ms_ti_mismatch
                                
                                	MSTi mismatch
                                	**type**\: bool
                                
                                .. attribute:: mtu_mismatched
                                
                                	MTU mismatched
                                	**type**\: bool
                                
                                .. attribute:: tdm_media_mismatched
                                
                                	TDM media parms mismatched
                                	**type**\: bool
                                
                                .. attribute:: bvi_mac_conflict
                                
                                	BVI Mac Conflict
                                	**type**\: bool
                                
                                .. attribute:: bvi_no_port_up
                                
                                	BVI no BP Up
                                	**type**\: bool
                                
                                .. attribute:: control_word_mismatched
                                
                                	Control word mismatched
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_mismatched
                                
                                	Encapsulation mismatched
                                	**type**\: bool
                                
                                .. attribute:: encapsulation_error
                                
                                	Encapsulation Error
                                	**type**\: str
                                
                                .. attribute:: interworking
                                
                                	Interworking type
                                	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                                
                                .. attribute:: out_of_memory_state
                                
                                	L2VPN Out of memory state
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: msti_mismatch_down
                                
                                	Oper down due to MSTI mismatch
                                	**type**\: bool
                                
                                .. attribute:: mac_limit_oper_down
                                
                                	Oper down because MAC limit reached
                                	**type**\: bool
                                
                                .. attribute:: redundancy_group_id
                                
                                	Redundancy Group ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: redundancy_group_state
                                
                                	Redundancy Group State
                                	**type**\:  :py:class:`L2vpnRgState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnRgState>`
                                
                                .. attribute:: redundancy_object_id
                                
                                	Redundancy Object ID
                                	**type**\: int
                                
                                	**range:** 0..18446744073709551615
                                
                                .. attribute:: is_ac_partially_programmed
                                
                                	Is attachment\-circuit partially programmed
                                	**type**\: bool
                                
                                .. attribute:: evpn_internal_label
                                
                                	EVPN Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, self).__init__()

                                    self.yang_name = "attachment-circuit"
                                    self.yang_parent_name = "flexible-xconnect-service-ac"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics)), ("l2vpn-protection", ("l2vpn_protection", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection))])
                                    self._leafs = OrderedDict([
                                        ('state', YLeaf(YType.enumeration, 'state')),
                                        ('msti', YLeaf(YType.str, 'msti')),
                                        ('internal_ms_ti', YLeaf(YType.str, 'internal-ms-ti')),
                                        ('interface_handle', YLeaf(YType.str, 'interface-handle')),
                                        ('node_id', YLeaf(YType.str, 'node-id')),
                                        ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                        ('ms_ti_mismatch', YLeaf(YType.boolean, 'ms-ti-mismatch')),
                                        ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                        ('tdm_media_mismatched', YLeaf(YType.boolean, 'tdm-media-mismatched')),
                                        ('bvi_mac_conflict', YLeaf(YType.boolean, 'bvi-mac-conflict')),
                                        ('bvi_no_port_up', YLeaf(YType.boolean, 'bvi-no-port-up')),
                                        ('control_word_mismatched', YLeaf(YType.boolean, 'control-word-mismatched')),
                                        ('encapsulation_mismatched', YLeaf(YType.boolean, 'encapsulation-mismatched')),
                                        ('encapsulation_error', YLeaf(YType.str, 'encapsulation-error')),
                                        ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                        ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                        ('msti_mismatch_down', YLeaf(YType.boolean, 'msti-mismatch-down')),
                                        ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                        ('redundancy_group_id', YLeaf(YType.uint32, 'redundancy-group-id')),
                                        ('redundancy_group_state', YLeaf(YType.enumeration, 'redundancy-group-state')),
                                        ('redundancy_object_id', YLeaf(YType.uint64, 'redundancy-object-id')),
                                        ('is_ac_partially_programmed', YLeaf(YType.boolean, 'is-ac-partially-programmed')),
                                        ('evpn_internal_label', YLeaf(YType.uint32, 'evpn-internal-label')),
                                    ])
                                    self.state = None
                                    self.msti = None
                                    self.internal_ms_ti = None
                                    self.interface_handle = None
                                    self.node_id = None
                                    self.xconnect_id = None
                                    self.ms_ti_mismatch = None
                                    self.mtu_mismatched = None
                                    self.tdm_media_mismatched = None
                                    self.bvi_mac_conflict = None
                                    self.bvi_no_port_up = None
                                    self.control_word_mismatched = None
                                    self.encapsulation_mismatched = None
                                    self.encapsulation_error = None
                                    self.interworking = None
                                    self.out_of_memory_state = None
                                    self.msti_mismatch_down = None
                                    self.mac_limit_oper_down = None
                                    self.redundancy_group_id = None
                                    self.redundancy_group_state = None
                                    self.redundancy_object_id = None
                                    self.is_ac_partially_programmed = None
                                    self.evpn_internal_label = None

                                    self.interface = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface()
                                    self.interface.parent = self
                                    self._children_name_map["interface"] = "interface"

                                    self.statistics = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics()
                                    self.statistics.parent = self
                                    self._children_name_map["statistics"] = "statistics"

                                    self.l2vpn_protection = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection()
                                    self.l2vpn_protection.parent = self
                                    self._children_name_map["l2vpn_protection"] = "l2vpn-protection"
                                    self._segment_path = lambda: "attachment-circuit"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit, ['state', 'msti', 'internal_ms_ti', 'interface_handle', 'node_id', 'xconnect_id', 'ms_ti_mismatch', 'mtu_mismatched', 'tdm_media_mismatched', 'bvi_mac_conflict', 'bvi_no_port_up', 'control_word_mismatched', 'encapsulation_mismatched', 'encapsulation_error', 'interworking', 'out_of_memory_state', 'msti_mismatch_down', 'mac_limit_oper_down', 'redundancy_group_id', 'redundancy_group_state', 'redundancy_object_id', 'is_ac_partially_programmed', 'evpn_internal_label'], name, value)


                                class Interface(Entity):
                                    """
                                    Interface
                                    
                                    .. attribute:: parameters
                                    
                                    	Interface parameters
                                    	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters>`
                                    
                                    .. attribute:: name
                                    
                                    	Interface name
                                    	**type**\: str
                                    
                                    	**length:** 0..81
                                    
                                    .. attribute:: mtu
                                    
                                    	Interface MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: payload_bytes
                                    
                                    	Payload bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    	**units**\: byte
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, self).__init__()

                                        self.yang_name = "interface"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters))])
                                        self._leafs = OrderedDict([
                                            ('name', YLeaf(YType.str, 'name')),
                                            ('mtu', YLeaf(YType.uint32, 'mtu')),
                                            ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                        ])
                                        self.name = None
                                        self.mtu = None
                                        self.payload_bytes = None

                                        self.parameters = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters()
                                        self.parameters.parent = self
                                        self._children_name_map["parameters"] = "parameters"
                                        self._segment_path = lambda: "interface"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface, ['name', 'mtu', 'payload_bytes'], name, value)


                                    class Parameters(Entity):
                                        """
                                        Interface parameters
                                        
                                        .. attribute:: ethernet
                                        
                                        	Ethernet
                                        	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet>`
                                        
                                        .. attribute:: vlan
                                        
                                        	VLAN
                                        	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan>`
                                        
                                        .. attribute:: tdm
                                        
                                        	TDM
                                        	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm>`
                                        
                                        .. attribute:: atm
                                        
                                        	ATM
                                        	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm>`
                                        
                                        .. attribute:: fr
                                        
                                        	Frame Relay
                                        	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr>`
                                        
                                        .. attribute:: pseudowire_ether
                                        
                                        	PW Ether
                                        	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther>`
                                        
                                        .. attribute:: pseudowire_iw
                                        
                                        	PW IW
                                        	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw>`
                                        
                                        .. attribute:: type
                                        
                                        	Type
                                        	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, self).__init__()

                                            self.yang_name = "parameters"
                                            self.yang_parent_name = "interface"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw))])
                                            self._leafs = OrderedDict([
                                                ('type', YLeaf(YType.enumeration, 'type')),
                                            ])
                                            self.type = None

                                            self.ethernet = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet()
                                            self.ethernet.parent = self
                                            self._children_name_map["ethernet"] = "ethernet"

                                            self.vlan = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan()
                                            self.vlan.parent = self
                                            self._children_name_map["vlan"] = "vlan"

                                            self.tdm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm()
                                            self.tdm.parent = self
                                            self._children_name_map["tdm"] = "tdm"

                                            self.atm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm()
                                            self.atm.parent = self
                                            self._children_name_map["atm"] = "atm"

                                            self.fr = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr()
                                            self.fr.parent = self
                                            self._children_name_map["fr"] = "fr"

                                            self.pseudowire_ether = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther()
                                            self.pseudowire_ether.parent = self
                                            self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                            self.pseudowire_iw = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw()
                                            self.pseudowire_iw.parent = self
                                            self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                            self._segment_path = lambda: "parameters"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters, ['type'], name, value)


                                        class Ethernet(Entity):
                                            """
                                            Ethernet
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, self).__init__()

                                                self.yang_name = "ethernet"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ])
                                                self.xconnect_tags = None
                                                self._segment_path = lambda: "ethernet"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                        class Vlan(Entity):
                                            """
                                            VLAN
                                            
                                            .. attribute:: xconnect_tags
                                            
                                            	XConnect tags
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: vlan_rewrite_tag
                                            
                                            	VLAN rewrite tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: simple_efp
                                            
                                            	Simple EFP
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: encapsulation_type
                                            
                                            	Encapsulation Type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: outer_tag
                                            
                                            	Outer Tag
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: rewrite_tag
                                            
                                            	Rewrite Tags
                                            	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag>`
                                            
                                            .. attribute:: vlan_range
                                            
                                            	vlan range
                                            	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, self).__init__()

                                                self.yang_name = "vlan"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange))])
                                                self._leafs = OrderedDict([
                                                    ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                    ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                    ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                    ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                    ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                                ])
                                                self.xconnect_tags = None
                                                self.vlan_rewrite_tag = None
                                                self.simple_efp = None
                                                self.encapsulation_type = None
                                                self.outer_tag = None

                                                self.rewrite_tag = YList(self)
                                                self.vlan_range = YList(self)
                                                self._segment_path = lambda: "vlan"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                            class RewriteTag(Entity):
                                                """
                                                Rewrite Tags
                                                
                                                .. attribute:: entry
                                                
                                                	
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, self).__init__()

                                                    self.yang_name = "rewrite-tag"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('entry', YLeaf(YType.uint16, 'entry')),
                                                    ])
                                                    self.entry = None
                                                    self._segment_path = lambda: "rewrite-tag"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                            class VlanRange(Entity):
                                                """
                                                vlan range
                                                
                                                .. attribute:: lower
                                                
                                                	Lower
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: upper
                                                
                                                	Upper
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, self).__init__()

                                                    self.yang_name = "vlan-range"
                                                    self.yang_parent_name = "vlan"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('lower', YLeaf(YType.uint16, 'lower')),
                                                        ('upper', YLeaf(YType.uint16, 'upper')),
                                                    ])
                                                    self.lower = None
                                                    self.upper = None
                                                    self._segment_path = lambda: "vlan-range"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                        class Tdm(Entity):
                                            """
                                            TDM
                                            
                                            .. attribute:: tdm_options
                                            
                                            	TDM options
                                            	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions>`
                                            
                                            .. attribute:: timeslot_group
                                            
                                            	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                            	**type**\: str
                                            
                                            .. attribute:: timeslot_rate
                                            
                                            	Timeslot rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: tdm_mode
                                            
                                            	TDM mode
                                            	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, self).__init__()

                                                self.yang_name = "tdm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions))])
                                                self._leafs = OrderedDict([
                                                    ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                    ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                    ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                                ])
                                                self.timeslot_group = None
                                                self.timeslot_rate = None
                                                self.tdm_mode = None

                                                self.tdm_options = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions()
                                                self.tdm_options.parent = self
                                                self._children_name_map["tdm_options"] = "tdm-options"
                                                self._segment_path = lambda: "tdm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                            class TdmOptions(Entity):
                                                """
                                                TDM options
                                                
                                                .. attribute:: payload_bytes
                                                
                                                	TDM payload bytes
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                	**units**\: byte
                                                
                                                .. attribute:: bit_rate
                                                
                                                	TDM bit rate in units of Kbps
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                	**units**\: kbit/s
                                                
                                                .. attribute:: rtp
                                                
                                                	RTP header
                                                	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                                
                                                .. attribute:: timestamp_mode
                                                
                                                	TDM Timestamping mode
                                                	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                                
                                                .. attribute:: signalling_packets
                                                
                                                	Signalling packets
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: cas
                                                
                                                	CAS
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: rtp_header_payload_type
                                                
                                                	RTP header payload type
                                                	**type**\: int
                                                
                                                	**range:** 0..255
                                                
                                                .. attribute:: timestamp_clock_freq
                                                
                                                	Timestamping clock frequency in units of 8Khz
                                                	**type**\: int
                                                
                                                	**range:** 0..65535
                                                
                                                .. attribute:: ssrc
                                                
                                                	Synchronization Source identifier
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, self).__init__()

                                                    self.yang_name = "tdm-options"
                                                    self.yang_parent_name = "tdm"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                        ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                        ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                        ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                        ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                        ('cas', YLeaf(YType.uint8, 'cas')),
                                                        ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                        ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                        ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                    ])
                                                    self.payload_bytes = None
                                                    self.bit_rate = None
                                                    self.rtp = None
                                                    self.timestamp_mode = None
                                                    self.signalling_packets = None
                                                    self.cas = None
                                                    self.rtp_header_payload_type = None
                                                    self.timestamp_clock_freq = None
                                                    self.ssrc = None
                                                    self._segment_path = lambda: "tdm-options"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                        class Atm(Entity):
                                            """
                                            ATM
                                            
                                            .. attribute:: maximum_number_cells_packed
                                            
                                            	Max number of cells packed
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: maximum_number_cells_un_packed
                                            
                                            	Max number of cells unpacked
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: atm_mode
                                            
                                            	ATM mode
                                            	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                            
                                            .. attribute:: vpi
                                            
                                            	Virtual path identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vci
                                            
                                            	Virtual channel identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, self).__init__()

                                                self.yang_name = "atm"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                    ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                    ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                    ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                    ('vci', YLeaf(YType.uint16, 'vci')),
                                                ])
                                                self.maximum_number_cells_packed = None
                                                self.maximum_number_cells_un_packed = None
                                                self.atm_mode = None
                                                self.vpi = None
                                                self.vci = None
                                                self._segment_path = lambda: "atm"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                        class Fr(Entity):
                                            """
                                            Frame Relay
                                            
                                            .. attribute:: fr_mode
                                            
                                            	Frame Relay mode
                                            	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                            
                                            .. attribute:: dlci
                                            
                                            	Data\-link connection identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, self).__init__()

                                                self.yang_name = "fr"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                    ('dlci', YLeaf(YType.uint32, 'dlci')),
                                                ])
                                                self.fr_mode = None
                                                self.dlci = None
                                                self._segment_path = lambda: "fr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                        class PseudowireEther(Entity):
                                            """
                                            PW Ether
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, self).__init__()

                                                self.yang_name = "pseudowire-ether"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-ether"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-ether"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface_(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireEther.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                        class PseudowireIw(Entity):
                                            """
                                            PW IW
                                            
                                            .. attribute:: interface_list
                                            
                                            	Interface list data
                                            	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList>`
                                            
                                            .. attribute:: is_valid
                                            
                                            	Is this Interface list valid
                                            	**type**\: bool
                                            
                                            .. attribute:: internal_label
                                            
                                            	Internal Label
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, self).__init__()

                                                self.yang_name = "pseudowire-iw"
                                                self.yang_parent_name = "parameters"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList))])
                                                self._leafs = OrderedDict([
                                                    ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                    ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                                ])
                                                self.is_valid = None
                                                self.internal_label = None

                                                self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList()
                                                self.interface_list.parent = self
                                                self._children_name_map["interface_list"] = "interface-list"
                                                self._segment_path = lambda: "pseudowire-iw"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                            class InterfaceList(Entity):
                                                """
                                                Interface list data
                                                
                                                .. attribute:: interface_list_name
                                                
                                                	Interface\-list name
                                                	**type**\: str
                                                
                                                	**length:** 0..33
                                                
                                                .. attribute:: interface_list_id
                                                
                                                	Interface internal ID
                                                	**type**\: int
                                                
                                                	**range:** 0..4294967295
                                                
                                                .. attribute:: interface
                                                
                                                	Interfaces
                                                	**type**\: list of  		 :py:class:`Interface_ <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                    self.yang_name = "interface-list"
                                                    self.yang_parent_name = "pseudowire-iw"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_))])
                                                    self._leafs = OrderedDict([
                                                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                    ])
                                                    self.interface_list_name = None
                                                    self.interface_list_id = None

                                                    self.interface = YList(self)
                                                    self._segment_path = lambda: "interface-list"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                                class Interface_(Entity):
                                                    """
                                                    Interfaces
                                                    
                                                    .. attribute:: interface_name
                                                    
                                                    	Interface name
                                                    	**type**\: str
                                                    
                                                    .. attribute:: replicate_status
                                                    
                                                    	Replicate status
                                                    	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                    
                                                    

                                                    """

                                                    _prefix = 'l2vpn-oper'
                                                    _revision = '2017-09-07'

                                                    def __init__(self):
                                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, self).__init__()

                                                        self.yang_name = "interface"
                                                        self.yang_parent_name = "interface-list"
                                                        self.is_top_level_class = False
                                                        self.has_list_ancestor = True
                                                        self.ylist_key_names = []
                                                        self._child_classes = OrderedDict([])
                                                        self._leafs = OrderedDict([
                                                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                            ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                        ])
                                                        self.interface_name = None
                                                        self.replicate_status = None
                                                        self._segment_path = lambda: "interface"

                                                    def __setattr__(self, name, value):
                                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Interface.Parameters.PseudowireIw.InterfaceList.Interface_, [u'interface_name', u'replicate_status'], name, value)


                                class Statistics(Entity):
                                    """
                                    Statistics
                                    
                                    .. attribute:: impostion_stats
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats>`
                                    
                                    .. attribute:: dispostion_stats
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats>`
                                    
                                    .. attribute:: sequence_number
                                    
                                    	sequence numbers
                                    	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, self).__init__()

                                        self.yang_name = "statistics"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber))])
                                        self._leafs = OrderedDict()

                                        self.impostion_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats()
                                        self.impostion_stats.parent = self
                                        self._children_name_map["impostion_stats"] = "impostion-stats"

                                        self.dispostion_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats()
                                        self.dispostion_stats.parent = self
                                        self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                        self.sequence_number = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber()
                                        self.sequence_number.parent = self
                                        self._children_name_map["sequence_number"] = "sequence-number"
                                        self._segment_path = lambda: "statistics"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics, [], name, value)


                                    class ImpostionStats(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: imposition_stat
                                        
                                        	imposition stats
                                        	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat>`
                                        
                                        .. attribute:: imposition_mtu_drop
                                        
                                        	imposition mtu drop stats
                                        	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                        
                                        .. attribute:: impostion_tail_drop
                                        
                                        	imposition tail drop stats
                                        	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop>`
                                        
                                        .. attribute:: l2fsbi_drop
                                        
                                        	rx discards
                                        	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop>`
                                        
                                        .. attribute:: multicast
                                        
                                        	Multicast
                                        	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast>`
                                        
                                        .. attribute:: broadcast
                                        
                                        	Broadcast
                                        	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast>`
                                        
                                        .. attribute:: unknown_unicast
                                        
                                        	Unknown Unicast
                                        	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, self).__init__()

                                            self.yang_name = "impostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast))])
                                            self._leafs = OrderedDict()

                                            self.imposition_stat = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat()
                                            self.imposition_stat.parent = self
                                            self._children_name_map["imposition_stat"] = "imposition-stat"

                                            self.imposition_mtu_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop()
                                            self.imposition_mtu_drop.parent = self
                                            self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                            self.impostion_tail_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop()
                                            self.impostion_tail_drop.parent = self
                                            self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                            self.l2fsbi_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop()
                                            self.l2fsbi_drop.parent = self
                                            self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                            self.multicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast()
                                            self.multicast.parent = self
                                            self._children_name_map["multicast"] = "multicast"

                                            self.broadcast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast()
                                            self.broadcast.parent = self
                                            self._children_name_map["broadcast"] = "broadcast"

                                            self.known_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.unknown_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast()
                                            self.unknown_unicast.parent = self
                                            self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                            self._segment_path = lambda: "impostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats, [], name, value)


                                        class ImpositionStat(Entity):
                                            """
                                            imposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                                self.yang_name = "imposition-stat"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpositionMtuDrop(Entity):
                                            """
                                            imposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                                self.yang_name = "imposition-mtu-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "imposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ImpostionTailDrop(Entity):
                                            """
                                            imposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                                self.yang_name = "impostion-tail-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "impostion-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class L2fsbiDrop(Entity):
                                            """
                                            rx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                                self.yang_name = "l2fsbi-drop"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "l2fsbi-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class Multicast(Entity):
                                            """
                                            Multicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, self).__init__()

                                                self.yang_name = "multicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                        class Broadcast(Entity):
                                            """
                                            Broadcast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, self).__init__()

                                                self.yang_name = "broadcast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class UnknownUnicast(Entity):
                                            """
                                            Unknown Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                                self.yang_name = "unknown-unicast"
                                                self.yang_parent_name = "impostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unknown-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class DispostionStats(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: disposition_stat
                                        
                                        	disposition stats
                                        	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat>`
                                        
                                        .. attribute:: disposition_mtu_drop
                                        
                                        	disposition mtu drop stats
                                        	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop>`
                                        
                                        .. attribute:: disposition_tail_drop
                                        
                                        	disposition tail drop stats
                                        	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop>`
                                        
                                        .. attribute:: multicast_drop
                                        
                                        	disposition storm control multicast drop stats
                                        	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop>`
                                        
                                        .. attribute:: unicast_drop
                                        
                                        	disposition storm control unknown unicast drop stats
                                        	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop>`
                                        
                                        .. attribute:: broadcast_drop
                                        
                                        	disposition storm control broadcast drop stats
                                        	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop>`
                                        
                                        .. attribute:: received_drops
                                        
                                        	tx discards
                                        	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops>`
                                        
                                        .. attribute:: dai_drop
                                        
                                        	Disposition dynamic ARP inspection drop statistics
                                        	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop>`
                                        
                                        .. attribute:: ipsg_drop
                                        
                                        	disposition IP source guard drop statistics
                                        	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop>`
                                        
                                        .. attribute:: disposition_oo_o_drops
                                        
                                        	Disposition Out\-of\-Order Drops
                                        	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops>`
                                        
                                        .. attribute:: disposition_p2mp_stats
                                        
                                        	Disposition P2MP Stats
                                        	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats>`
                                        
                                        .. attribute:: known_unicast
                                        
                                        	Known Unicast
                                        	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast>`
                                        
                                        .. attribute:: mac_move
                                        
                                        	MAC Move
                                        	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, self).__init__()

                                            self.yang_name = "dispostion-stats"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove))])
                                            self._leafs = OrderedDict()

                                            self.disposition_stat = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat()
                                            self.disposition_stat.parent = self
                                            self._children_name_map["disposition_stat"] = "disposition-stat"

                                            self.disposition_mtu_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop()
                                            self.disposition_mtu_drop.parent = self
                                            self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                            self.disposition_tail_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop()
                                            self.disposition_tail_drop.parent = self
                                            self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                            self.multicast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop()
                                            self.multicast_drop.parent = self
                                            self._children_name_map["multicast_drop"] = "multicast-drop"

                                            self.unicast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop()
                                            self.unicast_drop.parent = self
                                            self._children_name_map["unicast_drop"] = "unicast-drop"

                                            self.broadcast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop()
                                            self.broadcast_drop.parent = self
                                            self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                            self.received_drops = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops()
                                            self.received_drops.parent = self
                                            self._children_name_map["received_drops"] = "received-drops"

                                            self.dai_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop()
                                            self.dai_drop.parent = self
                                            self._children_name_map["dai_drop"] = "dai-drop"

                                            self.ipsg_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop()
                                            self.ipsg_drop.parent = self
                                            self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                            self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops()
                                            self.disposition_oo_o_drops.parent = self
                                            self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                            self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats()
                                            self.disposition_p2mp_stats.parent = self
                                            self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                            self.known_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast()
                                            self.known_unicast.parent = self
                                            self._children_name_map["known_unicast"] = "known-unicast"

                                            self.mac_move = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove()
                                            self.mac_move.parent = self
                                            self._children_name_map["mac_move"] = "mac-move"
                                            self._segment_path = lambda: "dispostion-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats, [], name, value)


                                        class DispositionStat(Entity):
                                            """
                                            disposition stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, self).__init__()

                                                self.yang_name = "disposition-stat"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-stat"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionMtuDrop(Entity):
                                            """
                                            disposition mtu drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                                self.yang_name = "disposition-mtu-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-mtu-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionTailDrop(Entity):
                                            """
                                            disposition tail drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                                self.yang_name = "disposition-tail-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-tail-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class MulticastDrop(Entity):
                                            """
                                            disposition storm control multicast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                                self.yang_name = "multicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "multicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class UnicastDrop(Entity):
                                            """
                                            disposition storm control unknown unicast drop
                                            stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                                self.yang_name = "unicast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "unicast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class BroadcastDrop(Entity):
                                            """
                                            disposition storm control broadcast drop stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                                self.yang_name = "broadcast-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "broadcast-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class ReceivedDrops(Entity):
                                            """
                                            tx discards
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                                self.yang_name = "received-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "received-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DaiDrop(Entity):
                                            """
                                            Disposition dynamic ARP inspection drop
                                            statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, self).__init__()

                                                self.yang_name = "dai-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "dai-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class IpsgDrop(Entity):
                                            """
                                            disposition IP source guard drop statistics
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                                self.yang_name = "ipsg-drop"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "ipsg-drop"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionOoODrops(Entity):
                                            """
                                            Disposition Out\-of\-Order Drops
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                                self.yang_name = "disposition-oo-o-drops"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-oo-o-drops"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                        class DispositionP2mpStats(Entity):
                                            """
                                            Disposition P2MP Stats
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                                self.yang_name = "disposition-p2mp-stats"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "disposition-p2mp-stats"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                        class KnownUnicast(Entity):
                                            """
                                            Known Unicast
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                                self.yang_name = "known-unicast"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "known-unicast"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                        class MacMove(Entity):
                                            """
                                            MAC Move
                                            
                                            .. attribute:: packet_counts
                                            
                                            	packets counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            .. attribute:: byte_counts
                                            
                                            	bytes counters
                                            	**type**\: int
                                            
                                            	**range:** 0..18446744073709551615
                                            
                                            	**units**\: byte
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, self).__init__()

                                                self.yang_name = "mac-move"
                                                self.yang_parent_name = "dispostion-stats"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                    ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                                ])
                                                self.packet_counts = None
                                                self.byte_counts = None
                                                self._segment_path = lambda: "mac-move"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                    class SequenceNumber(Entity):
                                        """
                                        sequence numbers
                                        
                                        .. attribute:: sequence_number_sent
                                        
                                        	sequence number sent
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: sequence_number_expected
                                        
                                        	sequence number expected
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        .. attribute:: bypassed_inbound_sequence_packet
                                        
                                        	Bypassed inbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: bypassed_out_sequence_packet
                                        
                                        	Bypassed outbound sequence packets
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, self).__init__()

                                            self.yang_name = "sequence-number"
                                            self.yang_parent_name = "statistics"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                                ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                                ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                                ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                            ])
                                            self.sequence_number_sent = None
                                            self.sequence_number_expected = None
                                            self.bypassed_inbound_sequence_packet = None
                                            self.bypassed_out_sequence_packet = None
                                            self._segment_path = lambda: "sequence-number"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                                class L2vpnProtection(Entity):
                                    """
                                    Protection object used for this segment
                                    
                                    .. attribute:: protection_type
                                    
                                    	Type of the protection
                                    	**type**\:  :py:class:`L2vpnProtection <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtection>`
                                    
                                    .. attribute:: protection_configured
                                    
                                    	Protection configured
                                    	**type**\:  :py:class:`L2vpnProtectionRole <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnProtectionRole>`
                                    
                                    .. attribute:: protection_name
                                    
                                    	Name of the segment acting as backup
                                    	**type**\: str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: protected_name
                                    
                                    	Name of the protected segment
                                    	**type**\: str
                                    
                                    	**length:** 0..65
                                    
                                    .. attribute:: active
                                    
                                    	Active
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, self).__init__()

                                        self.yang_name = "l2vpn-protection"
                                        self.yang_parent_name = "attachment-circuit"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('protection_type', YLeaf(YType.enumeration, 'protection-type')),
                                            ('protection_configured', YLeaf(YType.enumeration, 'protection-configured')),
                                            ('protection_name', YLeaf(YType.str, 'protection-name')),
                                            ('protected_name', YLeaf(YType.str, 'protected-name')),
                                            ('active', YLeaf(YType.boolean, 'active')),
                                        ])
                                        self.protection_type = None
                                        self.protection_configured = None
                                        self.protection_name = None
                                        self.protected_name = None
                                        self.active = None
                                        self._segment_path = lambda: "l2vpn-protection"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceAcs.FlexibleXconnectServiceAc.AttachmentCircuit.L2vpnProtection, ['protection_type', 'protection_configured', 'protection_name', 'protected_name', 'active'], name, value)


                    class FlexibleXconnectServiceInfo(Entity):
                        """
                        Flexible XConnect Service Information
                        
                        .. attribute:: fxc_id
                        
                        	Flexible XConnect ID
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: name
                        
                        	Flexible XConnect Service Name
                        	**type**\: str
                        
                        .. attribute:: state
                        
                        	State of the Flexible XConnect Service
                        	**type**\:  :py:class:`L2vpnXcState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnXcState>`
                        
                        .. attribute:: num_p_ws
                        
                        	Number of Pseudowires in Pseudowire List
                        	**type**\: int
                        
                        	**range:** 0..255
                        
                        .. attribute:: pseudowire
                        
                        	Flexible XConnect Service Pseudowire List
                        	**type**\: list of  		 :py:class:`Pseudowire <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, self).__init__()

                            self.yang_name = "flexible-xconnect-service-info"
                            self.yang_parent_name = "flexible-xconnect-service"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("pseudowire", ("pseudowire", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire))])
                            self._leafs = OrderedDict([
                                ('fxc_id', YLeaf(YType.uint32, 'fxc-id')),
                                ('name', YLeaf(YType.str, 'name')),
                                ('state', YLeaf(YType.enumeration, 'state')),
                                ('num_p_ws', YLeaf(YType.uint8, 'num-p-ws')),
                            ])
                            self.fxc_id = None
                            self.name = None
                            self.state = None
                            self.num_p_ws = None

                            self.pseudowire = YList(self)
                            self._segment_path = lambda: "flexible-xconnect-service-info"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo, ['fxc_id', 'name', 'state', 'num_p_ws'], name, value)


                        class Pseudowire(Entity):
                            """
                            Flexible XConnect Service Pseudowire List
                            
                            .. attribute:: peer_id
                            
                            	Peer
                            	**type**\:  :py:class:`PeerId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId>`
                            
                            .. attribute:: encapsulation_info
                            
                            	Encapsulation specific pseudowire information
                            	**type**\:  :py:class:`EncapsulationInfo <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo>`
                            
                            .. attribute:: local_interface
                            
                            	Local interface
                            	**type**\:  :py:class:`LocalInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface>`
                            
                            .. attribute:: remote_interface
                            
                            	Remote interface
                            	**type**\:  :py:class:`RemoteInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface>`
                            
                            .. attribute:: preferred_path
                            
                            	MPLS Preferred Path
                            	**type**\:  :py:class:`PreferredPath <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath>`
                            
                            .. attribute:: local_signalling
                            
                            	Local signalling
                            	**type**\:  :py:class:`LocalSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling>`
                            
                            .. attribute:: remote_signalling
                            
                            	Remote signalling
                            	**type**\:  :py:class:`RemoteSignalling <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling>`
                            
                            .. attribute:: statistics
                            
                            	Statistics
                            	**type**\:  :py:class:`Statistics <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics>`
                            
                            .. attribute:: p2mp_pw
                            
                            	P2MP Pseudowire Information
                            	**type**\:  :py:class:`P2mpPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw>`
                            
                            .. attribute:: local_source_address
                            
                            	Local Source Address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: ipv6_local_source_address
                            
                            	Local IPv6 Source Address
                            	**type**\: str
                            
                            	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: pseudo_wire_id
                            
                            	Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: is_pwr_type
                            
                            	is Pseudowire\-routed
                            	**type**\: bool
                            
                            .. attribute:: is_evpn_vpws_type
                            
                            	is EVPN VPWS
                            	**type**\: bool
                            
                            .. attribute:: xconnect_id
                            
                            	XConnect ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: state
                            
                            	State
                            	**type**\:  :py:class:`L2vpnSegmentState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSegmentState>`
                            
                            .. attribute:: pseudo_wire_state
                            
                            	Pseudowire state
                            	**type**\:  :py:class:`L2vpnPwState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwState>`
                            
                            .. attribute:: protocol
                            
                            	Protocol
                            	**type**\:  :py:class:`L2vpnSignallingProto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnSignallingProto>`
                            
                            .. attribute:: pw_class_name
                            
                            	Pseudowire class name
                            	**type**\: str
                            
                            	**length:** 0..33
                            
                            .. attribute:: tag_rewrite
                            
                            	StaticTagRewrite
                            	**type**\: int
                            
                            	**range:** 0..65535
                            
                            .. attribute:: interworking
                            
                            	Interworking type
                            	**type**\:  :py:class:`L2vpnInterworking <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterworking>`
                            
                            .. attribute:: fe_ctype
                            
                            	Pseudowire FEC type
                            	**type**\:  :py:class:`L2vpnPwFec <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFec>`
                            
                            .. attribute:: evpn_src_acid
                            
                            	EVPN VPWS Source AC ID
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: sequencing_type
                            
                            	Sequencing Type
                            	**type**\:  :py:class:`L2vpnPwSequence <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwSequence>`
                            
                            .. attribute:: resync_enabled
                            
                            	Resync if packets out of sequence
                            	**type**\: bool
                            
                            .. attribute:: resync_threshold
                            
                            	Number of Packets Out of Seqence to trigger resync
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: local_control_word
                            
                            	Local control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: remote_control_word
                            
                            	Remote control word
                            	**type**\:  :py:class:`L2vpnPwControlWord <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwControlWord>`
                            
                            .. attribute:: local_pseudo_wire_type
                            
                            	Local pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: remote_pseudo_wire_type
                            
                            	Remote pseudowire type
                            	**type**\:  :py:class:`L2vpnPw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPw>`
                            
                            .. attribute:: imposed_vlan_id
                            
                            	Imposed vlan id
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: time_created
                            
                            	Time when the pseudowire was created
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_creation
                            
                            	Time elapsed since creation
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_changed
                            
                            	Last time the pseudowire status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_changed
                            
                            	Time elapsed since status changed
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: last_time_status_down
                            
                            	Last time the pseudowire went down in format %d/%m/%Y %H\:%M\:%S
                            	**type**\: str
                            
                            	**length:** 0..50
                            
                            .. attribute:: time_elapsed_status_down
                            
                            	Time elapsed since last status down in seconds
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            	**units**\: second
                            
                            .. attribute:: shutdown
                            
                            	Shutdown
                            	**type**\: bool
                            
                            .. attribute:: data_path_down
                            
                            	True if LSP down
                            	**type**\: bool
                            
                            .. attribute:: use_tunnel_path
                            
                            	True if using TE tunnel
                            	**type**\: bool
                            
                            .. attribute:: odn_configured
                            
                            	True if ODN is configured
                            	**type**\: bool
                            
                            .. attribute:: pseudo_wire_type_mismatched
                            
                            	Pseudowire type mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_bytes_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: bitrate_mismatched
                            
                            	Bitrate mismatched
                            	**type**\: bool
                            
                            .. attribute:: rtp_mismatched
                            
                            	RTP mismatched
                            	**type**\: bool
                            
                            .. attribute:: diff_ts_mismatched
                            
                            	Differential timestamp mismatched
                            	**type**\: bool
                            
                            .. attribute:: sig_pkts_mismatched
                            
                            	Signalling packets mismatched
                            	**type**\: bool
                            
                            .. attribute:: cas_mismatched
                            
                            	CAS mismatched
                            	**type**\: bool
                            
                            .. attribute:: payload_type_mismatched
                            
                            	Payload bytes mismatched
                            	**type**\: bool
                            
                            .. attribute:: freq_mismatched
                            
                            	Frequency mismatched
                            	**type**\: bool
                            
                            .. attribute:: ssrc_mismatched
                            
                            	SSRC mismatched
                            	**type**\: bool
                            
                            .. attribute:: mtu_mismatched
                            
                            	MTU mismatched
                            	**type**\: bool
                            
                            .. attribute:: illegal_control_word
                            
                            	Illegal control word
                            	**type**\: bool
                            
                            .. attribute:: ad_remote_down
                            
                            	Auto\-Discovered PW remote state down
                            	**type**\: bool
                            
                            .. attribute:: not_supported_qinq
                            
                            	A true value indicates that QinQ is not supported with L2TPv3; A false value indicates that it is supported. Please note that this object has been deprecated and will be removed in the near future since QinQ is supported going forward
                            	**type**\: bool
                            
                            .. attribute:: local_label_failed
                            
                            	Failed to set BGP advertised local label
                            	**type**\: bool
                            
                            .. attribute:: remote_label_failed
                            
                            	Failed to set BGP advertised remote label
                            	**type**\: bool
                            
                            .. attribute:: preferred_path_disable_fallback
                            
                            	Prefpath fallback enable/disable
                            	**type**\: bool
                            
                            .. attribute:: backup_pw
                            
                            	TRUE if PW is a backup PW
                            	**type**\: bool
                            
                            .. attribute:: primary_pw
                            
                            	TRUE if PW is a primary PW
                            	**type**\: bool
                            
                            .. attribute:: backup_active
                            
                            	TRUE if backup is active
                            	**type**\: bool
                            
                            .. attribute:: backup_force_active
                            
                            	TRUE if backup is active due to switchover
                            	**type**\: bool
                            
                            .. attribute:: disable_never
                            
                            	TRUE if backup is not automatically disabled
                            	**type**\: bool
                            
                            .. attribute:: disable_delay
                            
                            	Backup disable delay
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: primary_peer_id
                            
                            	Primary Peer IP address
                            	**type**\: str
                            
                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                            
                            .. attribute:: primary_pseudo_wire_id
                            
                            	Primary Pseudowire ID
                            	**type**\: int
                            
                            	**range:** 0..18446744073709551615
                            
                            .. attribute:: number_ma_cwithdraw_message_sent
                            
                            	Num MW messages sent over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: num_ma_cwithdraw_msg_received
                            
                            	Num MW messages received over PW
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: out_of_memory_state
                            
                            	L2VPN Out of memory state
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: transport_lsp_down
                            
                            	Oper down due to Transport LSP down
                            	**type**\: bool
                            
                            .. attribute:: mac_limit_oper_down
                            
                            	Oper down because MAC limit reached
                            	**type**\: bool
                            
                            .. attribute:: pw_status_use
                            
                            	PW status in use
                            	**type**\: bool
                            
                            .. attribute:: auto_discovery
                            
                            	Is autodiscovery
                            	**type**\: bool
                            
                            .. attribute:: ad_method
                            
                            	Autodiscovery method
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: pwlsd_rewrite_failed
                            
                            	LSD rewrite failed
                            	**type**\: bool
                            
                            .. attribute:: ldp_label_advertise_failed
                            
                            	LDP label advertisment failed
                            	**type**\: bool
                            
                            .. attribute:: is_vfi
                            
                            	Is VFI interface
                            	**type**\: bool
                            
                            .. attribute:: is_multi_segment_pseudowire
                            
                            	Is Multi\-Segment Pseudowire
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_one_way
                            
                            	Force one\-way PW redundancy behaviour in Redundancy Group
                            	**type**\: bool
                            
                            .. attribute:: load_balance
                            
                            	Load Balance Type
                            	**type**\:  :py:class:`L2vpnLoadBal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnLoadBal>`
                            
                            .. attribute:: pw_flow_label_type
                            
                            	Negotiated pseudowire flow label type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_type_cfg
                            
                            	Configured pseudowire flow label Type
                            	**type**\:  :py:class:`L2vpnPwFlowLabel <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPwFlowLabel>`
                            
                            .. attribute:: pw_flow_label_code17_disabled
                            
                            	Disable sending Code 17 TLV
                            	**type**\: bool
                            
                            .. attribute:: is_flow_label_static
                            
                            	is flow label static
                            	**type**\: bool
                            
                            .. attribute:: is_partially_programmed
                            
                            	Is Pseudowire partially programmed
                            	**type**\: bool
                            
                            .. attribute:: pw_redundancy_initial_delay
                            
                            	Initial delay for redundant PW in seconds
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            	**units**\: second
                            
                            .. attribute:: bridge_pw_type_mismatch
                            
                            	Oper down because Bridge has mismatched PW Types
                            	**type**\: bool
                            
                            .. attribute:: required_bw
                            
                            	Required Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: admited_bw
                            
                            	Admited Bandwidth
                            	**type**\: int
                            
                            	**range:** 0..4294967295
                            
                            .. attribute:: forward_class
                            
                            	Forward Class attribute
                            	**type**\: int
                            
                            	**range:** 0..255
                            
                            .. attribute:: table_policy_name
                            
                            	Table\-policy Name
                            	**type**\: str
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, self).__init__()

                                self.yang_name = "pseudowire"
                                self.yang_parent_name = "flexible-xconnect-service-info"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("peer-id", ("peer_id", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId)), ("encapsulation-info", ("encapsulation_info", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo)), ("local-interface", ("local_interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface)), ("remote-interface", ("remote_interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface)), ("preferred-path", ("preferred_path", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath)), ("local-signalling", ("local_signalling", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling)), ("remote-signalling", ("remote_signalling", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling)), ("statistics", ("statistics", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics)), ("p2mp-pw", ("p2mp_pw", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw))])
                                self._leafs = OrderedDict([
                                    ('local_source_address', YLeaf(YType.str, 'local-source-address')),
                                    ('ipv6_local_source_address', YLeaf(YType.str, 'ipv6-local-source-address')),
                                    ('pseudo_wire_id', YLeaf(YType.uint64, 'pseudo-wire-id')),
                                    ('is_pwr_type', YLeaf(YType.boolean, 'is-pwr-type')),
                                    ('is_evpn_vpws_type', YLeaf(YType.boolean, 'is-evpn-vpws-type')),
                                    ('xconnect_id', YLeaf(YType.uint32, 'xconnect-id')),
                                    ('state', YLeaf(YType.enumeration, 'state')),
                                    ('pseudo_wire_state', YLeaf(YType.enumeration, 'pseudo-wire-state')),
                                    ('protocol', YLeaf(YType.enumeration, 'protocol')),
                                    ('pw_class_name', YLeaf(YType.str, 'pw-class-name')),
                                    ('tag_rewrite', YLeaf(YType.uint16, 'tag-rewrite')),
                                    ('interworking', YLeaf(YType.enumeration, 'interworking')),
                                    ('fe_ctype', YLeaf(YType.enumeration, 'fe-ctype')),
                                    ('evpn_src_acid', YLeaf(YType.uint32, 'evpn-src-acid')),
                                    ('sequencing_type', YLeaf(YType.enumeration, 'sequencing-type')),
                                    ('resync_enabled', YLeaf(YType.boolean, 'resync-enabled')),
                                    ('resync_threshold', YLeaf(YType.uint32, 'resync-threshold')),
                                    ('local_control_word', YLeaf(YType.enumeration, 'local-control-word')),
                                    ('remote_control_word', YLeaf(YType.enumeration, 'remote-control-word')),
                                    ('local_pseudo_wire_type', YLeaf(YType.enumeration, 'local-pseudo-wire-type')),
                                    ('remote_pseudo_wire_type', YLeaf(YType.enumeration, 'remote-pseudo-wire-type')),
                                    ('imposed_vlan_id', YLeaf(YType.uint32, 'imposed-vlan-id')),
                                    ('time_created', YLeaf(YType.str, 'time-created')),
                                    ('time_elapsed_creation', YLeaf(YType.str, 'time-elapsed-creation')),
                                    ('last_time_status_changed', YLeaf(YType.str, 'last-time-status-changed')),
                                    ('time_elapsed_status_changed', YLeaf(YType.str, 'time-elapsed-status-changed')),
                                    ('last_time_status_down', YLeaf(YType.str, 'last-time-status-down')),
                                    ('time_elapsed_status_down', YLeaf(YType.uint32, 'time-elapsed-status-down')),
                                    ('shutdown', YLeaf(YType.boolean, 'shutdown')),
                                    ('data_path_down', YLeaf(YType.boolean, 'data-path-down')),
                                    ('use_tunnel_path', YLeaf(YType.boolean, 'use-tunnel-path')),
                                    ('odn_configured', YLeaf(YType.boolean, 'odn-configured')),
                                    ('pseudo_wire_type_mismatched', YLeaf(YType.boolean, 'pseudo-wire-type-mismatched')),
                                    ('payload_bytes_mismatched', YLeaf(YType.boolean, 'payload-bytes-mismatched')),
                                    ('bitrate_mismatched', YLeaf(YType.boolean, 'bitrate-mismatched')),
                                    ('rtp_mismatched', YLeaf(YType.boolean, 'rtp-mismatched')),
                                    ('diff_ts_mismatched', YLeaf(YType.boolean, 'diff-ts-mismatched')),
                                    ('sig_pkts_mismatched', YLeaf(YType.boolean, 'sig-pkts-mismatched')),
                                    ('cas_mismatched', YLeaf(YType.boolean, 'cas-mismatched')),
                                    ('payload_type_mismatched', YLeaf(YType.boolean, 'payload-type-mismatched')),
                                    ('freq_mismatched', YLeaf(YType.boolean, 'freq-mismatched')),
                                    ('ssrc_mismatched', YLeaf(YType.boolean, 'ssrc-mismatched')),
                                    ('mtu_mismatched', YLeaf(YType.boolean, 'mtu-mismatched')),
                                    ('illegal_control_word', YLeaf(YType.boolean, 'illegal-control-word')),
                                    ('ad_remote_down', YLeaf(YType.boolean, 'ad-remote-down')),
                                    ('not_supported_qinq', YLeaf(YType.boolean, 'not-supported-qinq')),
                                    ('local_label_failed', YLeaf(YType.boolean, 'local-label-failed')),
                                    ('remote_label_failed', YLeaf(YType.boolean, 'remote-label-failed')),
                                    ('preferred_path_disable_fallback', YLeaf(YType.boolean, 'preferred-path-disable-fallback')),
                                    ('backup_pw', YLeaf(YType.boolean, 'backup-pw')),
                                    ('primary_pw', YLeaf(YType.boolean, 'primary-pw')),
                                    ('backup_active', YLeaf(YType.boolean, 'backup-active')),
                                    ('backup_force_active', YLeaf(YType.boolean, 'backup-force-active')),
                                    ('disable_never', YLeaf(YType.boolean, 'disable-never')),
                                    ('disable_delay', YLeaf(YType.uint8, 'disable-delay')),
                                    ('primary_peer_id', YLeaf(YType.str, 'primary-peer-id')),
                                    ('primary_pseudo_wire_id', YLeaf(YType.uint64, 'primary-pseudo-wire-id')),
                                    ('number_ma_cwithdraw_message_sent', YLeaf(YType.uint32, 'number-ma-cwithdraw-message-sent')),
                                    ('num_ma_cwithdraw_msg_received', YLeaf(YType.uint32, 'num-ma-cwithdraw-msg-received')),
                                    ('out_of_memory_state', YLeaf(YType.uint32, 'out-of-memory-state')),
                                    ('transport_lsp_down', YLeaf(YType.boolean, 'transport-lsp-down')),
                                    ('mac_limit_oper_down', YLeaf(YType.boolean, 'mac-limit-oper-down')),
                                    ('pw_status_use', YLeaf(YType.boolean, 'pw-status-use')),
                                    ('auto_discovery', YLeaf(YType.boolean, 'auto-discovery')),
                                    ('ad_method', YLeaf(YType.uint32, 'ad-method')),
                                    ('pwlsd_rewrite_failed', YLeaf(YType.boolean, 'pwlsd-rewrite-failed')),
                                    ('ldp_label_advertise_failed', YLeaf(YType.boolean, 'ldp-label-advertise-failed')),
                                    ('is_vfi', YLeaf(YType.boolean, 'is-vfi')),
                                    ('is_multi_segment_pseudowire', YLeaf(YType.boolean, 'is-multi-segment-pseudowire')),
                                    ('pw_redundancy_one_way', YLeaf(YType.boolean, 'pw-redundancy-one-way')),
                                    ('load_balance', YLeaf(YType.enumeration, 'load-balance')),
                                    ('pw_flow_label_type', YLeaf(YType.enumeration, 'pw-flow-label-type')),
                                    ('pw_flow_label_type_cfg', YLeaf(YType.enumeration, 'pw-flow-label-type-cfg')),
                                    ('pw_flow_label_code17_disabled', YLeaf(YType.boolean, 'pw-flow-label-code17-disabled')),
                                    ('is_flow_label_static', YLeaf(YType.boolean, 'is-flow-label-static')),
                                    ('is_partially_programmed', YLeaf(YType.boolean, 'is-partially-programmed')),
                                    ('pw_redundancy_initial_delay', YLeaf(YType.uint8, 'pw-redundancy-initial-delay')),
                                    ('bridge_pw_type_mismatch', YLeaf(YType.boolean, 'bridge-pw-type-mismatch')),
                                    ('required_bw', YLeaf(YType.uint32, 'required-bw')),
                                    ('admited_bw', YLeaf(YType.uint32, 'admited-bw')),
                                    ('forward_class', YLeaf(YType.uint8, 'forward-class')),
                                    ('table_policy_name', YLeaf(YType.str, 'table-policy-name')),
                                ])
                                self.local_source_address = None
                                self.ipv6_local_source_address = None
                                self.pseudo_wire_id = None
                                self.is_pwr_type = None
                                self.is_evpn_vpws_type = None
                                self.xconnect_id = None
                                self.state = None
                                self.pseudo_wire_state = None
                                self.protocol = None
                                self.pw_class_name = None
                                self.tag_rewrite = None
                                self.interworking = None
                                self.fe_ctype = None
                                self.evpn_src_acid = None
                                self.sequencing_type = None
                                self.resync_enabled = None
                                self.resync_threshold = None
                                self.local_control_word = None
                                self.remote_control_word = None
                                self.local_pseudo_wire_type = None
                                self.remote_pseudo_wire_type = None
                                self.imposed_vlan_id = None
                                self.time_created = None
                                self.time_elapsed_creation = None
                                self.last_time_status_changed = None
                                self.time_elapsed_status_changed = None
                                self.last_time_status_down = None
                                self.time_elapsed_status_down = None
                                self.shutdown = None
                                self.data_path_down = None
                                self.use_tunnel_path = None
                                self.odn_configured = None
                                self.pseudo_wire_type_mismatched = None
                                self.payload_bytes_mismatched = None
                                self.bitrate_mismatched = None
                                self.rtp_mismatched = None
                                self.diff_ts_mismatched = None
                                self.sig_pkts_mismatched = None
                                self.cas_mismatched = None
                                self.payload_type_mismatched = None
                                self.freq_mismatched = None
                                self.ssrc_mismatched = None
                                self.mtu_mismatched = None
                                self.illegal_control_word = None
                                self.ad_remote_down = None
                                self.not_supported_qinq = None
                                self.local_label_failed = None
                                self.remote_label_failed = None
                                self.preferred_path_disable_fallback = None
                                self.backup_pw = None
                                self.primary_pw = None
                                self.backup_active = None
                                self.backup_force_active = None
                                self.disable_never = None
                                self.disable_delay = None
                                self.primary_peer_id = None
                                self.primary_pseudo_wire_id = None
                                self.number_ma_cwithdraw_message_sent = None
                                self.num_ma_cwithdraw_msg_received = None
                                self.out_of_memory_state = None
                                self.transport_lsp_down = None
                                self.mac_limit_oper_down = None
                                self.pw_status_use = None
                                self.auto_discovery = None
                                self.ad_method = None
                                self.pwlsd_rewrite_failed = None
                                self.ldp_label_advertise_failed = None
                                self.is_vfi = None
                                self.is_multi_segment_pseudowire = None
                                self.pw_redundancy_one_way = None
                                self.load_balance = None
                                self.pw_flow_label_type = None
                                self.pw_flow_label_type_cfg = None
                                self.pw_flow_label_code17_disabled = None
                                self.is_flow_label_static = None
                                self.is_partially_programmed = None
                                self.pw_redundancy_initial_delay = None
                                self.bridge_pw_type_mismatch = None
                                self.required_bw = None
                                self.admited_bw = None
                                self.forward_class = None
                                self.table_policy_name = None

                                self.peer_id = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId()
                                self.peer_id.parent = self
                                self._children_name_map["peer_id"] = "peer-id"

                                self.encapsulation_info = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo()
                                self.encapsulation_info.parent = self
                                self._children_name_map["encapsulation_info"] = "encapsulation-info"

                                self.local_interface = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface()
                                self.local_interface.parent = self
                                self._children_name_map["local_interface"] = "local-interface"

                                self.remote_interface = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface()
                                self.remote_interface.parent = self
                                self._children_name_map["remote_interface"] = "remote-interface"

                                self.preferred_path = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath()
                                self.preferred_path.parent = self
                                self._children_name_map["preferred_path"] = "preferred-path"

                                self.local_signalling = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling()
                                self.local_signalling.parent = self
                                self._children_name_map["local_signalling"] = "local-signalling"

                                self.remote_signalling = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling()
                                self.remote_signalling.parent = self
                                self._children_name_map["remote_signalling"] = "remote-signalling"

                                self.statistics = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics()
                                self.statistics.parent = self
                                self._children_name_map["statistics"] = "statistics"

                                self.p2mp_pw = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw()
                                self.p2mp_pw.parent = self
                                self._children_name_map["p2mp_pw"] = "p2mp-pw"
                                self._segment_path = lambda: "pseudowire"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire, ['local_source_address', 'ipv6_local_source_address', 'pseudo_wire_id', 'is_pwr_type', 'is_evpn_vpws_type', 'xconnect_id', 'state', 'pseudo_wire_state', 'protocol', 'pw_class_name', 'tag_rewrite', 'interworking', 'fe_ctype', 'evpn_src_acid', 'sequencing_type', 'resync_enabled', 'resync_threshold', 'local_control_word', 'remote_control_word', 'local_pseudo_wire_type', 'remote_pseudo_wire_type', 'imposed_vlan_id', 'time_created', 'time_elapsed_creation', 'last_time_status_changed', 'time_elapsed_status_changed', 'last_time_status_down', 'time_elapsed_status_down', 'shutdown', 'data_path_down', 'use_tunnel_path', 'odn_configured', 'pseudo_wire_type_mismatched', 'payload_bytes_mismatched', 'bitrate_mismatched', 'rtp_mismatched', 'diff_ts_mismatched', 'sig_pkts_mismatched', 'cas_mismatched', 'payload_type_mismatched', 'freq_mismatched', 'ssrc_mismatched', 'mtu_mismatched', 'illegal_control_word', 'ad_remote_down', 'not_supported_qinq', 'local_label_failed', 'remote_label_failed', 'preferred_path_disable_fallback', 'backup_pw', 'primary_pw', 'backup_active', 'backup_force_active', 'disable_never', 'disable_delay', 'primary_peer_id', 'primary_pseudo_wire_id', 'number_ma_cwithdraw_message_sent', 'num_ma_cwithdraw_msg_received', 'out_of_memory_state', 'transport_lsp_down', 'mac_limit_oper_down', 'pw_status_use', 'auto_discovery', 'ad_method', 'pwlsd_rewrite_failed', 'ldp_label_advertise_failed', 'is_vfi', 'is_multi_segment_pseudowire', 'pw_redundancy_one_way', 'load_balance', 'pw_flow_label_type', 'pw_flow_label_type_cfg', 'pw_flow_label_code17_disabled', 'is_flow_label_static', 'is_partially_programmed', 'pw_redundancy_initial_delay', 'bridge_pw_type_mismatch', 'required_bw', 'admited_bw', 'forward_class', 'table_policy_name'], name, value)


                            class PeerId(Entity):
                                """
                                Peer
                                
                                .. attribute:: type
                                
                                	type
                                	**type**\:  :py:class:`L2vpnPeer <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPeer>`
                                
                                .. attribute:: ipv4_peer_id
                                
                                	Peer IPv4 address
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: ipv6_peer_id
                                
                                	Peer IPv6 address
                                	**type**\: str
                                
                                	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: internal_label
                                
                                	Internal Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, self).__init__()

                                    self.yang_name = "peer-id"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('type', YLeaf(YType.enumeration, 'type')),
                                        ('ipv4_peer_id', YLeaf(YType.str, 'ipv4-peer-id')),
                                        ('ipv6_peer_id', YLeaf(YType.str, 'ipv6-peer-id')),
                                        ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                    ])
                                    self.type = None
                                    self.ipv4_peer_id = None
                                    self.ipv6_peer_id = None
                                    self.internal_label = None
                                    self._segment_path = lambda: "peer-id"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PeerId, ['type', 'ipv4_peer_id', 'ipv6_peer_id', 'internal_label'], name, value)


                            class EncapsulationInfo(Entity):
                                """
                                Encapsulation specific pseudowire information
                                
                                .. attribute:: atom
                                
                                	atom
                                	**type**\:  :py:class:`Atom <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom>`
                                
                                .. attribute:: l2tpv3
                                
                                	l2tpv3
                                	**type**\:  :py:class:`L2tpv3 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3>`
                                
                                .. attribute:: encapsulation
                                
                                	Encapsulation
                                	**type**\:  :py:class:`L2vpnEncapMethod <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnEncapMethod>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, self).__init__()

                                    self.yang_name = "encapsulation-info"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("atom", ("atom", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom)), ("l2tpv3", ("l2tpv3", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3))])
                                    self._leafs = OrderedDict([
                                        ('encapsulation', YLeaf(YType.enumeration, 'encapsulation')),
                                    ])
                                    self.encapsulation = None

                                    self.atom = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom()
                                    self.atom.parent = self
                                    self._children_name_map["atom"] = "atom"

                                    self.l2tpv3 = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3()
                                    self.l2tpv3.parent = self
                                    self._children_name_map["l2tpv3"] = "l2tpv3"
                                    self._segment_path = lambda: "encapsulation-info"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo, ['encapsulation'], name, value)


                                class Atom(Entity):
                                    """
                                    atom
                                    
                                    .. attribute:: local_agi
                                    
                                    	Local Attachment Group Identifier
                                    	**type**\:  :py:class:`LocalAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi>`
                                    
                                    .. attribute:: remote_agi
                                    
                                    	Remote Attachment Group Identifier
                                    	**type**\:  :py:class:`RemoteAgi <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi>`
                                    
                                    .. attribute:: multi_segment_pseudowire_stats
                                    
                                    	Multisegment pseudowire statistics
                                    	**type**\:  :py:class:`MultiSegmentPseudowireStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats>`
                                    
                                    .. attribute:: is_pseudowire_headend
                                    
                                    	Is this connected to a PW\-HE AC
                                    	**type**\: bool
                                    
                                    .. attribute:: local_label
                                    
                                    	Local label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_label
                                    
                                    	Remote label
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_group_id
                                    
                                    	Local group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_group_id
                                    
                                    	Remote group ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cv_type
                                    
                                    	Local VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_c_ctype
                                    
                                    	Local VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cv_type
                                    
                                    	Remote VCCV CV type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_c_ctype
                                    
                                    	Remote VCCV CC type
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_veid
                                    
                                    	Local VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_veid
                                    
                                    	Remote VE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_ceid
                                    
                                    	Local CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_ceid
                                    
                                    	Remote CE ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: source_address
                                    
                                    	Local BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_source_address
                                    
                                    	Remote BGP source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: local_ldp_id
                                    
                                    	Local LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_ldp_id
                                    
                                    	Remote LDP ID
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: saii
                                    
                                    	Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: taii
                                    
                                    	Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: is_sai_itype2
                                    
                                    	Is SAII FEC129 Type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_saii_gbl_id
                                    
                                    	Local SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_saiiac_id
                                    
                                    	Local SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: is_tai_itype2
                                    
                                    	Is TAII type 2
                                    	**type**\: bool
                                    
                                    .. attribute:: local_taii_gbl_id
                                    
                                    	Local TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_taiiac_id
                                    
                                    	Local TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii_gbl_id
                                    
                                    	Remote SAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saiiac_id
                                    
                                    	Remote SAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taii_gbl_id
                                    
                                    	Remote TAII Global ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_taiiac_id
                                    
                                    	Remote TAII AC ID
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: rem_saii
                                    
                                    	Remote Source Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: rem_taii
                                    
                                    	Remote Target Attachment Individual Identifer
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: lsd_rewrite_failed
                                    
                                    	LSD rewrite failed
                                    	**type**\: bool
                                    
                                    .. attribute:: ldp_label_advertisment_failed
                                    
                                    	LDP label advertisment failed
                                    	**type**\: bool
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, self).__init__()

                                        self.yang_name = "atom"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("local-agi", ("local_agi", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi)), ("remote-agi", ("remote_agi", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi)), ("multi-segment-pseudowire-stats", ("multi_segment_pseudowire_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats))])
                                        self._leafs = OrderedDict([
                                            ('is_pseudowire_headend', YLeaf(YType.boolean, 'is-pseudowire-headend')),
                                            ('local_label', YLeaf(YType.uint32, 'local-label')),
                                            ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                            ('local_group_id', YLeaf(YType.uint32, 'local-group-id')),
                                            ('remote_group_id', YLeaf(YType.uint32, 'remote-group-id')),
                                            ('local_cv_type', YLeaf(YType.uint8, 'local-cv-type')),
                                            ('local_c_ctype', YLeaf(YType.uint8, 'local-c-ctype')),
                                            ('remote_cv_type', YLeaf(YType.uint8, 'remote-cv-type')),
                                            ('remote_c_ctype', YLeaf(YType.uint8, 'remote-c-ctype')),
                                            ('local_veid', YLeaf(YType.uint32, 'local-veid')),
                                            ('remote_veid', YLeaf(YType.uint32, 'remote-veid')),
                                            ('local_ceid', YLeaf(YType.uint32, 'local-ceid')),
                                            ('remote_ceid', YLeaf(YType.uint32, 'remote-ceid')),
                                            ('source_address', YLeaf(YType.str, 'source-address')),
                                            ('remote_source_address', YLeaf(YType.str, 'remote-source-address')),
                                            ('local_ldp_id', YLeaf(YType.str, 'local-ldp-id')),
                                            ('remote_ldp_id', YLeaf(YType.str, 'remote-ldp-id')),
                                            ('saii', YLeaf(YType.str, 'saii')),
                                            ('taii', YLeaf(YType.str, 'taii')),
                                            ('is_sai_itype2', YLeaf(YType.boolean, 'is-sai-itype2')),
                                            ('local_saii_gbl_id', YLeaf(YType.uint32, 'local-saii-gbl-id')),
                                            ('local_saiiac_id', YLeaf(YType.uint32, 'local-saiiac-id')),
                                            ('is_tai_itype2', YLeaf(YType.boolean, 'is-tai-itype2')),
                                            ('local_taii_gbl_id', YLeaf(YType.uint32, 'local-taii-gbl-id')),
                                            ('local_taiiac_id', YLeaf(YType.uint32, 'local-taiiac-id')),
                                            ('rem_saii_gbl_id', YLeaf(YType.uint32, 'rem-saii-gbl-id')),
                                            ('rem_saiiac_id', YLeaf(YType.uint32, 'rem-saiiac-id')),
                                            ('rem_taii_gbl_id', YLeaf(YType.uint32, 'rem-taii-gbl-id')),
                                            ('rem_taiiac_id', YLeaf(YType.uint32, 'rem-taiiac-id')),
                                            ('rem_saii', YLeaf(YType.str, 'rem-saii')),
                                            ('rem_taii', YLeaf(YType.str, 'rem-taii')),
                                            ('lsd_rewrite_failed', YLeaf(YType.boolean, 'lsd-rewrite-failed')),
                                            ('ldp_label_advertisment_failed', YLeaf(YType.boolean, 'ldp-label-advertisment-failed')),
                                        ])
                                        self.is_pseudowire_headend = None
                                        self.local_label = None
                                        self.remote_label = None
                                        self.local_group_id = None
                                        self.remote_group_id = None
                                        self.local_cv_type = None
                                        self.local_c_ctype = None
                                        self.remote_cv_type = None
                                        self.remote_c_ctype = None
                                        self.local_veid = None
                                        self.remote_veid = None
                                        self.local_ceid = None
                                        self.remote_ceid = None
                                        self.source_address = None
                                        self.remote_source_address = None
                                        self.local_ldp_id = None
                                        self.remote_ldp_id = None
                                        self.saii = None
                                        self.taii = None
                                        self.is_sai_itype2 = None
                                        self.local_saii_gbl_id = None
                                        self.local_saiiac_id = None
                                        self.is_tai_itype2 = None
                                        self.local_taii_gbl_id = None
                                        self.local_taiiac_id = None
                                        self.rem_saii_gbl_id = None
                                        self.rem_saiiac_id = None
                                        self.rem_taii_gbl_id = None
                                        self.rem_taiiac_id = None
                                        self.rem_saii = None
                                        self.rem_taii = None
                                        self.lsd_rewrite_failed = None
                                        self.ldp_label_advertisment_failed = None

                                        self.local_agi = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi()
                                        self.local_agi.parent = self
                                        self._children_name_map["local_agi"] = "local-agi"

                                        self.remote_agi = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi()
                                        self.remote_agi.parent = self
                                        self._children_name_map["remote_agi"] = "remote-agi"

                                        self.multi_segment_pseudowire_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats()
                                        self.multi_segment_pseudowire_stats.parent = self
                                        self._children_name_map["multi_segment_pseudowire_stats"] = "multi-segment-pseudowire-stats"
                                        self._segment_path = lambda: "atom"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom, ['is_pseudowire_headend', 'local_label', 'remote_label', 'local_group_id', 'remote_group_id', 'local_cv_type', 'local_c_ctype', 'remote_cv_type', 'remote_c_ctype', 'local_veid', 'remote_veid', 'local_ceid', 'remote_ceid', 'source_address', 'remote_source_address', 'local_ldp_id', 'remote_ldp_id', 'saii', 'taii', 'is_sai_itype2', 'local_saii_gbl_id', 'local_saiiac_id', 'is_tai_itype2', 'local_taii_gbl_id', 'local_taiiac_id', 'rem_saii_gbl_id', 'rem_saiiac_id', 'rem_taii_gbl_id', 'rem_taiiac_id', 'rem_saii', 'rem_taii', 'lsd_rewrite_failed', 'ldp_label_advertisment_failed'], name, value)


                                    class LocalAgi(Entity):
                                        """
                                        Local Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, self).__init__()

                                            self.yang_name = "local-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "local-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "local-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.LocalAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class RemoteAgi(Entity):
                                        """
                                        Remote Attachment Group Identifier
                                        
                                        .. attribute:: auto
                                        
                                        	auto
                                        	**type**\:  :py:class:`Auto <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto>`
                                        
                                        .. attribute:: two_byte_as
                                        
                                        	two byte as
                                        	**type**\:  :py:class:`TwoByteAs <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs>`
                                        
                                        .. attribute:: v4_addr
                                        
                                        	v4 addr
                                        	**type**\:  :py:class:`V4Addr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr>`
                                        
                                        .. attribute:: vpls_id_type
                                        
                                        	VPLS ID TYPE
                                        	**type**\:  :py:class:`L2vpnAdVplsId <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAdVplsId>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, self).__init__()

                                            self.yang_name = "remote-agi"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("auto", ("auto", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto)), ("two-byte-as", ("two_byte_as", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs)), ("v4-addr", ("v4_addr", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr))])
                                            self._leafs = OrderedDict([
                                                ('vpls_id_type', YLeaf(YType.enumeration, 'vpls-id-type')),
                                            ])
                                            self.vpls_id_type = None

                                            self.auto = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto()
                                            self.auto.parent = self
                                            self._children_name_map["auto"] = "auto"

                                            self.two_byte_as = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs()
                                            self.two_byte_as.parent = self
                                            self._children_name_map["two_byte_as"] = "two-byte-as"

                                            self.v4_addr = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr()
                                            self.v4_addr.parent = self
                                            self._children_name_map["v4_addr"] = "v4-addr"
                                            self._segment_path = lambda: "remote-agi"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi, ['vpls_id_type'], name, value)


                                        class Auto(Entity):
                                            """
                                            auto
                                            
                                            .. attribute:: asn
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: vpn_id
                                            
                                            	VPN ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, self).__init__()

                                                self.yang_name = "auto"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('asn', YLeaf(YType.uint16, 'asn')),
                                                    ('vpn_id', YLeaf(YType.uint32, 'vpn-id')),
                                                ])
                                                self.asn = None
                                                self.vpn_id = None
                                                self._segment_path = lambda: "auto"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.Auto, ['asn', 'vpn_id'], name, value)


                                        class TwoByteAs(Entity):
                                            """
                                            two byte as
                                            
                                            .. attribute:: two_byte_as
                                            
                                            	2 Byte AS Number
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: four_byte_index
                                            
                                            	4 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, self).__init__()

                                                self.yang_name = "two-byte-as"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('two_byte_as', YLeaf(YType.uint16, 'two-byte-as')),
                                                    ('four_byte_index', YLeaf(YType.uint32, 'four-byte-index')),
                                                ])
                                                self.two_byte_as = None
                                                self.four_byte_index = None
                                                self._segment_path = lambda: "two-byte-as"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.TwoByteAs, ['two_byte_as', 'four_byte_index'], name, value)


                                        class V4Addr(Entity):
                                            """
                                            v4 addr
                                            
                                            .. attribute:: ipv4_address
                                            
                                            	IPv4 Address
                                            	**type**\: str
                                            
                                            	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                            
                                            .. attribute:: two_byte_index
                                            
                                            	2 Byte Index
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, self).__init__()

                                                self.yang_name = "v4-addr"
                                                self.yang_parent_name = "remote-agi"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('ipv4_address', YLeaf(YType.str, 'ipv4-address')),
                                                    ('two_byte_index', YLeaf(YType.uint16, 'two-byte-index')),
                                                ])
                                                self.ipv4_address = None
                                                self.two_byte_index = None
                                                self._segment_path = lambda: "v4-addr"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.RemoteAgi.V4Addr, ['ipv4_address', 'two_byte_index'], name, value)


                                    class MultiSegmentPseudowireStats(Entity):
                                        """
                                        Multisegment pseudowire statistics
                                        
                                        .. attribute:: received_packets
                                        
                                        	Packets received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: received_bytes
                                        
                                        	Bytes received
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, self).__init__()

                                            self.yang_name = "multi-segment-pseudowire-stats"
                                            self.yang_parent_name = "atom"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('received_packets', YLeaf(YType.uint64, 'received-packets')),
                                                ('received_bytes', YLeaf(YType.uint64, 'received-bytes')),
                                            ])
                                            self.received_packets = None
                                            self.received_bytes = None
                                            self._segment_path = lambda: "multi-segment-pseudowire-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.Atom.MultiSegmentPseudowireStats, ['received_packets', 'received_bytes'], name, value)


                                class L2tpv3(Entity):
                                    """
                                    l2tpv3
                                    
                                    .. attribute:: l2tp_class_name
                                    
                                    	L2TPClassName
                                    	**type**\: str
                                    
                                    	**length:** 0..32
                                    
                                    .. attribute:: ipv4_source_address
                                    
                                    	IPv4 source address
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: ipv6_source_address
                                    
                                    	IPv6 source address
                                    	**type**\: str
                                    
                                    	**pattern:** ((\:\|[0\-9a\-fA\-F]{0,4})\:)([0\-9a\-fA\-F]{0,4}\:){0,5}((([0\-9a\-fA\-F]{0,4}\:)?(\:\|[0\-9a\-fA\-F]{0,4}))\|(((25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])\\.){3}(25[0\-5]\|2[0\-4][0\-9]\|[01]?[0\-9]?[0\-9])))(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: path_mtu_enabled
                                    
                                    	Path MTU enabled
                                    	**type**\: bool
                                    
                                    .. attribute:: path_mtu_max_value
                                    
                                    	Path MTU Maximum allowable session MTU
                                    	**type**\: int
                                    
                                    	**range:** 0..65535
                                    
                                    .. attribute:: dont_fragment_bit
                                    
                                    	Don't Fragment Bit
                                    	**type**\: bool
                                    
                                    .. attribute:: tos_mode
                                    
                                    	Type Of Service Mode
                                    	**type**\:  :py:class:`L2vpnTosMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTosMode>`
                                    
                                    .. attribute:: tos
                                    
                                    	Type Of Service Value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: ttl
                                    
                                    	Time To Live value
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_session_id
                                    
                                    	Local session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_session_id
                                    
                                    	Remote session id
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_size
                                    
                                    	Local cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: remote_cookie_size
                                    
                                    	Remote cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the remote cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: remote_circuit_status_up
                                    
                                    	RemoteCircuitStatusUp
                                    	**type**\: bool
                                    
                                    .. attribute:: tunnel_state
                                    
                                    	L2TP tunnel state
                                    	**type**\:  :py:class:`L2vpnL2tpTunnelState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnL2tpTunnelState>`
                                    
                                    .. attribute:: local_secondary_cookie_size
                                    
                                    	Local secondary cookie size\: 0, 4, or 8 bytes
                                    	**type**\: int
                                    
                                    	**range:** 0..255
                                    
                                    .. attribute:: local_secondary_cookie_low_value
                                    
                                    	Lower 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_secondary_cookie_high_value
                                    
                                    	Upper 4 bytes of the value of the local secondary cookie
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, self).__init__()

                                        self.yang_name = "l2tpv3"
                                        self.yang_parent_name = "encapsulation-info"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('l2tp_class_name', YLeaf(YType.str, 'l2tp-class-name')),
                                            ('ipv4_source_address', YLeaf(YType.str, 'ipv4-source-address')),
                                            ('ipv6_source_address', YLeaf(YType.str, 'ipv6-source-address')),
                                            ('path_mtu_enabled', YLeaf(YType.boolean, 'path-mtu-enabled')),
                                            ('path_mtu_max_value', YLeaf(YType.uint16, 'path-mtu-max-value')),
                                            ('dont_fragment_bit', YLeaf(YType.boolean, 'dont-fragment-bit')),
                                            ('tos_mode', YLeaf(YType.enumeration, 'tos-mode')),
                                            ('tos', YLeaf(YType.uint8, 'tos')),
                                            ('ttl', YLeaf(YType.uint8, 'ttl')),
                                            ('local_session_id', YLeaf(YType.uint32, 'local-session-id')),
                                            ('remote_session_id', YLeaf(YType.uint32, 'remote-session-id')),
                                            ('local_cookie_size', YLeaf(YType.uint8, 'local-cookie-size')),
                                            ('remote_cookie_size', YLeaf(YType.uint8, 'remote-cookie-size')),
                                            ('local_cookie_low_value', YLeaf(YType.uint32, 'local-cookie-low-value')),
                                            ('remote_cookie_low_value', YLeaf(YType.uint32, 'remote-cookie-low-value')),
                                            ('local_cookie_high_value', YLeaf(YType.uint32, 'local-cookie-high-value')),
                                            ('remote_cookie_high_value', YLeaf(YType.uint32, 'remote-cookie-high-value')),
                                            ('remote_circuit_status_up', YLeaf(YType.boolean, 'remote-circuit-status-up')),
                                            ('tunnel_state', YLeaf(YType.enumeration, 'tunnel-state')),
                                            ('local_secondary_cookie_size', YLeaf(YType.uint8, 'local-secondary-cookie-size')),
                                            ('local_secondary_cookie_low_value', YLeaf(YType.uint32, 'local-secondary-cookie-low-value')),
                                            ('local_secondary_cookie_high_value', YLeaf(YType.uint32, 'local-secondary-cookie-high-value')),
                                        ])
                                        self.l2tp_class_name = None
                                        self.ipv4_source_address = None
                                        self.ipv6_source_address = None
                                        self.path_mtu_enabled = None
                                        self.path_mtu_max_value = None
                                        self.dont_fragment_bit = None
                                        self.tos_mode = None
                                        self.tos = None
                                        self.ttl = None
                                        self.local_session_id = None
                                        self.remote_session_id = None
                                        self.local_cookie_size = None
                                        self.remote_cookie_size = None
                                        self.local_cookie_low_value = None
                                        self.remote_cookie_low_value = None
                                        self.local_cookie_high_value = None
                                        self.remote_cookie_high_value = None
                                        self.remote_circuit_status_up = None
                                        self.tunnel_state = None
                                        self.local_secondary_cookie_size = None
                                        self.local_secondary_cookie_low_value = None
                                        self.local_secondary_cookie_high_value = None
                                        self._segment_path = lambda: "l2tpv3"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.EncapsulationInfo.L2tpv3, ['l2tp_class_name', 'ipv4_source_address', 'ipv6_source_address', 'path_mtu_enabled', 'path_mtu_max_value', 'dont_fragment_bit', 'tos_mode', 'tos', 'ttl', 'local_session_id', 'remote_session_id', 'local_cookie_size', 'remote_cookie_size', 'local_cookie_low_value', 'remote_cookie_low_value', 'local_cookie_high_value', 'remote_cookie_high_value', 'remote_circuit_status_up', 'tunnel_state', 'local_secondary_cookie_size', 'local_secondary_cookie_low_value', 'local_secondary_cookie_high_value'], name, value)


                            class LocalInterface(Entity):
                                """
                                Local interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, self).__init__()

                                    self.yang_name = "local-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "local-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "local-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class RemoteInterface(Entity):
                                """
                                Remote interface
                                
                                .. attribute:: parameters
                                
                                	Interface parameters
                                	**type**\:  :py:class:`Parameters <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters>`
                                
                                .. attribute:: name
                                
                                	Interface name
                                	**type**\: str
                                
                                	**length:** 0..81
                                
                                .. attribute:: mtu
                                
                                	Interface MTU
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: payload_bytes
                                
                                	Payload bytes
                                	**type**\: int
                                
                                	**range:** 0..65535
                                
                                	**units**\: byte
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, self).__init__()

                                    self.yang_name = "remote-interface"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("parameters", ("parameters", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters))])
                                    self._leafs = OrderedDict([
                                        ('name', YLeaf(YType.str, 'name')),
                                        ('mtu', YLeaf(YType.uint32, 'mtu')),
                                        ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                    ])
                                    self.name = None
                                    self.mtu = None
                                    self.payload_bytes = None

                                    self.parameters = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters()
                                    self.parameters.parent = self
                                    self._children_name_map["parameters"] = "parameters"
                                    self._segment_path = lambda: "remote-interface"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface, ['name', 'mtu', 'payload_bytes'], name, value)


                                class Parameters(Entity):
                                    """
                                    Interface parameters
                                    
                                    .. attribute:: ethernet
                                    
                                    	Ethernet
                                    	**type**\:  :py:class:`Ethernet <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet>`
                                    
                                    .. attribute:: vlan
                                    
                                    	VLAN
                                    	**type**\:  :py:class:`Vlan <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan>`
                                    
                                    .. attribute:: tdm
                                    
                                    	TDM
                                    	**type**\:  :py:class:`Tdm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm>`
                                    
                                    .. attribute:: atm
                                    
                                    	ATM
                                    	**type**\:  :py:class:`Atm <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm>`
                                    
                                    .. attribute:: fr
                                    
                                    	Frame Relay
                                    	**type**\:  :py:class:`Fr <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr>`
                                    
                                    .. attribute:: pseudowire_ether
                                    
                                    	PW Ether
                                    	**type**\:  :py:class:`PseudowireEther <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther>`
                                    
                                    .. attribute:: pseudowire_iw
                                    
                                    	PW IW
                                    	**type**\:  :py:class:`PseudowireIw <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw>`
                                    
                                    .. attribute:: type
                                    
                                    	Type
                                    	**type**\:  :py:class:`L2vpnInterface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnInterface>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, self).__init__()

                                        self.yang_name = "parameters"
                                        self.yang_parent_name = "remote-interface"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("ethernet", ("ethernet", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet)), ("vlan", ("vlan", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan)), ("tdm", ("tdm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm)), ("atm", ("atm", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm)), ("fr", ("fr", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr)), ("pseudowire-ether", ("pseudowire_ether", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther)), ("pseudowire-iw", ("pseudowire_iw", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw))])
                                        self._leafs = OrderedDict([
                                            ('type', YLeaf(YType.enumeration, 'type')),
                                        ])
                                        self.type = None

                                        self.ethernet = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet()
                                        self.ethernet.parent = self
                                        self._children_name_map["ethernet"] = "ethernet"

                                        self.vlan = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan()
                                        self.vlan.parent = self
                                        self._children_name_map["vlan"] = "vlan"

                                        self.tdm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm()
                                        self.tdm.parent = self
                                        self._children_name_map["tdm"] = "tdm"

                                        self.atm = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm()
                                        self.atm.parent = self
                                        self._children_name_map["atm"] = "atm"

                                        self.fr = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr()
                                        self.fr.parent = self
                                        self._children_name_map["fr"] = "fr"

                                        self.pseudowire_ether = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther()
                                        self.pseudowire_ether.parent = self
                                        self._children_name_map["pseudowire_ether"] = "pseudowire-ether"

                                        self.pseudowire_iw = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw()
                                        self.pseudowire_iw.parent = self
                                        self._children_name_map["pseudowire_iw"] = "pseudowire-iw"
                                        self._segment_path = lambda: "parameters"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters, ['type'], name, value)


                                    class Ethernet(Entity):
                                        """
                                        Ethernet
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, self).__init__()

                                            self.yang_name = "ethernet"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                            ])
                                            self.xconnect_tags = None
                                            self._segment_path = lambda: "ethernet"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Ethernet, ['xconnect_tags'], name, value)


                                    class Vlan(Entity):
                                        """
                                        VLAN
                                        
                                        .. attribute:: xconnect_tags
                                        
                                        	XConnect tags
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: vlan_rewrite_tag
                                        
                                        	VLAN rewrite tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: simple_efp
                                        
                                        	Simple EFP
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: encapsulation_type
                                        
                                        	Encapsulation Type
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        .. attribute:: outer_tag
                                        
                                        	Outer Tag
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: rewrite_tag
                                        
                                        	Rewrite Tags
                                        	**type**\: list of  		 :py:class:`RewriteTag <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag>`
                                        
                                        .. attribute:: vlan_range
                                        
                                        	vlan range
                                        	**type**\: list of  		 :py:class:`VlanRange <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, self).__init__()

                                            self.yang_name = "vlan"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("rewrite-tag", ("rewrite_tag", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag)), ("vlan-range", ("vlan_range", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange))])
                                            self._leafs = OrderedDict([
                                                ('xconnect_tags', YLeaf(YType.uint8, 'xconnect-tags')),
                                                ('vlan_rewrite_tag', YLeaf(YType.uint16, 'vlan-rewrite-tag')),
                                                ('simple_efp', YLeaf(YType.uint8, 'simple-efp')),
                                                ('encapsulation_type', YLeaf(YType.uint8, 'encapsulation-type')),
                                                ('outer_tag', YLeaf(YType.uint16, 'outer-tag')),
                                            ])
                                            self.xconnect_tags = None
                                            self.vlan_rewrite_tag = None
                                            self.simple_efp = None
                                            self.encapsulation_type = None
                                            self.outer_tag = None

                                            self.rewrite_tag = YList(self)
                                            self.vlan_range = YList(self)
                                            self._segment_path = lambda: "vlan"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan, ['xconnect_tags', 'vlan_rewrite_tag', 'simple_efp', 'encapsulation_type', 'outer_tag'], name, value)


                                        class RewriteTag(Entity):
                                            """
                                            Rewrite Tags
                                            
                                            .. attribute:: entry
                                            
                                            	
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, self).__init__()

                                                self.yang_name = "rewrite-tag"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('entry', YLeaf(YType.uint16, 'entry')),
                                                ])
                                                self.entry = None
                                                self._segment_path = lambda: "rewrite-tag"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.RewriteTag, ['entry'], name, value)


                                        class VlanRange(Entity):
                                            """
                                            vlan range
                                            
                                            .. attribute:: lower
                                            
                                            	Lower
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: upper
                                            
                                            	Upper
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, self).__init__()

                                                self.yang_name = "vlan-range"
                                                self.yang_parent_name = "vlan"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('lower', YLeaf(YType.uint16, 'lower')),
                                                    ('upper', YLeaf(YType.uint16, 'upper')),
                                                ])
                                                self.lower = None
                                                self.upper = None
                                                self._segment_path = lambda: "vlan-range"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Vlan.VlanRange, ['lower', 'upper'], name, value)


                                    class Tdm(Entity):
                                        """
                                        TDM
                                        
                                        .. attribute:: tdm_options
                                        
                                        	TDM options
                                        	**type**\:  :py:class:`TdmOptions <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions>`
                                        
                                        .. attribute:: timeslot_group
                                        
                                        	Timeslots separated by , or \- from 1 to 31. \: indicates individual timeslot and \- represents a range.E.g. 1\-3,5 represents timeslots 1, 2, 3, and 5
                                        	**type**\: str
                                        
                                        .. attribute:: timeslot_rate
                                        
                                        	Timeslot rate in units of Kbps
                                        	**type**\: int
                                        
                                        	**range:** 0..255
                                        
                                        	**units**\: kbit/s
                                        
                                        .. attribute:: tdm_mode
                                        
                                        	TDM mode
                                        	**type**\:  :py:class:`L2vpnTdmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmMode>`
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, self).__init__()

                                            self.yang_name = "tdm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("tdm-options", ("tdm_options", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions))])
                                            self._leafs = OrderedDict([
                                                ('timeslot_group', YLeaf(YType.str, 'timeslot-group')),
                                                ('timeslot_rate', YLeaf(YType.uint8, 'timeslot-rate')),
                                                ('tdm_mode', YLeaf(YType.enumeration, 'tdm-mode')),
                                            ])
                                            self.timeslot_group = None
                                            self.timeslot_rate = None
                                            self.tdm_mode = None

                                            self.tdm_options = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions()
                                            self.tdm_options.parent = self
                                            self._children_name_map["tdm_options"] = "tdm-options"
                                            self._segment_path = lambda: "tdm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm, ['timeslot_group', 'timeslot_rate', 'tdm_mode'], name, value)


                                        class TdmOptions(Entity):
                                            """
                                            TDM options
                                            
                                            .. attribute:: payload_bytes
                                            
                                            	TDM payload bytes
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            	**units**\: byte
                                            
                                            .. attribute:: bit_rate
                                            
                                            	TDM bit rate in units of Kbps
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            	**units**\: kbit/s
                                            
                                            .. attribute:: rtp
                                            
                                            	RTP header
                                            	**type**\:  :py:class:`L2vpnTdmRtpOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTdmRtpOption>`
                                            
                                            .. attribute:: timestamp_mode
                                            
                                            	TDM Timestamping mode
                                            	**type**\:  :py:class:`L2vpnTimeStampMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnTimeStampMode>`
                                            
                                            .. attribute:: signalling_packets
                                            
                                            	Signalling packets
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: cas
                                            
                                            	CAS
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: rtp_header_payload_type
                                            
                                            	RTP header payload type
                                            	**type**\: int
                                            
                                            	**range:** 0..255
                                            
                                            .. attribute:: timestamp_clock_freq
                                            
                                            	Timestamping clock frequency in units of 8Khz
                                            	**type**\: int
                                            
                                            	**range:** 0..65535
                                            
                                            .. attribute:: ssrc
                                            
                                            	Synchronization Source identifier
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, self).__init__()

                                                self.yang_name = "tdm-options"
                                                self.yang_parent_name = "tdm"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([])
                                                self._leafs = OrderedDict([
                                                    ('payload_bytes', YLeaf(YType.uint16, 'payload-bytes')),
                                                    ('bit_rate', YLeaf(YType.uint32, 'bit-rate')),
                                                    ('rtp', YLeaf(YType.enumeration, 'rtp')),
                                                    ('timestamp_mode', YLeaf(YType.enumeration, 'timestamp-mode')),
                                                    ('signalling_packets', YLeaf(YType.uint8, 'signalling-packets')),
                                                    ('cas', YLeaf(YType.uint8, 'cas')),
                                                    ('rtp_header_payload_type', YLeaf(YType.uint8, 'rtp-header-payload-type')),
                                                    ('timestamp_clock_freq', YLeaf(YType.uint16, 'timestamp-clock-freq')),
                                                    ('ssrc', YLeaf(YType.uint32, 'ssrc')),
                                                ])
                                                self.payload_bytes = None
                                                self.bit_rate = None
                                                self.rtp = None
                                                self.timestamp_mode = None
                                                self.signalling_packets = None
                                                self.cas = None
                                                self.rtp_header_payload_type = None
                                                self.timestamp_clock_freq = None
                                                self.ssrc = None
                                                self._segment_path = lambda: "tdm-options"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Tdm.TdmOptions, ['payload_bytes', 'bit_rate', 'rtp', 'timestamp_mode', 'signalling_packets', 'cas', 'rtp_header_payload_type', 'timestamp_clock_freq', 'ssrc'], name, value)


                                    class Atm(Entity):
                                        """
                                        ATM
                                        
                                        .. attribute:: maximum_number_cells_packed
                                        
                                        	Max number of cells packed
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: maximum_number_cells_un_packed
                                        
                                        	Max number of cells unpacked
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: atm_mode
                                        
                                        	ATM mode
                                        	**type**\:  :py:class:`L2vpnAtmMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAtmMode>`
                                        
                                        .. attribute:: vpi
                                        
                                        	Virtual path identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        .. attribute:: vci
                                        
                                        	Virtual channel identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..65535
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, self).__init__()

                                            self.yang_name = "atm"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('maximum_number_cells_packed', YLeaf(YType.uint16, 'maximum-number-cells-packed')),
                                                ('maximum_number_cells_un_packed', YLeaf(YType.uint16, 'maximum-number-cells-un-packed')),
                                                ('atm_mode', YLeaf(YType.enumeration, 'atm-mode')),
                                                ('vpi', YLeaf(YType.uint16, 'vpi')),
                                                ('vci', YLeaf(YType.uint16, 'vci')),
                                            ])
                                            self.maximum_number_cells_packed = None
                                            self.maximum_number_cells_un_packed = None
                                            self.atm_mode = None
                                            self.vpi = None
                                            self.vci = None
                                            self._segment_path = lambda: "atm"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Atm, ['maximum_number_cells_packed', 'maximum_number_cells_un_packed', 'atm_mode', 'vpi', 'vci'], name, value)


                                    class Fr(Entity):
                                        """
                                        Frame Relay
                                        
                                        .. attribute:: fr_mode
                                        
                                        	Frame Relay mode
                                        	**type**\:  :py:class:`L2vpnFrMode <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnFrMode>`
                                        
                                        .. attribute:: dlci
                                        
                                        	Data\-link connection identifier
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, self).__init__()

                                            self.yang_name = "fr"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('fr_mode', YLeaf(YType.enumeration, 'fr-mode')),
                                                ('dlci', YLeaf(YType.uint32, 'dlci')),
                                            ])
                                            self.fr_mode = None
                                            self.dlci = None
                                            self._segment_path = lambda: "fr"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.Fr, ['fr_mode', 'dlci'], name, value)


                                    class PseudowireEther(Entity):
                                        """
                                        PW Ether
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, self).__init__()

                                            self.yang_name = "pseudowire-ether"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-ether"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-ether"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireEther.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                                    class PseudowireIw(Entity):
                                        """
                                        PW IW
                                        
                                        .. attribute:: interface_list
                                        
                                        	Interface list data
                                        	**type**\:  :py:class:`InterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList>`
                                        
                                        .. attribute:: is_valid
                                        
                                        	Is this Interface list valid
                                        	**type**\: bool
                                        
                                        .. attribute:: internal_label
                                        
                                        	Internal Label
                                        	**type**\: int
                                        
                                        	**range:** 0..4294967295
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, self).__init__()

                                            self.yang_name = "pseudowire-iw"
                                            self.yang_parent_name = "parameters"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([("interface-list", ("interface_list", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList))])
                                            self._leafs = OrderedDict([
                                                ('is_valid', YLeaf(YType.boolean, 'is-valid')),
                                                ('internal_label', YLeaf(YType.uint32, 'internal-label')),
                                            ])
                                            self.is_valid = None
                                            self.internal_label = None

                                            self.interface_list = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList()
                                            self.interface_list.parent = self
                                            self._children_name_map["interface_list"] = "interface-list"
                                            self._segment_path = lambda: "pseudowire-iw"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw, ['is_valid', 'internal_label'], name, value)


                                        class InterfaceList(Entity):
                                            """
                                            Interface list data
                                            
                                            .. attribute:: interface_list_name
                                            
                                            	Interface\-list name
                                            	**type**\: str
                                            
                                            	**length:** 0..33
                                            
                                            .. attribute:: interface_list_id
                                            
                                            	Interface internal ID
                                            	**type**\: int
                                            
                                            	**range:** 0..4294967295
                                            
                                            .. attribute:: interface
                                            
                                            	Interfaces
                                            	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface>`
                                            
                                            

                                            """

                                            _prefix = 'l2vpn-oper'
                                            _revision = '2017-09-07'

                                            def __init__(self):
                                                super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, self).__init__()

                                                self.yang_name = "interface-list"
                                                self.yang_parent_name = "pseudowire-iw"
                                                self.is_top_level_class = False
                                                self.has_list_ancestor = True
                                                self.ylist_key_names = []
                                                self._child_classes = OrderedDict([("interface", ("interface", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface))])
                                                self._leafs = OrderedDict([
                                                    ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                                                    ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                                                ])
                                                self.interface_list_name = None
                                                self.interface_list_id = None

                                                self.interface = YList(self)
                                                self._segment_path = lambda: "interface-list"

                                            def __setattr__(self, name, value):
                                                self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList, [u'interface_list_name', u'interface_list_id'], name, value)


                                            class Interface(Entity):
                                                """
                                                Interfaces
                                                
                                                .. attribute:: interface_name
                                                
                                                	Interface name
                                                	**type**\: str
                                                
                                                .. attribute:: replicate_status
                                                
                                                	Replicate status
                                                	**type**\:  :py:class:`IflistRepStatus <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.IflistRepStatus>`
                                                
                                                

                                                """

                                                _prefix = 'l2vpn-oper'
                                                _revision = '2017-09-07'

                                                def __init__(self):
                                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, self).__init__()

                                                    self.yang_name = "interface"
                                                    self.yang_parent_name = "interface-list"
                                                    self.is_top_level_class = False
                                                    self.has_list_ancestor = True
                                                    self.ylist_key_names = []
                                                    self._child_classes = OrderedDict([])
                                                    self._leafs = OrderedDict([
                                                        ('interface_name', YLeaf(YType.str, 'interface-name')),
                                                        ('replicate_status', YLeaf(YType.enumeration, 'replicate-status')),
                                                    ])
                                                    self.interface_name = None
                                                    self.replicate_status = None
                                                    self._segment_path = lambda: "interface"

                                                def __setattr__(self, name, value):
                                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteInterface.Parameters.PseudowireIw.InterfaceList.Interface, [u'interface_name', u'replicate_status'], name, value)


                            class PreferredPath(Entity):
                                """
                                MPLS Preferred Path
                                
                                .. attribute:: srte_policy
                                
                                	srte policy
                                	**type**\:  :py:class:`SrtePolicy <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy>`
                                
                                .. attribute:: option
                                
                                	Option
                                	**type**\:  :py:class:`L2vpnPrefpathOption <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnPrefpathOption>`
                                
                                .. attribute:: next_hop_ip
                                
                                	NextHopIP
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: te_tunnel_interface_number
                                
                                	TETunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: ip_tunnel_interface_number
                                
                                	IPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tp_tunnel_interface_number
                                
                                	TPTunnelInterfaceNumber
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, self).__init__()

                                    self.yang_name = "preferred-path"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("srte-policy", ("srte_policy", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy))])
                                    self._leafs = OrderedDict([
                                        ('option', YLeaf(YType.enumeration, 'option')),
                                        ('next_hop_ip', YLeaf(YType.uint32, 'next-hop-ip')),
                                        ('te_tunnel_interface_number', YLeaf(YType.uint32, 'te-tunnel-interface-number')),
                                        ('ip_tunnel_interface_number', YLeaf(YType.uint32, 'ip-tunnel-interface-number')),
                                        ('tp_tunnel_interface_number', YLeaf(YType.uint32, 'tp-tunnel-interface-number')),
                                    ])
                                    self.option = None
                                    self.next_hop_ip = None
                                    self.te_tunnel_interface_number = None
                                    self.ip_tunnel_interface_number = None
                                    self.tp_tunnel_interface_number = None

                                    self.srte_policy = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy()
                                    self.srte_policy.parent = self
                                    self._children_name_map["srte_policy"] = "srte-policy"
                                    self._segment_path = lambda: "preferred-path"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath, ['option', 'next_hop_ip', 'te_tunnel_interface_number', 'ip_tunnel_interface_number', 'tp_tunnel_interface_number'], name, value)


                                class SrtePolicy(Entity):
                                    """
                                    srte policy
                                    
                                    .. attribute:: policy_name
                                    
                                    	SR TE Policy Name
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, self).__init__()

                                        self.yang_name = "srte-policy"
                                        self.yang_parent_name = "preferred-path"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('policy_name', YLeaf(YType.str, 'policy-name')),
                                        ])
                                        self.policy_name = None
                                        self._segment_path = lambda: "srte-policy"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.PreferredPath.SrtePolicy, ['policy_name'], name, value)


                            class LocalSignalling(Entity):
                                """
                                Local signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, self).__init__()

                                    self.yang_name = "local-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "local-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "local-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.LocalSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class RemoteSignalling(Entity):
                                """
                                Remote signalling
                                
                                .. attribute:: status_tlv
                                
                                	PW Status Switching TLV
                                	**type**\:  :py:class:`StatusTlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv>`
                                
                                .. attribute:: pw_status
                                
                                	PW Status
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: tlv
                                
                                	Switching TLV info
                                	**type**\: list of  		 :py:class:`Tlv <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, self).__init__()

                                    self.yang_name = "remote-signalling"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("status-tlv", ("status_tlv", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv)), ("tlv", ("tlv", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv))])
                                    self._leafs = OrderedDict([
                                        ('pw_status', YLeaf(YType.uint32, 'pw-status')),
                                    ])
                                    self.pw_status = None

                                    self.status_tlv = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv()
                                    self.status_tlv.parent = self
                                    self._children_name_map["status_tlv"] = "status-tlv"

                                    self.tlv = YList(self)
                                    self._segment_path = lambda: "remote-signalling"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling, ['pw_status'], name, value)


                                class StatusTlv(Entity):
                                    """
                                    PW Status Switching TLV
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, self).__init__()

                                        self.yang_name = "status-tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "status-tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.StatusTlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                                class Tlv(Entity):
                                    """
                                    Switching TLV info
                                    
                                    .. attribute:: pw_id
                                    
                                    	PW ID of last PW segment traversed
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: local_address
                                    
                                    	Local IP Address of PW Switching Point
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: remote_address
                                    
                                    	Remote IP Address of Last PW Switching Point traversed
                                    	**type**\: str
                                    
                                    	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                    
                                    .. attribute:: description
                                    
                                    	PW Switching Point description
                                    	**type**\: str
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, self).__init__()

                                        self.yang_name = "tlv"
                                        self.yang_parent_name = "remote-signalling"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('pw_id', YLeaf(YType.uint32, 'pw-id')),
                                            ('local_address', YLeaf(YType.str, 'local-address')),
                                            ('remote_address', YLeaf(YType.str, 'remote-address')),
                                            ('description', YLeaf(YType.str, 'description')),
                                        ])
                                        self.pw_id = None
                                        self.local_address = None
                                        self.remote_address = None
                                        self.description = None
                                        self._segment_path = lambda: "tlv"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.RemoteSignalling.Tlv, ['pw_id', 'local_address', 'remote_address', 'description'], name, value)


                            class Statistics(Entity):
                                """
                                Statistics
                                
                                .. attribute:: impostion_stats
                                
                                	imposition stats
                                	**type**\:  :py:class:`ImpostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats>`
                                
                                .. attribute:: dispostion_stats
                                
                                	disposition stats
                                	**type**\:  :py:class:`DispostionStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats>`
                                
                                .. attribute:: sequence_number
                                
                                	sequence numbers
                                	**type**\:  :py:class:`SequenceNumber <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber>`
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, self).__init__()

                                    self.yang_name = "statistics"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([("impostion-stats", ("impostion_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats)), ("dispostion-stats", ("dispostion_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats)), ("sequence-number", ("sequence_number", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber))])
                                    self._leafs = OrderedDict()

                                    self.impostion_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats()
                                    self.impostion_stats.parent = self
                                    self._children_name_map["impostion_stats"] = "impostion-stats"

                                    self.dispostion_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats()
                                    self.dispostion_stats.parent = self
                                    self._children_name_map["dispostion_stats"] = "dispostion-stats"

                                    self.sequence_number = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber()
                                    self.sequence_number.parent = self
                                    self._children_name_map["sequence_number"] = "sequence-number"
                                    self._segment_path = lambda: "statistics"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics, [], name, value)


                                class ImpostionStats(Entity):
                                    """
                                    imposition stats
                                    
                                    .. attribute:: imposition_stat
                                    
                                    	imposition stats
                                    	**type**\:  :py:class:`ImpositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat>`
                                    
                                    .. attribute:: imposition_mtu_drop
                                    
                                    	imposition mtu drop stats
                                    	**type**\:  :py:class:`ImpositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop>`
                                    
                                    .. attribute:: impostion_tail_drop
                                    
                                    	imposition tail drop stats
                                    	**type**\:  :py:class:`ImpostionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop>`
                                    
                                    .. attribute:: l2fsbi_drop
                                    
                                    	rx discards
                                    	**type**\:  :py:class:`L2fsbiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop>`
                                    
                                    .. attribute:: multicast
                                    
                                    	Multicast
                                    	**type**\:  :py:class:`Multicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast>`
                                    
                                    .. attribute:: broadcast
                                    
                                    	Broadcast
                                    	**type**\:  :py:class:`Broadcast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast>`
                                    
                                    .. attribute:: unknown_unicast
                                    
                                    	Unknown Unicast
                                    	**type**\:  :py:class:`UnknownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, self).__init__()

                                        self.yang_name = "impostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("imposition-stat", ("imposition_stat", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat)), ("imposition-mtu-drop", ("imposition_mtu_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop)), ("impostion-tail-drop", ("impostion_tail_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop)), ("l2fsbi-drop", ("l2fsbi_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop)), ("multicast", ("multicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast)), ("broadcast", ("broadcast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast)), ("unknown-unicast", ("unknown_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast))])
                                        self._leafs = OrderedDict()

                                        self.imposition_stat = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat()
                                        self.imposition_stat.parent = self
                                        self._children_name_map["imposition_stat"] = "imposition-stat"

                                        self.imposition_mtu_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop()
                                        self.imposition_mtu_drop.parent = self
                                        self._children_name_map["imposition_mtu_drop"] = "imposition-mtu-drop"

                                        self.impostion_tail_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop()
                                        self.impostion_tail_drop.parent = self
                                        self._children_name_map["impostion_tail_drop"] = "impostion-tail-drop"

                                        self.l2fsbi_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop()
                                        self.l2fsbi_drop.parent = self
                                        self._children_name_map["l2fsbi_drop"] = "l2fsbi-drop"

                                        self.multicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast()
                                        self.multicast.parent = self
                                        self._children_name_map["multicast"] = "multicast"

                                        self.broadcast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast()
                                        self.broadcast.parent = self
                                        self._children_name_map["broadcast"] = "broadcast"

                                        self.known_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.unknown_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast()
                                        self.unknown_unicast.parent = self
                                        self._children_name_map["unknown_unicast"] = "unknown-unicast"
                                        self._segment_path = lambda: "impostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats, [], name, value)


                                    class ImpositionStat(Entity):
                                        """
                                        imposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, self).__init__()

                                            self.yang_name = "imposition-stat"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpositionMtuDrop(Entity):
                                        """
                                        imposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, self).__init__()

                                            self.yang_name = "imposition-mtu-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "imposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ImpostionTailDrop(Entity):
                                        """
                                        imposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, self).__init__()

                                            self.yang_name = "impostion-tail-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "impostion-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.ImpostionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class L2fsbiDrop(Entity):
                                        """
                                        rx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, self).__init__()

                                            self.yang_name = "l2fsbi-drop"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "l2fsbi-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.L2fsbiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class Multicast(Entity):
                                        """
                                        Multicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, self).__init__()

                                            self.yang_name = "multicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Multicast, ['packet_counts', 'byte_counts'], name, value)


                                    class Broadcast(Entity):
                                        """
                                        Broadcast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, self).__init__()

                                            self.yang_name = "broadcast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.Broadcast, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class UnknownUnicast(Entity):
                                        """
                                        Unknown Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, self).__init__()

                                            self.yang_name = "unknown-unicast"
                                            self.yang_parent_name = "impostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unknown-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.ImpostionStats.UnknownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                class DispostionStats(Entity):
                                    """
                                    disposition stats
                                    
                                    .. attribute:: disposition_stat
                                    
                                    	disposition stats
                                    	**type**\:  :py:class:`DispositionStat <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat>`
                                    
                                    .. attribute:: disposition_mtu_drop
                                    
                                    	disposition mtu drop stats
                                    	**type**\:  :py:class:`DispositionMtuDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop>`
                                    
                                    .. attribute:: disposition_tail_drop
                                    
                                    	disposition tail drop stats
                                    	**type**\:  :py:class:`DispositionTailDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop>`
                                    
                                    .. attribute:: multicast_drop
                                    
                                    	disposition storm control multicast drop stats
                                    	**type**\:  :py:class:`MulticastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop>`
                                    
                                    .. attribute:: unicast_drop
                                    
                                    	disposition storm control unknown unicast drop stats
                                    	**type**\:  :py:class:`UnicastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop>`
                                    
                                    .. attribute:: broadcast_drop
                                    
                                    	disposition storm control broadcast drop stats
                                    	**type**\:  :py:class:`BroadcastDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop>`
                                    
                                    .. attribute:: received_drops
                                    
                                    	tx discards
                                    	**type**\:  :py:class:`ReceivedDrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops>`
                                    
                                    .. attribute:: dai_drop
                                    
                                    	Disposition dynamic ARP inspection drop statistics
                                    	**type**\:  :py:class:`DaiDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop>`
                                    
                                    .. attribute:: ipsg_drop
                                    
                                    	disposition IP source guard drop statistics
                                    	**type**\:  :py:class:`IpsgDrop <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop>`
                                    
                                    .. attribute:: disposition_oo_o_drops
                                    
                                    	Disposition Out\-of\-Order Drops
                                    	**type**\:  :py:class:`DispositionOoODrops <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops>`
                                    
                                    .. attribute:: disposition_p2mp_stats
                                    
                                    	Disposition P2MP Stats
                                    	**type**\:  :py:class:`DispositionP2mpStats <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats>`
                                    
                                    .. attribute:: known_unicast
                                    
                                    	Known Unicast
                                    	**type**\:  :py:class:`KnownUnicast <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast>`
                                    
                                    .. attribute:: mac_move
                                    
                                    	MAC Move
                                    	**type**\:  :py:class:`MacMove <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove>`
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, self).__init__()

                                        self.yang_name = "dispostion-stats"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([("disposition-stat", ("disposition_stat", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat)), ("disposition-mtu-drop", ("disposition_mtu_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop)), ("disposition-tail-drop", ("disposition_tail_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop)), ("multicast-drop", ("multicast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop)), ("unicast-drop", ("unicast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop)), ("broadcast-drop", ("broadcast_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop)), ("received-drops", ("received_drops", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops)), ("dai-drop", ("dai_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop)), ("ipsg-drop", ("ipsg_drop", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop)), ("disposition-oo-o-drops", ("disposition_oo_o_drops", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops)), ("disposition-p2mp-stats", ("disposition_p2mp_stats", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats)), ("known-unicast", ("known_unicast", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast)), ("mac-move", ("mac_move", L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove))])
                                        self._leafs = OrderedDict()

                                        self.disposition_stat = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat()
                                        self.disposition_stat.parent = self
                                        self._children_name_map["disposition_stat"] = "disposition-stat"

                                        self.disposition_mtu_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop()
                                        self.disposition_mtu_drop.parent = self
                                        self._children_name_map["disposition_mtu_drop"] = "disposition-mtu-drop"

                                        self.disposition_tail_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop()
                                        self.disposition_tail_drop.parent = self
                                        self._children_name_map["disposition_tail_drop"] = "disposition-tail-drop"

                                        self.multicast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop()
                                        self.multicast_drop.parent = self
                                        self._children_name_map["multicast_drop"] = "multicast-drop"

                                        self.unicast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop()
                                        self.unicast_drop.parent = self
                                        self._children_name_map["unicast_drop"] = "unicast-drop"

                                        self.broadcast_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop()
                                        self.broadcast_drop.parent = self
                                        self._children_name_map["broadcast_drop"] = "broadcast-drop"

                                        self.received_drops = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops()
                                        self.received_drops.parent = self
                                        self._children_name_map["received_drops"] = "received-drops"

                                        self.dai_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop()
                                        self.dai_drop.parent = self
                                        self._children_name_map["dai_drop"] = "dai-drop"

                                        self.ipsg_drop = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop()
                                        self.ipsg_drop.parent = self
                                        self._children_name_map["ipsg_drop"] = "ipsg-drop"

                                        self.disposition_oo_o_drops = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops()
                                        self.disposition_oo_o_drops.parent = self
                                        self._children_name_map["disposition_oo_o_drops"] = "disposition-oo-o-drops"

                                        self.disposition_p2mp_stats = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats()
                                        self.disposition_p2mp_stats.parent = self
                                        self._children_name_map["disposition_p2mp_stats"] = "disposition-p2mp-stats"

                                        self.known_unicast = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast()
                                        self.known_unicast.parent = self
                                        self._children_name_map["known_unicast"] = "known-unicast"

                                        self.mac_move = L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove()
                                        self.mac_move.parent = self
                                        self._children_name_map["mac_move"] = "mac-move"
                                        self._segment_path = lambda: "dispostion-stats"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats, [], name, value)


                                    class DispositionStat(Entity):
                                        """
                                        disposition stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, self).__init__()

                                            self.yang_name = "disposition-stat"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-stat"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionStat, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionMtuDrop(Entity):
                                        """
                                        disposition mtu drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, self).__init__()

                                            self.yang_name = "disposition-mtu-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-mtu-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionMtuDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionTailDrop(Entity):
                                        """
                                        disposition tail drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, self).__init__()

                                            self.yang_name = "disposition-tail-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-tail-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionTailDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class MulticastDrop(Entity):
                                        """
                                        disposition storm control multicast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, self).__init__()

                                            self.yang_name = "multicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "multicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MulticastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class UnicastDrop(Entity):
                                        """
                                        disposition storm control unknown unicast drop
                                        stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, self).__init__()

                                            self.yang_name = "unicast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "unicast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.UnicastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class BroadcastDrop(Entity):
                                        """
                                        disposition storm control broadcast drop stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, self).__init__()

                                            self.yang_name = "broadcast-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "broadcast-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.BroadcastDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class ReceivedDrops(Entity):
                                        """
                                        tx discards
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, self).__init__()

                                            self.yang_name = "received-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "received-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.ReceivedDrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DaiDrop(Entity):
                                        """
                                        Disposition dynamic ARP inspection drop
                                        statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, self).__init__()

                                            self.yang_name = "dai-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "dai-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DaiDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class IpsgDrop(Entity):
                                        """
                                        disposition IP source guard drop statistics
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, self).__init__()

                                            self.yang_name = "ipsg-drop"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "ipsg-drop"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.IpsgDrop, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionOoODrops(Entity):
                                        """
                                        Disposition Out\-of\-Order Drops
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, self).__init__()

                                            self.yang_name = "disposition-oo-o-drops"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-oo-o-drops"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionOoODrops, ['packet_counts', 'byte_counts'], name, value)


                                    class DispositionP2mpStats(Entity):
                                        """
                                        Disposition P2MP Stats
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, self).__init__()

                                            self.yang_name = "disposition-p2mp-stats"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "disposition-p2mp-stats"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.DispositionP2mpStats, ['packet_counts', 'byte_counts'], name, value)


                                    class KnownUnicast(Entity):
                                        """
                                        Known Unicast
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, self).__init__()

                                            self.yang_name = "known-unicast"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "known-unicast"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.KnownUnicast, ['packet_counts', 'byte_counts'], name, value)


                                    class MacMove(Entity):
                                        """
                                        MAC Move
                                        
                                        .. attribute:: packet_counts
                                        
                                        	packets counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        .. attribute:: byte_counts
                                        
                                        	bytes counters
                                        	**type**\: int
                                        
                                        	**range:** 0..18446744073709551615
                                        
                                        	**units**\: byte
                                        
                                        

                                        """

                                        _prefix = 'l2vpn-oper'
                                        _revision = '2017-09-07'

                                        def __init__(self):
                                            super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, self).__init__()

                                            self.yang_name = "mac-move"
                                            self.yang_parent_name = "dispostion-stats"
                                            self.is_top_level_class = False
                                            self.has_list_ancestor = True
                                            self.ylist_key_names = []
                                            self._child_classes = OrderedDict([])
                                            self._leafs = OrderedDict([
                                                ('packet_counts', YLeaf(YType.uint64, 'packet-counts')),
                                                ('byte_counts', YLeaf(YType.uint64, 'byte-counts')),
                                            ])
                                            self.packet_counts = None
                                            self.byte_counts = None
                                            self._segment_path = lambda: "mac-move"

                                        def __setattr__(self, name, value):
                                            self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.DispostionStats.MacMove, ['packet_counts', 'byte_counts'], name, value)


                                class SequenceNumber(Entity):
                                    """
                                    sequence numbers
                                    
                                    .. attribute:: sequence_number_sent
                                    
                                    	sequence number sent
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: sequence_number_expected
                                    
                                    	sequence number expected
                                    	**type**\: int
                                    
                                    	**range:** 0..4294967295
                                    
                                    .. attribute:: bypassed_inbound_sequence_packet
                                    
                                    	Bypassed inbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    .. attribute:: bypassed_out_sequence_packet
                                    
                                    	Bypassed outbound sequence packets
                                    	**type**\: int
                                    
                                    	**range:** 0..18446744073709551615
                                    
                                    

                                    """

                                    _prefix = 'l2vpn-oper'
                                    _revision = '2017-09-07'

                                    def __init__(self):
                                        super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, self).__init__()

                                        self.yang_name = "sequence-number"
                                        self.yang_parent_name = "statistics"
                                        self.is_top_level_class = False
                                        self.has_list_ancestor = True
                                        self.ylist_key_names = []
                                        self._child_classes = OrderedDict([])
                                        self._leafs = OrderedDict([
                                            ('sequence_number_sent', YLeaf(YType.uint32, 'sequence-number-sent')),
                                            ('sequence_number_expected', YLeaf(YType.uint32, 'sequence-number-expected')),
                                            ('bypassed_inbound_sequence_packet', YLeaf(YType.uint64, 'bypassed-inbound-sequence-packet')),
                                            ('bypassed_out_sequence_packet', YLeaf(YType.uint64, 'bypassed-out-sequence-packet')),
                                        ])
                                        self.sequence_number_sent = None
                                        self.sequence_number_expected = None
                                        self.bypassed_inbound_sequence_packet = None
                                        self.bypassed_out_sequence_packet = None
                                        self._segment_path = lambda: "sequence-number"

                                    def __setattr__(self, name, value):
                                        self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.Statistics.SequenceNumber, ['sequence_number_sent', 'sequence_number_expected', 'bypassed_inbound_sequence_packet', 'bypassed_out_sequence_packet'], name, value)


                            class P2mpPw(Entity):
                                """
                                P2MP Pseudowire Information
                                
                                .. attribute:: local_available
                                
                                	Local LSM info available
                                	**type**\: bool
                                
                                .. attribute:: local_label
                                
                                	Local Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_ptree_type
                                
                                	Local P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: local_tunnel_id
                                
                                	Local Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_extended_tunnel_id
                                
                                	Local Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: local_p2mp_id
                                
                                	Local P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: local_flags
                                
                                	Local Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                .. attribute:: remote_available
                                
                                	Remote LSM info available
                                	**type**\: bool
                                
                                .. attribute:: remote_label
                                
                                	Remote Label
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_ptree_type
                                
                                	Remote P\-Tree Type
                                	**type**\:  :py:class:`L2vpnP2mpPwPtree <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnP2mpPwPtree>`
                                
                                .. attribute:: remote_tunnel_id
                                
                                	Remote Tunnel ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_extended_tunnel_id
                                
                                	Remote Extended Tunnel ID
                                	**type**\: str
                                
                                	**pattern:** (([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])\\.){3}([0\-9]\|[1\-9][0\-9]\|1[0\-9][0\-9]\|2[0\-4][0\-9]\|25[0\-5])(%[\\p{N}\\p{L}]+)?
                                
                                .. attribute:: remote_p2mp_id
                                
                                	Remote P2MP ID
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                .. attribute:: remote_flags
                                
                                	Remote Flags (see draft\-ietf\-l3vpn\-2547bis\-mcast\-bgp\-08)
                                	**type**\: int
                                
                                	**range:** 0..255
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, self).__init__()

                                    self.yang_name = "p2mp-pw"
                                    self.yang_parent_name = "pseudowire"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('local_available', YLeaf(YType.boolean, 'local-available')),
                                        ('local_label', YLeaf(YType.uint32, 'local-label')),
                                        ('local_ptree_type', YLeaf(YType.enumeration, 'local-ptree-type')),
                                        ('local_tunnel_id', YLeaf(YType.uint32, 'local-tunnel-id')),
                                        ('local_extended_tunnel_id', YLeaf(YType.str, 'local-extended-tunnel-id')),
                                        ('local_p2mp_id', YLeaf(YType.uint32, 'local-p2mp-id')),
                                        ('local_flags', YLeaf(YType.uint8, 'local-flags')),
                                        ('remote_available', YLeaf(YType.boolean, 'remote-available')),
                                        ('remote_label', YLeaf(YType.uint32, 'remote-label')),
                                        ('remote_ptree_type', YLeaf(YType.enumeration, 'remote-ptree-type')),
                                        ('remote_tunnel_id', YLeaf(YType.uint32, 'remote-tunnel-id')),
                                        ('remote_extended_tunnel_id', YLeaf(YType.str, 'remote-extended-tunnel-id')),
                                        ('remote_p2mp_id', YLeaf(YType.uint32, 'remote-p2mp-id')),
                                        ('remote_flags', YLeaf(YType.uint8, 'remote-flags')),
                                    ])
                                    self.local_available = None
                                    self.local_label = None
                                    self.local_ptree_type = None
                                    self.local_tunnel_id = None
                                    self.local_extended_tunnel_id = None
                                    self.local_p2mp_id = None
                                    self.local_flags = None
                                    self.remote_available = None
                                    self.remote_label = None
                                    self.remote_ptree_type = None
                                    self.remote_tunnel_id = None
                                    self.remote_extended_tunnel_id = None
                                    self.remote_p2mp_id = None
                                    self.remote_flags = None
                                    self._segment_path = lambda: "p2mp-pw"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.FlexibleXconnectServices.FlexibleXconnectService.FlexibleXconnectServiceInfo.Pseudowire.P2mpPw, ['local_available', 'local_label', 'local_ptree_type', 'local_tunnel_id', 'local_extended_tunnel_id', 'local_p2mp_id', 'local_flags', 'remote_available', 'remote_label', 'remote_ptree_type', 'remote_tunnel_id', 'remote_extended_tunnel_id', 'remote_p2mp_id', 'remote_flags'], name, value)


            class XconnectBrief(Entity):
                """
                XConnect brief information
                
                .. attribute:: main_total_up
                
                	Total Number of active Cross\-Conections with valid encaps
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_down
                
                	Total Number of non\-active Cross\-Conections with valid encaps
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: main_total_unresolved
                
                	Total Number of unresolved Cross\-Conections with valid encaps
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: undefined_xc
                
                	Undefined xc including PW\-PW
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: memory_state
                
                	L2VPN memory state
                	**type**\:  :py:class:`L2vpnMemoryState <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnMemoryState>`
                
                .. attribute:: encapsulation_report_matrix
                
                	Encapsulation report counters matrix
                	**type**\: list of  		 :py:class:`EncapsulationReportMatrix <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix>`
                
                .. attribute:: encapsulation_total
                
                	Total summary
                	**type**\: list of  		 :py:class:`EncapsulationTotal <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(L2vpnv2.Nodes.Node.XconnectBrief, self).__init__()

                    self.yang_name = "xconnect-brief"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("encapsulation-report-matrix", ("encapsulation_report_matrix", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix)), ("encapsulation-total", ("encapsulation_total", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal))])
                    self._leafs = OrderedDict([
                        ('main_total_up', YLeaf(YType.uint32, 'main-total-up')),
                        ('main_total_down', YLeaf(YType.uint32, 'main-total-down')),
                        ('main_total_unresolved', YLeaf(YType.uint32, 'main-total-unresolved')),
                        ('undefined_xc', YLeaf(YType.uint32, 'undefined-xc')),
                        ('memory_state', YLeaf(YType.enumeration, 'memory-state')),
                    ])
                    self.main_total_up = None
                    self.main_total_down = None
                    self.main_total_unresolved = None
                    self.undefined_xc = None
                    self.memory_state = None

                    self.encapsulation_report_matrix = YList(self)
                    self.encapsulation_total = YList(self)
                    self._segment_path = lambda: "xconnect-brief"

                def __setattr__(self, name, value):
                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief, ['main_total_up', 'main_total_down', 'main_total_unresolved', 'undefined_xc', 'memory_state'], name, value)


                class EncapsulationReportMatrix(Entity):
                    """
                    Encapsulation report counters matrix
                    
                    .. attribute:: ac1
                    
                    	Array of l2vpn\_xc\_brief\_first layer indexed by the AC1 encapsulation type
                    	**type**\: list of  		 :py:class:`Ac1 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix, self).__init__()

                        self.yang_name = "encapsulation-report-matrix"
                        self.yang_parent_name = "xconnect-brief"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("ac1", ("ac1", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1))])
                        self._leafs = OrderedDict()

                        self.ac1 = YList(self)
                        self._segment_path = lambda: "encapsulation-report-matrix"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix, [], name, value)


                    class Ac1(Entity):
                        """
                        Array of l2vpn\_xc\_brief\_first layer indexed by
                        the AC1 encapsulation type
                        
                        .. attribute:: ac2
                        
                        	Array of l2vpn\_xc\_brief\_line indexed by the AC2 encapsulation type plus one type for PW
                        	**type**\: list of  		 :py:class:`Ac2 <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2>`
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1, self).__init__()

                            self.yang_name = "ac1"
                            self.yang_parent_name = "encapsulation-report-matrix"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([("ac2", ("ac2", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2))])
                            self._leafs = OrderedDict()

                            self.ac2 = YList(self)
                            self._segment_path = lambda: "ac1"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1, [], name, value)


                        class Ac2(Entity):
                            """
                            Array of l2vpn\_xc\_brief\_line indexed by the AC2
                            encapsulation type plus one type for PW
                            
                            .. attribute:: psn_type
                            
                            	PSN Type
                            	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                            
                            .. attribute:: ac1_encapsulation
                            
                            	AC1 encapsulation
                            	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                            
                            .. attribute:: ac2_encapsulation
                            
                            	AC2 encapsulation
                            	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                            
                            .. attribute:: up_count
                            
                            	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                            	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount>`
                            
                            .. attribute:: down_count
                            
                            	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                            	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount>`
                            
                            .. attribute:: unresolved_count
                            
                            	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                            	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount>`
                            
                            

                            """

                            _prefix = 'l2vpn-oper'
                            _revision = '2017-09-07'

                            def __init__(self):
                                super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, self).__init__()

                                self.yang_name = "ac2"
                                self.yang_parent_name = "ac1"
                                self.is_top_level_class = False
                                self.has_list_ancestor = True
                                self.ylist_key_names = []
                                self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount)), ("down-count", ("down_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount))])
                                self._leafs = OrderedDict([
                                    ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                                    ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                                    ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                                ])
                                self.psn_type = None
                                self.ac1_encapsulation = None
                                self.ac2_encapsulation = None

                                self.up_count = YList(self)
                                self.down_count = YList(self)
                                self.unresolved_count = YList(self)
                                self._segment_path = lambda: "ac2"

                            def __setattr__(self, name, value):
                                self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                            class UpCount(Entity):
                                """
                                Number of active cross\-connections array \- 
                                
                                Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                                
                                EthernetInterworking, 3 is Total
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, self).__init__()

                                    self.yang_name = "up-count"
                                    self.yang_parent_name = "ac2"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint32, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "up-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UpCount, ['entry'], name, value)


                            class DownCount(Entity):
                                """
                                Number of non\-active cross\-connections array \-
                                
                                Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                                
                                EthernetInterworking, 3 is Total
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, self).__init__()

                                    self.yang_name = "down-count"
                                    self.yang_parent_name = "ac2"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint32, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "down-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.DownCount, ['entry'], name, value)


                            class UnresolvedCount(Entity):
                                """
                                Number of unresolved cross\-connections array \-
                                
                                Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                                
                                EthernetInterworking, 3 is Total
                                
                                .. attribute:: entry
                                
                                	
                                	**type**\: int
                                
                                	**range:** 0..4294967295
                                
                                

                                """

                                _prefix = 'l2vpn-oper'
                                _revision = '2017-09-07'

                                def __init__(self):
                                    super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, self).__init__()

                                    self.yang_name = "unresolved-count"
                                    self.yang_parent_name = "ac2"
                                    self.is_top_level_class = False
                                    self.has_list_ancestor = True
                                    self.ylist_key_names = []
                                    self._child_classes = OrderedDict([])
                                    self._leafs = OrderedDict([
                                        ('entry', YLeaf(YType.uint32, 'entry')),
                                    ])
                                    self.entry = None
                                    self._segment_path = lambda: "unresolved-count"

                                def __setattr__(self, name, value):
                                    self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationReportMatrix.Ac1.Ac2.UnresolvedCount, ['entry'], name, value)


                class EncapsulationTotal(Entity):
                    """
                    Total summary
                    
                    .. attribute:: psn_type
                    
                    	PSN Type
                    	**type**\:  :py:class:`L2vpnBriefPsn <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnBriefPsn>`
                    
                    .. attribute:: ac1_encapsulation
                    
                    	AC1 encapsulation
                    	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                    
                    .. attribute:: ac2_encapsulation
                    
                    	AC2 encapsulation
                    	**type**\:  :py:class:`L2vpnAcEncap <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnAcEncap>`
                    
                    .. attribute:: up_count
                    
                    	Number of active cross\-connections array \-   Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                    	**type**\: list of  		 :py:class:`UpCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UpCount>`
                    
                    .. attribute:: down_count
                    
                    	Number of non\-active cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                    	**type**\: list of  		 :py:class:`DownCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.DownCount>`
                    
                    .. attribute:: unresolved_count
                    
                    	Number of unresolved cross\-connections array \-  Index 0 is LikeToLike, 1 is IPInterworking, 2 is  EthernetInterworking, 3 is Total
                    	**type**\: list of  		 :py:class:`UnresolvedCount <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UnresolvedCount>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal, self).__init__()

                        self.yang_name = "encapsulation-total"
                        self.yang_parent_name = "xconnect-brief"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([("up-count", ("up_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UpCount)), ("down-count", ("down_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.DownCount)), ("unresolved-count", ("unresolved_count", L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UnresolvedCount))])
                        self._leafs = OrderedDict([
                            ('psn_type', YLeaf(YType.enumeration, 'psn-type')),
                            ('ac1_encapsulation', YLeaf(YType.enumeration, 'ac1-encapsulation')),
                            ('ac2_encapsulation', YLeaf(YType.enumeration, 'ac2-encapsulation')),
                        ])
                        self.psn_type = None
                        self.ac1_encapsulation = None
                        self.ac2_encapsulation = None

                        self.up_count = YList(self)
                        self.down_count = YList(self)
                        self.unresolved_count = YList(self)
                        self._segment_path = lambda: "encapsulation-total"

                    def __setattr__(self, name, value):
                        self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal, ['psn_type', 'ac1_encapsulation', 'ac2_encapsulation'], name, value)


                    class UpCount(Entity):
                        """
                        Number of active cross\-connections array \- 
                        
                        Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                        
                        EthernetInterworking, 3 is Total
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UpCount, self).__init__()

                            self.yang_name = "up-count"
                            self.yang_parent_name = "encapsulation-total"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.uint32, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "up-count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UpCount, ['entry'], name, value)


                    class DownCount(Entity):
                        """
                        Number of non\-active cross\-connections array \-
                        
                        Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                        
                        EthernetInterworking, 3 is Total
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.DownCount, self).__init__()

                            self.yang_name = "down-count"
                            self.yang_parent_name = "encapsulation-total"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.uint32, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "down-count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.DownCount, ['entry'], name, value)


                    class UnresolvedCount(Entity):
                        """
                        Number of unresolved cross\-connections array \-
                        
                        Index 0 is LikeToLike, 1 is IPInterworking, 2 is
                        
                        EthernetInterworking, 3 is Total
                        
                        .. attribute:: entry
                        
                        	
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UnresolvedCount, self).__init__()

                            self.yang_name = "unresolved-count"
                            self.yang_parent_name = "encapsulation-total"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('entry', YLeaf(YType.uint32, 'entry')),
                            ])
                            self.entry = None
                            self._segment_path = lambda: "unresolved-count"

                        def __setattr__(self, name, value):
                            self._perform_setattr(L2vpnv2.Nodes.Node.XconnectBrief.EncapsulationTotal.UnresolvedCount, ['entry'], name, value)

    def clone_ptr(self):
        self._top_entity = L2vpnv2()
        return self._top_entity

class GenericInterfaceListV2(Entity):
    """
    generic interface list v2
    
    .. attribute:: nodes
    
    	Table of generic interface list operational data for a particular node
    	**type**\:  :py:class:`Nodes <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes>`
    
    .. attribute:: standby
    
    	Standby generic interface list operational data
    	**type**\:  :py:class:`Standby <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby>`
    
    .. attribute:: active
    
    	Active generic interface list operational data
    	**type**\:  :py:class:`Active <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active>`
    
    

    """

    _prefix = 'l2vpn-oper'
    _revision = '2017-09-07'

    def __init__(self):
        super(GenericInterfaceListV2, self).__init__()
        self._top_entity = None

        self.yang_name = "generic-interface-list-v2"
        self.yang_parent_name = "Cisco-IOS-XR-l2vpn-oper"
        self.is_top_level_class = True
        self.has_list_ancestor = False
        self.ylist_key_names = []
        self._child_classes = OrderedDict([("nodes", ("nodes", GenericInterfaceListV2.Nodes)), ("standby", ("standby", GenericInterfaceListV2.Standby)), ("active", ("active", GenericInterfaceListV2.Active))])
        self._leafs = OrderedDict()

        self.nodes = GenericInterfaceListV2.Nodes()
        self.nodes.parent = self
        self._children_name_map["nodes"] = "nodes"

        self.standby = GenericInterfaceListV2.Standby()
        self.standby.parent = self
        self._children_name_map["standby"] = "standby"

        self.active = GenericInterfaceListV2.Active()
        self.active.parent = self
        self._children_name_map["active"] = "active"
        self._segment_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2"

    def __setattr__(self, name, value):
        self._perform_setattr(GenericInterfaceListV2, [], name, value)


    class Nodes(Entity):
        """
        Table of generic interface list operational data
        for a particular node
        
        .. attribute:: node
        
        	Generic interface list operational data for a particular node
        	**type**\: list of  		 :py:class:`Node <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(GenericInterfaceListV2.Nodes, self).__init__()

            self.yang_name = "nodes"
            self.yang_parent_name = "generic-interface-list-v2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("node", ("node", GenericInterfaceListV2.Nodes.Node))])
            self._leafs = OrderedDict()

            self.node = YList(self)
            self._segment_path = lambda: "nodes"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(GenericInterfaceListV2.Nodes, [], name, value)


        class Node(Entity):
            """
            Generic interface list operational data for a
            particular node
            
            .. attribute:: node_id  (key)
            
            	Location
            	**type**\: str
            
            	**pattern:** ([a\-zA\-Z0\-9\_]\*\\d+/){1,2}([a\-zA\-Z0\-9\_]\*\\d+)
            
            .. attribute:: generic_interface_lists
            
            	Generic interface list table
            	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(GenericInterfaceListV2.Nodes.Node, self).__init__()

                self.yang_name = "node"
                self.yang_parent_name = "nodes"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = ['node_id']
                self._child_classes = OrderedDict([("generic-interface-lists", ("generic_interface_lists", GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists))])
                self._leafs = OrderedDict([
                    ('node_id', YLeaf(YType.str, 'node-id')),
                ])
                self.node_id = None

                self.generic_interface_lists = GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists()
                self.generic_interface_lists.parent = self
                self._children_name_map["generic_interface_lists"] = "generic-interface-lists"
                self._segment_path = lambda: "node" + "[node-id='" + str(self.node_id) + "']"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/nodes/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(GenericInterfaceListV2.Nodes.Node, ['node_id'], name, value)


            class GenericInterfaceLists(Entity):
                """
                Generic interface list table
                
                .. attribute:: generic_interface_list
                
                	Generic Interface List
                	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists, self).__init__()

                    self.yang_name = "generic-interface-lists"
                    self.yang_parent_name = "node"
                    self.is_top_level_class = False
                    self.has_list_ancestor = True
                    self.ylist_key_names = []
                    self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList))])
                    self._leafs = OrderedDict()

                    self.generic_interface_list = YList(self)
                    self._segment_path = lambda: "generic-interface-lists"

                def __setattr__(self, name, value):
                    self._perform_setattr(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists, [], name, value)


                class GenericInterfaceList(Entity):
                    """
                    Generic Interface List
                    
                    .. attribute:: generic_interface_list_name  (key)
                    
                    	Generic Interface List Name
                    	**type**\: str
                    
                    	**length:** 1..32
                    
                    .. attribute:: interface_list_name
                    
                    	Interface\-list name
                    	**type**\: str
                    
                    	**length:** 0..33
                    
                    .. attribute:: interface_list_id
                    
                    	Interface internal ID
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: items
                    
                    	Number of items on which interface list is replicated
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_provisioned
                    
                    	Is Provisioned
                    	**type**\: bool
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is Interface list downloaded to FIB
                    	**type**\: bool
                    
                    .. attribute:: interface
                    
                    	Interfaces
                    	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface>`
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                        self.yang_name = "generic-interface-list"
                        self.yang_parent_name = "generic-interface-lists"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = ['generic_interface_list_name']
                        self._child_classes = OrderedDict([("interface", ("interface", GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface))])
                        self._leafs = OrderedDict([
                            ('generic_interface_list_name', YLeaf(YType.str, 'generic-interface-list-name')),
                            ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                            ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                            ('items', YLeaf(YType.uint32, 'items')),
                            ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.generic_interface_list_name = None
                        self.interface_list_name = None
                        self.interface_list_id = None
                        self.items = None
                        self.is_provisioned = None
                        self.is_fib_downloaded = None

                        self.interface = YList(self)
                        self._segment_path = lambda: "generic-interface-list" + "[generic-interface-list-name='" + str(self.generic_interface_list_name) + "']"

                    def __setattr__(self, name, value):
                        self._perform_setattr(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList, ['generic_interface_list_name', u'interface_list_name', u'interface_list_id', u'items', u'is_provisioned', u'is_fib_downloaded'], name, value)


                    class Interface(Entity):
                        """
                        Interfaces
                        
                        .. attribute:: interface_name
                        
                        	Interface name
                        	**type**\: str
                        
                        .. attribute:: pending_replications
                        
                        	Number of pending replications
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: not_supported_replications
                        
                        	Number of replications failed because unsupported
                        	**type**\: int
                        
                        	**range:** 0..4294967295
                        
                        .. attribute:: is_fib_downloaded
                        
                        	Is interface downloaded to FIB
                        	**type**\: bool
                        
                        

                        """

                        _prefix = 'l2vpn-oper'
                        _revision = '2017-09-07'

                        def __init__(self):
                            super(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                            self.yang_name = "interface"
                            self.yang_parent_name = "generic-interface-list"
                            self.is_top_level_class = False
                            self.has_list_ancestor = True
                            self.ylist_key_names = []
                            self._child_classes = OrderedDict([])
                            self._leafs = OrderedDict([
                                ('interface_name', YLeaf(YType.str, 'interface-name')),
                                ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                                ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                                ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                            ])
                            self.interface_name = None
                            self.pending_replications = None
                            self.not_supported_replications = None
                            self.is_fib_downloaded = None
                            self._segment_path = lambda: "interface"

                        def __setattr__(self, name, value):
                            self._perform_setattr(GenericInterfaceListV2.Nodes.Node.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


    class Standby(Entity):
        """
        Standby generic interface list operational data
        
        .. attribute:: generic_interface_lists
        
        	Generic interface list table
        	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaceLists>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(GenericInterfaceListV2.Standby, self).__init__()

            self.yang_name = "standby"
            self.yang_parent_name = "generic-interface-list-v2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("generic-interface-lists", ("generic_interface_lists", GenericInterfaceListV2.Standby.GenericInterfaceLists))])
            self._leafs = OrderedDict()

            self.generic_interface_lists = GenericInterfaceListV2.Standby.GenericInterfaceLists()
            self.generic_interface_lists.parent = self
            self._children_name_map["generic_interface_lists"] = "generic-interface-lists"
            self._segment_path = lambda: "standby"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(GenericInterfaceListV2.Standby, [], name, value)


        class GenericInterfaceLists(Entity):
            """
            Generic interface list table
            
            .. attribute:: generic_interface_list
            
            	Generic Interface List
            	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(GenericInterfaceListV2.Standby.GenericInterfaceLists, self).__init__()

                self.yang_name = "generic-interface-lists"
                self.yang_parent_name = "standby"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList))])
                self._leafs = OrderedDict()

                self.generic_interface_list = YList(self)
                self._segment_path = lambda: "generic-interface-lists"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/standby/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(GenericInterfaceListV2.Standby.GenericInterfaceLists, [], name, value)


            class GenericInterfaceList(Entity):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\: bool
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\: bool
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                    self.yang_name = "generic-interface-list"
                    self.yang_parent_name = "generic-interface-lists"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['generic_interface_list_name']
                    self._child_classes = OrderedDict([("interface", ("interface", GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface))])
                    self._leafs = OrderedDict([
                        ('generic_interface_list_name', YLeaf(YType.str, 'generic-interface-list-name')),
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                        ('items', YLeaf(YType.uint32, 'items')),
                        ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                        ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                    ])
                    self.generic_interface_list_name = None
                    self.interface_list_name = None
                    self.interface_list_id = None
                    self.items = None
                    self.is_provisioned = None
                    self.is_fib_downloaded = None

                    self.interface = YList(self)
                    self._segment_path = lambda: "generic-interface-list" + "[generic-interface-list-name='" + str(self.generic_interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/standby/generic-interface-lists/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList, ['generic_interface_list_name', u'interface_list_name', u'interface_list_id', u'items', u'is_provisioned', u'is_fib_downloaded'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(GenericInterfaceListV2.Standby.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)


    class Active(Entity):
        """
        Active generic interface list operational data
        
        .. attribute:: generic_interface_lists
        
        	Generic interface list table
        	**type**\:  :py:class:`GenericInterfaceLists <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaceLists>`
        
        

        """

        _prefix = 'l2vpn-oper'
        _revision = '2017-09-07'

        def __init__(self):
            super(GenericInterfaceListV2.Active, self).__init__()

            self.yang_name = "active"
            self.yang_parent_name = "generic-interface-list-v2"
            self.is_top_level_class = False
            self.has_list_ancestor = False
            self.ylist_key_names = []
            self._child_classes = OrderedDict([("generic-interface-lists", ("generic_interface_lists", GenericInterfaceListV2.Active.GenericInterfaceLists))])
            self._leafs = OrderedDict()

            self.generic_interface_lists = GenericInterfaceListV2.Active.GenericInterfaceLists()
            self.generic_interface_lists.parent = self
            self._children_name_map["generic_interface_lists"] = "generic-interface-lists"
            self._segment_path = lambda: "active"
            self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/%s" % self._segment_path()

        def __setattr__(self, name, value):
            self._perform_setattr(GenericInterfaceListV2.Active, [], name, value)


        class GenericInterfaceLists(Entity):
            """
            Generic interface list table
            
            .. attribute:: generic_interface_list
            
            	Generic Interface List
            	**type**\: list of  		 :py:class:`GenericInterfaceList <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList>`
            
            

            """

            _prefix = 'l2vpn-oper'
            _revision = '2017-09-07'

            def __init__(self):
                super(GenericInterfaceListV2.Active.GenericInterfaceLists, self).__init__()

                self.yang_name = "generic-interface-lists"
                self.yang_parent_name = "active"
                self.is_top_level_class = False
                self.has_list_ancestor = False
                self.ylist_key_names = []
                self._child_classes = OrderedDict([("generic-interface-list", ("generic_interface_list", GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList))])
                self._leafs = OrderedDict()

                self.generic_interface_list = YList(self)
                self._segment_path = lambda: "generic-interface-lists"
                self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/active/%s" % self._segment_path()

            def __setattr__(self, name, value):
                self._perform_setattr(GenericInterfaceListV2.Active.GenericInterfaceLists, [], name, value)


            class GenericInterfaceList(Entity):
                """
                Generic Interface List
                
                .. attribute:: generic_interface_list_name  (key)
                
                	Generic Interface List Name
                	**type**\: str
                
                	**length:** 1..32
                
                .. attribute:: interface_list_name
                
                	Interface\-list name
                	**type**\: str
                
                	**length:** 0..33
                
                .. attribute:: interface_list_id
                
                	Interface internal ID
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: items
                
                	Number of items on which interface list is replicated
                	**type**\: int
                
                	**range:** 0..4294967295
                
                .. attribute:: is_provisioned
                
                	Is Provisioned
                	**type**\: bool
                
                .. attribute:: is_fib_downloaded
                
                	Is Interface list downloaded to FIB
                	**type**\: bool
                
                .. attribute:: interface
                
                	Interfaces
                	**type**\: list of  		 :py:class:`Interface <ydk.models.cisco_ios_xr.Cisco_IOS_XR_l2vpn_oper.GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList.Interface>`
                
                

                """

                _prefix = 'l2vpn-oper'
                _revision = '2017-09-07'

                def __init__(self):
                    super(GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList, self).__init__()

                    self.yang_name = "generic-interface-list"
                    self.yang_parent_name = "generic-interface-lists"
                    self.is_top_level_class = False
                    self.has_list_ancestor = False
                    self.ylist_key_names = ['generic_interface_list_name']
                    self._child_classes = OrderedDict([("interface", ("interface", GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList.Interface))])
                    self._leafs = OrderedDict([
                        ('generic_interface_list_name', YLeaf(YType.str, 'generic-interface-list-name')),
                        ('interface_list_name', YLeaf(YType.str, 'interface-list-name')),
                        ('interface_list_id', YLeaf(YType.uint32, 'interface-list-id')),
                        ('items', YLeaf(YType.uint32, 'items')),
                        ('is_provisioned', YLeaf(YType.boolean, 'is-provisioned')),
                        ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                    ])
                    self.generic_interface_list_name = None
                    self.interface_list_name = None
                    self.interface_list_id = None
                    self.items = None
                    self.is_provisioned = None
                    self.is_fib_downloaded = None

                    self.interface = YList(self)
                    self._segment_path = lambda: "generic-interface-list" + "[generic-interface-list-name='" + str(self.generic_interface_list_name) + "']"
                    self._absolute_path = lambda: "Cisco-IOS-XR-l2vpn-oper:generic-interface-list-v2/active/generic-interface-lists/%s" % self._segment_path()

                def __setattr__(self, name, value):
                    self._perform_setattr(GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList, ['generic_interface_list_name', u'interface_list_name', u'interface_list_id', u'items', u'is_provisioned', u'is_fib_downloaded'], name, value)


                class Interface(Entity):
                    """
                    Interfaces
                    
                    .. attribute:: interface_name
                    
                    	Interface name
                    	**type**\: str
                    
                    .. attribute:: pending_replications
                    
                    	Number of pending replications
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: not_supported_replications
                    
                    	Number of replications failed because unsupported
                    	**type**\: int
                    
                    	**range:** 0..4294967295
                    
                    .. attribute:: is_fib_downloaded
                    
                    	Is interface downloaded to FIB
                    	**type**\: bool
                    
                    

                    """

                    _prefix = 'l2vpn-oper'
                    _revision = '2017-09-07'

                    def __init__(self):
                        super(GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList.Interface, self).__init__()

                        self.yang_name = "interface"
                        self.yang_parent_name = "generic-interface-list"
                        self.is_top_level_class = False
                        self.has_list_ancestor = True
                        self.ylist_key_names = []
                        self._child_classes = OrderedDict([])
                        self._leafs = OrderedDict([
                            ('interface_name', YLeaf(YType.str, 'interface-name')),
                            ('pending_replications', YLeaf(YType.uint32, 'pending-replications')),
                            ('not_supported_replications', YLeaf(YType.uint32, 'not-supported-replications')),
                            ('is_fib_downloaded', YLeaf(YType.boolean, 'is-fib-downloaded')),
                        ])
                        self.interface_name = None
                        self.pending_replications = None
                        self.not_supported_replications = None
                        self.is_fib_downloaded = None
                        self._segment_path = lambda: "interface"

                    def __setattr__(self, name, value):
                        self._perform_setattr(GenericInterfaceListV2.Active.GenericInterfaceLists.GenericInterfaceList.Interface, [u'interface_name', u'pending_replications', u'not_supported_replications', u'is_fib_downloaded'], name, value)

    def clone_ptr(self):
        self._top_entity = GenericInterfaceListV2()
        return self._top_entity

